/* Generated by Cython 0.29.24 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [],
        "extra_compile_args": [
            "-std=c++17",
            "-O3",
            "-Wno-deprecated-declarations",
            "-Wno-unreachable-code",
            "-Wno-unused-function",
            "-fpermissive",
            "-Wno-c++11-narrowing"
        ],
        "extra_link_args": [
            "-std=c++17"
        ],
        "language": "c++",
        "libraries": [
            "uchardet",
            "lexbor"
        ],
        "name": "resiliparse.parse.html",
        "sources": [
            "resiliparse/parse/html.pyx"
        ]
    },
    "module_name": "resiliparse.parse.html"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_24"
#define CYTHON_HEX_VERSION 0x001D18F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef __cplusplus
  #error "Cython files generated with the C++ option must be compiled with a C++ compiler."
#endif
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #else
    #define CYTHON_INLINE inline
  #endif
#endif
template<typename T>
void __Pyx_call_destructor(T& x) {
    x.~T();
}
template<typename T>
class __Pyx_FakeReference {
  public:
    __Pyx_FakeReference() : ptr(NULL) { }
    __Pyx_FakeReference(const T& ref) : ptr(const_cast<T*>(&ref)) { }
    T *operator->() { return ptr; }
    T *operator&() { return ptr; }
    operator T&() { return *ptr; }
    template<typename U> bool operator ==(U other) { return *ptr == other; }
    template<typename U> bool operator !=(U other) { return *ptr != other; }
  private:
    T *ptr;
};

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if defined(PyUnicode_IS_READY)
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #else
  #define __Pyx_PyUnicode_READY(op)       (0)
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #endif
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__resiliparse__parse__html
#define __PYX_HAVE_API__resiliparse__parse__html
/* Early includes */
#include <stdint.h>
#include <lexbor/core/core.h>
#include <lexbor/html/html.h>
#include <lexbor/dom/dom.h>
#include <lexbor/dom/interfaces/element.h>
#include "lexbor/dom/interfaces/document.h"
#include <lexbor/dom/collection.h>
#include <lexbor/css/css.h>
#include <lexbor/tag/tag.h>
#include <lexbor/selectors/selectors.h>
#include <lexbor/html/encoding.h>
#include <lexbor/encoding/encoding.h>
#include <string.h>
#include <stdio.h>
#include "ios"
#include "new"
#include "stdexcept"
#include "typeinfo"
#include <string>
#include <uchardet/uchardet.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "resiliparse/parse/html.pyx",
  "stringsource",
  "type.pxd",
  "resiliparse/parse/encoding.pxd",
};
/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif


/*--- Type declarations ---*/
struct __pyx_obj_11resiliparse_5parse_8encoding_EncodingDetector;
struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList;
struct __pyx_obj_11resiliparse_5parse_4html_DOMNode;
struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection;
struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree;
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__;
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__;
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr;
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__;
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__;
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr;
struct __pyx_obj___Pyx_EnumMeta;
struct __pyx_opt_args_11resiliparse_5parse_8encoding_16EncodingDetector_encoding;
struct __pyx_opt_args_11resiliparse_5parse_8encoding_detect_encoding;
struct __pyx_opt_args_11resiliparse_5parse_8encoding_bytes_to_str;
struct __pyx_opt_args_11resiliparse_5parse_8encoding_map_encoding_to_html5;

/* "resiliparse/parse/encoding.pxd":22
 * 
 *     cpdef void update(self, const string& data)
 *     cpdef str encoding(self, bint html5_compatible=*)             # <<<<<<<<<<<<<<
 * 
 * cpdef str detect_encoding(bytes data, size_t max_len=*, bint html5_compatible=*, bint from_html_meta=*)
 */
struct __pyx_opt_args_11resiliparse_5parse_8encoding_16EncodingDetector_encoding {
  int __pyx_n;
  int html5_compatible;
};

/* "resiliparse/parse/encoding.pxd":24
 *     cpdef str encoding(self, bint html5_compatible=*)
 * 
 * cpdef str detect_encoding(bytes data, size_t max_len=*, bint html5_compatible=*, bint from_html_meta=*)             # <<<<<<<<<<<<<<
 * cpdef str bytes_to_str(bytes data, str encoding=*, str errors=*, fallback_encodings=*, bint strip_bom=*)
 * cpdef str map_encoding_to_html5(str encoding, bint fallback_utf8=*)
 */
struct __pyx_opt_args_11resiliparse_5parse_8encoding_detect_encoding {
  int __pyx_n;
  size_t max_len;
  int html5_compatible;
  int from_html_meta;
};

/* "resiliparse/parse/encoding.pxd":25
 * 
 * cpdef str detect_encoding(bytes data, size_t max_len=*, bint html5_compatible=*, bint from_html_meta=*)
 * cpdef str bytes_to_str(bytes data, str encoding=*, str errors=*, fallback_encodings=*, bint strip_bom=*)             # <<<<<<<<<<<<<<
 * cpdef str map_encoding_to_html5(str encoding, bint fallback_utf8=*)
 */
struct __pyx_opt_args_11resiliparse_5parse_8encoding_bytes_to_str {
  int __pyx_n;
  PyObject *encoding;
  PyObject *errors;
  PyObject *fallback_encodings;
  int strip_bom;
};

/* "resiliparse/parse/encoding.pxd":26
 * cpdef str detect_encoding(bytes data, size_t max_len=*, bint html5_compatible=*, bint from_html_meta=*)
 * cpdef str bytes_to_str(bytes data, str encoding=*, str errors=*, fallback_encodings=*, bint strip_bom=*)
 * cpdef str map_encoding_to_html5(str encoding, bint fallback_utf8=*)             # <<<<<<<<<<<<<<
 */
struct __pyx_opt_args_11resiliparse_5parse_8encoding_map_encoding_to_html5 {
  int __pyx_n;
  int fallback_utf8;
};
struct __pyx_opt_args_11resiliparse_5parse_4html_get_element_by_id_impl;
struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_attr_impl;
struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_class_name_impl;
struct __pyx_opt_args_11resiliparse_5parse_4html_query_selector_all_impl;
struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_getattr;
struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_element_by_id;
struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr;
struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name;
struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id;
struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr;
struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name;
struct __pyx_opt_args_11resiliparse_5parse_4html_create_html_tree;
struct __pyx_t_11resiliparse_5parse_4html_element_by_id_match_ctx;

/* "resiliparse/parse/html.pxd":85
 * 
 * # noinspection DuplicatedCode
 * cpdef enum NodeType:             # <<<<<<<<<<<<<<
 *     ELEMENT = 0x01,
 *     ATTRIBUTE = 0x02,
 */
enum __pyx_t_11resiliparse_5parse_4html_NodeType {
  __pyx_e_11resiliparse_5parse_4html_ELEMENT = 0x01,
  __pyx_e_11resiliparse_5parse_4html_ATTRIBUTE = 0x02,
  __pyx_e_11resiliparse_5parse_4html_TEXT = 0x03,
  __pyx_e_11resiliparse_5parse_4html_CDATA_SECTION = 0x04,
  __pyx_e_11resiliparse_5parse_4html_ENTITY_REFERENCE = 0x05,
  __pyx_e_11resiliparse_5parse_4html_ENTITY = 0x06,
  __pyx_e_11resiliparse_5parse_4html_PROCESSING_INSTRUCTION = 0x07,
  __pyx_e_11resiliparse_5parse_4html_COMMENT = 0x08,
  __pyx_e_11resiliparse_5parse_4html_DOCUMENT = 0x09,
  __pyx_e_11resiliparse_5parse_4html_DOCUMENT_TYPE = 0x0A,
  __pyx_e_11resiliparse_5parse_4html_DOCUMENT_FRAGMENT = 0x0B,
  __pyx_e_11resiliparse_5parse_4html_NOTATION = 0x0C,
  __pyx_e_11resiliparse_5parse_4html_LAST_ENTRY = 0x0D
};

/* "resiliparse/parse/html.pxd":18
 *     lxb_css_parser_t, lxb_selectors_t, lxb_css_selectors_t
 * 
 * cdef lxb_dom_node_t* get_element_by_id_impl(lxb_dom_node_t* node, bytes id_value, bint case_insensitive=*)             # <<<<<<<<<<<<<<
 * cdef lxb_dom_collection_t* get_elements_by_attr_impl(lxb_dom_node_t* node, bytes attr_name, bytes attr_value,
 *                                                      size_t init_size=*, bint case_insensitive=*)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_get_element_by_id_impl {
  int __pyx_n;
  int case_insensitive;
};

/* "resiliparse/parse/html.pxd":19
 * 
 * cdef lxb_dom_node_t* get_element_by_id_impl(lxb_dom_node_t* node, bytes id_value, bint case_insensitive=*)
 * cdef lxb_dom_collection_t* get_elements_by_attr_impl(lxb_dom_node_t* node, bytes attr_name, bytes attr_value,             # <<<<<<<<<<<<<<
 *                                                      size_t init_size=*, bint case_insensitive=*)
 * cdef lxb_dom_collection_t* get_elements_by_class_name_impl(lxb_dom_node_t* node, bytes class_name, size_t init_size=*)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_attr_impl {
  int __pyx_n;
  size_t init_size;
  int case_insensitive;
};

/* "resiliparse/parse/html.pxd":21
 * cdef lxb_dom_collection_t* get_elements_by_attr_impl(lxb_dom_node_t* node, bytes attr_name, bytes attr_value,
 *                                                      size_t init_size=*, bint case_insensitive=*)
 * cdef lxb_dom_collection_t* get_elements_by_class_name_impl(lxb_dom_node_t* node, bytes class_name, size_t init_size=*)             # <<<<<<<<<<<<<<
 * cdef lxb_dom_collection_t* get_elements_by_tag_name_impl(lxb_dom_node_t* node, bytes tag_name)
 * cdef lxb_dom_node_t* query_selector_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_class_name_impl {
  int __pyx_n;
  size_t init_size;
};

/* "resiliparse/parse/html.pxd":24
 * cdef lxb_dom_collection_t* get_elements_by_tag_name_impl(lxb_dom_node_t* node, bytes tag_name)
 * cdef lxb_dom_node_t* query_selector_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector)
 * cdef lxb_dom_collection_t* query_selector_all_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector,             # <<<<<<<<<<<<<<
 *                                                    size_t init_size=*)
 * cdef bint matches_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_query_selector_all_impl {
  int __pyx_n;
  size_t init_size;
};

/* "resiliparse/parse/html.pxd":45
 *     cpdef bint hasattr(self, str attr_name)
 *     cdef str _getattr_impl(self, bytes attr_name)
 *     cpdef str getattr(self, str attr_name, str default_value=*)             # <<<<<<<<<<<<<<
 *     cdef bint _setattr_impl(self, bytes attr_name, bytes attr_value)  except -1
 *     cpdef void setattr(self, str attr_name, str attr_value)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_getattr {
  int __pyx_n;
  PyObject *default_value;
};

/* "resiliparse/parse/html.pxd":51
 *     cpdef void delattr(self, str attr_name)
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=*)             # <<<<<<<<<<<<<<
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=*)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_element_by_id {
  int __pyx_n;
  int case_insensitive;
};

/* "resiliparse/parse/html.pxd":52
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=*)             # <<<<<<<<<<<<<<
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr {
  int __pyx_n;
  int case_insensitive;
};

/* "resiliparse/parse/html.pxd":53
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=*)             # <<<<<<<<<<<<<<
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name)
 * 
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name {
  int __pyx_n;
  int case_insensitive;
};

/* "resiliparse/parse/html.pxd":74
 *     cdef DOMCollection _forward_collection_match(self, bytes func, attrs)
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=*)             # <<<<<<<<<<<<<<
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=*)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id {
  int __pyx_n;
  int case_insensitive;
};

/* "resiliparse/parse/html.pxd":75
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=*)             # <<<<<<<<<<<<<<
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name)
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr {
  int __pyx_n;
  int case_insensitive;
};

/* "resiliparse/parse/html.pxd":76
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=*)
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=*)             # <<<<<<<<<<<<<<
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name)
 * 
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name {
  int __pyx_n;
  int case_insensitive;
};

/* "resiliparse/parse/html.pxd":101
 * 
 * 
 * cdef HTMLTree create_html_tree(bytes document, bint reencode=*, str encoding=*, str errors=*)             # <<<<<<<<<<<<<<
 * 
 * cdef class HTMLTree:
 */
struct __pyx_opt_args_11resiliparse_5parse_4html_create_html_tree {
  int __pyx_n;
  int reencode;
  PyObject *encoding;
  PyObject *errors;
};

/* "resiliparse/parse/html.pyx":71
 * 
 * 
 * cdef struct element_by_id_match_ctx:             # <<<<<<<<<<<<<<
 *     const lxb_char_t* id_val
 *     size_t id_val_len
 */
struct __pyx_t_11resiliparse_5parse_4html_element_by_id_match_ctx {
  lxb_char_t const *id_val;
  size_t id_val_len;
  lxb_dom_node_t *result_node;
};

/* "resiliparse/parse/html.pyx":76
 *     lxb_dom_node_t* result_node
 * 
 * ctypedef element_by_id_match_ctx element_by_id_match_ctx_t             # <<<<<<<<<<<<<<
 * 
 * 
 */
typedef struct __pyx_t_11resiliparse_5parse_4html_element_by_id_match_ctx __pyx_t_11resiliparse_5parse_4html_element_by_id_match_ctx_t;

/* "resiliparse/parse/encoding.pxd":18
 * from resiliparse_inc.uchardet cimport uchardet_t
 * 
 * cdef class EncodingDetector:             # <<<<<<<<<<<<<<
 *     cdef uchardet_t d
 * 
 */
struct __pyx_obj_11resiliparse_5parse_8encoding_EncodingDetector {
  PyObject_HEAD
  struct __pyx_vtabstruct_11resiliparse_5parse_8encoding_EncodingDetector *__pyx_vtab;
  uchardet_t d;
};


/* "resiliparse/parse/html.pxd":29
 * 
 * 
 * cdef class DOMElementClassList:             # <<<<<<<<<<<<<<
 *     cdef DOMNode node
 * 
 */
struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList {
  PyObject_HEAD
  struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *__pyx_vtab;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *node;
};


/* "resiliparse/parse/html.pxd":38
 * 
 * 
 * cdef class DOMNode:             # <<<<<<<<<<<<<<
 *     cdef HTMLTree tree
 *     cdef lxb_dom_node_t* node
 */
struct __pyx_obj_11resiliparse_5parse_4html_DOMNode {
  PyObject_HEAD
  struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *__pyx_vtab;
  struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *tree;
  lxb_dom_node_t *node;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *class_list_singleton;
};


/* "resiliparse/parse/html.pxd":67
 * 
 * 
 * cdef class DOMCollection:             # <<<<<<<<<<<<<<
 *     cdef HTMLTree tree
 *     cdef lxb_dom_collection_t* coll
 */
struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection {
  PyObject_HEAD
  struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMCollection *__pyx_vtab;
  struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *tree;
  lxb_dom_collection_t *coll;
};


/* "resiliparse/parse/html.pxd":103
 * cdef HTMLTree create_html_tree(bytes document, bint reencode=*, str encoding=*, str errors=*)
 * 
 * cdef class HTMLTree:             # <<<<<<<<<<<<<<
 *     cdef lxb_html_document_t* dom_document
 *     cdef str encoding
 */
struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree {
  PyObject_HEAD
  struct __pyx_vtabstruct_11resiliparse_5parse_4html_HTMLTree *__pyx_vtab;
  lxb_html_document_t *dom_document;
  PyObject *encoding;
  lxb_css_parser_t *css_parser;
  lxb_selectors_t *selectors;
  lxb_css_selectors_t *css_selectors;
};


/* "resiliparse/parse/html.pyx":399
 *         self.node = NULL
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __iter__(self)
 */
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ {
  PyObject_HEAD
  lxb_dom_node_t *__pyx_v_node;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self;
};


/* "resiliparse/parse/html.pyx":1086
 *         self.tree = None
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             return '<INVALID ELEMENT>'
 */
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ {
  PyObject_HEAD
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self;
};


/* "resiliparse/parse/html.pyx":1091
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_ELEMENT:
 *             attrs = ' '.join(f'{a}="{self[a]}"' for a in self.attrs)             # <<<<<<<<<<<<<<
 *             if attrs:
 *                 attrs = ' ' + attrs
 */
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr {
  PyObject_HEAD
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *__pyx_outer_scope;
  PyObject *__pyx_v_a;
};


/* "resiliparse/parse/html.pyx":1334
 *         return False
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __iter__(self)
 */
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ {
  PyObject_HEAD
  size_t __pyx_v_i;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self;
  size_t __pyx_t_0;
  size_t __pyx_t_1;
  size_t __pyx_t_2;
};


/* "resiliparse/parse/html.pyx":1412
 *         return _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, self._wrap_idx(key)))
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return f'{{{", ".join(repr(n) for n in self)}}}'
 * 
 */
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ {
  PyObject_HEAD
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self;
};


/* "resiliparse/parse/html.pyx":1413
 * 
 *     def __repr__(self):
 *         return f'{{{", ".join(repr(n) for n in self)}}}'             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr {
  PyObject_HEAD
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *__pyx_outer_scope;
  PyObject *__pyx_v_n;
};


/* "EnumBase":15
 * 
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):             # <<<<<<<<<<<<<<
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)
 */
struct __pyx_obj___Pyx_EnumMeta {
  PyHeapTypeObject __pyx_base;
};



/* "resiliparse/parse/encoding.pxd":18
 * from resiliparse_inc.uchardet cimport uchardet_t
 * 
 * cdef class EncodingDetector:             # <<<<<<<<<<<<<<
 *     cdef uchardet_t d
 * 
 */

struct __pyx_vtabstruct_11resiliparse_5parse_8encoding_EncodingDetector {
  void (*update)(struct __pyx_obj_11resiliparse_5parse_8encoding_EncodingDetector *, std::string const &, int __pyx_skip_dispatch);
  PyObject *(*encoding)(struct __pyx_obj_11resiliparse_5parse_8encoding_EncodingDetector *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_8encoding_16EncodingDetector_encoding *__pyx_optional_args);
};
static struct __pyx_vtabstruct_11resiliparse_5parse_8encoding_EncodingDetector *__pyx_vtabptr_11resiliparse_5parse_8encoding_EncodingDetector;


/* "resiliparse/parse/html.pyx":250
 * 
 * 
 * cdef class DOMElementClassList:             # <<<<<<<<<<<<<<
 *     """Class name list of an Element DOM node."""
 * 
 */

struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList {
  PyObject *(*_create_list)(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *);
  PyObject *(*_class_name_bytes)(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *);
  void (*add)(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *, PyObject *, int __pyx_skip_dispatch);
  void (*remove)(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *__pyx_vtabptr_11resiliparse_5parse_4html_DOMElementClassList;
static CYTHON_INLINE PyObject *__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList__class_name_bytes(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *);


/* "resiliparse/parse/html.pyx":371
 * 
 * 
 * cdef class DOMNode:             # <<<<<<<<<<<<<<
 *     """
 *     __init__(self)
 */

struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode {
  int (*hasattr)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_getattr_impl)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *);
  PyObject *(*getattr)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_getattr *__pyx_optional_args);
  int (*_setattr_impl)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, PyObject *);
  void (*setattr)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  int (*_delattr_impl)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *);
  void (*delattr)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*get_element_by_id)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_element_by_id *__pyx_optional_args);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*get_elements_by_attr)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr *__pyx_optional_args);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*get_elements_by_class_name)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name *__pyx_optional_args);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*get_elements_by_tag_name)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*query_selector)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*query_selector_all)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch);
  int (*matches)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*append_child)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*insert_before)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*replace_child)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*remove_child)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch);
  void (*decompose)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *__pyx_vtabptr_11resiliparse_5parse_4html_DOMNode;


/* "resiliparse/parse/html.pyx":1132
 * 
 * 
 * cdef class DOMCollection:             # <<<<<<<<<<<<<<
 *     """
 *     __init__(self)
 */

struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMCollection {
  size_t (*_wrap_idx)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, Py_ssize_t);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*_forward_collection_match)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, PyObject *);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*get_element_by_id)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id *__pyx_optional_args);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*get_elements_by_attr)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr *__pyx_optional_args);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*get_elements_by_class_name)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name *__pyx_optional_args);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*get_elements_by_tag_name)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*query_selector)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*query_selector_all)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch);
  int (*matches)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMCollection *__pyx_vtabptr_11resiliparse_5parse_4html_DOMCollection;
static CYTHON_INLINE size_t __pyx_f_11resiliparse_5parse_4html_13DOMCollection__wrap_idx(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, Py_ssize_t);


/* "resiliparse/parse/html.pyx":1443
 * 
 * 
 * cdef class HTMLTree:             # <<<<<<<<<<<<<<
 *     """
 *     __init__(self)
 */

struct __pyx_vtabstruct_11resiliparse_5parse_4html_HTMLTree {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*create_element)(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*create_text_node)(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *, int __pyx_skip_dispatch);
  void (*init_css_parser)(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *);
};
static struct __pyx_vtabstruct_11resiliparse_5parse_4html_HTMLTree *__pyx_vtabptr_11resiliparse_5parse_4html_HTMLTree;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* IncludeStringH.proto */
#include <string.h>

/* decode_c_string_utf16.proto */
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 0;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16LE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = -1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16BE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}

/* decode_c_string.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* StringJoin.proto */
#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION < 3
    #define __Pyx_PyBytes_Join _PyString_Join
    #else
    #define __Pyx_PyBytes_Join _PyBytes_Join
    #endif
#else
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_str(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_str(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* None.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_mod_Py_ssize_t(Py_ssize_t, Py_ssize_t);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* py_abs.proto */
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject *__Pyx_PyLong_AbsNeg(PyObject *num);
#define __Pyx_PyNumber_Absolute(x)\
    ((likely(PyLong_CheckExact(x))) ?\
         (likely(Py_SIZE(x) >= 0) ? (Py_INCREF(x), (x)) : __Pyx_PyLong_AbsNeg(x)) :\
         PyNumber_Absolute(x))
#else
#define __Pyx_PyNumber_Absolute(x)  PyNumber_Absolute(x)
#endif

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* ClassMethod.proto */
#include "descrobject.h"
static CYTHON_UNUSED PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(enum __pyx_t_11resiliparse_5parse_4html_NodeType value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList__create_list(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList__class_name_bytes(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self); /* proto*/
static void __pyx_f_11resiliparse_5parse_4html_19DOMElementClassList_add(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_11resiliparse_5parse_4html_19DOMElementClassList_remove(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_11resiliparse_5parse_4html_7DOMNode_hasattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_11resiliparse_5parse_4html_7DOMNode__getattr_impl(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name); /* proto*/
static PyObject *__pyx_f_11resiliparse_5parse_4html_7DOMNode_getattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_getattr *__pyx_optional_args); /* proto*/
static int __pyx_f_11resiliparse_5parse_4html_7DOMNode__setattr_impl(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value); /* proto*/
static void __pyx_f_11resiliparse_5parse_4html_7DOMNode_setattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_11resiliparse_5parse_4html_7DOMNode__delattr_impl(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name); /* proto*/
static void __pyx_f_11resiliparse_5parse_4html_7DOMNode_delattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_query_selector(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_7DOMNode_query_selector_all(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_11resiliparse_5parse_4html_7DOMNode_matches(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr *__pyx_optional_args); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_element_by_id(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_element_id, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_element_by_id *__pyx_optional_args); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name *__pyx_optional_args); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_tag_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_tag_name, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_append_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_insert_before(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_reference, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_replace_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_new_child, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_old_child, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_remove_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_11resiliparse_5parse_4html_7DOMNode_decompose(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static CYTHON_INLINE size_t __pyx_f_11resiliparse_5parse_4html_13DOMCollection__wrap_idx(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, Py_ssize_t __pyx_v_idx); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection__forward_collection_match(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_func, PyObject *__pyx_v_attrs); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_element_id, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id *__pyx_optional_args); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr *__pyx_optional_args); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name *__pyx_optional_args); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_tag_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_tag_name, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_query_selector(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_query_selector_all(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_11resiliparse_5parse_4html_13DOMCollection_matches(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_11resiliparse_5parse_4html_8HTMLTree_init_css_parser(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_8HTMLTree_create_element(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, PyObject *__pyx_v_tag_name, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_8HTMLTree_create_text_node(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, PyObject *__pyx_v_text, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'libc.stdint' */

/* Module declarations from 'resiliparse_inc.lexbor' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'resiliparse_inc.string' */

/* Module declarations from 'resiliparse_inc.uchardet' */

/* Module declarations from 'resiliparse.parse.encoding' */
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_8encoding_EncodingDetector = 0;
static PyObject *(*__pyx_f_11resiliparse_5parse_8encoding_bytes_to_str)(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_8encoding_bytes_to_str *__pyx_optional_args); /*proto*/
static PyObject *(*__pyx_f_11resiliparse_5parse_8encoding_map_encoding_to_html5)(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_8encoding_map_encoding_to_html5 *__pyx_optional_args); /*proto*/

/* Module declarations from 'resiliparse.parse.html' */
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html_DOMElementClassList = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html_DOMNode = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html_DOMCollection = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html_HTMLTree = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct____iter__ = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ = 0;
static PyTypeObject *__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr = 0;
static PyTypeObject *__pyx_ptype___Pyx_EnumMeta = 0;
static PyObject *__Pyx_OrderedDict = 0;
static PyObject *__Pyx_EnumBase = 0;
static PyObject *__Pyx_globals = 0;
static lxb_dom_node_t *__pyx_f_11resiliparse_5parse_4html_get_element_by_id_impl(lxb_dom_node_t *, PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_get_element_by_id_impl *__pyx_optional_args); /*proto*/
static lxb_dom_collection_t *__pyx_f_11resiliparse_5parse_4html_get_elements_by_attr_impl(lxb_dom_node_t *, PyObject *, PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_attr_impl *__pyx_optional_args); /*proto*/
static lxb_dom_collection_t *__pyx_f_11resiliparse_5parse_4html_get_elements_by_class_name_impl(lxb_dom_node_t *, PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_class_name_impl *__pyx_optional_args); /*proto*/
static lxb_dom_collection_t *__pyx_f_11resiliparse_5parse_4html_get_elements_by_tag_name_impl(lxb_dom_node_t *, PyObject *); /*proto*/
static lxb_dom_node_t *__pyx_f_11resiliparse_5parse_4html_query_selector_impl(lxb_dom_node_t *, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *); /*proto*/
static lxb_dom_collection_t *__pyx_f_11resiliparse_5parse_4html_query_selector_all_impl(lxb_dom_node_t *, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_query_selector_all_impl *__pyx_optional_args); /*proto*/
static int __pyx_f_11resiliparse_5parse_4html_matches_impl(lxb_dom_node_t *, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_f_11resiliparse_5parse_4html_create_html_tree(PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_create_html_tree *__pyx_optional_args); /*proto*/
static CYTHON_INLINE struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html__create_dom_node(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, lxb_dom_node_t *); /*proto*/
static CYTHON_INLINE struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html__create_dom_collection(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, lxb_dom_collection_t *); /*proto*/
static CYTHON_INLINE int __pyx_f_11resiliparse_5parse_4html_check_node(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *); /*proto*/
static CYTHON_INLINE lexbor_action_t __pyx_f_11resiliparse_5parse_4html_element_by_id_callback(lxb_dom_node_t *, void *); /*proto*/
static CYTHON_INLINE lxb_status_t __pyx_f_11resiliparse_5parse_4html_css_select_callback(lxb_dom_node_t *, lxb_css_selector_specificity_t *, void *); /*proto*/
static CYTHON_INLINE lxb_status_t __pyx_f_11resiliparse_5parse_4html_css_select_callback_single(lxb_dom_node_t *, lxb_css_selector_specificity_t *, void *); /*proto*/
static CYTHON_INLINE lxb_status_t __pyx_f_11resiliparse_5parse_4html_css_match_callback(lxb_dom_node_t *, lxb_css_selector_specificity_t *, void *); /*proto*/
static CYTHON_INLINE int __pyx_f_11resiliparse_5parse_4html_is_whitespace(char const ); /*proto*/
static CYTHON_INLINE void __pyx_f_11resiliparse_5parse_4html__join_collections(lxb_dom_collection_t *, lxb_dom_collection_t *); /*proto*/
static PyObject *__pyx_unpickle___Pyx_EnumMeta__set_state(struct __pyx_obj___Pyx_EnumMeta *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "resiliparse.parse.html"
extern int __pyx_module_is_main_resiliparse__parse__html;
int __pyx_module_is_main_resiliparse__parse__html = 0;

/* Implementation of 'resiliparse.parse.html' */
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_IndexError;
static const char __pyx_k_t[] = "t";
static const char __pyx_k_v[] = "v";
static const char __pyx_k__2[] = "";
static const char __pyx_k__3[] = " ";
static const char __pyx_k_id[] = "id";
static const char __pyx_k__19[] = "=\"";
static const char __pyx_k__20[] = "\"";
static const char __pyx_k__21[] = "<";
static const char __pyx_k__22[] = ">";
static const char __pyx_k__28[] = "{";
  static const char __pyx_k__29[] = ", ";
static const char __pyx_k__30[] = "}";
static const char __pyx_k_add[] = "add";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_dct[] = "dct";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_s_s[] = "%s.%s";
static const char __pyx_k_str[] = "__str__";
static const char __pyx_k_tag[] = "tag";
static const char __pyx_k_None[] = "None";
static const char __pyx_k_TEXT[] = "TEXT";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_enum[] = "enum";
static const char __pyx_k_html[] = "html";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_iter[] = "__iter__";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_node[] = "node";
static const char __pyx_k_repr[] = "__repr__";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_step[] = "step";
static const char __pyx_k_stop[] = "stop";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_text[] = "#text";
static const char __pyx_k_tree[] = "tree";
static const char __pyx_k_attrs[] = "attrs";
static const char __pyx_k_class[] = "class";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_parse[] = "parse";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_s_s_d[] = "<%s.%s: %d>";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_utf_8[] = "utf-8";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_ENTITY[] = "ENTITY";
static const char __pyx_k_by_tag[] = "by_tag";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_errors[] = "errors";
static const char __pyx_k_ignore[] = "ignore";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "name";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_remove[] = "remove";
static const char __pyx_k_text_2[] = "text";
static const char __pyx_k_typing[] = "typing";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_COMMENT[] = "COMMENT";
static const char __pyx_k_DOMNode[] = "DOMNode";
static const char __pyx_k_ELEMENT[] = "ELEMENT";
static const char __pyx_k_Element[] = " Element>";
static const char __pyx_k_IntEnum[] = "IntEnum";
static const char __pyx_k_by_attr[] = "by_attr";
static const char __pyx_k_class_2[] = "__class__";
static const char __pyx_k_delattr[] = "delattr";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_getattr[] = "getattr";
static const char __pyx_k_hasattr[] = "hasattr";
static const char __pyx_k_matches[] = "matches";
static const char __pyx_k_members[] = "__members__";
static const char __pyx_k_parents[] = "parents";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_setattr[] = "setattr";
static const char __pyx_k_DOCUMENT[] = "DOCUMENT";
static const char __pyx_k_EnumBase[] = "EnumBase";
static const char __pyx_k_EnumType[] = "EnumType";
static const char __pyx_k_HTMLTree[] = "HTMLTree";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_NOTATION[] = "NOTATION";
static const char __pyx_k_NodeType[] = "NodeType";
static const char __pyx_k_by_class[] = "by_class";
static const char __pyx_k_document[] = "#document";
static const char __pyx_k_encoding[] = "encoding";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_ATTRIBUTE[] = "ATTRIBUTE";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_attr_name[] = "attr_name";
static const char __pyx_k_decompose[] = "decompose";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_new_child[] = "new_child";
static const char __pyx_k_old_child[] = "old_child";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_reference[] = "reference";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_LAST_ENTRY[] = "LAST_ENTRY";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_attr_value[] = "attr_value";
static const char __pyx_k_class_name[] = "class_name";
static const char __pyx_k_document_2[] = "document";
static const char __pyx_k_element_id[] = "element_id";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_OrderedDict[] = "OrderedDict";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_DOCTYPE_html[] = "<!DOCTYPE html>";
static const char __pyx_k_Pyx_EnumBase[] = "__Pyx_EnumBase";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_append_child[] = "append_child";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_remove_child[] = "remove_child";
static const char __pyx_k_selector_all[] = "selector_all";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_CDATA_SECTION[] = "CDATA_SECTION";
static const char __pyx_k_DOCUMENT_TYPE[] = "DOCUMENT_TYPE";
static const char __pyx_k_DOMCollection[] = "DOMCollection";
static const char __pyx_k_HTML_Document[] = "[HTML Document]";
static const char __pyx_k_default_value[] = "default_value";
static const char __pyx_k_insert_before[] = "insert_before";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_replace_child[] = "replace_child";
static const char __pyx_k_DOMNode___iter[] = "DOMNode.__iter__";
static const char __pyx_k_create_element[] = "create_element";
static const char __pyx_k_query_selector[] = "query_selector";
static const char __pyx_k_INVALID_ELEMENT[] = "<INVALID ELEMENT>";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_ENTITY_REFERENCE[] = "ENTITY_REFERENCE";
static const char __pyx_k_Invalid_key_type[] = "Invalid key type: ";
static const char __pyx_k_case_insensitive[] = "case_insensitive";
static const char __pyx_k_create_text_node[] = "create_text_node";
static const char __pyx_k_parse_from_bytes[] = "parse_from_bytes";
static const char __pyx_k_DOCUMENT_FRAGMENT[] = "DOCUMENT_FRAGMENT";
static const char __pyx_k_No_such_attribute[] = "No such attribute: ";
static const char __pyx_k_get_element_by_id[] = "get_element_by_id";
static const char __pyx_k_Index_out_of_range[] = "Index out of range";
static const char __pyx_k_Pyx_EnumBase___new[] = "__Pyx_EnumBase.__new__";
static const char __pyx_k_Pyx_EnumBase___str[] = "__Pyx_EnumBase.__str__";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_query_selector_all[] = "query_selector_all";
static const char __pyx_k_DOMElementClassList[] = "DOMElementClassList";
static const char __pyx_k_Pyx_EnumBase___repr[] = "__Pyx_EnumBase.__repr__";
static const char __pyx_k_DOMCollection___iter[] = "DOMCollection.__iter__";
static const char __pyx_k_Unknown_enum_value_s[] = "Unknown enum value: '%s'";
static const char __pyx_k_get_elements_by_attr[] = "get_elements_by_attr";
static const char __pyx_k_repr___locals_genexpr[] = "__repr__.<locals>.genexpr";
static const char __pyx_k_PROCESSING_INSTRUCTION[] = "PROCESSING_INSTRUCTION";
static const char __pyx_k_resiliparse_parse_html[] = "resiliparse.parse.html";
static const char __pyx_k_get_elements_by_tag_name[] = "get_elements_by_tag_name";
static const char __pyx_k_get_elements_by_class_name[] = "get_elements_by_class_name";
static const char __pyx_k_pyx_unpickle___Pyx_EnumMeta[] = "__pyx_unpickle___Pyx_EnumMeta";
static const char __pyx_k_Node_ist_not_an_Element_node[] = "Node ist not an Element node.";
static const char __pyx_k_Failed_to_parse_HTML_document[] = "Failed to parse HTML document";
static const char __pyx_k_Failed_to_create_DOM_collection[] = "Failed to create DOM collection";
static const char __pyx_k_Failed_to_match_elements_by_CSS[] = "Failed to match elements by CSS selector";
static const char __pyx_k_Append_operation_on_uninitialize[] = "Append operation on uninitialized node";
static const char __pyx_k_Decompose_operation_on_uninitial[] = "Decompose operation on uninitialized node";
static const char __pyx_k_Failed_to_allocate_HTML_document[] = "Failed to allocate HTML document";
static const char __pyx_k_Incompatible_checksums_s_vs_0xd4[] = "Incompatible checksums (%s vs 0xd41d8cd = ())";
static const char __pyx_k_Insert_operation_on_uninitialize[] = "Insert operation on uninitialized node";
static const char __pyx_k_Node_is_not_a_child_of_the_curre[] = "Node is not a child of the current node";
static const char __pyx_k_Reference_node_must_be_a_child_n[] = "Reference node must be a child node";
static const char __pyx_k_Remove_operation_on_uninitialize[] = "Remove operation on uninitialized node";
static const char __pyx_k_Replace_operation_on_uninitializ[] = "Replace operation on uninitialized node";
static const char __pyx_k_Trying_to_append_child_to_itself[] = "Trying to append child to itself";
static const char __pyx_k_Trying_to_create_element_in_unin[] = "Trying to create element in uninitialized document.";
static const char __pyx_k_Trying_to_create_text_node_in_un[] = "Trying to create text node in uninitialized document.";
static const char __pyx_k_Trying_to_get_item_of_uninitiali[] = "Trying to get item of uninitialized collection";
static const char __pyx_k_Trying_to_insert_node_as_its_own[] = "Trying to insert node as its own child";
static const char __pyx_k_Trying_to_select_items_from_unin[] = "Trying to select items from uninitialized collection";
static const char __pyx_k_Trying_to_set_HTML_contents_of_u[] = "Trying to set HTML contents of uninitialized DOM node";
static const char __pyx_k_Trying_to_set_text_contents_of_u[] = "Trying to set text contents of uninitialized DOM node";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static PyObject *__pyx_n_s_ATTRIBUTE;
static PyObject *__pyx_kp_u_Append_operation_on_uninitialize;
static PyObject *__pyx_n_s_CDATA_SECTION;
static PyObject *__pyx_n_s_COMMENT;
static PyObject *__pyx_kp_u_DOCTYPE_html;
static PyObject *__pyx_n_s_DOCUMENT;
static PyObject *__pyx_n_s_DOCUMENT_FRAGMENT;
static PyObject *__pyx_n_s_DOCUMENT_TYPE;
static PyObject *__pyx_n_s_DOMCollection;
static PyObject *__pyx_n_s_DOMCollection___iter;
static PyObject *__pyx_n_s_DOMElementClassList;
static PyObject *__pyx_n_s_DOMNode;
static PyObject *__pyx_n_s_DOMNode___iter;
static PyObject *__pyx_kp_u_Decompose_operation_on_uninitial;
static PyObject *__pyx_n_s_ELEMENT;
static PyObject *__pyx_n_s_ENTITY;
static PyObject *__pyx_n_s_ENTITY_REFERENCE;
static PyObject *__pyx_kp_u_Element;
static PyObject *__pyx_n_s_EnumBase;
static PyObject *__pyx_n_s_EnumType;
static PyObject *__pyx_kp_u_Failed_to_allocate_HTML_document;
static PyObject *__pyx_kp_u_Failed_to_create_DOM_collection;
static PyObject *__pyx_kp_u_Failed_to_match_elements_by_CSS;
static PyObject *__pyx_kp_u_Failed_to_parse_HTML_document;
static PyObject *__pyx_n_s_HTMLTree;
static PyObject *__pyx_kp_u_HTML_Document;
static PyObject *__pyx_kp_u_INVALID_ELEMENT;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xd4;
static PyObject *__pyx_n_s_IndexError;
static PyObject *__pyx_kp_u_Index_out_of_range;
static PyObject *__pyx_kp_u_Insert_operation_on_uninitialize;
static PyObject *__pyx_n_s_IntEnum;
static PyObject *__pyx_kp_u_Invalid_key_type;
static PyObject *__pyx_n_s_KeyError;
static PyObject *__pyx_n_s_LAST_ENTRY;
static PyObject *__pyx_n_s_NOTATION;
static PyObject *__pyx_kp_u_No_such_attribute;
static PyObject *__pyx_n_s_NodeType;
static PyObject *__pyx_kp_u_Node_is_not_a_child_of_the_curre;
static PyObject *__pyx_kp_u_Node_ist_not_an_Element_node;
static PyObject *__pyx_kp_u_None;
static PyObject *__pyx_n_s_OrderedDict;
static PyObject *__pyx_n_s_PROCESSING_INSTRUCTION;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_s_Pyx_EnumBase;
static PyObject *__pyx_n_s_Pyx_EnumBase___new;
static PyObject *__pyx_n_s_Pyx_EnumBase___repr;
static PyObject *__pyx_n_s_Pyx_EnumBase___str;
static PyObject *__pyx_kp_u_Reference_node_must_be_a_child_n;
static PyObject *__pyx_kp_u_Remove_operation_on_uninitialize;
static PyObject *__pyx_kp_u_Replace_operation_on_uninitializ;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_n_s_TEXT;
static PyObject *__pyx_kp_u_Trying_to_append_child_to_itself;
static PyObject *__pyx_kp_u_Trying_to_create_element_in_unin;
static PyObject *__pyx_kp_u_Trying_to_create_text_node_in_un;
static PyObject *__pyx_kp_u_Trying_to_get_item_of_uninitiali;
static PyObject *__pyx_kp_u_Trying_to_insert_node_as_its_own;
static PyObject *__pyx_kp_u_Trying_to_select_items_from_unin;
static PyObject *__pyx_kp_u_Trying_to_set_HTML_contents_of_u;
static PyObject *__pyx_kp_u_Trying_to_set_text_contents_of_u;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_kp_s_Unknown_enum_value_s;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_kp_u__19;
static PyObject *__pyx_kp_b__2;
static PyObject *__pyx_kp_u__2;
static PyObject *__pyx_kp_u__20;
static PyObject *__pyx_kp_u__21;
static PyObject *__pyx_kp_u__22;
static PyObject *__pyx_kp_u__28;
static PyObject *__pyx_kp_u__29;
static PyObject *__pyx_kp_b__3;
static PyObject *__pyx_kp_u__3;
static PyObject *__pyx_kp_u__30;
static PyObject *__pyx_n_s_add;
static PyObject *__pyx_n_s_append_child;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_attr_name;
static PyObject *__pyx_n_s_attr_value;
static PyObject *__pyx_n_s_attrs;
static PyObject *__pyx_n_b_by_attr;
static PyObject *__pyx_n_b_by_class;
static PyObject *__pyx_n_b_by_tag;
static PyObject *__pyx_n_s_case_insensitive;
static PyObject *__pyx_n_b_class;
static PyObject *__pyx_n_s_class_2;
static PyObject *__pyx_n_s_class_name;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_n_s_cls;
static PyObject *__pyx_n_s_collections;
static PyObject *__pyx_n_s_create_element;
static PyObject *__pyx_n_s_create_text_node;
static PyObject *__pyx_n_s_dct;
static PyObject *__pyx_n_s_decompose;
static PyObject *__pyx_n_s_default_value;
static PyObject *__pyx_n_s_delattr;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_kp_u_document;
static PyObject *__pyx_n_s_document_2;
static PyObject *__pyx_n_s_element_id;
static PyObject *__pyx_n_s_encode;
static PyObject *__pyx_n_s_encoding;
static PyObject *__pyx_n_s_enum;
static PyObject *__pyx_n_s_errors;
static PyObject *__pyx_n_s_genexpr;
static PyObject *__pyx_n_s_get_element_by_id;
static PyObject *__pyx_n_s_get_elements_by_attr;
static PyObject *__pyx_n_s_get_elements_by_class_name;
static PyObject *__pyx_n_s_get_elements_by_tag_name;
static PyObject *__pyx_n_s_getattr;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_hasattr;
static PyObject *__pyx_n_s_html;
static PyObject *__pyx_n_b_id;
static PyObject *__pyx_n_u_ignore;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_insert_before;
static PyObject *__pyx_n_s_iter;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_matches;
static PyObject *__pyx_n_s_members;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_new_child;
static PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
static PyObject *__pyx_n_s_node;
static PyObject *__pyx_n_s_old_child;
static PyObject *__pyx_n_s_parents;
static PyObject *__pyx_n_s_parse;
static PyObject *__pyx_n_s_parse_from_bytes;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle___Pyx_EnumMeta;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_query_selector;
static PyObject *__pyx_n_s_query_selector_all;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_reference;
static PyObject *__pyx_n_s_remove;
static PyObject *__pyx_n_s_remove_child;
static PyObject *__pyx_n_s_replace_child;
static PyObject *__pyx_n_s_repr;
static PyObject *__pyx_n_s_repr___locals_genexpr;
static PyObject *__pyx_n_s_res;
static PyObject *__pyx_n_s_resiliparse_parse_html;
static PyObject *__pyx_kp_s_s_s;
static PyObject *__pyx_kp_s_s_s_d;
static PyObject *__pyx_n_b_selector_all;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_setattr;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_start;
static PyObject *__pyx_n_s_step;
static PyObject *__pyx_n_s_stop;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_t;
static PyObject *__pyx_n_s_tag;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_kp_u_text;
static PyObject *__pyx_n_s_text_2;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_tree;
static PyObject *__pyx_n_s_typing;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_kp_u_utf_8;
static PyObject *__pyx_n_s_v;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_values;
static int __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList___cinit__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_2add(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_class_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_4remove(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_class_name); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static Py_ssize_t __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_12__len__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_18__str__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_20__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_22__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode___cinit__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree); /* proto */
static void __pyx_pf_11resiliparse_5parse_4html_7DOMNode_2__dealloc__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4__iter__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4type___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_3tag___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_11first_child___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_10last_child___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_11child_nodes___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_6parent___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4next___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4prev___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4text___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4text_2__set__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4html___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4html_2__set__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_html); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_2id___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_2id_2__set__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_class_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_name___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_name_2__set__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_class_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_list___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_5attrs___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_7hasattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_9getattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_default_value); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_11__getitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_13setattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_15__setitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_17delattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_19__delitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_21query_selector(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_23query_selector_all(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_25matches(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_27get_elements_by_attr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_v_case_insensitive); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_29get_element_by_id(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_element_id, int __pyx_v_case_insensitive); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_31get_elements_by_class_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_v_case_insensitive); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_33get_elements_by_tag_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_tag_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_35append_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_37insert_before(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_reference); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_39replace_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_new_child, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_old_child); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_41remove_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_43decompose(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_8__repr___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_45__repr__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_47__str__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_49__eq__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static Py_hash_t __pyx_pf_11resiliparse_5parse_4html_7DOMNode_51__hash__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_53__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_55__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_13DOMCollection___cinit__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree); /* proto */
static void __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_2__dealloc__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_4get_element_by_id(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_element_id, int __pyx_v_case_insensitive); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_6get_elements_by_attr(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_v_case_insensitive); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_8get_elements_by_class_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_v_case_insensitive); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_10get_elements_by_tag_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_tag_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_12query_selector(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_14query_selector_all(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_16matches(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_18__iter__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_21__len__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_23__getitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_8__repr___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_25__repr__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_27__str__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_29__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_31__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11resiliparse_5parse_4html_8HTMLTree___cinit__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto */
static void __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_2__dealloc__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4parse(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_document); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_6parse_from_bytes(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_document, PyObject *__pyx_v_encoding, PyObject *__pyx_v_errors); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_8document___get__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4head___get__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4body___get__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_5title___get__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_8create_element(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, PyObject *__pyx_v_tag_name); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_10create_text_node(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_12__str__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_14__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_16__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name, PyObject *__pyx_v_parents, PyObject *__pyx_v_dct); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_value, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html_DOMElementClassList(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html_DOMNode(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html_DOMCollection(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html_HTMLTree(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct____iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new___Pyx_EnumMeta(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_10;
static PyObject *__pyx_int_222419149;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_codeobj__40;
static PyObject *__pyx_codeobj__43;
static PyObject *__pyx_codeobj__45;
static PyObject *__pyx_codeobj__47;
/* Late includes */

/* "resiliparse/parse/html.pyx":25
 * 
 * 
 * cdef inline DOMNode _create_dom_node(HTMLTree tree, lxb_dom_node_t* dom_node):             # <<<<<<<<<<<<<<
 *     if dom_node == NULL:
 *         return None
 */

static CYTHON_INLINE struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html__create_dom_node(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree, lxb_dom_node_t *__pyx_v_dom_node) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node = 0;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_dom_node", 0);

  /* "resiliparse/parse/html.pyx":26
 * 
 * cdef inline DOMNode _create_dom_node(HTMLTree tree, lxb_dom_node_t* dom_node):
 *     if dom_node == NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     if dom_node.user != NULL:
 */
  __pyx_t_1 = ((__pyx_v_dom_node == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":27
 * cdef inline DOMNode _create_dom_node(HTMLTree tree, lxb_dom_node_t* dom_node):
 *     if dom_node == NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     if dom_node.user != NULL:
 *         return <DOMNode>dom_node.user
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":26
 * 
 * cdef inline DOMNode _create_dom_node(HTMLTree tree, lxb_dom_node_t* dom_node):
 *     if dom_node == NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     if dom_node.user != NULL:
 */
  }

  /* "resiliparse/parse/html.pyx":28
 *     if dom_node == NULL:
 *         return None
 *     if dom_node.user != NULL:             # <<<<<<<<<<<<<<
 *         return <DOMNode>dom_node.user
 *     cdef DOMNode node = DOMNode.__new__(DOMNode, tree)
 */
  __pyx_t_1 = ((__pyx_v_dom_node->user != NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":29
 *         return None
 *     if dom_node.user != NULL:
 *         return <DOMNode>dom_node.user             # <<<<<<<<<<<<<<
 *     cdef DOMNode node = DOMNode.__new__(DOMNode, tree)
 *     node.node = dom_node
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_dom_node->user)));
    __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_dom_node->user);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":28
 *     if dom_node == NULL:
 *         return None
 *     if dom_node.user != NULL:             # <<<<<<<<<<<<<<
 *         return <DOMNode>dom_node.user
 *     cdef DOMNode node = DOMNode.__new__(DOMNode, tree)
 */
  }

  /* "resiliparse/parse/html.pyx":30
 *     if dom_node.user != NULL:
 *         return <DOMNode>dom_node.user
 *     cdef DOMNode node = DOMNode.__new__(DOMNode, tree)             # <<<<<<<<<<<<<<
 *     node.node = dom_node
 *     node.node.user = <PyObject*>node
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_tree));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_tree));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_tree));
  __pyx_t_3 = ((PyObject *)__pyx_tp_new_11resiliparse_5parse_4html_DOMNode(((PyTypeObject *)__pyx_ptype_11resiliparse_5parse_4html_DOMNode), __pyx_t_2, NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_node = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "resiliparse/parse/html.pyx":31
 *         return <DOMNode>dom_node.user
 *     cdef DOMNode node = DOMNode.__new__(DOMNode, tree)
 *     node.node = dom_node             # <<<<<<<<<<<<<<
 *     node.node.user = <PyObject*>node
 *     return node
 */
  __pyx_v_node->node = __pyx_v_dom_node;

  /* "resiliparse/parse/html.pyx":32
 *     cdef DOMNode node = DOMNode.__new__(DOMNode, tree)
 *     node.node = dom_node
 *     node.node.user = <PyObject*>node             # <<<<<<<<<<<<<<
 *     return node
 * 
 */
  __pyx_v_node->node->user = ((PyObject *)__pyx_v_node);

  /* "resiliparse/parse/html.pyx":33
 *     node.node = dom_node
 *     node.node.user = <PyObject*>node
 *     return node             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_node));
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":25
 * 
 * 
 * cdef inline DOMNode _create_dom_node(HTMLTree tree, lxb_dom_node_t* dom_node):             # <<<<<<<<<<<<<<
 *     if dom_node == NULL:
 *         return None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html._create_dom_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_node);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":36
 * 
 * 
 * cdef inline DOMCollection _create_dom_collection(HTMLTree tree, lxb_dom_collection_t* coll):             # <<<<<<<<<<<<<<
 *     cdef DOMCollection return_coll = DOMCollection.__new__(DOMCollection, tree)
 *     return_coll.coll = coll
 */

static CYTHON_INLINE struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html__create_dom_collection(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree, lxb_dom_collection_t *__pyx_v_coll) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_return_coll = 0;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_dom_collection", 0);

  /* "resiliparse/parse/html.pyx":37
 * 
 * cdef inline DOMCollection _create_dom_collection(HTMLTree tree, lxb_dom_collection_t* coll):
 *     cdef DOMCollection return_coll = DOMCollection.__new__(DOMCollection, tree)             # <<<<<<<<<<<<<<
 *     return_coll.coll = coll
 *     return return_coll
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_tree));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_tree));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_tree));
  __pyx_t_2 = ((PyObject *)__pyx_tp_new_11resiliparse_5parse_4html_DOMCollection(((PyTypeObject *)__pyx_ptype_11resiliparse_5parse_4html_DOMCollection), __pyx_t_1, NULL)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_return_coll = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":38
 * cdef inline DOMCollection _create_dom_collection(HTMLTree tree, lxb_dom_collection_t* coll):
 *     cdef DOMCollection return_coll = DOMCollection.__new__(DOMCollection, tree)
 *     return_coll.coll = coll             # <<<<<<<<<<<<<<
 *     return return_coll
 * 
 */
  __pyx_v_return_coll->coll = __pyx_v_coll;

  /* "resiliparse/parse/html.pyx":39
 *     cdef DOMCollection return_coll = DOMCollection.__new__(DOMCollection, tree)
 *     return_coll.coll = coll
 *     return return_coll             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_return_coll));
  __pyx_r = __pyx_v_return_coll;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":36
 * 
 * 
 * cdef inline DOMCollection _create_dom_collection(HTMLTree tree, lxb_dom_collection_t* coll):             # <<<<<<<<<<<<<<
 *     cdef DOMCollection return_coll = DOMCollection.__new__(DOMCollection, tree)
 *     return_coll.coll = coll
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html._create_dom_collection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_return_coll);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":42
 * 
 * 
 * cdef inline bint check_node(DOMNode node):             # <<<<<<<<<<<<<<
 *     return node is not None and node.tree is not None and node.node != NULL
 * 
 */

static CYTHON_INLINE int __pyx_f_11resiliparse_5parse_4html_check_node(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("check_node", 0);

  /* "resiliparse/parse/html.pyx":43
 * 
 * cdef inline bint check_node(DOMNode node):
 *     return node is not None and node.tree is not None and node.node != NULL             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_node) != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = (((PyObject *)__pyx_v_node->tree) != Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_node->node != NULL) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":42
 * 
 * 
 * cdef inline bint check_node(DOMNode node):             # <<<<<<<<<<<<<<
 *     return node is not None and node.tree is not None and node.node != NULL
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":46
 * 
 * 
 * cdef lxb_dom_collection_t* get_elements_by_class_name_impl(lxb_dom_node_t* node, bytes class_name, size_t init_size=5):             # <<<<<<<<<<<<<<
 *     """
 *     Return a collection of elements matching the given attribute name and value.
 */

static lxb_dom_collection_t *__pyx_f_11resiliparse_5parse_4html_get_elements_by_class_name_impl(lxb_dom_node_t *__pyx_v_node, PyObject *__pyx_v_class_name, struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_class_name_impl *__pyx_optional_args) {
  size_t __pyx_v_init_size = ((size_t)5);
  lxb_dom_collection_t *__pyx_v_coll;
  lxb_status_t __pyx_v_status;
  lxb_dom_collection_t *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  lxb_char_t *__pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_class_name_impl", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_init_size = __pyx_optional_args->init_size;
    }
  }

  /* "resiliparse/parse/html.pyx":57
 *     :return: pointer to created DOM collection or ``NULL`` if error occurred
 *     """
 *     cdef lxb_dom_collection_t * coll = lxb_dom_collection_make(node.owner_document, init_size)             # <<<<<<<<<<<<<<
 *     if coll == NULL:
 *         return NULL
 */
  __pyx_v_coll = lxb_dom_collection_make(__pyx_v_node->owner_document, __pyx_v_init_size);

  /* "resiliparse/parse/html.pyx":58
 *     """
 *     cdef lxb_dom_collection_t * coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if coll == NULL:             # <<<<<<<<<<<<<<
 *         return NULL
 * 
 */
  __pyx_t_1 = ((__pyx_v_coll == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":59
 *     cdef lxb_dom_collection_t * coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if coll == NULL:
 *         return NULL             # <<<<<<<<<<<<<<
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_class_name(<lxb_dom_element_t*>node, coll,
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":58
 *     """
 *     cdef lxb_dom_collection_t * coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if coll == NULL:             # <<<<<<<<<<<<<<
 *         return NULL
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":62
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_class_name(<lxb_dom_element_t*>node, coll,
 *                                                               <lxb_char_t*>class_name, len(class_name))             # <<<<<<<<<<<<<<
 * 
 *     if status != LXB_STATUS_OK:
 */
  if (unlikely(__pyx_v_class_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 62, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyBytes_AsWritableUString(__pyx_v_class_name); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 62, __pyx_L1_error)
  if (unlikely(__pyx_v_class_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 62, __pyx_L1_error)
  }
  __pyx_t_3 = PyBytes_GET_SIZE(__pyx_v_class_name); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 62, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":61
 *         return NULL
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_class_name(<lxb_dom_element_t*>node, coll,             # <<<<<<<<<<<<<<
 *                                                               <lxb_char_t*>class_name, len(class_name))
 * 
 */
  __pyx_v_status = lxb_dom_elements_by_class_name(((lxb_dom_element_t *)__pyx_v_node), __pyx_v_coll, ((lxb_char_t *)__pyx_t_2), __pyx_t_3);

  /* "resiliparse/parse/html.pyx":64
 *                                                               <lxb_char_t*>class_name, len(class_name))
 * 
 *     if status != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         lxb_dom_collection_destroy(coll, True)
 *         return NULL
 */
  __pyx_t_1 = ((__pyx_v_status != LXB_STATUS_OK) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":65
 * 
 *     if status != LXB_STATUS_OK:
 *         lxb_dom_collection_destroy(coll, True)             # <<<<<<<<<<<<<<
 *         return NULL
 * 
 */
    (void)(lxb_dom_collection_destroy(__pyx_v_coll, 1));

    /* "resiliparse/parse/html.pyx":66
 *     if status != LXB_STATUS_OK:
 *         lxb_dom_collection_destroy(coll, True)
 *         return NULL             # <<<<<<<<<<<<<<
 * 
 *     return coll
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":64
 *                                                               <lxb_char_t*>class_name, len(class_name))
 * 
 *     if status != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         lxb_dom_collection_destroy(coll, True)
 *         return NULL
 */
  }

  /* "resiliparse/parse/html.pyx":68
 *         return NULL
 * 
 *     return coll             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_coll;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":46
 * 
 * 
 * cdef lxb_dom_collection_t* get_elements_by_class_name_impl(lxb_dom_node_t* node, bytes class_name, size_t init_size=5):             # <<<<<<<<<<<<<<
 *     """
 *     Return a collection of elements matching the given attribute name and value.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("resiliparse.parse.html.get_elements_by_class_name_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":79
 * 
 * 
 * cdef inline lexbor_action_t element_by_id_callback(lxb_dom_node_t* node, void* ctx) nogil:             # <<<<<<<<<<<<<<
 *     if node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *         return LEXBOR_ACTION_OK
 */

static CYTHON_INLINE lexbor_action_t __pyx_f_11resiliparse_5parse_4html_element_by_id_callback(lxb_dom_node_t *__pyx_v_node, void *__pyx_v_ctx) {
  __pyx_t_11resiliparse_5parse_4html_element_by_id_match_ctx_t *__pyx_v_match_ctx;
  lxb_char_t const *__pyx_v_id_val;
  size_t __pyx_v_id_val_len;
  lexbor_action_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "resiliparse/parse/html.pyx":80
 * 
 * cdef inline lexbor_action_t element_by_id_callback(lxb_dom_node_t* node, void* ctx) nogil:
 *     if node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *         return LEXBOR_ACTION_OK
 * 
 */
  __pyx_t_1 = ((__pyx_v_node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":81
 * cdef inline lexbor_action_t element_by_id_callback(lxb_dom_node_t* node, void* ctx) nogil:
 *     if node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *         return LEXBOR_ACTION_OK             # <<<<<<<<<<<<<<
 * 
 *     cdef element_by_id_match_ctx_t* match_ctx = <element_by_id_match_ctx_t*>ctx
 */
    __pyx_r = LEXBOR_ACTION_OK;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":80
 * 
 * cdef inline lexbor_action_t element_by_id_callback(lxb_dom_node_t* node, void* ctx) nogil:
 *     if node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *         return LEXBOR_ACTION_OK
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":83
 *         return LEXBOR_ACTION_OK
 * 
 *     cdef element_by_id_match_ctx_t* match_ctx = <element_by_id_match_ctx_t*>ctx             # <<<<<<<<<<<<<<
 *     cdef const lxb_char_t* id_val
 *     cdef size_t id_val_len = 0
 */
  __pyx_v_match_ctx = ((__pyx_t_11resiliparse_5parse_4html_element_by_id_match_ctx_t *)__pyx_v_ctx);

  /* "resiliparse/parse/html.pyx":85
 *     cdef element_by_id_match_ctx_t* match_ctx = <element_by_id_match_ctx_t*>ctx
 *     cdef const lxb_char_t* id_val
 *     cdef size_t id_val_len = 0             # <<<<<<<<<<<<<<
 * 
 *     id_val = lxb_dom_element_id(<lxb_dom_element_t*>node, &id_val_len)
 */
  __pyx_v_id_val_len = 0;

  /* "resiliparse/parse/html.pyx":87
 *     cdef size_t id_val_len = 0
 * 
 *     id_val = lxb_dom_element_id(<lxb_dom_element_t*>node, &id_val_len)             # <<<<<<<<<<<<<<
 *     if id_val == NULL or id_val_len != match_ctx.id_val_len:
 *         return LEXBOR_ACTION_OK
 */
  __pyx_v_id_val = lxb_dom_element_id(((lxb_dom_element_t *)__pyx_v_node), (&__pyx_v_id_val_len));

  /* "resiliparse/parse/html.pyx":88
 * 
 *     id_val = lxb_dom_element_id(<lxb_dom_element_t*>node, &id_val_len)
 *     if id_val == NULL or id_val_len != match_ctx.id_val_len:             # <<<<<<<<<<<<<<
 *         return LEXBOR_ACTION_OK
 * 
 */
  __pyx_t_2 = ((__pyx_v_id_val == NULL) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_id_val_len != __pyx_v_match_ctx->id_val_len) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":89
 *     id_val = lxb_dom_element_id(<lxb_dom_element_t*>node, &id_val_len)
 *     if id_val == NULL or id_val_len != match_ctx.id_val_len:
 *         return LEXBOR_ACTION_OK             # <<<<<<<<<<<<<<
 * 
 *     if lexbor_str_data_ncmp(id_val, match_ctx.id_val, id_val_len):
 */
    __pyx_r = LEXBOR_ACTION_OK;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":88
 * 
 *     id_val = lxb_dom_element_id(<lxb_dom_element_t*>node, &id_val_len)
 *     if id_val == NULL or id_val_len != match_ctx.id_val_len:             # <<<<<<<<<<<<<<
 *         return LEXBOR_ACTION_OK
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":91
 *         return LEXBOR_ACTION_OK
 * 
 *     if lexbor_str_data_ncmp(id_val, match_ctx.id_val, id_val_len):             # <<<<<<<<<<<<<<
 *         match_ctx.result_node = node
 *         return LEXBOR_ACTION_STOP
 */
  __pyx_t_1 = (lexbor_str_data_ncmp(__pyx_v_id_val, __pyx_v_match_ctx->id_val, __pyx_v_id_val_len) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":92
 * 
 *     if lexbor_str_data_ncmp(id_val, match_ctx.id_val, id_val_len):
 *         match_ctx.result_node = node             # <<<<<<<<<<<<<<
 *         return LEXBOR_ACTION_STOP
 * 
 */
    __pyx_v_match_ctx->result_node = __pyx_v_node;

    /* "resiliparse/parse/html.pyx":93
 *     if lexbor_str_data_ncmp(id_val, match_ctx.id_val, id_val_len):
 *         match_ctx.result_node = node
 *         return LEXBOR_ACTION_STOP             # <<<<<<<<<<<<<<
 * 
 *     return LEXBOR_ACTION_OK
 */
    __pyx_r = LEXBOR_ACTION_STOP;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":91
 *         return LEXBOR_ACTION_OK
 * 
 *     if lexbor_str_data_ncmp(id_val, match_ctx.id_val, id_val_len):             # <<<<<<<<<<<<<<
 *         match_ctx.result_node = node
 *         return LEXBOR_ACTION_STOP
 */
  }

  /* "resiliparse/parse/html.pyx":95
 *         return LEXBOR_ACTION_STOP
 * 
 *     return LEXBOR_ACTION_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = LEXBOR_ACTION_OK;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":79
 * 
 * 
 * cdef inline lexbor_action_t element_by_id_callback(lxb_dom_node_t* node, void* ctx) nogil:             # <<<<<<<<<<<<<<
 *     if node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *         return LEXBOR_ACTION_OK
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":98
 * 
 * 
 * cdef lxb_dom_node_t* get_element_by_id_impl(lxb_dom_node_t* node, bytes id_value, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *     """
 *     Return a pointer to the first element matching the given ID or NULL.
 */

static lxb_dom_node_t *__pyx_f_11resiliparse_5parse_4html_get_element_by_id_impl(lxb_dom_node_t *__pyx_v_node, PyObject *__pyx_v_id_value, struct __pyx_opt_args_11resiliparse_5parse_4html_get_element_by_id_impl *__pyx_optional_args) {
  struct __pyx_t_11resiliparse_5parse_4html_element_by_id_match_ctx __pyx_v_ctx;
  lxb_dom_node_t *__pyx_r;
  __Pyx_RefNannyDeclarations
  lxb_char_t const *__pyx_t_1;
  Py_ssize_t __pyx_t_2;
  struct __pyx_t_11resiliparse_5parse_4html_element_by_id_match_ctx __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_element_by_id_impl", 0);
  if (__pyx_optional_args) {
  }

  /* "resiliparse/parse/html.pyx":108
 *     """
 * 
 *     cdef element_by_id_match_ctx ctx = [<const lxb_char_t*>id_value, len(id_value), NULL]             # <<<<<<<<<<<<<<
 *     lxb_dom_node_simple_walk(node, <lxb_dom_node_simple_walker_f>element_by_id_callback, &ctx)
 *     return ctx.result_node
 */
  if (unlikely(__pyx_v_id_value == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 108, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyBytes_AsUString(__pyx_v_id_value); if (unlikely((!__pyx_t_1) && PyErr_Occurred())) __PYX_ERR(0, 108, __pyx_L1_error)
  if (unlikely(__pyx_v_id_value == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 108, __pyx_L1_error)
  }
  __pyx_t_2 = PyBytes_GET_SIZE(__pyx_v_id_value); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 108, __pyx_L1_error)
  __pyx_t_3.id_val = ((lxb_char_t const *)__pyx_t_1);
  __pyx_t_3.id_val_len = __pyx_t_2;
  __pyx_t_3.result_node = NULL;
  __pyx_v_ctx = __pyx_t_3;

  /* "resiliparse/parse/html.pyx":109
 * 
 *     cdef element_by_id_match_ctx ctx = [<const lxb_char_t*>id_value, len(id_value), NULL]
 *     lxb_dom_node_simple_walk(node, <lxb_dom_node_simple_walker_f>element_by_id_callback, &ctx)             # <<<<<<<<<<<<<<
 *     return ctx.result_node
 * 
 */
  lxb_dom_node_simple_walk(__pyx_v_node, ((lxb_dom_node_simple_walker_f)__pyx_f_11resiliparse_5parse_4html_element_by_id_callback), (&__pyx_v_ctx));

  /* "resiliparse/parse/html.pyx":110
 *     cdef element_by_id_match_ctx ctx = [<const lxb_char_t*>id_value, len(id_value), NULL]
 *     lxb_dom_node_simple_walk(node, <lxb_dom_node_simple_walker_f>element_by_id_callback, &ctx)
 *     return ctx.result_node             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_ctx.result_node;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":98
 * 
 * 
 * cdef lxb_dom_node_t* get_element_by_id_impl(lxb_dom_node_t* node, bytes id_value, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *     """
 *     Return a pointer to the first element matching the given ID or NULL.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("resiliparse.parse.html.get_element_by_id_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":113
 * 
 * 
 * cdef lxb_dom_collection_t* get_elements_by_attr_impl(lxb_dom_node_t* node, bytes attr_name, bytes attr_value,             # <<<<<<<<<<<<<<
 *                                                      size_t init_size=5, bint case_insensitive=False):
 *     """
 */

static lxb_dom_collection_t *__pyx_f_11resiliparse_5parse_4html_get_elements_by_attr_impl(lxb_dom_node_t *__pyx_v_node, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_attr_impl *__pyx_optional_args) {
  size_t __pyx_v_init_size = ((size_t)5);

  /* "resiliparse/parse/html.pyx":114
 * 
 * cdef lxb_dom_collection_t* get_elements_by_attr_impl(lxb_dom_node_t* node, bytes attr_name, bytes attr_value,
 *                                                      size_t init_size=5, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *     """
 *     Return a collection of elements matching the given attribute name and value.
 */
  int __pyx_v_case_insensitive = ((int)0);
  lxb_dom_collection_t *__pyx_v_coll;
  lxb_status_t __pyx_v_status;
  lxb_dom_collection_t *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  lxb_char_t *__pyx_t_2;
  Py_ssize_t __pyx_t_3;
  lxb_char_t *__pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_attr_impl", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_init_size = __pyx_optional_args->init_size;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_case_insensitive = __pyx_optional_args->case_insensitive;
      }
    }
  }

  /* "resiliparse/parse/html.pyx":127
 *     :return: pointer to created DOM collection or ``NULL`` if error occurred
 *     """
 *     cdef lxb_dom_collection_t * coll = lxb_dom_collection_make(node.owner_document, init_size)             # <<<<<<<<<<<<<<
 *     if coll == NULL:
 *         return NULL
 */
  __pyx_v_coll = lxb_dom_collection_make(__pyx_v_node->owner_document, __pyx_v_init_size);

  /* "resiliparse/parse/html.pyx":128
 *     """
 *     cdef lxb_dom_collection_t * coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if coll == NULL:             # <<<<<<<<<<<<<<
 *         return NULL
 * 
 */
  __pyx_t_1 = ((__pyx_v_coll == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":129
 *     cdef lxb_dom_collection_t * coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if coll == NULL:
 *         return NULL             # <<<<<<<<<<<<<<
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_attr(<lxb_dom_element_t*>node, coll,
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":128
 *     """
 *     cdef lxb_dom_collection_t * coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if coll == NULL:             # <<<<<<<<<<<<<<
 *         return NULL
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":132
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_attr(<lxb_dom_element_t*>node, coll,
 *                                                         <lxb_char_t*>attr_name, len(attr_name),             # <<<<<<<<<<<<<<
 *                                                         <lxb_char_t*>attr_value, len(attr_value),
 *                                                         case_insensitive)
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 132, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_name); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 132, __pyx_L1_error)
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 132, __pyx_L1_error)
  }
  __pyx_t_3 = PyBytes_GET_SIZE(__pyx_v_attr_name); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 132, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":133
 *     cdef lxb_status_t status = lxb_dom_elements_by_attr(<lxb_dom_element_t*>node, coll,
 *                                                         <lxb_char_t*>attr_name, len(attr_name),
 *                                                         <lxb_char_t*>attr_value, len(attr_value),             # <<<<<<<<<<<<<<
 *                                                         case_insensitive)
 * 
 */
  if (unlikely(__pyx_v_attr_value == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 133, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_value); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 133, __pyx_L1_error)
  if (unlikely(__pyx_v_attr_value == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 133, __pyx_L1_error)
  }
  __pyx_t_5 = PyBytes_GET_SIZE(__pyx_v_attr_value); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 133, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":131
 *         return NULL
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_attr(<lxb_dom_element_t*>node, coll,             # <<<<<<<<<<<<<<
 *                                                         <lxb_char_t*>attr_name, len(attr_name),
 *                                                         <lxb_char_t*>attr_value, len(attr_value),
 */
  __pyx_v_status = lxb_dom_elements_by_attr(((lxb_dom_element_t *)__pyx_v_node), __pyx_v_coll, ((lxb_char_t *)__pyx_t_2), __pyx_t_3, ((lxb_char_t *)__pyx_t_4), __pyx_t_5, __pyx_v_case_insensitive);

  /* "resiliparse/parse/html.pyx":136
 *                                                         case_insensitive)
 * 
 *     if status != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         lxb_dom_collection_destroy(coll, True)
 *         return NULL
 */
  __pyx_t_1 = ((__pyx_v_status != LXB_STATUS_OK) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":137
 * 
 *     if status != LXB_STATUS_OK:
 *         lxb_dom_collection_destroy(coll, True)             # <<<<<<<<<<<<<<
 *         return NULL
 * 
 */
    (void)(lxb_dom_collection_destroy(__pyx_v_coll, 1));

    /* "resiliparse/parse/html.pyx":138
 *     if status != LXB_STATUS_OK:
 *         lxb_dom_collection_destroy(coll, True)
 *         return NULL             # <<<<<<<<<<<<<<
 * 
 *     return coll
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":136
 *                                                         case_insensitive)
 * 
 *     if status != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         lxb_dom_collection_destroy(coll, True)
 *         return NULL
 */
  }

  /* "resiliparse/parse/html.pyx":140
 *         return NULL
 * 
 *     return coll             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_coll;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":113
 * 
 * 
 * cdef lxb_dom_collection_t* get_elements_by_attr_impl(lxb_dom_node_t* node, bytes attr_name, bytes attr_value,             # <<<<<<<<<<<<<<
 *                                                      size_t init_size=5, bint case_insensitive=False):
 *     """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("resiliparse.parse.html.get_elements_by_attr_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":143
 * 
 * 
 * cdef lxb_dom_collection_t* get_elements_by_tag_name_impl(lxb_dom_node_t* node, bytes tag_name):             # <<<<<<<<<<<<<<
 *     """
 *     Return a collection of elements matching the given tag name.
 */

static lxb_dom_collection_t *__pyx_f_11resiliparse_5parse_4html_get_elements_by_tag_name_impl(lxb_dom_node_t *__pyx_v_node, PyObject *__pyx_v_tag_name) {
  lxb_dom_collection_t *__pyx_v_coll;
  CYTHON_UNUSED lxb_status_t __pyx_v_status;
  lxb_dom_collection_t *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  lxb_char_t *__pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_tag_name_impl", 0);

  /* "resiliparse/parse/html.pyx":152
 *     :param tag_name: tag name as UTF-8 bytes
 *     """
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, 20)             # <<<<<<<<<<<<<<
 *     if coll == NULL:
 *         raise RuntimeError('Failed to create DOM collection')
 */
  __pyx_v_coll = lxb_dom_collection_make(__pyx_v_node->owner_document, 20);

  /* "resiliparse/parse/html.pyx":153
 *     """
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, 20)
 *     if coll == NULL:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Failed to create DOM collection')
 * 
 */
  __pyx_t_1 = ((__pyx_v_coll == NULL) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":154
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, 20)
 *     if coll == NULL:
 *         raise RuntimeError('Failed to create DOM collection')             # <<<<<<<<<<<<<<
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_tag_name(<lxb_dom_element_t*>node,
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 154, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":153
 *     """
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, 20)
 *     if coll == NULL:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Failed to create DOM collection')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":157
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_tag_name(<lxb_dom_element_t*>node,
 *                                                             coll, <lxb_char_t*>tag_name, len(tag_name))             # <<<<<<<<<<<<<<
 *     return coll
 * 
 */
  if (unlikely(__pyx_v_tag_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 157, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsWritableUString(__pyx_v_tag_name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 157, __pyx_L1_error)
  if (unlikely(__pyx_v_tag_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 157, __pyx_L1_error)
  }
  __pyx_t_4 = PyBytes_GET_SIZE(__pyx_v_tag_name); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 157, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":156
 *         raise RuntimeError('Failed to create DOM collection')
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_tag_name(<lxb_dom_element_t*>node,             # <<<<<<<<<<<<<<
 *                                                             coll, <lxb_char_t*>tag_name, len(tag_name))
 *     return coll
 */
  __pyx_v_status = lxb_dom_elements_by_tag_name(((lxb_dom_element_t *)__pyx_v_node), __pyx_v_coll, ((lxb_char_t *)__pyx_t_3), __pyx_t_4);

  /* "resiliparse/parse/html.pyx":158
 *     cdef lxb_status_t status = lxb_dom_elements_by_tag_name(<lxb_dom_element_t*>node,
 *                                                             coll, <lxb_char_t*>tag_name, len(tag_name))
 *     return coll             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_coll;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":143
 * 
 * 
 * cdef lxb_dom_collection_t* get_elements_by_tag_name_impl(lxb_dom_node_t* node, bytes tag_name):             # <<<<<<<<<<<<<<
 *     """
 *     Return a collection of elements matching the given tag name.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("resiliparse.parse.html.get_elements_by_tag_name_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":161
 * 
 * 
 * cdef inline lxb_status_t css_select_callback(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,             # <<<<<<<<<<<<<<
 *                                              void* ctx) nogil:
 *     lxb_dom_collection_append(<lxb_dom_collection_t*>ctx, node)
 */

static CYTHON_INLINE lxb_status_t __pyx_f_11resiliparse_5parse_4html_css_select_callback(lxb_dom_node_t *__pyx_v_node, CYTHON_UNUSED lxb_css_selector_specificity_t *__pyx_v_spec, void *__pyx_v_ctx) {
  lxb_status_t __pyx_r;

  /* "resiliparse/parse/html.pyx":163
 * cdef inline lxb_status_t css_select_callback(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,
 *                                              void* ctx) nogil:
 *     lxb_dom_collection_append(<lxb_dom_collection_t*>ctx, node)             # <<<<<<<<<<<<<<
 *     return LXB_STATUS_OK
 * 
 */
  (void)(lxb_dom_collection_append(((lxb_dom_collection_t *)__pyx_v_ctx), __pyx_v_node));

  /* "resiliparse/parse/html.pyx":164
 *                                              void* ctx) nogil:
 *     lxb_dom_collection_append(<lxb_dom_collection_t*>ctx, node)
 *     return LXB_STATUS_OK             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = LXB_STATUS_OK;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":161
 * 
 * 
 * cdef inline lxb_status_t css_select_callback(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,             # <<<<<<<<<<<<<<
 *                                              void* ctx) nogil:
 *     lxb_dom_collection_append(<lxb_dom_collection_t*>ctx, node)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":167
 * 
 * 
 * cdef inline lxb_status_t css_select_callback_single(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,             # <<<<<<<<<<<<<<
 *                                                     void* ctx) nogil:
 *     (<lxb_dom_node_t**>ctx)[0] = node
 */

static CYTHON_INLINE lxb_status_t __pyx_f_11resiliparse_5parse_4html_css_select_callback_single(lxb_dom_node_t *__pyx_v_node, CYTHON_UNUSED lxb_css_selector_specificity_t *__pyx_v_spec, void *__pyx_v_ctx) {
  lxb_status_t __pyx_r;

  /* "resiliparse/parse/html.pyx":169
 * cdef inline lxb_status_t css_select_callback_single(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,
 *                                                     void* ctx) nogil:
 *     (<lxb_dom_node_t**>ctx)[0] = node             # <<<<<<<<<<<<<<
 *     return LXB_STATUS_STOP
 * 
 */
  (((lxb_dom_node_t **)__pyx_v_ctx)[0]) = __pyx_v_node;

  /* "resiliparse/parse/html.pyx":170
 *                                                     void* ctx) nogil:
 *     (<lxb_dom_node_t**>ctx)[0] = node
 *     return LXB_STATUS_STOP             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = LXB_STATUS_STOP;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":167
 * 
 * 
 * cdef inline lxb_status_t css_select_callback_single(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,             # <<<<<<<<<<<<<<
 *                                                     void* ctx) nogil:
 *     (<lxb_dom_node_t**>ctx)[0] = node
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":173
 * 
 * 
 * cdef lxb_dom_node_t* query_selector_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector):             # <<<<<<<<<<<<<<
 *     """
 *     Return a pointer to the first element matching the given CSS selector.
 */

static lxb_dom_node_t *__pyx_f_11resiliparse_5parse_4html_query_selector_impl(lxb_dom_node_t *__pyx_v_node, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree, PyObject *__pyx_v_selector) {
  lxb_css_selector_list_t *__pyx_v_sel_list;
  lxb_dom_node_t *__pyx_v_result_node;
  lxb_dom_node_t *__pyx_r;
  __Pyx_RefNannyDeclarations
  lxb_char_t *__pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector_impl", 0);

  /* "resiliparse/parse/html.pyx":182
 *     :return: pointer to created DOM collection or ``NULL`` if error occurred
 *     """
 *     tree.init_css_parser()             # <<<<<<<<<<<<<<
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 */
  ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_tree->__pyx_vtab)->init_css_parser(__pyx_v_tree);

  /* "resiliparse/parse/html.pyx":185
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 *                                                                      <lxb_char_t*>selector, len(selector))             # <<<<<<<<<<<<<<
 *     cdef lxb_dom_node_t* result_node = NULL
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 */
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 185, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyBytes_AsWritableUString(__pyx_v_selector); if (unlikely((!__pyx_t_1) && PyErr_Occurred())) __PYX_ERR(0, 185, __pyx_L1_error)
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 185, __pyx_L1_error)
  }
  __pyx_t_2 = PyBytes_GET_SIZE(__pyx_v_selector); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 185, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":184
 *     tree.init_css_parser()
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,             # <<<<<<<<<<<<<<
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef lxb_dom_node_t* result_node = NULL
 */
  __pyx_v_sel_list = lxb_css_selectors_parse(__pyx_v_tree->css_parser, ((lxb_char_t *)__pyx_t_1), __pyx_t_2);

  /* "resiliparse/parse/html.pyx":186
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef lxb_dom_node_t* result_node = NULL             # <<<<<<<<<<<<<<
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_select_callback_single, &result_node) != LXB_STATUS_OK:
 */
  __pyx_v_result_node = NULL;

  /* "resiliparse/parse/html.pyx":188
 *     cdef lxb_dom_node_t* result_node = NULL
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_select_callback_single, &result_node) != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         return NULL
 * 
 */
  __pyx_t_3 = ((lxb_selectors_find(__pyx_v_tree->selectors, __pyx_v_node, __pyx_v_sel_list, ((lxb_selectors_cb_f)__pyx_f_11resiliparse_5parse_4html_css_select_callback_single), (&__pyx_v_result_node)) != LXB_STATUS_OK) != 0);

  /* "resiliparse/parse/html.pyx":187
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef lxb_dom_node_t* result_node = NULL
 *     if lxb_selectors_find(tree.selectors, node, sel_list,             # <<<<<<<<<<<<<<
 *                           <lxb_selectors_cb_f>css_select_callback_single, &result_node) != LXB_STATUS_OK:
 *         return NULL
 */
  if (__pyx_t_3) {

    /* "resiliparse/parse/html.pyx":189
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_select_callback_single, &result_node) != LXB_STATUS_OK:
 *         return NULL             # <<<<<<<<<<<<<<
 * 
 *     return result_node
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":187
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef lxb_dom_node_t* result_node = NULL
 *     if lxb_selectors_find(tree.selectors, node, sel_list,             # <<<<<<<<<<<<<<
 *                           <lxb_selectors_cb_f>css_select_callback_single, &result_node) != LXB_STATUS_OK:
 *         return NULL
 */
  }

  /* "resiliparse/parse/html.pyx":191
 *         return NULL
 * 
 *     return result_node             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_result_node;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":173
 * 
 * 
 * cdef lxb_dom_node_t* query_selector_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector):             # <<<<<<<<<<<<<<
 *     """
 *     Return a pointer to the first element matching the given CSS selector.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("resiliparse.parse.html.query_selector_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":194
 * 
 * 
 * cdef lxb_dom_collection_t* query_selector_all_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector,             # <<<<<<<<<<<<<<
 *                                                    size_t init_size=32):
 *     """
 */

static lxb_dom_collection_t *__pyx_f_11resiliparse_5parse_4html_query_selector_all_impl(lxb_dom_node_t *__pyx_v_node, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree, PyObject *__pyx_v_selector, struct __pyx_opt_args_11resiliparse_5parse_4html_query_selector_all_impl *__pyx_optional_args) {
  size_t __pyx_v_init_size = ((size_t)32);
  lxb_css_selector_list_t *__pyx_v_sel_list;
  lxb_dom_collection_t *__pyx_v_coll;
  lxb_dom_collection_t *__pyx_r;
  __Pyx_RefNannyDeclarations
  lxb_char_t *__pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector_all_impl", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_init_size = __pyx_optional_args->init_size;
    }
  }

  /* "resiliparse/parse/html.pyx":207
 *     :return: pointer to created DOM collection or ``NULL`` if error occurred
 *     """
 *     tree.init_css_parser()             # <<<<<<<<<<<<<<
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 */
  ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_tree->__pyx_vtab)->init_css_parser(__pyx_v_tree);

  /* "resiliparse/parse/html.pyx":210
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 *                                                                      <lxb_char_t*>selector, len(selector))             # <<<<<<<<<<<<<<
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 */
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 210, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyBytes_AsWritableUString(__pyx_v_selector); if (unlikely((!__pyx_t_1) && PyErr_Occurred())) __PYX_ERR(0, 210, __pyx_L1_error)
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 210, __pyx_L1_error)
  }
  __pyx_t_2 = PyBytes_GET_SIZE(__pyx_v_selector); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 210, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":209
 *     tree.init_css_parser()
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,             # <<<<<<<<<<<<<<
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, init_size)
 */
  __pyx_v_sel_list = lxb_css_selectors_parse(__pyx_v_tree->css_parser, ((lxb_char_t *)__pyx_t_1), __pyx_t_2);

  /* "resiliparse/parse/html.pyx":211
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, init_size)             # <<<<<<<<<<<<<<
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_select_callback, coll) != LXB_STATUS_OK:
 */
  __pyx_v_coll = lxb_dom_collection_make(__pyx_v_node->owner_document, __pyx_v_init_size);

  /* "resiliparse/parse/html.pyx":213
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_select_callback, coll) != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         return NULL
 * 
 */
  __pyx_t_3 = ((lxb_selectors_find(__pyx_v_tree->selectors, __pyx_v_node, __pyx_v_sel_list, ((lxb_selectors_cb_f)__pyx_f_11resiliparse_5parse_4html_css_select_callback), __pyx_v_coll) != LXB_STATUS_OK) != 0);

  /* "resiliparse/parse/html.pyx":212
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if lxb_selectors_find(tree.selectors, node, sel_list,             # <<<<<<<<<<<<<<
 *                           <lxb_selectors_cb_f>css_select_callback, coll) != LXB_STATUS_OK:
 *         return NULL
 */
  if (__pyx_t_3) {

    /* "resiliparse/parse/html.pyx":214
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_select_callback, coll) != LXB_STATUS_OK:
 *         return NULL             # <<<<<<<<<<<<<<
 * 
 *     return coll
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":212
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, init_size)
 *     if lxb_selectors_find(tree.selectors, node, sel_list,             # <<<<<<<<<<<<<<
 *                           <lxb_selectors_cb_f>css_select_callback, coll) != LXB_STATUS_OK:
 *         return NULL
 */
  }

  /* "resiliparse/parse/html.pyx":216
 *         return NULL
 * 
 *     return coll             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_coll;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":194
 * 
 * 
 * cdef lxb_dom_collection_t* query_selector_all_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector,             # <<<<<<<<<<<<<<
 *                                                    size_t init_size=32):
 *     """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("resiliparse.parse.html.query_selector_all_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":219
 * 
 * 
 * cdef inline lxb_status_t css_match_callback(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,             # <<<<<<<<<<<<<<
 *                                             void* ctx) nogil:
 *     (<bint*>ctx)[0] = True
 */

static CYTHON_INLINE lxb_status_t __pyx_f_11resiliparse_5parse_4html_css_match_callback(CYTHON_UNUSED lxb_dom_node_t *__pyx_v_node, CYTHON_UNUSED lxb_css_selector_specificity_t *__pyx_v_spec, void *__pyx_v_ctx) {
  lxb_status_t __pyx_r;

  /* "resiliparse/parse/html.pyx":221
 * cdef inline lxb_status_t css_match_callback(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,
 *                                             void* ctx) nogil:
 *     (<bint*>ctx)[0] = True             # <<<<<<<<<<<<<<
 *     return LXB_STATUS_STOP
 * 
 */
  (((int *)__pyx_v_ctx)[0]) = 1;

  /* "resiliparse/parse/html.pyx":222
 *                                             void* ctx) nogil:
 *     (<bint*>ctx)[0] = True
 *     return LXB_STATUS_STOP             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = LXB_STATUS_STOP;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":219
 * 
 * 
 * cdef inline lxb_status_t css_match_callback(lxb_dom_node_t* node, lxb_css_selector_specificity_t* spec,             # <<<<<<<<<<<<<<
 *                                             void* ctx) nogil:
 *     (<bint*>ctx)[0] = True
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":225
 * 
 * 
 * cdef bint matches_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector):             # <<<<<<<<<<<<<<
 *     """
 *     Check whether any element in the DOM subtree matches the given CSS selector.
 */

static int __pyx_f_11resiliparse_5parse_4html_matches_impl(lxb_dom_node_t *__pyx_v_node, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree, PyObject *__pyx_v_selector) {
  lxb_css_selector_list_t *__pyx_v_sel_list;
  int __pyx_v_matches;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  lxb_char_t *__pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matches_impl", 0);

  /* "resiliparse/parse/html.pyx":234
 *     :return: boolean value indicating whether a matching element exists
 *     """
 *     tree.init_css_parser()             # <<<<<<<<<<<<<<
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 */
  ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_tree->__pyx_vtab)->init_css_parser(__pyx_v_tree);

  /* "resiliparse/parse/html.pyx":237
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 *                                                                      <lxb_char_t*>selector, len(selector))             # <<<<<<<<<<<<<<
 *     cdef bint matches = False
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 */
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 237, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyBytes_AsWritableUString(__pyx_v_selector); if (unlikely((!__pyx_t_1) && PyErr_Occurred())) __PYX_ERR(0, 237, __pyx_L1_error)
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 237, __pyx_L1_error)
  }
  __pyx_t_2 = PyBytes_GET_SIZE(__pyx_v_selector); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 237, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":236
 *     tree.init_css_parser()
 * 
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,             # <<<<<<<<<<<<<<
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef bint matches = False
 */
  __pyx_v_sel_list = lxb_css_selectors_parse(__pyx_v_tree->css_parser, ((lxb_char_t *)__pyx_t_1), __pyx_t_2);

  /* "resiliparse/parse/html.pyx":238
 *     cdef lxb_css_selector_list_t* sel_list = lxb_css_selectors_parse(tree.css_parser,
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef bint matches = False             # <<<<<<<<<<<<<<
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_match_callback, <void*>&matches) != LXB_STATUS_OK:
 */
  __pyx_v_matches = 0;

  /* "resiliparse/parse/html.pyx":240
 *     cdef bint matches = False
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_match_callback, <void*>&matches) != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
  __pyx_t_3 = ((lxb_selectors_find(__pyx_v_tree->selectors, __pyx_v_node, __pyx_v_sel_list, ((lxb_selectors_cb_f)__pyx_f_11resiliparse_5parse_4html_css_match_callback), ((void *)(&__pyx_v_matches))) != LXB_STATUS_OK) != 0);

  /* "resiliparse/parse/html.pyx":239
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef bint matches = False
 *     if lxb_selectors_find(tree.selectors, node, sel_list,             # <<<<<<<<<<<<<<
 *                           <lxb_selectors_cb_f>css_match_callback, <void*>&matches) != LXB_STATUS_OK:
 *         return False
 */
  if (__pyx_t_3) {

    /* "resiliparse/parse/html.pyx":241
 *     if lxb_selectors_find(tree.selectors, node, sel_list,
 *                           <lxb_selectors_cb_f>css_match_callback, <void*>&matches) != LXB_STATUS_OK:
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     return matches
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":239
 *                                                                      <lxb_char_t*>selector, len(selector))
 *     cdef bint matches = False
 *     if lxb_selectors_find(tree.selectors, node, sel_list,             # <<<<<<<<<<<<<<
 *                           <lxb_selectors_cb_f>css_match_callback, <void*>&matches) != LXB_STATUS_OK:
 *         return False
 */
  }

  /* "resiliparse/parse/html.pyx":243
 *         return False
 * 
 *     return matches             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_matches;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":225
 * 
 * 
 * cdef bint matches_impl(lxb_dom_node_t* node, HTMLTree tree, bytes selector):             # <<<<<<<<<<<<<<
 *     """
 *     Check whether any element in the DOM subtree matches the given CSS selector.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("resiliparse.parse.html.matches_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":246
 * 
 * 
 * cdef inline bint is_whitespace(const char c):             # <<<<<<<<<<<<<<
 *     return c == b' ' or c == b'\t' or c == b'\n' or c == b'\f' or c == b'\r'
 * 
 */

static CYTHON_INLINE int __pyx_f_11resiliparse_5parse_4html_is_whitespace(char const __pyx_v_c) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("is_whitespace", 0);

  /* "resiliparse/parse/html.pyx":247
 * 
 * cdef inline bint is_whitespace(const char c):
 *     return c == b' ' or c == b'\t' or c == b'\n' or c == b'\f' or c == b'\r'             # <<<<<<<<<<<<<<
 * 
 * 
 */
  switch (__pyx_v_c) {
    case ' ':
    case '\t':
    case '\n':
    case '\x0C':
    case '\r':
    __pyx_t_1 = 1;
    break;
    default:
    __pyx_t_1 = 0;
    break;
  }
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":246
 * 
 * 
 * cdef inline bint is_whitespace(const char c):             # <<<<<<<<<<<<<<
 *     return c == b' ' or c == b'\t' or c == b'\n' or c == b'\f' or c == b'\r'
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":253
 *     """Class name list of an Element DOM node."""
 * 
 *     def __cinit__(self, DOMNode node):             # <<<<<<<<<<<<<<
 *         self.node = node
 * 
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_node,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_node)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 253, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_node = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 253, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_node), __pyx_ptype_11resiliparse_5parse_4html_DOMNode, 1, "node", 0))) __PYX_ERR(0, 253, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList___cinit__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self), __pyx_v_node);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList___cinit__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "resiliparse/parse/html.pyx":254
 * 
 *     def __cinit__(self, DOMNode node):
 *         self.node = node             # <<<<<<<<<<<<<<
 * 
 *     cdef list _create_list(self):
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_node));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_node));
  __Pyx_GOTREF(__pyx_v_self->node);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->node));
  __pyx_v_self->node = __pyx_v_node;

  /* "resiliparse/parse/html.pyx":253
 *     """Class name list of an Element DOM node."""
 * 
 *     def __cinit__(self, DOMNode node):             # <<<<<<<<<<<<<<
 *         self.node = node
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":256
 *         self.node = node
 * 
 *     cdef list _create_list(self):             # <<<<<<<<<<<<<<
 *         if self.node is None or self.node.node == NULL:
 *             return []
 */

static PyObject *__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList__create_list(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self) {
  size_t __pyx_v_class_name_len;
  lxb_char_t const *__pyx_v_class_name;
  PyObject *__pyx_v_class_list = 0;
  PyObject *__pyx_v_start = 0;
  PyObject *__pyx_v_end = 0;
  size_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  size_t __pyx_t_6;
  size_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_list", 0);

  /* "resiliparse/parse/html.pyx":257
 * 
 *     cdef list _create_list(self):
 *         if self.node is None or self.node.node == NULL:             # <<<<<<<<<<<<<<
 *             return []
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->node) == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_v_self->node->node == NULL) != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":258
 *     cdef list _create_list(self):
 *         if self.node is None or self.node.node == NULL:
 *             return []             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t class_name_len = 0
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":257
 * 
 *     cdef list _create_list(self):
 *         if self.node is None or self.node.node == NULL:             # <<<<<<<<<<<<<<
 *             return []
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":260
 *             return []
 * 
 *         cdef size_t class_name_len = 0             # <<<<<<<<<<<<<<
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 *         if class_name == NULL:
 */
  __pyx_v_class_name_len = 0;

  /* "resiliparse/parse/html.pyx":261
 * 
 *         cdef size_t class_name_len = 0
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)             # <<<<<<<<<<<<<<
 *         if class_name == NULL:
 *             return []
 */
  __pyx_v_class_name = lxb_dom_element_class(((lxb_dom_element_t *)__pyx_v_self->node->node), (&__pyx_v_class_name_len));

  /* "resiliparse/parse/html.pyx":262
 *         cdef size_t class_name_len = 0
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 *         if class_name == NULL:             # <<<<<<<<<<<<<<
 *             return []
 * 
 */
  __pyx_t_1 = ((__pyx_v_class_name == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":263
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 *         if class_name == NULL:
 *             return []             # <<<<<<<<<<<<<<
 * 
 *         cdef list class_list = []
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":262
 *         cdef size_t class_name_len = 0
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 *         if class_name == NULL:             # <<<<<<<<<<<<<<
 *             return []
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":265
 *             return []
 * 
 *         cdef list class_list = []             # <<<<<<<<<<<<<<
 *         cdef start = 0, end = 0
 *         cdef size_t i
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_class_list = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "resiliparse/parse/html.pyx":266
 * 
 *         cdef list class_list = []
 *         cdef start = 0, end = 0             # <<<<<<<<<<<<<<
 *         cdef size_t i
 *         for i in range(class_name_len):
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_start = __pyx_int_0;
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_end = __pyx_int_0;

  /* "resiliparse/parse/html.pyx":268
 *         cdef start = 0, end = 0
 *         cdef size_t i
 *         for i in range(class_name_len):             # <<<<<<<<<<<<<<
 * 
 *             if is_whitespace(class_name[start]):
 */
  __pyx_t_5 = __pyx_v_class_name_len;
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
    __pyx_v_i = __pyx_t_7;

    /* "resiliparse/parse/html.pyx":270
 *         for i in range(class_name_len):
 * 
 *             if is_whitespace(class_name[start]):             # <<<<<<<<<<<<<<
 *                 start = i + 1
 *                 continue
 */
    __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_start); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 270, __pyx_L1_error)
    __pyx_t_1 = (__pyx_f_11resiliparse_5parse_4html_is_whitespace((__pyx_v_class_name[__pyx_t_8])) != 0);
    if (__pyx_t_1) {

      /* "resiliparse/parse/html.pyx":271
 * 
 *             if is_whitespace(class_name[start]):
 *                 start = i + 1             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      __pyx_t_4 = __Pyx_PyInt_FromSize_t((__pyx_v_i + 1)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "resiliparse/parse/html.pyx":272
 *             if is_whitespace(class_name[start]):
 *                 start = i + 1
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             if is_whitespace(class_name[i]) or i == class_name_len - 1:
 */
      goto __pyx_L7_continue;

      /* "resiliparse/parse/html.pyx":270
 *         for i in range(class_name_len):
 * 
 *             if is_whitespace(class_name[start]):             # <<<<<<<<<<<<<<
 *                 start = i + 1
 *                 continue
 */
    }

    /* "resiliparse/parse/html.pyx":274
 *                 continue
 * 
 *             if is_whitespace(class_name[i]) or i == class_name_len - 1:             # <<<<<<<<<<<<<<
 *                 end = i if i < class_name_len - 1 else i + 1
 *                 if start < end:
 */
    __pyx_t_3 = (__pyx_f_11resiliparse_5parse_4html_is_whitespace((__pyx_v_class_name[__pyx_v_i])) != 0);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_1 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = ((__pyx_v_i == (__pyx_v_class_name_len - 1)) != 0);
    __pyx_t_1 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_1) {

      /* "resiliparse/parse/html.pyx":275
 * 
 *             if is_whitespace(class_name[i]) or i == class_name_len - 1:
 *                 end = i if i < class_name_len - 1 else i + 1             # <<<<<<<<<<<<<<
 *                 if start < end:
 *                     class_list.append(class_name[start:end].decode())
 */
      if (((__pyx_v_i < (__pyx_v_class_name_len - 1)) != 0)) {
        __pyx_t_9 = __Pyx_PyInt_FromSize_t(__pyx_v_i); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 275, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_4 = __pyx_t_9;
        __pyx_t_9 = 0;
      } else {
        __pyx_t_9 = __Pyx_PyInt_FromSize_t((__pyx_v_i + 1)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 275, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_4 = __pyx_t_9;
        __pyx_t_9 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_end, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "resiliparse/parse/html.pyx":276
 *             if is_whitespace(class_name[i]) or i == class_name_len - 1:
 *                 end = i if i < class_name_len - 1 else i + 1
 *                 if start < end:             # <<<<<<<<<<<<<<
 *                     class_list.append(class_name[start:end].decode())
 *                     start = i + 1
 */
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_start, __pyx_v_end, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 276, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_1) {

        /* "resiliparse/parse/html.pyx":277
 *                 end = i if i < class_name_len - 1 else i + 1
 *                 if start < end:
 *                     class_list.append(class_name[start:end].decode())             # <<<<<<<<<<<<<<
 *                     start = i + 1
 * 
 */
        __Pyx_INCREF(__pyx_v_start);
        __pyx_t_4 = __pyx_v_start;
        __pyx_t_1 = (__pyx_t_4 == Py_None);
        if (__pyx_t_1) {
          __pyx_t_8 = 0;
        } else {
          __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_t_4); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 277, __pyx_L1_error)
          __pyx_t_8 = __pyx_t_10;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_INCREF(__pyx_v_end);
        __pyx_t_4 = __pyx_v_end;
        __pyx_t_1 = (__pyx_t_4 == Py_None);
        if (__pyx_t_1) {
          __pyx_t_10 = PY_SSIZE_T_MAX;
        } else {
          __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_4); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 277, __pyx_L1_error)
          __pyx_t_10 = __pyx_t_11;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_decode_c_string(((char const *)__pyx_v_class_name), __pyx_t_8, __pyx_t_10, NULL, NULL, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 277, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_class_list, __pyx_t_4); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 277, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "resiliparse/parse/html.pyx":278
 *                 if start < end:
 *                     class_list.append(class_name[start:end].decode())
 *                     start = i + 1             # <<<<<<<<<<<<<<
 * 
 *         return class_list
 */
        __pyx_t_4 = __Pyx_PyInt_FromSize_t((__pyx_v_i + 1)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 278, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "resiliparse/parse/html.pyx":276
 *             if is_whitespace(class_name[i]) or i == class_name_len - 1:
 *                 end = i if i < class_name_len - 1 else i + 1
 *                 if start < end:             # <<<<<<<<<<<<<<
 *                     class_list.append(class_name[start:end].decode())
 *                     start = i + 1
 */
      }

      /* "resiliparse/parse/html.pyx":274
 *                 continue
 * 
 *             if is_whitespace(class_name[i]) or i == class_name_len - 1:             # <<<<<<<<<<<<<<
 *                 end = i if i < class_name_len - 1 else i + 1
 *                 if start < end:
 */
    }
    __pyx_L7_continue:;
  }

  /* "resiliparse/parse/html.pyx":280
 *                     start = i + 1
 * 
 *         return class_list             # <<<<<<<<<<<<<<
 * 
 *     cdef inline bytes _class_name_bytes(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_class_list);
  __pyx_r = __pyx_v_class_list;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":256
 *         self.node = node
 * 
 *     cdef list _create_list(self):             # <<<<<<<<<<<<<<
 *         if self.node is None or self.node.node == NULL:
 *             return []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList._create_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_class_list);
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_end);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":282
 *         return class_list
 * 
 *     cdef inline bytes _class_name_bytes(self):             # <<<<<<<<<<<<<<
 *         cdef size_t class_name_len = 0
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 */

static CYTHON_INLINE PyObject *__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList__class_name_bytes(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self) {
  size_t __pyx_v_class_name_len;
  lxb_char_t const *__pyx_v_class_name;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_class_name_bytes", 0);

  /* "resiliparse/parse/html.pyx":283
 * 
 *     cdef inline bytes _class_name_bytes(self):
 *         cdef size_t class_name_len = 0             # <<<<<<<<<<<<<<
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 *         if class_name == NULL:
 */
  __pyx_v_class_name_len = 0;

  /* "resiliparse/parse/html.pyx":284
 *     cdef inline bytes _class_name_bytes(self):
 *         cdef size_t class_name_len = 0
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)             # <<<<<<<<<<<<<<
 *         if class_name == NULL:
 *             return b''
 */
  __pyx_v_class_name = lxb_dom_element_class(((lxb_dom_element_t *)__pyx_v_self->node->node), (&__pyx_v_class_name_len));

  /* "resiliparse/parse/html.pyx":285
 *         cdef size_t class_name_len = 0
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 *         if class_name == NULL:             # <<<<<<<<<<<<<<
 *             return b''
 *         return class_name[:class_name_len]
 */
  __pyx_t_1 = ((__pyx_v_class_name == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":286
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 *         if class_name == NULL:
 *             return b''             # <<<<<<<<<<<<<<
 *         return class_name[:class_name_len]
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_b__2);
    __pyx_r = __pyx_kp_b__2;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":285
 *         cdef size_t class_name_len = 0
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 *         if class_name == NULL:             # <<<<<<<<<<<<<<
 *             return b''
 *         return class_name[:class_name_len]
 */
  }

  /* "resiliparse/parse/html.pyx":287
 *         if class_name == NULL:
 *             return b''
 *         return class_name[:class_name_len]             # <<<<<<<<<<<<<<
 * 
 *     cpdef void add(self, str class_name):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBytes_FromStringAndSize(((const char*)__pyx_v_class_name) + 0, __pyx_v_class_name_len - 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":282
 *         return class_list
 * 
 *     cdef inline bytes _class_name_bytes(self):             # <<<<<<<<<<<<<<
 *         cdef size_t class_name_len = 0
 *         cdef const lxb_char_t* class_name = lxb_dom_element_class(<lxb_dom_element_t*>self.node.node, &class_name_len)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList._class_name_bytes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":289
 *         return class_name[:class_name_len]
 * 
 *     cpdef void add(self, str class_name):             # <<<<<<<<<<<<<<
 *         """
 *         add(self, class_name)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_3add(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name); /*proto*/
static void __pyx_f_11resiliparse_5parse_4html_19DOMElementClassList_add(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_new_class_name = 0;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  char __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);
  __Pyx_INCREF(__pyx_v_class_name);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_add); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_3add)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_class_name) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_class_name);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 289, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":298
 *         :type class_name: str
 *         """
 *         if self.node is None or self.node.node == NULL:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_6 = (((PyObject *)__pyx_v_self->node) == Py_None);
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = ((__pyx_v_self->node->node == NULL) != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "resiliparse/parse/html.pyx":299
 *         """
 *         if self.node is None or self.node.node == NULL:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cdef list l = self._create_list()
 */
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":298
 *         :type class_name: str
 *         """
 *         if self.node is None or self.node.node == NULL:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":301
 *             return
 * 
 *         cdef list l = self._create_list()             # <<<<<<<<<<<<<<
 *         if class_name in l:
 *             return
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":302
 * 
 *         cdef list l = self._create_list()
 *         if class_name in l:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_v_class_name, __pyx_v_l, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 302, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_5 != 0);
  if (__pyx_t_7) {

    /* "resiliparse/parse/html.pyx":303
 *         cdef list l = self._create_list()
 *         if class_name in l:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes new_class_name = self._class_name_bytes()
 */
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":302
 * 
 *         cdef list l = self._create_list()
 *         if class_name in l:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":305
 *             return
 * 
 *         cdef bytes new_class_name = self._class_name_bytes()             # <<<<<<<<<<<<<<
 *         if not is_whitespace(new_class_name[-1]):
 *             class_name = ' ' + class_name
 */
  __pyx_t_1 = __pyx_f_11resiliparse_5parse_4html_19DOMElementClassList__class_name_bytes(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_new_class_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":306
 * 
 *         cdef bytes new_class_name = self._class_name_bytes()
 *         if not is_whitespace(new_class_name[-1]):             # <<<<<<<<<<<<<<
 *             class_name = ' ' + class_name
 *         new_class_name = new_class_name + class_name.encode()
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_new_class_name, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_PyInt_As_char(__pyx_t_1); if (unlikely((__pyx_t_8 == (char)-1) && PyErr_Occurred())) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = ((!(__pyx_f_11resiliparse_5parse_4html_is_whitespace(__pyx_t_8) != 0)) != 0);
  if (__pyx_t_7) {

    /* "resiliparse/parse/html.pyx":307
 *         cdef bytes new_class_name = self._class_name_bytes()
 *         if not is_whitespace(new_class_name[-1]):
 *             class_name = ' ' + class_name             # <<<<<<<<<<<<<<
 *         new_class_name = new_class_name + class_name.encode()
 *         # noinspection PyProtectedMember
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u__3, __pyx_v_class_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_class_name, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "resiliparse/parse/html.pyx":306
 * 
 *         cdef bytes new_class_name = self._class_name_bytes()
 *         if not is_whitespace(new_class_name[-1]):             # <<<<<<<<<<<<<<
 *             class_name = ' ' + class_name
 *         new_class_name = new_class_name + class_name.encode()
 */
  }

  /* "resiliparse/parse/html.pyx":308
 *         if not is_whitespace(new_class_name[-1]):
 *             class_name = ' ' + class_name
 *         new_class_name = new_class_name + class_name.encode()             # <<<<<<<<<<<<<<
 *         # noinspection PyProtectedMember
 *         self.node._setattr_impl(b'class', new_class_name)
 */
  if (unlikely(__pyx_v_class_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 308, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_class_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_v_new_class_name, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyBytes_CheckExact(__pyx_t_2))||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_DECREF_SET(__pyx_v_new_class_name, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":310
 *         new_class_name = new_class_name + class_name.encode()
 *         # noinspection PyProtectedMember
 *         self.node._setattr_impl(b'class', new_class_name)             # <<<<<<<<<<<<<<
 * 
 *     cpdef void remove(self, str class_name):
 */
  __pyx_t_7 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->node->__pyx_vtab)->_setattr_impl(__pyx_v_self->node, __pyx_n_b_class, __pyx_v_new_class_name); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 310, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":289
 *         return class_name[:class_name_len]
 * 
 *     cpdef void add(self, str class_name):             # <<<<<<<<<<<<<<
 *         """
 *         add(self, class_name)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMElementClassList.add", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_new_class_name);
  __Pyx_XDECREF(__pyx_v_class_name);
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_3add(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_2add[] = "\n        add(self, class_name)\n        \n        Add new class name to Element node if not already present.\n        \n        :param class_name: new class name\n        :type class_name: str\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_3add(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_class_name), (&PyUnicode_Type), 1, "class_name", 1))) __PYX_ERR(0, 289, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_2add(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self), ((PyObject*)__pyx_v_class_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_2add(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_class_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_void_to_None(__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList_add(__pyx_v_self, __pyx_v_class_name, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":312
 *         self.node._setattr_impl(b'class', new_class_name)
 * 
 *     cpdef void remove(self, str class_name):             # <<<<<<<<<<<<<<
 *         """
 *         remove(self, class_name)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_5remove(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name); /*proto*/
static void __pyx_f_11resiliparse_5parse_4html_19DOMElementClassList_remove(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_7genexpr__pyx_v_c = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_c = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_remove); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_5remove)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_class_name) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_class_name);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 312, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":321
 *         :type class_name: str
 *         """
 *         if self.node is None or self.node.node == NULL:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_6 = (((PyObject *)__pyx_v_self->node) == Py_None);
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = ((__pyx_v_self->node->node == NULL) != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "resiliparse/parse/html.pyx":322
 *         """
 *         if self.node is None or self.node.node == NULL:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cdef list l = [c for c in self._create_list() if c != class_name]
 */
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":321
 *         :type class_name: str
 *         """
 *         if self.node is None or self.node.node == NULL:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":324
 *             return
 * 
 *         cdef list l = [c for c in self._create_list() if c != class_name]             # <<<<<<<<<<<<<<
 *         # noinspection PyProtectedMember
 *         self.node._setattr_impl(b'class', b' '.join([c.encode() for c in l]))
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 324, __pyx_L8_error)
    }
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_2); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 324, __pyx_L8_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_c, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_7genexpr__pyx_v_c, __pyx_v_class_name, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 324, __pyx_L8_error)
      if (__pyx_t_5) {
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_7genexpr__pyx_v_c))) __PYX_ERR(0, 324, __pyx_L8_error)
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_c); __pyx_7genexpr__pyx_v_c = 0;
    goto __pyx_L12_exit_scope;
    __pyx_L8_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_c); __pyx_7genexpr__pyx_v_c = 0;
    goto __pyx_L1_error;
    __pyx_L12_exit_scope:;
  } /* exit inner scope */
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":326
 *         cdef list l = [c for c in self._create_list() if c != class_name]
 *         # noinspection PyProtectedMember
 *         self.node._setattr_impl(b'class', b' '.join([c.encode() for c in l]))             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, item):
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 326, __pyx_L15_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __pyx_v_l; __Pyx_INCREF(__pyx_t_3); __pyx_t_8 = 0;
    for (;;) {
      if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_2); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 326, __pyx_L15_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 326, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_c, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr1__pyx_v_c, __pyx_n_s_encode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 326, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_2 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 326, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 326, __pyx_L15_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_c); __pyx_8genexpr1__pyx_v_c = 0;
    goto __pyx_L18_exit_scope;
    __pyx_L15_error:;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_c); __pyx_8genexpr1__pyx_v_c = 0;
    goto __pyx_L1_error;
    __pyx_L18_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = __Pyx_PyBytes_Join(__pyx_kp_b__3, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 326, __pyx_L1_error)
  __pyx_t_5 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->node->__pyx_vtab)->_setattr_impl(__pyx_v_self->node, __pyx_n_b_class, ((PyObject*)__pyx_t_3)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "resiliparse/parse/html.pyx":312
 *         self.node._setattr_impl(b'class', new_class_name)
 * 
 *     cpdef void remove(self, str class_name):             # <<<<<<<<<<<<<<
 *         """
 *         remove(self, class_name)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMElementClassList.remove", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_c);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_c);
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_5remove(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_4remove[] = "\n        remove(self, class_name)\n        \n        Remove a class name from this Element node.\n        \n        :param class_name: new class name\n        :type class_name: str\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_5remove(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_class_name), (&PyUnicode_Type), 1, "class_name", 1))) __PYX_ERR(0, 312, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_4remove(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self), ((PyObject*)__pyx_v_class_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_4remove(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_class_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_void_to_None(__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList_remove(__pyx_v_self, __pyx_v_class_name, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.remove", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":328
 *         self.node._setattr_impl(b'class', b' '.join([c.encode() for c in l]))
 * 
 *     def __contains__(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         __contains__(self, item):
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__[] = "\n        __contains__(self, item):\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__;
#endif
static int __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_item) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__contains__", 0);

  /* "resiliparse/parse/html.pyx":332
 *         __contains__(self, item):
 *         """
 *         return item in self._create_list()             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, item):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_item, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":328
 *         self.node._setattr_impl(b'class', b' '.join([c.encode() for c in l]))
 * 
 *     def __contains__(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         __contains__(self, item):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":334
 *         return item in self._create_list()
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         __contains__(self, item)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_9__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__[] = "\n        __contains__(self, item)\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_9__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "resiliparse/parse/html.pyx":338
 *         __contains__(self, item)
 *         """
 *         return self._create_list()[item]             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 338, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_item); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":334
 *         return item in self._create_list()
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         __contains__(self, item)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":340
 *         return self._create_list()[item]
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         __eq__(self, other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_11__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__[] = "\n        __eq__(self, other)\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_11__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "resiliparse/parse/html.pyx":344
 *         __eq__(self, other)
 *         """
 *         return other == self._create_list()             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_other, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 344, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":340
 *         return self._create_list()[item]
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         __eq__(self, other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":346
 *         return other == self._create_list()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __len__(self)
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_13__len__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_12__len__[] = "\n        __len__(self)\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_12__len__;
#endif
static Py_ssize_t __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_13__len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_12__len__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_12__len__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "resiliparse/parse/html.pyx":350
 *         __len__(self)
 *         """
 *         return len(self._create_list())             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 350, __pyx_L1_error)
  }
  __pyx_t_2 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":346
 *         return other == self._create_list()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __len__(self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":352
 *         return len(self._create_list())
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __iter__(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_15__iter__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__[] = "\n        __iter__(self)\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_15__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "resiliparse/parse/html.pyx":356
 *         __iter__(self)
 *         """
 *         return iter(self._create_list())             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":352
 *         return len(self._create_list())
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __iter__(self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":358
 *         return iter(self._create_list())
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __repr__(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_17__repr__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__[] = "\n        __repr__(self)\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_17__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "resiliparse/parse/html.pyx":362
 *         __repr__(self)
 *         """
 *         return repr(self._create_list())             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Repr(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":358
 *         return iter(self._create_list())
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __repr__(self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":364
 *         return repr(self._create_list())
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __str__(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_19__str__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_18__str__[] = "\n        __str__(self)\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_18__str__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_19__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_18__str__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_18__str__(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "resiliparse/parse/html.pyx":368
 *         __str__(self)
 *         """
 *         return str(self._create_list())             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self->__pyx_vtab)->_create_list(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":364
 *         return repr(self._create_list())
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __str__(self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_21__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_21__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_20__reduce_cython__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_20__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_23__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_23__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_22__setstate_cython__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_19DOMElementClassList_22__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMElementClassList.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":382
 *     """
 * 
 *     def __cinit__(self, HTMLTree tree):             # <<<<<<<<<<<<<<
 *         self.tree = tree
 *         self.node = NULL
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tree,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tree)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 382, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_tree = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 382, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tree), __pyx_ptype_11resiliparse_5parse_4html_HTMLTree, 1, "tree", 0))) __PYX_ERR(0, 382, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode___cinit__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), __pyx_v_tree);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode___cinit__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "resiliparse/parse/html.pyx":383
 * 
 *     def __cinit__(self, HTMLTree tree):
 *         self.tree = tree             # <<<<<<<<<<<<<<
 *         self.node = NULL
 *         self.class_list_singleton = None
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_tree));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_tree));
  __Pyx_GOTREF(__pyx_v_self->tree);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->tree));
  __pyx_v_self->tree = __pyx_v_tree;

  /* "resiliparse/parse/html.pyx":384
 *     def __cinit__(self, HTMLTree tree):
 *         self.tree = tree
 *         self.node = NULL             # <<<<<<<<<<<<<<
 *         self.class_list_singleton = None
 * 
 */
  __pyx_v_self->node = NULL;

  /* "resiliparse/parse/html.pyx":385
 *         self.tree = tree
 *         self.node = NULL
 *         self.class_list_singleton = None             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->class_list_singleton);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->class_list_singleton));
  __pyx_v_self->class_list_singleton = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)Py_None);

  /* "resiliparse/parse/html.pyx":382
 *     """
 * 
 *     def __cinit__(self, HTMLTree tree):             # <<<<<<<<<<<<<<
 *         self.tree = tree
 *         self.node = NULL
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":387
 *         self.class_list_singleton = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.node == NULL or self.tree is None:
 *             return
 */

/* Python wrapper */
static void __pyx_pw_11resiliparse_5parse_4html_7DOMNode_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_11resiliparse_5parse_4html_7DOMNode_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_11resiliparse_5parse_4html_7DOMNode_2__dealloc__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_11resiliparse_5parse_4html_7DOMNode_2__dealloc__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "resiliparse/parse/html.pyx":388
 * 
 *     def __dealloc__(self):
 *         if self.node == NULL or self.tree is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = ((__pyx_v_self->node == NULL) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (((PyObject *)__pyx_v_self->tree) == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":389
 *     def __dealloc__(self):
 *         if self.node == NULL or self.tree is None:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self.node.user = NULL
 */
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":388
 * 
 *     def __dealloc__(self):
 *         if self.node == NULL or self.tree is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":391
 *             return
 * 
 *         self.node.user = NULL             # <<<<<<<<<<<<<<
 * 
 *         # Cannot be done until https://github.com/lexbor/lexbor/issues/132 is fixed
 */
  __pyx_v_self->node->user = NULL;

  /* "resiliparse/parse/html.pyx":397
 *         # if self.node.parent == NULL and self.node != <lxb_dom_node_t*>self.node.owner_document:
 *         #     lxb_dom_node_destroy_deep(self.node)
 *         self.node = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  __pyx_v_self->node = NULL;

  /* "resiliparse/parse/html.pyx":387
 *         self.class_list_singleton = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.node == NULL or self.tree is None:
 *             return
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}
static PyObject *__pyx_gb_11resiliparse_5parse_4html_7DOMNode_6generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "resiliparse/parse/html.pyx":399
 *         self.node = NULL
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __iter__(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_5__iter__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_4__iter__[] = "\n        __iter__(self)\n\n        Traverse the DOM tree in pre-order starting at the current node.\n\n        :rtype: t.Iterable[DOMNode]\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_4__iter__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_5__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4__iter__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4__iter__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 0);
  __pyx_cur_scope = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *)__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct____iter__(__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct____iter__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 399, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11resiliparse_5parse_4html_7DOMNode_6generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter, __pyx_n_s_DOMNode___iter, __pyx_n_s_resiliparse_parse_html); if (unlikely(!gen)) __PYX_ERR(0, 399, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11resiliparse_5parse_4html_7DOMNode_6generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *__pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  lxb_dom_node_t *__pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L5_resume_from_yield;
    case 2: goto __pyx_L14_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 399, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":407
 *         :rtype: t.Iterable[DOMNode]
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_cur_scope->__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":408
 *         """
 *         if not check_node(self):
 *             return             # <<<<<<<<<<<<<<
 * 
 *         yield self
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":407
 *         :rtype: t.Iterable[DOMNode]
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":410
 *             return
 * 
 *         yield self             # <<<<<<<<<<<<<<
 *         cdef lxb_dom_node_t* node = self.node
 *         while True:
 */
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
  __pyx_r = ((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  /* return from generator, yielding value */
  __pyx_generator->resume_label = 1;
  return __pyx_r;
  __pyx_L5_resume_from_yield:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 410, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":411
 * 
 *         yield self
 *         cdef lxb_dom_node_t* node = self.node             # <<<<<<<<<<<<<<
 *         while True:
 *             if node.first_child != NULL:
 */
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_self->node;
  __pyx_cur_scope->__pyx_v_node = __pyx_t_2;

  /* "resiliparse/parse/html.pyx":412
 *         yield self
 *         cdef lxb_dom_node_t* node = self.node
 *         while True:             # <<<<<<<<<<<<<<
 *             if node.first_child != NULL:
 *                 node = node.first_child
 */
  while (1) {

    /* "resiliparse/parse/html.pyx":413
 *         cdef lxb_dom_node_t* node = self.node
 *         while True:
 *             if node.first_child != NULL:             # <<<<<<<<<<<<<<
 *                 node = node.first_child
 *             else:
 */
    __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_node->first_child != NULL) != 0);
    if (__pyx_t_1) {

      /* "resiliparse/parse/html.pyx":414
 *         while True:
 *             if node.first_child != NULL:
 *                 node = node.first_child             # <<<<<<<<<<<<<<
 *             else:
 *                 while node != self.node and node.next == NULL:
 */
      __pyx_t_2 = __pyx_cur_scope->__pyx_v_node->first_child;
      __pyx_cur_scope->__pyx_v_node = __pyx_t_2;

      /* "resiliparse/parse/html.pyx":413
 *         cdef lxb_dom_node_t* node = self.node
 *         while True:
 *             if node.first_child != NULL:             # <<<<<<<<<<<<<<
 *                 node = node.first_child
 *             else:
 */
      goto __pyx_L8;
    }

    /* "resiliparse/parse/html.pyx":416
 *                 node = node.first_child
 *             else:
 *                 while node != self.node and node.next == NULL:             # <<<<<<<<<<<<<<
 *                     node = node.parent
 *                 if node == self.node:
 */
    /*else*/ {
      while (1) {
        __pyx_t_3 = ((__pyx_cur_scope->__pyx_v_node != __pyx_cur_scope->__pyx_v_self->node) != 0);
        if (__pyx_t_3) {
        } else {
          __pyx_t_1 = __pyx_t_3;
          goto __pyx_L11_bool_binop_done;
        }
        __pyx_t_3 = ((__pyx_cur_scope->__pyx_v_node->next == NULL) != 0);
        __pyx_t_1 = __pyx_t_3;
        __pyx_L11_bool_binop_done:;
        if (!__pyx_t_1) break;

        /* "resiliparse/parse/html.pyx":417
 *             else:
 *                 while node != self.node and node.next == NULL:
 *                     node = node.parent             # <<<<<<<<<<<<<<
 *                 if node == self.node:
 *                     return
 */
        __pyx_t_2 = __pyx_cur_scope->__pyx_v_node->parent;
        __pyx_cur_scope->__pyx_v_node = __pyx_t_2;
      }

      /* "resiliparse/parse/html.pyx":418
 *                 while node != self.node and node.next == NULL:
 *                     node = node.parent
 *                 if node == self.node:             # <<<<<<<<<<<<<<
 *                     return
 *                 node = node.next
 */
      __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_node == __pyx_cur_scope->__pyx_v_self->node) != 0);
      if (__pyx_t_1) {

        /* "resiliparse/parse/html.pyx":419
 *                     node = node.parent
 *                 if node == self.node:
 *                     return             # <<<<<<<<<<<<<<
 *                 node = node.next
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = NULL;
        goto __pyx_L0;

        /* "resiliparse/parse/html.pyx":418
 *                 while node != self.node and node.next == NULL:
 *                     node = node.parent
 *                 if node == self.node:             # <<<<<<<<<<<<<<
 *                     return
 *                 node = node.next
 */
      }

      /* "resiliparse/parse/html.pyx":420
 *                 if node == self.node:
 *                     return
 *                 node = node.next             # <<<<<<<<<<<<<<
 * 
 *             yield _create_dom_node(self.tree, node)
 */
      __pyx_t_2 = __pyx_cur_scope->__pyx_v_node->next;
      __pyx_cur_scope->__pyx_v_node = __pyx_t_2;
    }
    __pyx_L8:;

    /* "resiliparse/parse/html.pyx":422
 *                 node = node.next
 * 
 *             yield _create_dom_node(self.tree, node)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
    __pyx_t_4 = ((PyObject *)__pyx_cur_scope->__pyx_v_self->tree);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_4), __pyx_cur_scope->__pyx_v_node)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 2;
    return __pyx_r;
    __pyx_L14_resume_from_yield:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 422, __pyx_L1_error)
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "resiliparse/parse/html.pyx":399
 *         self.node = NULL
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __iter__(self)
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":425
 * 
 *     @property
 *     def type(self):             # <<<<<<<<<<<<<<
 *         """
 *         DOM node type.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4type_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4type___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4type___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":431
 *         :type: NodeType
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return <NodeType>self.node.type
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":432
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 *         return <NodeType>self.node.type
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":431
 *         :type: NodeType
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return <NodeType>self.node.type
 */
  }

  /* "resiliparse/parse/html.pyx":433
 *         if not check_node(self):
 *             return None
 *         return <NodeType>self.node.type             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(((enum __pyx_t_11resiliparse_5parse_4html_NodeType)__pyx_v_self->node->type)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":425
 * 
 *     @property
 *     def type(self):             # <<<<<<<<<<<<<<
 *         """
 *         DOM node type.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.type.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":436
 * 
 *     @property
 *     def tag(self):             # <<<<<<<<<<<<<<
 *         """
 *         DOM node tag name if node is an Element node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_3tag_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_3tag_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_3tag___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_3tag___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  size_t __pyx_v_name_len;
  lxb_char_t const *__pyx_v_name;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":442
 *         :type: str or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":443
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_TEXT:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":442
 *         :type: str or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":445
 *             return None
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_TEXT:             # <<<<<<<<<<<<<<
 *             return '#text'
 *         if self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 */
  __pyx_t_1 = ((__pyx_v_self->node->type == LXB_DOM_NODE_TYPE_TEXT) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":446
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_TEXT:
 *             return '#text'             # <<<<<<<<<<<<<<
 *         if self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 *             return '#document'
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_text);
    __pyx_r = __pyx_kp_u_text;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":445
 *             return None
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_TEXT:             # <<<<<<<<<<<<<<
 *             return '#text'
 *         if self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 */
  }

  /* "resiliparse/parse/html.pyx":447
 *         if self.node.type == LXB_DOM_NODE_TYPE_TEXT:
 *             return '#text'
 *         if self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:             # <<<<<<<<<<<<<<
 *             return '#document'
 *         if self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 */
  __pyx_t_1 = ((__pyx_v_self->node->type == LXB_DOM_NODE_TYPE_DOCUMENT) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":448
 *             return '#text'
 *         if self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 *             return '#document'             # <<<<<<<<<<<<<<
 *         if self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_document);
    __pyx_r = __pyx_kp_u_document;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":447
 *         if self.node.type == LXB_DOM_NODE_TYPE_TEXT:
 *             return '#text'
 *         if self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:             # <<<<<<<<<<<<<<
 *             return '#document'
 *         if self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 */
  }

  /* "resiliparse/parse/html.pyx":449
 *         if self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 *             return '#document'
 *         if self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":450
 *             return '#document'
 *         if self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t name_len = 0
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":449
 *         if self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 *             return '#document'
 *         if self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":452
 *             return None
 * 
 *         cdef size_t name_len = 0             # <<<<<<<<<<<<<<
 *         cdef const lxb_char_t* name = lxb_dom_element_qualified_name(<lxb_dom_element_t*>self.node, &name_len)
 *         if name == NULL:
 */
  __pyx_v_name_len = 0;

  /* "resiliparse/parse/html.pyx":453
 * 
 *         cdef size_t name_len = 0
 *         cdef const lxb_char_t* name = lxb_dom_element_qualified_name(<lxb_dom_element_t*>self.node, &name_len)             # <<<<<<<<<<<<<<
 *         if name == NULL:
 *             return None
 */
  __pyx_v_name = lxb_dom_element_qualified_name(((lxb_dom_element_t *)__pyx_v_self->node), (&__pyx_v_name_len));

  /* "resiliparse/parse/html.pyx":454
 *         cdef size_t name_len = 0
 *         cdef const lxb_char_t* name = lxb_dom_element_qualified_name(<lxb_dom_element_t*>self.node, &name_len)
 *         if name == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return name[:name_len].decode()
 */
  __pyx_t_1 = ((__pyx_v_name == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":455
 *         cdef const lxb_char_t* name = lxb_dom_element_qualified_name(<lxb_dom_element_t*>self.node, &name_len)
 *         if name == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         return name[:name_len].decode()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":454
 *         cdef size_t name_len = 0
 *         cdef const lxb_char_t* name = lxb_dom_element_qualified_name(<lxb_dom_element_t*>self.node, &name_len)
 *         if name == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return name[:name_len].decode()
 */
  }

  /* "resiliparse/parse/html.pyx":456
 *         if name == NULL:
 *             return None
 *         return name[:name_len].decode()             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_decode_c_string(((char const *)__pyx_v_name), 0, __pyx_v_name_len, NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":436
 * 
 *     @property
 *     def tag(self):             # <<<<<<<<<<<<<<
 *         """
 *         DOM node tag name if node is an Element node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.tag.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":459
 * 
 *     @property
 *     def first_child(self):             # <<<<<<<<<<<<<<
 *         """
 *         First child element of this DOM node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_11first_child_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_11first_child_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_11first_child___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_11first_child___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":465
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.first_child)
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":466
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self.tree, self.node.first_child)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":465
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.first_child)
 */
  }

  /* "resiliparse/parse/html.pyx":467
 *         if not check_node(self):
 *             return None
 *         return _create_dom_node(self.tree, self.node.first_child)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_2), __pyx_v_self->node->first_child)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":459
 * 
 *     @property
 *     def first_child(self):             # <<<<<<<<<<<<<<
 *         """
 *         First child element of this DOM node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.first_child.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":470
 * 
 *     @property
 *     def last_child(self):             # <<<<<<<<<<<<<<
 *         """
 *         Last child element of this DOM node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10last_child_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10last_child_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_10last_child___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_10last_child___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":476
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.last_child)
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":477
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self.tree, self.node.last_child)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":476
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.last_child)
 */
  }

  /* "resiliparse/parse/html.pyx":478
 *         if not check_node(self):
 *             return None
 *         return _create_dom_node(self.tree, self.node.last_child)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_2), __pyx_v_self->node->last_child)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":470
 * 
 *     @property
 *     def last_child(self):             # <<<<<<<<<<<<<<
 *         """
 *         Last child element of this DOM node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.last_child.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":481
 * 
 *     @property
 *     def child_nodes(self):             # <<<<<<<<<<<<<<
 *         """
 *         List of child nodes.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_11child_nodes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_11child_nodes_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_11child_nodes___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_11child_nodes___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  lxb_dom_node_t *__pyx_v_child;
  PyObject *__pyx_v_child_nodes = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  lxb_dom_node_t *__pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":487
 *         :type: t.List[DOMNode]
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":488
 *         """
 *         if not check_node(self):
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cdef lxb_dom_node_t* child = self.node.first_child
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":487
 *         :type: t.List[DOMNode]
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":490
 *             return
 * 
 *         cdef lxb_dom_node_t* child = self.node.first_child             # <<<<<<<<<<<<<<
 *         child_nodes = []
 *         while child != NULL:
 */
  __pyx_t_2 = __pyx_v_self->node->first_child;
  __pyx_v_child = __pyx_t_2;

  /* "resiliparse/parse/html.pyx":491
 * 
 *         cdef lxb_dom_node_t* child = self.node.first_child
 *         child_nodes = []             # <<<<<<<<<<<<<<
 *         while child != NULL:
 *             child_nodes.append(_create_dom_node(self.tree, child))
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_child_nodes = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "resiliparse/parse/html.pyx":492
 *         cdef lxb_dom_node_t* child = self.node.first_child
 *         child_nodes = []
 *         while child != NULL:             # <<<<<<<<<<<<<<
 *             child_nodes.append(_create_dom_node(self.tree, child))
 *             child = child.next
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_child != NULL) != 0);
    if (!__pyx_t_1) break;

    /* "resiliparse/parse/html.pyx":493
 *         child_nodes = []
 *         while child != NULL:
 *             child_nodes.append(_create_dom_node(self.tree, child))             # <<<<<<<<<<<<<<
 *             child = child.next
 *         return child_nodes
 */
    __pyx_t_3 = ((PyObject *)__pyx_v_self->tree);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_3), __pyx_v_child)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_child_nodes, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 493, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "resiliparse/parse/html.pyx":494
 *         while child != NULL:
 *             child_nodes.append(_create_dom_node(self.tree, child))
 *             child = child.next             # <<<<<<<<<<<<<<
 *         return child_nodes
 * 
 */
    __pyx_t_2 = __pyx_v_child->next;
    __pyx_v_child = __pyx_t_2;
  }

  /* "resiliparse/parse/html.pyx":495
 *             child_nodes.append(_create_dom_node(self.tree, child))
 *             child = child.next
 *         return child_nodes             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_child_nodes);
  __pyx_r = __pyx_v_child_nodes;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":481
 * 
 *     @property
 *     def child_nodes(self):             # <<<<<<<<<<<<<<
 *         """
 *         List of child nodes.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.child_nodes.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_child_nodes);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":498
 * 
 *     @property
 *     def parent(self):             # <<<<<<<<<<<<<<
 *         """
 *         Parent of this node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_6parent_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_6parent_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_6parent___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_6parent___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":504
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.parent)
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":505
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self.tree, self.node.parent)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":504
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.parent)
 */
  }

  /* "resiliparse/parse/html.pyx":506
 *         if not check_node(self):
 *             return None
 *         return _create_dom_node(self.tree, self.node.parent)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_2), __pyx_v_self->node->parent)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":498
 * 
 *     @property
 *     def parent(self):             # <<<<<<<<<<<<<<
 *         """
 *         Parent of this node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.parent.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":509
 * 
 *     @property
 *     def next(self):             # <<<<<<<<<<<<<<
 *         """
 *         Next sibling node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4next_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4next_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4next___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4next___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":515
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.next)
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":516
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self.tree, self.node.next)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":515
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.next)
 */
  }

  /* "resiliparse/parse/html.pyx":517
 *         if not check_node(self):
 *             return None
 *         return _create_dom_node(self.tree, self.node.next)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_2), __pyx_v_self->node->next)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":509
 * 
 *     @property
 *     def next(self):             # <<<<<<<<<<<<<<
 *         """
 *         Next sibling node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.next.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":520
 * 
 *     @property
 *     def prev(self):             # <<<<<<<<<<<<<<
 *         """
 *         Previous sibling node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4prev_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4prev_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4prev___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4prev___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":526
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.prev)
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":527
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self.tree, self.node.prev)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":526
 *         :type: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, self.node.prev)
 */
  }

  /* "resiliparse/parse/html.pyx":528
 *         if not check_node(self):
 *             return None
 *         return _create_dom_node(self.tree, self.node.prev)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_2), __pyx_v_self->node->prev)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":520
 * 
 *     @property
 *     def prev(self):             # <<<<<<<<<<<<<<
 *         """
 *         Previous sibling node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.prev.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":531
 * 
 *     @property
 *     def text(self):             # <<<<<<<<<<<<<<
 *         """
 *         Text contents of this DOM node and its children.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4text_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4text_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4text___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4text___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  size_t __pyx_v_text_len;
  lxb_char_t *__pyx_v_text;
  PyObject *__pyx_v_py_text = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":539
 *         :type: str
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         cdef size_t text_len = 0
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":540
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 *         cdef size_t text_len = 0
 *         cdef lxb_char_t* text = lxb_dom_node_text_content(self.node, &text_len)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":539
 *         :type: str
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 *         cdef size_t text_len = 0
 */
  }

  /* "resiliparse/parse/html.pyx":541
 *         if not check_node(self):
 *             return None
 *         cdef size_t text_len = 0             # <<<<<<<<<<<<<<
 *         cdef lxb_char_t* text = lxb_dom_node_text_content(self.node, &text_len)
 *         if text == NULL:
 */
  __pyx_v_text_len = 0;

  /* "resiliparse/parse/html.pyx":542
 *             return None
 *         cdef size_t text_len = 0
 *         cdef lxb_char_t* text = lxb_dom_node_text_content(self.node, &text_len)             # <<<<<<<<<<<<<<
 *         if text == NULL:
 *             return ''
 */
  __pyx_v_text = lxb_dom_node_text_content(__pyx_v_self->node, (&__pyx_v_text_len));

  /* "resiliparse/parse/html.pyx":543
 *         cdef size_t text_len = 0
 *         cdef lxb_char_t* text = lxb_dom_node_text_content(self.node, &text_len)
 *         if text == NULL:             # <<<<<<<<<<<<<<
 *             return ''
 *         cdef str py_text = text[:text_len].decode()
 */
  __pyx_t_1 = ((__pyx_v_text == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":544
 *         cdef lxb_char_t* text = lxb_dom_node_text_content(self.node, &text_len)
 *         if text == NULL:
 *             return ''             # <<<<<<<<<<<<<<
 *         cdef str py_text = text[:text_len].decode()
 *         lxb_dom_document_destroy_text(self.node.owner_document, text)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u__2);
    __pyx_r = __pyx_kp_u__2;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":543
 *         cdef size_t text_len = 0
 *         cdef lxb_char_t* text = lxb_dom_node_text_content(self.node, &text_len)
 *         if text == NULL:             # <<<<<<<<<<<<<<
 *             return ''
 *         cdef str py_text = text[:text_len].decode()
 */
  }

  /* "resiliparse/parse/html.pyx":545
 *         if text == NULL:
 *             return ''
 *         cdef str py_text = text[:text_len].decode()             # <<<<<<<<<<<<<<
 *         lxb_dom_document_destroy_text(self.node.owner_document, text)
 *         return py_text
 */
  __pyx_t_2 = __Pyx_decode_c_string(((char const *)__pyx_v_text), 0, __pyx_v_text_len, NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_py_text = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":546
 *             return ''
 *         cdef str py_text = text[:text_len].decode()
 *         lxb_dom_document_destroy_text(self.node.owner_document, text)             # <<<<<<<<<<<<<<
 *         return py_text
 * 
 */
  (void)(lxb_dom_document_destroy_text(__pyx_v_self->node->owner_document, __pyx_v_text));

  /* "resiliparse/parse/html.pyx":547
 *         cdef str py_text = text[:text_len].decode()
 *         lxb_dom_document_destroy_text(self.node.owner_document, text)
 *         return py_text             # <<<<<<<<<<<<<<
 * 
 *     @text.setter
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_py_text);
  __pyx_r = __pyx_v_py_text;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":531
 * 
 *     @property
 *     def text(self):             # <<<<<<<<<<<<<<
 *         """
 *         Text contents of this DOM node and its children.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.text.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_py_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":550
 * 
 *     @text.setter
 *     def text(self, str text):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             raise RuntimeError('Trying to set text contents of uninitialized DOM node')
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_text), (&PyUnicode_Type), 1, "text", 1))) __PYX_ERR(0, 550, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4text_2__set__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_text));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4text_2__set__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_text_bytes = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  lxb_char_t *__pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "resiliparse/parse/html.pyx":551
 *     @text.setter
 *     def text(self, str text):
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to set text contents of uninitialized DOM node')
 * 
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":552
 *     def text(self, str text):
 *         if not check_node(self):
 *             raise RuntimeError('Trying to set text contents of uninitialized DOM node')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes text_bytes = text.encode()
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 552, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":551
 *     @text.setter
 *     def text(self, str text):
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to set text contents of uninitialized DOM node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":554
 *             raise RuntimeError('Trying to set text contents of uninitialized DOM node')
 * 
 *         cdef bytes text_bytes = text.encode()             # <<<<<<<<<<<<<<
 *         lxb_dom_node_text_content_set(self.node, <lxb_char_t*>text_bytes, len(text_bytes))
 * 
 */
  if (unlikely(__pyx_v_text == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 554, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_text, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_text_bytes = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":555
 * 
 *         cdef bytes text_bytes = text.encode()
 *         lxb_dom_node_text_content_set(self.node, <lxb_char_t*>text_bytes, len(text_bytes))             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  if (unlikely(__pyx_v_text_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 555, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsWritableUString(__pyx_v_text_bytes); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 555, __pyx_L1_error)
  if (unlikely(__pyx_v_text_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 555, __pyx_L1_error)
  }
  __pyx_t_4 = PyBytes_GET_SIZE(__pyx_v_text_bytes); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 555, __pyx_L1_error)
  (void)(lxb_dom_node_text_content_set(__pyx_v_self->node, ((lxb_char_t *)__pyx_t_3), __pyx_t_4));

  /* "resiliparse/parse/html.pyx":550
 * 
 *     @text.setter
 *     def text(self, str text):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             raise RuntimeError('Trying to set text contents of uninitialized DOM node')
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.text.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text_bytes);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":558
 * 
 *     @property
 *     def html(self):             # <<<<<<<<<<<<<<
 *         """
 *         HTML contents of this DOM node and its children.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4html_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_4html_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4html___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_4html___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  lexbor_str_t *__pyx_v_html_str;
  PyObject *__pyx_v_py_text = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":566
 *         :type: str
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":567
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef lexbor_str_t* html_str = lexbor_str_create()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":566
 *         :type: str
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":569
 *             return None
 * 
 *         cdef lexbor_str_t* html_str = lexbor_str_create()             # <<<<<<<<<<<<<<
 *         lxb_html_serialize_tree_str(self.node, html_str)
 *         cdef str py_text = html_str.data[:html_str.length].decode()
 */
  __pyx_v_html_str = lexbor_str_create();

  /* "resiliparse/parse/html.pyx":570
 * 
 *         cdef lexbor_str_t* html_str = lexbor_str_create()
 *         lxb_html_serialize_tree_str(self.node, html_str)             # <<<<<<<<<<<<<<
 *         cdef str py_text = html_str.data[:html_str.length].decode()
 *         lexbor_str_destroy(html_str, self.node.owner_document.text, True)
 */
  (void)(lxb_html_serialize_tree_str(__pyx_v_self->node, __pyx_v_html_str));

  /* "resiliparse/parse/html.pyx":571
 *         cdef lexbor_str_t* html_str = lexbor_str_create()
 *         lxb_html_serialize_tree_str(self.node, html_str)
 *         cdef str py_text = html_str.data[:html_str.length].decode()             # <<<<<<<<<<<<<<
 *         lexbor_str_destroy(html_str, self.node.owner_document.text, True)
 *         return py_text
 */
  __pyx_t_2 = __Pyx_decode_c_string(((char const *)__pyx_v_html_str->data), 0, __pyx_v_html_str->length, NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_py_text = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":572
 *         lxb_html_serialize_tree_str(self.node, html_str)
 *         cdef str py_text = html_str.data[:html_str.length].decode()
 *         lexbor_str_destroy(html_str, self.node.owner_document.text, True)             # <<<<<<<<<<<<<<
 *         return py_text
 * 
 */
  (void)(lexbor_str_destroy(__pyx_v_html_str, __pyx_v_self->node->owner_document->text, 1));

  /* "resiliparse/parse/html.pyx":573
 *         cdef str py_text = html_str.data[:html_str.length].decode()
 *         lexbor_str_destroy(html_str, self.node.owner_document.text, True)
 *         return py_text             # <<<<<<<<<<<<<<
 * 
 *     @html.setter
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_py_text);
  __pyx_r = __pyx_v_py_text;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":558
 * 
 *     @property
 *     def html(self):             # <<<<<<<<<<<<<<
 *         """
 *         HTML contents of this DOM node and its children.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.html.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_py_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":576
 * 
 *     @html.setter
 *     def html(self, str html):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             raise RuntimeError('Trying to set HTML contents of uninitialized DOM node')
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4html_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_html); /*proto*/
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4html_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_html) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_html), (&PyUnicode_Type), 1, "html", 1))) __PYX_ERR(0, 576, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4html_2__set__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_html));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_4html_2__set__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_html) {
  PyObject *__pyx_v_html_bytes = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  lxb_char_t *__pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "resiliparse/parse/html.pyx":577
 *     @html.setter
 *     def html(self, str html):
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to set HTML contents of uninitialized DOM node')
 * 
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":578
 *     def html(self, str html):
 *         if not check_node(self):
 *             raise RuntimeError('Trying to set HTML contents of uninitialized DOM node')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes html_bytes = html.encode()
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 578, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 578, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":577
 *     @html.setter
 *     def html(self, str html):
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to set HTML contents of uninitialized DOM node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":580
 *             raise RuntimeError('Trying to set HTML contents of uninitialized DOM node')
 * 
 *         cdef bytes html_bytes = html.encode()             # <<<<<<<<<<<<<<
 *         lxb_html_element_inner_html_set(<lxb_html_element_t*>self.node, <lxb_char_t*>html_bytes, len(html_bytes))
 * 
 */
  if (unlikely(__pyx_v_html == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 580, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_html, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_html_bytes = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":581
 * 
 *         cdef bytes html_bytes = html.encode()
 *         lxb_html_element_inner_html_set(<lxb_html_element_t*>self.node, <lxb_char_t*>html_bytes, len(html_bytes))             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  if (unlikely(__pyx_v_html_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 581, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsWritableUString(__pyx_v_html_bytes); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 581, __pyx_L1_error)
  if (unlikely(__pyx_v_html_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 581, __pyx_L1_error)
  }
  __pyx_t_4 = PyBytes_GET_SIZE(__pyx_v_html_bytes); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 581, __pyx_L1_error)
  (void)(lxb_html_element_inner_html_set(((lxb_html_element_t *)__pyx_v_self->node), ((lxb_char_t *)__pyx_t_3), __pyx_t_4));

  /* "resiliparse/parse/html.pyx":576
 * 
 *     @html.setter
 *     def html(self, str html):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             raise RuntimeError('Trying to set HTML contents of uninitialized DOM node')
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.html.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_html_bytes);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":584
 * 
 *     @property
 *     def id(self):             # <<<<<<<<<<<<<<
 *         """
 *         ID attribute of this Element node (empty string if unset).
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_2id_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_2id_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_2id___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_2id___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  size_t __pyx_v_value_len;
  lxb_char_t const *__pyx_v_value;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":590
 *         :type: str
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":591
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t value_len = 0
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":590
 *         :type: str
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":593
 *             return None
 * 
 *         cdef size_t value_len = 0             # <<<<<<<<<<<<<<
 *         cdef const lxb_char_t* value = lxb_dom_element_id(<lxb_dom_element_t*>self.node, &value_len)
 *         if value == NULL:
 */
  __pyx_v_value_len = 0;

  /* "resiliparse/parse/html.pyx":594
 * 
 *         cdef size_t value_len = 0
 *         cdef const lxb_char_t* value = lxb_dom_element_id(<lxb_dom_element_t*>self.node, &value_len)             # <<<<<<<<<<<<<<
 *         if value == NULL:
 *             return ''
 */
  __pyx_v_value = lxb_dom_element_id(((lxb_dom_element_t *)__pyx_v_self->node), (&__pyx_v_value_len));

  /* "resiliparse/parse/html.pyx":595
 *         cdef size_t value_len = 0
 *         cdef const lxb_char_t* value = lxb_dom_element_id(<lxb_dom_element_t*>self.node, &value_len)
 *         if value == NULL:             # <<<<<<<<<<<<<<
 *             return ''
 *         return value[:value_len].decode()
 */
  __pyx_t_1 = ((__pyx_v_value == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":596
 *         cdef const lxb_char_t* value = lxb_dom_element_id(<lxb_dom_element_t*>self.node, &value_len)
 *         if value == NULL:
 *             return ''             # <<<<<<<<<<<<<<
 *         return value[:value_len].decode()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u__2);
    __pyx_r = __pyx_kp_u__2;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":595
 *         cdef size_t value_len = 0
 *         cdef const lxb_char_t* value = lxb_dom_element_id(<lxb_dom_element_t*>self.node, &value_len)
 *         if value == NULL:             # <<<<<<<<<<<<<<
 *             return ''
 *         return value[:value_len].decode()
 */
  }

  /* "resiliparse/parse/html.pyx":597
 *         if value == NULL:
 *             return ''
 *         return value[:value_len].decode()             # <<<<<<<<<<<<<<
 * 
 *     @id.setter
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_decode_c_string(((char const *)__pyx_v_value), 0, __pyx_v_value_len, NULL, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":584
 * 
 *     @property
 *     def id(self):             # <<<<<<<<<<<<<<
 *         """
 *         ID attribute of this Element node (empty string if unset).
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.id.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":600
 * 
 *     @id.setter
 *     def id(self, str class_name):             # <<<<<<<<<<<<<<
 *         self._setattr_impl(b'id', class_name.encode())
 * 
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_2id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name); /*proto*/
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_2id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_class_name), (&PyUnicode_Type), 1, "class_name", 1))) __PYX_ERR(0, 600, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_2id_2__set__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_class_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_2id_2__set__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_class_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "resiliparse/parse/html.pyx":601
 *     @id.setter
 *     def id(self, str class_name):
 *         self._setattr_impl(b'id', class_name.encode())             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  if (unlikely(__pyx_v_class_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 601, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_class_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->__pyx_vtab)->_setattr_impl(__pyx_v_self, __pyx_n_b_id, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":600
 * 
 *     @id.setter
 *     def id(self, str class_name):             # <<<<<<<<<<<<<<
 *         self._setattr_impl(b'id', class_name.encode())
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.id.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":604
 * 
 *     @property
 *     def class_name(self):             # <<<<<<<<<<<<<<
 *         """
 *         Class name attribute of this Element node (empty string if unset).
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_name___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_name___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  size_t __pyx_v_value_len;
  lxb_char_t const *__pyx_v_value;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":610
 *         :type: str
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":611
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t value_len = 0
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":610
 *         :type: str
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":613
 *             return None
 * 
 *         cdef size_t value_len = 0             # <<<<<<<<<<<<<<
 *         cdef const lxb_char_t* value = lxb_dom_element_class(<lxb_dom_element_t*>self.node, &value_len)
 *         if value == NULL:
 */
  __pyx_v_value_len = 0;

  /* "resiliparse/parse/html.pyx":614
 * 
 *         cdef size_t value_len = 0
 *         cdef const lxb_char_t* value = lxb_dom_element_class(<lxb_dom_element_t*>self.node, &value_len)             # <<<<<<<<<<<<<<
 *         if value == NULL:
 *             return ''
 */
  __pyx_v_value = lxb_dom_element_class(((lxb_dom_element_t *)__pyx_v_self->node), (&__pyx_v_value_len));

  /* "resiliparse/parse/html.pyx":615
 *         cdef size_t value_len = 0
 *         cdef const lxb_char_t* value = lxb_dom_element_class(<lxb_dom_element_t*>self.node, &value_len)
 *         if value == NULL:             # <<<<<<<<<<<<<<
 *             return ''
 *         return value[:value_len].decode()
 */
  __pyx_t_1 = ((__pyx_v_value == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":616
 *         cdef const lxb_char_t* value = lxb_dom_element_class(<lxb_dom_element_t*>self.node, &value_len)
 *         if value == NULL:
 *             return ''             # <<<<<<<<<<<<<<
 *         return value[:value_len].decode()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u__2);
    __pyx_r = __pyx_kp_u__2;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":615
 *         cdef size_t value_len = 0
 *         cdef const lxb_char_t* value = lxb_dom_element_class(<lxb_dom_element_t*>self.node, &value_len)
 *         if value == NULL:             # <<<<<<<<<<<<<<
 *             return ''
 *         return value[:value_len].decode()
 */
  }

  /* "resiliparse/parse/html.pyx":617
 *         if value == NULL:
 *             return ''
 *         return value[:value_len].decode()             # <<<<<<<<<<<<<<
 * 
 *     @class_name.setter
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_decode_c_string(((char const *)__pyx_v_value), 0, __pyx_v_value_len, NULL, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":604
 * 
 *     @property
 *     def class_name(self):             # <<<<<<<<<<<<<<
 *         """
 *         Class name attribute of this Element node (empty string if unset).
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.class_name.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":620
 * 
 *     @class_name.setter
 *     def class_name(self, str class_name):             # <<<<<<<<<<<<<<
 *         self._setattr_impl(b'class', class_name.encode())
 * 
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name); /*proto*/
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_class_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_class_name), (&PyUnicode_Type), 1, "class_name", 1))) __PYX_ERR(0, 620, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_name_2__set__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_class_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_name_2__set__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_class_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "resiliparse/parse/html.pyx":621
 *     @class_name.setter
 *     def class_name(self, str class_name):
 *         self._setattr_impl(b'class', class_name.encode())             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  if (unlikely(__pyx_v_class_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 621, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_class_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->__pyx_vtab)->_setattr_impl(__pyx_v_self, __pyx_n_b_class, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":620
 * 
 *     @class_name.setter
 *     def class_name(self, str class_name):             # <<<<<<<<<<<<<<
 *         self._setattr_impl(b'class', class_name.encode())
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.class_name.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":624
 * 
 *     @property
 *     def class_list(self):             # <<<<<<<<<<<<<<
 *         """
 *         List of class names set on this Element node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_list_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_list_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_list___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_10class_list___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":630
 *         :type: DOMElementClassList
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":631
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         if self.class_list_singleton is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":630
 *         :type: DOMElementClassList
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":633
 *             return None
 * 
 *         if self.class_list_singleton is None:             # <<<<<<<<<<<<<<
 *             # noinspection PyAttributeOutsideInit
 *             self.class_list_singleton = DOMElementClassList.__new__(DOMElementClassList, self)
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->class_list_singleton) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "resiliparse/parse/html.pyx":635
 *         if self.class_list_singleton is None:
 *             # noinspection PyAttributeOutsideInit
 *             self.class_list_singleton = DOMElementClassList.__new__(DOMElementClassList, self)             # <<<<<<<<<<<<<<
 *         return self.class_list_singleton
 * 
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self));
    __pyx_t_4 = ((PyObject *)__pyx_tp_new_11resiliparse_5parse_4html_DOMElementClassList(((PyTypeObject *)__pyx_ptype_11resiliparse_5parse_4html_DOMElementClassList), __pyx_t_3, NULL)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_GOTREF(((PyObject *)__pyx_t_4));
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GIVEREF(((PyObject *)__pyx_t_4));
    __Pyx_GOTREF(__pyx_v_self->class_list_singleton);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->class_list_singleton));
    __pyx_v_self->class_list_singleton = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "resiliparse/parse/html.pyx":633
 *             return None
 * 
 *         if self.class_list_singleton is None:             # <<<<<<<<<<<<<<
 *             # noinspection PyAttributeOutsideInit
 *             self.class_list_singleton = DOMElementClassList.__new__(DOMElementClassList, self)
 */
  }

  /* "resiliparse/parse/html.pyx":636
 *             # noinspection PyAttributeOutsideInit
 *             self.class_list_singleton = DOMElementClassList.__new__(DOMElementClassList, self)
 *         return self.class_list_singleton             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->class_list_singleton));
  __pyx_r = ((PyObject *)__pyx_v_self->class_list_singleton);
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":624
 * 
 *     @property
 *     def class_list(self):             # <<<<<<<<<<<<<<
 *         """
 *         List of class names set on this Element node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.class_list.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":639
 * 
 *     @property
 *     def attrs(self):             # <<<<<<<<<<<<<<
 *         """
 *         List of attribute names if node is an Element node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_5attrs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_5attrs_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_5attrs___get__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_5attrs___get__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  lxb_dom_attr_t *__pyx_v_attr;
  lxb_char_t const *__pyx_v_local_name;
  size_t __pyx_v_local_name_len;
  PyObject *__pyx_v_attrs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  lxb_dom_attr_t *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":645
 *         :type: t.List[str] or None
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":646
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_first_attribute(<lxb_dom_element_t*>self.node)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":645
 *         :type: t.List[str] or None
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":648
 *             return None
 * 
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_first_attribute(<lxb_dom_element_t*>self.node)             # <<<<<<<<<<<<<<
 *         cdef const lxb_char_t* local_name
 *         cdef size_t local_name_len = 0
 */
  __pyx_v_attr = lxb_dom_element_first_attribute(((lxb_dom_element_t *)__pyx_v_self->node));

  /* "resiliparse/parse/html.pyx":650
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_first_attribute(<lxb_dom_element_t*>self.node)
 *         cdef const lxb_char_t* local_name
 *         cdef size_t local_name_len = 0             # <<<<<<<<<<<<<<
 * 
 *         attrs = []
 */
  __pyx_v_local_name_len = 0;

  /* "resiliparse/parse/html.pyx":652
 *         cdef size_t local_name_len = 0
 * 
 *         attrs = []             # <<<<<<<<<<<<<<
 *         while attr != NULL:
 *             local_name = lxb_dom_attr_local_name(attr, &local_name_len)
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_attrs = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "resiliparse/parse/html.pyx":653
 * 
 *         attrs = []
 *         while attr != NULL:             # <<<<<<<<<<<<<<
 *             local_name = lxb_dom_attr_local_name(attr, &local_name_len)
 *             attrs.append(local_name[:local_name_len].decode())
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_attr != NULL) != 0);
    if (!__pyx_t_1) break;

    /* "resiliparse/parse/html.pyx":654
 *         attrs = []
 *         while attr != NULL:
 *             local_name = lxb_dom_attr_local_name(attr, &local_name_len)             # <<<<<<<<<<<<<<
 *             attrs.append(local_name[:local_name_len].decode())
 *             attr = attr.next
 */
    __pyx_v_local_name = lxb_dom_attr_local_name(__pyx_v_attr, (&__pyx_v_local_name_len));

    /* "resiliparse/parse/html.pyx":655
 *         while attr != NULL:
 *             local_name = lxb_dom_attr_local_name(attr, &local_name_len)
 *             attrs.append(local_name[:local_name_len].decode())             # <<<<<<<<<<<<<<
 *             attr = attr.next
 * 
 */
    __pyx_t_3 = __Pyx_decode_c_string(((char const *)__pyx_v_local_name), 0, __pyx_v_local_name_len, NULL, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_attrs, __pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "resiliparse/parse/html.pyx":656
 *             local_name = lxb_dom_attr_local_name(attr, &local_name_len)
 *             attrs.append(local_name[:local_name_len].decode())
 *             attr = attr.next             # <<<<<<<<<<<<<<
 * 
 *         return attrs
 */
    __pyx_t_5 = __pyx_v_attr->next;
    __pyx_v_attr = __pyx_t_5;
  }

  /* "resiliparse/parse/html.pyx":658
 *             attr = attr.next
 * 
 *         return attrs             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint hasattr(self, str attr_name):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_attrs);
  __pyx_r = __pyx_v_attrs;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":639
 * 
 *     @property
 *     def attrs(self):             # <<<<<<<<<<<<<<
 *         """
 *         List of attribute names if node is an Element node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.attrs.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attrs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":660
 *         return attrs
 * 
 *     cpdef bint hasattr(self, str attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         hasattr(self, attr_name)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_8hasattr(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name); /*proto*/
static int __pyx_f_11resiliparse_5parse_4html_7DOMNode_hasattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_attr_name_bytes = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  lxb_char_t *__pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hasattr", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_hasattr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_8hasattr)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_attr_name) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_attr_name);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 660, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 660, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":671
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node ist not an Element node.')
 * 
 */
  __pyx_t_6 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":672
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             raise ValueError('Node ist not an Element node.')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes attr_name_bytes = attr_name.encode()
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 672, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":671
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node ist not an Element node.')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":674
 *             raise ValueError('Node ist not an Element node.')
 * 
 *         cdef bytes attr_name_bytes = attr_name.encode()             # <<<<<<<<<<<<<<
 *         return <bint>lxb_dom_element_has_attribute(<lxb_dom_element_t*>self.node,
 *                                                    <lxb_char_t*>attr_name_bytes, len(attr_name_bytes))
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 674, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_attr_name_bytes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":676
 *         cdef bytes attr_name_bytes = attr_name.encode()
 *         return <bint>lxb_dom_element_has_attribute(<lxb_dom_element_t*>self.node,
 *                                                    <lxb_char_t*>attr_name_bytes, len(attr_name_bytes))             # <<<<<<<<<<<<<<
 * 
 *     cdef str _getattr_impl(self, bytes attr_name):
 */
  if (unlikely(__pyx_v_attr_name_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 676, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_name_bytes); if (unlikely((!__pyx_t_7) && PyErr_Occurred())) __PYX_ERR(0, 676, __pyx_L1_error)
  if (unlikely(__pyx_v_attr_name_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 676, __pyx_L1_error)
  }
  __pyx_t_8 = PyBytes_GET_SIZE(__pyx_v_attr_name_bytes); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 676, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":675
 * 
 *         cdef bytes attr_name_bytes = attr_name.encode()
 *         return <bint>lxb_dom_element_has_attribute(<lxb_dom_element_t*>self.node,             # <<<<<<<<<<<<<<
 *                                                    <lxb_char_t*>attr_name_bytes, len(attr_name_bytes))
 * 
 */
  __pyx_r = (lxb_dom_element_has_attribute(((lxb_dom_element_t *)__pyx_v_self->node), ((lxb_char_t *)__pyx_t_7), __pyx_t_8) != 0);
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":660
 *         return attrs
 * 
 *     cpdef bint hasattr(self, str attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         hasattr(self, attr_name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMNode.hasattr", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attr_name_bytes);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_8hasattr(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_7hasattr[] = "\n        hasattr(self, attr_name)\n        \n        Check if node has an attribute with the given name.\n\n        :param attr_name: attribute name\n        :type attr_name: str\n        :rtype: bool\n        :raises ValueError: if node is not an Element node\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_8hasattr(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hasattr (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 660, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_7hasattr(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_attr_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_7hasattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hasattr", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_11resiliparse_5parse_4html_7DOMNode_hasattr(__pyx_v_self, __pyx_v_attr_name, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.hasattr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":678
 *                                                    <lxb_char_t*>attr_name_bytes, len(attr_name_bytes))
 * 
 *     cdef str _getattr_impl(self, bytes attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         Get an attribute value as string.
 */

static PyObject *__pyx_f_11resiliparse_5parse_4html_7DOMNode__getattr_impl(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  size_t __pyx_v_value_len;
  lxb_char_t const *__pyx_v_value;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  lxb_char_t *__pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_getattr_impl", 0);

  /* "resiliparse/parse/html.pyx":685
 *         :return: attribute value or None
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node ist not an Element node.')
 * 
 */
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":686
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             raise ValueError('Node ist not an Element node.')             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t value_len = 0
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 686, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":685
 *         :return: attribute value or None
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node ist not an Element node.')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":688
 *             raise ValueError('Node ist not an Element node.')
 * 
 *         cdef size_t value_len = 0             # <<<<<<<<<<<<<<
 *         cdef const lxb_char_t* value = lxb_dom_element_get_attribute(<lxb_dom_element_t*>self.node,
 *                                                                      <lxb_char_t*>attr_name, len(attr_name),
 */
  __pyx_v_value_len = 0;

  /* "resiliparse/parse/html.pyx":690
 *         cdef size_t value_len = 0
 *         cdef const lxb_char_t* value = lxb_dom_element_get_attribute(<lxb_dom_element_t*>self.node,
 *                                                                      <lxb_char_t*>attr_name, len(attr_name),             # <<<<<<<<<<<<<<
 *                                                                      &value_len)
 *         if value == NULL:
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 690, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_name); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 690, __pyx_L1_error)
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 690, __pyx_L1_error)
  }
  __pyx_t_5 = PyBytes_GET_SIZE(__pyx_v_attr_name); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 690, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":689
 * 
 *         cdef size_t value_len = 0
 *         cdef const lxb_char_t* value = lxb_dom_element_get_attribute(<lxb_dom_element_t*>self.node,             # <<<<<<<<<<<<<<
 *                                                                      <lxb_char_t*>attr_name, len(attr_name),
 *                                                                      &value_len)
 */
  __pyx_v_value = lxb_dom_element_get_attribute(((lxb_dom_element_t *)__pyx_v_self->node), ((lxb_char_t *)__pyx_t_4), __pyx_t_5, (&__pyx_v_value_len));

  /* "resiliparse/parse/html.pyx":692
 *                                                                      <lxb_char_t*>attr_name, len(attr_name),
 *                                                                      &value_len)
 *         if value == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return value[:value_len].decode()
 */
  __pyx_t_1 = ((__pyx_v_value == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":693
 *                                                                      &value_len)
 *         if value == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         return value[:value_len].decode()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":692
 *                                                                      <lxb_char_t*>attr_name, len(attr_name),
 *                                                                      &value_len)
 *         if value == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return value[:value_len].decode()
 */
  }

  /* "resiliparse/parse/html.pyx":694
 *         if value == NULL:
 *             return None
 *         return value[:value_len].decode()             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getattr(self, str attr_name, str default_value=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_decode_c_string(((char const *)__pyx_v_value), 0, __pyx_v_value_len, NULL, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":678
 *                                                    <lxb_char_t*>attr_name_bytes, len(attr_name_bytes))
 * 
 *     cdef str _getattr_impl(self, bytes attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         Get an attribute value as string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode._getattr_impl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":696
 *         return value[:value_len].decode()
 * 
 *     cpdef str getattr(self, str attr_name, str default_value=None):             # <<<<<<<<<<<<<<
 *         """
 *         getattr(self, attr_name, default_value=None)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10getattr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_11resiliparse_5parse_4html_7DOMNode_getattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_getattr *__pyx_optional_args) {
  PyObject *__pyx_v_default_value = ((PyObject*)Py_None);
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getattr", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_default_value = __pyx_optional_args->default_value;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getattr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10getattr)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_attr_name, __pyx_v_default_value};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_attr_name, __pyx_v_default_value};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 696, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(__pyx_v_attr_name);
          __Pyx_GIVEREF(__pyx_v_attr_name);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_attr_name);
          __Pyx_INCREF(__pyx_v_default_value);
          __Pyx_GIVEREF(__pyx_v_default_value);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_default_value);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 696, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":710
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_7 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_7) {

    /* "resiliparse/parse/html.pyx":711
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef str value = self._getattr_impl(attr_name.encode())
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":710
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":713
 *             return None
 * 
 *         cdef str value = self._getattr_impl(attr_name.encode())             # <<<<<<<<<<<<<<
 *         if value is None:
 *             return default_value
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 713, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->__pyx_vtab)->_getattr_impl(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_value = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":714
 * 
 *         cdef str value = self._getattr_impl(attr_name.encode())
 *         if value is None:             # <<<<<<<<<<<<<<
 *             return default_value
 *         return value
 */
  __pyx_t_7 = (__pyx_v_value == ((PyObject*)Py_None));
  __pyx_t_8 = (__pyx_t_7 != 0);
  if (__pyx_t_8) {

    /* "resiliparse/parse/html.pyx":715
 *         cdef str value = self._getattr_impl(attr_name.encode())
 *         if value is None:
 *             return default_value             # <<<<<<<<<<<<<<
 *         return value
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_default_value);
    __pyx_r = __pyx_v_default_value;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":714
 * 
 *         cdef str value = self._getattr_impl(attr_name.encode())
 *         if value is None:             # <<<<<<<<<<<<<<
 *             return default_value
 *         return value
 */
  }

  /* "resiliparse/parse/html.pyx":716
 *         if value is None:
 *             return default_value
 *         return value             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, str attr_name):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_value);
  __pyx_r = __pyx_v_value;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":696
 *         return value[:value_len].decode()
 * 
 *     cpdef str getattr(self, str attr_name, str default_value=None):             # <<<<<<<<<<<<<<
 *         """
 *         getattr(self, attr_name, default_value=None)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.getattr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10getattr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_9getattr[] = "\n        getattr(self, attr_name, default_value=None)\n\n        Get the value of the attribute ``attr_name`` or ``default_value`` if the element has no such attribute.\n\n        :param attr_name: attribute name\n        :type attr_name: str\n        :param default_value: default value to return if attribute is unset\n        :type default_value: str\n        :return: attribute value\n        :rtype: str\n        :raises ValueError: if node is not an Element node\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10getattr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_attr_name = 0;
  PyObject *__pyx_v_default_value = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getattr (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_attr_name,&__pyx_n_s_default_value,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject*)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_attr_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_default_value);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "getattr") < 0)) __PYX_ERR(0, 696, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_attr_name = ((PyObject*)values[0]);
    __pyx_v_default_value = ((PyObject*)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getattr", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 696, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.getattr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 696, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_default_value), (&PyUnicode_Type), 1, "default_value", 1))) __PYX_ERR(0, 696, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_9getattr(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), __pyx_v_attr_name, __pyx_v_default_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_9getattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_default_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_getattr __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getattr", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.default_value = __pyx_v_default_value;
  __pyx_t_1 = __pyx_vtabptr_11resiliparse_5parse_4html_DOMNode->getattr(__pyx_v_self, __pyx_v_attr_name, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.getattr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":718
 *         return value
 * 
 *     def __getitem__(self, str attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         __getitem__(self, attr_name)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_12__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_11__getitem__[] = "\n        __getitem__(self, attr_name)\n\n        Get the value of the an attribute.\n\n        :param attr_name: attribute name\n        :rtype: str\n        :raises KeyError: if no such attribute exists\n        :raises ValueError: if node is not an Element node\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_11__getitem__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_12__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 718, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_11__getitem__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_attr_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_11__getitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "resiliparse/parse/html.pyx":729
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":730
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef str value = self._getattr_impl(attr_name.encode())
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":729
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":732
 *             return None
 * 
 *         cdef str value = self._getattr_impl(attr_name.encode())             # <<<<<<<<<<<<<<
 *         if value is None:
 *             raise KeyError(f'No such attribute: {attr_name}')
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 732, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->__pyx_vtab)->_getattr_impl(__pyx_v_self, ((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_value = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "resiliparse/parse/html.pyx":733
 * 
 *         cdef str value = self._getattr_impl(attr_name.encode())
 *         if value is None:             # <<<<<<<<<<<<<<
 *             raise KeyError(f'No such attribute: {attr_name}')
 *         return value
 */
  __pyx_t_1 = (__pyx_v_value == ((PyObject*)Py_None));
  __pyx_t_4 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_4)) {

    /* "resiliparse/parse/html.pyx":734
 *         cdef str value = self._getattr_impl(attr_name.encode())
 *         if value is None:
 *             raise KeyError(f'No such attribute: {attr_name}')             # <<<<<<<<<<<<<<
 *         return value
 * 
 */
    __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_attr_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_No_such_attribute, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 734, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":733
 * 
 *         cdef str value = self._getattr_impl(attr_name.encode())
 *         if value is None:             # <<<<<<<<<<<<<<
 *             raise KeyError(f'No such attribute: {attr_name}')
 *         return value
 */
  }

  /* "resiliparse/parse/html.pyx":735
 *         if value is None:
 *             raise KeyError(f'No such attribute: {attr_name}')
 *         return value             # <<<<<<<<<<<<<<
 * 
 *     cdef bint _setattr_impl(self, bytes attr_name, bytes attr_value) except -1:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_value);
  __pyx_r = __pyx_v_value;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":718
 *         return value
 * 
 *     def __getitem__(self, str attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         __getitem__(self, attr_name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":737
 *         return value
 * 
 *     cdef bint _setattr_impl(self, bytes attr_name, bytes attr_value) except -1:             # <<<<<<<<<<<<<<
 *         """
 *         Insert or update an attribute with the given value.
 */

static int __pyx_f_11resiliparse_5parse_4html_7DOMNode__setattr_impl(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value) {
  lxb_dom_attr_t *__pyx_v_attr;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  lxb_char_t *__pyx_t_4;
  Py_ssize_t __pyx_t_5;
  lxb_char_t *__pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_setattr_impl", 0);

  /* "resiliparse/parse/html.pyx":745
 *         :return: attribute value or None
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node ist not an Element node.')
 * 
 */
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":746
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             raise ValueError('Node ist not an Element node.')             # <<<<<<<<<<<<<<
 * 
 *         # Lexbor's check of existing attributes is buggy
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 746, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":745
 *         :return: attribute value or None
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node ist not an Element node.')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":750
 *         # Lexbor's check of existing attributes is buggy
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_attr_is_exist(<lxb_dom_element_t*>self.node,
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))             # <<<<<<<<<<<<<<
 * 
 *         if attr != NULL:
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 750, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_name); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 750, __pyx_L1_error)
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 750, __pyx_L1_error)
  }
  __pyx_t_5 = PyBytes_GET_SIZE(__pyx_v_attr_name); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 750, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":749
 * 
 *         # Lexbor's check of existing attributes is buggy
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_attr_is_exist(<lxb_dom_element_t*>self.node,             # <<<<<<<<<<<<<<
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))
 * 
 */
  __pyx_v_attr = lxb_dom_element_attr_is_exist(((lxb_dom_element_t *)__pyx_v_self->node), ((lxb_char_t *)__pyx_t_4), __pyx_t_5);

  /* "resiliparse/parse/html.pyx":752
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))
 * 
 *         if attr != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_attr_set_value(attr, <lxb_char_t*>attr_value, len(attr_value))
 *             return True
 */
  __pyx_t_1 = ((__pyx_v_attr != NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":753
 * 
 *         if attr != NULL:
 *             lxb_dom_attr_set_value(attr, <lxb_char_t*>attr_value, len(attr_value))             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
    if (unlikely(__pyx_v_attr_value == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 753, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_value); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 753, __pyx_L1_error)
    if (unlikely(__pyx_v_attr_value == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 753, __pyx_L1_error)
    }
    __pyx_t_5 = PyBytes_GET_SIZE(__pyx_v_attr_value); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 753, __pyx_L1_error)
    (void)(lxb_dom_attr_set_value(__pyx_v_attr, ((lxb_char_t *)__pyx_t_4), __pyx_t_5));

    /* "resiliparse/parse/html.pyx":754
 *         if attr != NULL:
 *             lxb_dom_attr_set_value(attr, <lxb_char_t*>attr_value, len(attr_value))
 *             return True             # <<<<<<<<<<<<<<
 * 
 *         lxb_dom_element_set_attribute(<lxb_dom_element_t*>self.node,
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":752
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))
 * 
 *         if attr != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_attr_set_value(attr, <lxb_char_t*>attr_value, len(attr_value))
 *             return True
 */
  }

  /* "resiliparse/parse/html.pyx":757
 * 
 *         lxb_dom_element_set_attribute(<lxb_dom_element_t*>self.node,
 *                                       <lxb_char_t*>attr_name, len(attr_name),             # <<<<<<<<<<<<<<
 *                                       <lxb_char_t*>attr_value, len(attr_value))
 *         return True
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 757, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_name); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 757, __pyx_L1_error)
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 757, __pyx_L1_error)
  }
  __pyx_t_5 = PyBytes_GET_SIZE(__pyx_v_attr_name); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 757, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":758
 *         lxb_dom_element_set_attribute(<lxb_dom_element_t*>self.node,
 *                                       <lxb_char_t*>attr_name, len(attr_name),
 *                                       <lxb_char_t*>attr_value, len(attr_value))             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
  if (unlikely(__pyx_v_attr_value == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 758, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_value); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 758, __pyx_L1_error)
  if (unlikely(__pyx_v_attr_value == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 758, __pyx_L1_error)
  }
  __pyx_t_7 = PyBytes_GET_SIZE(__pyx_v_attr_value); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 758, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":756
 *             return True
 * 
 *         lxb_dom_element_set_attribute(<lxb_dom_element_t*>self.node,             # <<<<<<<<<<<<<<
 *                                       <lxb_char_t*>attr_name, len(attr_name),
 *                                       <lxb_char_t*>attr_value, len(attr_value))
 */
  (void)(lxb_dom_element_set_attribute(((lxb_dom_element_t *)__pyx_v_self->node), ((lxb_char_t *)__pyx_t_4), __pyx_t_5, ((lxb_char_t *)__pyx_t_6), __pyx_t_7));

  /* "resiliparse/parse/html.pyx":759
 *                                       <lxb_char_t*>attr_name, len(attr_name),
 *                                       <lxb_char_t*>attr_value, len(attr_value))
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     cpdef void setattr(self, str attr_name, str attr_value):
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":737
 *         return value
 * 
 *     cdef bint _setattr_impl(self, bytes attr_name, bytes attr_value) except -1:             # <<<<<<<<<<<<<<
 *         """
 *         Insert or update an attribute with the given value.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode._setattr_impl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":761
 *         return True
 * 
 *     cpdef void setattr(self, str attr_name, str attr_value):             # <<<<<<<<<<<<<<
 *         """
 *         setattr(self, attr_name, attr_value)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_14setattr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static void __pyx_f_11resiliparse_5parse_4html_7DOMNode_setattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_skip_dispatch) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setattr", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setattr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_14setattr)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_attr_name, __pyx_v_attr_value};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 761, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_attr_name, __pyx_v_attr_value};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 761, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 761, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(__pyx_v_attr_name);
          __Pyx_GIVEREF(__pyx_v_attr_name);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_attr_name);
          __Pyx_INCREF(__pyx_v_attr_value);
          __Pyx_GIVEREF(__pyx_v_attr_value);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_attr_value);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 761, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":774
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_7 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_7) {

    /* "resiliparse/parse/html.pyx":775
 *         """
 *         if not check_node(self):
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._setattr_impl(attr_name.encode(), attr_value.encode())
 */
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":774
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":777
 *             return
 * 
 *         self._setattr_impl(attr_name.encode(), attr_value.encode())             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(self, str attr_name, str attr_value):
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 777, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_v_attr_value == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 777, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_attr_value, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->__pyx_vtab)->_setattr_impl(__pyx_v_self, ((PyObject*)__pyx_t_1), ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":761
 *         return True
 * 
 *     cpdef void setattr(self, str attr_name, str attr_value):             # <<<<<<<<<<<<<<
 *         """
 *         setattr(self, attr_name, attr_value)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMNode.setattr", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_14setattr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_13setattr[] = "\n        setattr(self, attr_name, attr_value)\n        \n        Insert or update an attribute with the given name to the given value.\n\n        :param attr_name: attribute name\n        :type attr_name: str\n        :param attr_value: attribute value\n        :type attr_value: str\n        :return: attribute value\n        :raises ValueError: if node is not an Element node\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_14setattr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_attr_name = 0;
  PyObject *__pyx_v_attr_value = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setattr (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_attr_name,&__pyx_n_s_attr_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_attr_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_attr_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setattr", 1, 2, 2, 1); __PYX_ERR(0, 761, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setattr") < 0)) __PYX_ERR(0, 761, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_attr_name = ((PyObject*)values[0]);
    __pyx_v_attr_value = ((PyObject*)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setattr", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 761, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.setattr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 761, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_value), (&PyUnicode_Type), 1, "attr_value", 1))) __PYX_ERR(0, 761, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_13setattr(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), __pyx_v_attr_name, __pyx_v_attr_value);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_13setattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setattr", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_void_to_None(__pyx_f_11resiliparse_5parse_4html_7DOMNode_setattr(__pyx_v_self, __pyx_v_attr_name, __pyx_v_attr_value, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.setattr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":779
 *         self._setattr_impl(attr_name.encode(), attr_value.encode())
 * 
 *     def __setitem__(self, str attr_name, str attr_value):             # <<<<<<<<<<<<<<
 *         """
 *         __setitem__(self, attr_name, attr_value)
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_16__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_15__setitem__[] = "\n        __setitem__(self, attr_name, attr_value)\n\n        Insert or update an attribute with the given name to the given value.\n\n        :param attr_name: attribute name\n        :type attr_name: str\n        :param attr_value: attribute value\n        :type attr_value: str\n        :return: attribute value\n        :raises ValueError: if node is not an Element node\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_15__setitem__;
#endif
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_16__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 779, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_value), (&PyUnicode_Type), 1, "attr_value", 1))) __PYX_ERR(0, 779, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_15__setitem__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_attr_name), ((PyObject*)__pyx_v_attr_value));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_15__setitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "resiliparse/parse/html.pyx":792
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":793
 *         """
 *         if not check_node(self):
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._setattr_impl(attr_name.encode(), attr_value.encode())
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":792
 *         :raises ValueError: if node is not an Element node
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":795
 *             return
 * 
 *         self._setattr_impl(attr_name.encode(), attr_value.encode())             # <<<<<<<<<<<<<<
 * 
 *     cdef bint _delattr_impl(self, bytes attr_name) except -1:
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 795, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_v_attr_value == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 795, __pyx_L1_error)
  }
  __pyx_t_3 = PyUnicode_AsEncodedString(__pyx_v_attr_value, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->__pyx_vtab)->_setattr_impl(__pyx_v_self, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 795, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "resiliparse/parse/html.pyx":779
 *         self._setattr_impl(attr_name.encode(), attr_value.encode())
 * 
 *     def __setitem__(self, str attr_name, str attr_value):             # <<<<<<<<<<<<<<
 *         """
 *         __setitem__(self, attr_name, attr_value)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":797
 *         self._setattr_impl(attr_name.encode(), attr_value.encode())
 * 
 *     cdef bint _delattr_impl(self, bytes attr_name) except -1:             # <<<<<<<<<<<<<<
 *         """
 *         Remove the given attribute.
 */

static int __pyx_f_11resiliparse_5parse_4html_7DOMNode__delattr_impl(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  lxb_dom_attr_t *__pyx_v_attr;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  lxb_char_t *__pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_delattr_impl", 0);

  /* "resiliparse/parse/html.pyx":803
 *         :param attr_name: attribute to remove
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node ist not an Element node.')
 * 
 */
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_self->node->type != LXB_DOM_NODE_TYPE_ELEMENT) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":804
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             raise ValueError('Node ist not an Element node.')             # <<<<<<<<<<<<<<
 * 
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_attr_is_exist(<lxb_dom_element_t*>self.node,
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 804, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":803
 *         :param attr_name: attribute to remove
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node ist not an Element node.')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":807
 * 
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_attr_is_exist(<lxb_dom_element_t*>self.node,
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))             # <<<<<<<<<<<<<<
 *         if attr == NULL:
 *             return False
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 807, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_AsWritableUString(__pyx_v_attr_name); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 807, __pyx_L1_error)
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 807, __pyx_L1_error)
  }
  __pyx_t_5 = PyBytes_GET_SIZE(__pyx_v_attr_name); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 807, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":806
 *             raise ValueError('Node ist not an Element node.')
 * 
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_attr_is_exist(<lxb_dom_element_t*>self.node,             # <<<<<<<<<<<<<<
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))
 *         if attr == NULL:
 */
  __pyx_v_attr = lxb_dom_element_attr_is_exist(((lxb_dom_element_t *)__pyx_v_self->node), ((lxb_char_t *)__pyx_t_4), __pyx_t_5);

  /* "resiliparse/parse/html.pyx":808
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_attr_is_exist(<lxb_dom_element_t*>self.node,
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))
 *         if attr == NULL:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_1 = ((__pyx_v_attr == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":809
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))
 *         if attr == NULL:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         lxb_dom_element_attr_remove(<lxb_dom_element_t*>self.node, attr)
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":808
 *         cdef lxb_dom_attr_t* attr = lxb_dom_element_attr_is_exist(<lxb_dom_element_t*>self.node,
 *                                                                   <lxb_char_t*>attr_name, len(attr_name))
 *         if attr == NULL:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":811
 *             return False
 * 
 *         lxb_dom_element_attr_remove(<lxb_dom_element_t*>self.node, attr)             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
  (void)(lxb_dom_element_attr_remove(((lxb_dom_element_t *)__pyx_v_self->node), __pyx_v_attr));

  /* "resiliparse/parse/html.pyx":812
 * 
 *         lxb_dom_element_attr_remove(<lxb_dom_element_t*>self.node, attr)
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     cpdef void delattr(self, str attr_name):
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":797
 *         self._setattr_impl(attr_name.encode(), attr_value.encode())
 * 
 *     cdef bint _delattr_impl(self, bytes attr_name) except -1:             # <<<<<<<<<<<<<<
 *         """
 *         Remove the given attribute.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode._delattr_impl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":814
 *         return True
 * 
 *     cpdef void delattr(self, str attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         delattr(self, attr_name)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_18delattr(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name); /*proto*/
static void __pyx_f_11resiliparse_5parse_4html_7DOMNode_delattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, int __pyx_skip_dispatch) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delattr", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delattr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 814, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_18delattr)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_attr_name) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_attr_name);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 814, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":824
 *         :raises ValueError: if node is not an Element node
 *         """
 *         self._delattr_impl(attr_name.encode())             # <<<<<<<<<<<<<<
 * 
 *     def __delitem__(self, str attr_name):
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 824, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->__pyx_vtab)->_delattr_impl(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":814
 *         return True
 * 
 *     cpdef void delattr(self, str attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         delattr(self, attr_name)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMNode.delattr", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_18delattr(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_17delattr[] = "\n        delattr(self, attr_name)\n        \n        Remove the given attribute if it exists.\n\n        :param attr_name: attribute to remove\n        :type attr_name: str\n        :raises ValueError: if node is not an Element node\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_18delattr(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delattr (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 814, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_17delattr(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_attr_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_17delattr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delattr", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_void_to_None(__pyx_f_11resiliparse_5parse_4html_7DOMNode_delattr(__pyx_v_self, __pyx_v_attr_name, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.delattr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":826
 *         self._delattr_impl(attr_name.encode())
 * 
 *     def __delitem__(self, str attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         __delitem__(self, attr_name)
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_20__delitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_19__delitem__[] = "\n        __delitem__(self, attr_name)\n\n        Remove the given attribute.\n\n        :param attr_name: attribute to remove\n        :type attr_name: str\n        :raises ValueError: if node is not an Element node\n        :raises KeyError: if node \n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_19__delitem__;
#endif
static int __pyx_pw_11resiliparse_5parse_4html_7DOMNode_20__delitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__delitem__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 826, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_19__delitem__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_attr_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_7DOMNode_19__delitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name) {
  int __pyx_v_ret;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__delitem__", 0);

  /* "resiliparse/parse/html.pyx":837
 *         :raises KeyError: if node
 *         """
 *         cdef bint ret = self._delattr_impl(attr_name.encode())             # <<<<<<<<<<<<<<
 *         if not ret:
 *             raise KeyError(f'No such attribute: {attr_name}')
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 837, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self->__pyx_vtab)->_delattr_impl(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_ret = __pyx_t_2;

  /* "resiliparse/parse/html.pyx":838
 *         """
 *         cdef bint ret = self._delattr_impl(attr_name.encode())
 *         if not ret:             # <<<<<<<<<<<<<<
 *             raise KeyError(f'No such attribute: {attr_name}')
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_ret != 0)) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "resiliparse/parse/html.pyx":839
 *         cdef bint ret = self._delattr_impl(attr_name.encode())
 *         if not ret:
 *             raise KeyError(f'No such attribute: {attr_name}')             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode query_selector(self, str selector):
 */
    __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_attr_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_No_such_attribute, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 839, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":838
 *         """
 *         cdef bint ret = self._delattr_impl(attr_name.encode())
 *         if not ret:             # <<<<<<<<<<<<<<
 *             raise KeyError(f'No such attribute: {attr_name}')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":826
 *         self._delattr_impl(attr_name.encode())
 * 
 *     def __delitem__(self, str attr_name):             # <<<<<<<<<<<<<<
 *         """
 *         __delitem__(self, attr_name)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__delitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":841
 *             raise KeyError(f'No such attribute: {attr_name}')
 * 
 *     cpdef DOMNode query_selector(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         query_selector(self, selector)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_22query_selector(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_query_selector(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch) {
  lxb_dom_node_t *__pyx_v_node;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_query_selector); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 841, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_22query_selector)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_selector) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_selector);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 841, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 841, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":853
 *         :rtype: DOMNode or None
 *         """
 *         cdef lxb_dom_node_t* node = query_selector_impl(self.node, self.tree, selector.encode())             # <<<<<<<<<<<<<<
 *         if node == NULL:
 *             return None
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 853, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_selector, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_node = __pyx_f_11resiliparse_5parse_4html_query_selector_impl(__pyx_v_self->node, ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), ((PyObject*)__pyx_t_2));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":854
 *         """
 *         cdef lxb_dom_node_t* node = query_selector_impl(self.node, self.tree, selector.encode())
 *         if node == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, node)
 */
  __pyx_t_5 = ((__pyx_v_node == NULL) != 0);
  if (__pyx_t_5) {

    /* "resiliparse/parse/html.pyx":855
 *         cdef lxb_dom_node_t* node = query_selector_impl(self.node, self.tree, selector.encode())
 *         if node == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self.tree, node)
 * 
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":854
 *         """
 *         cdef lxb_dom_node_t* node = query_selector_impl(self.node, self.tree, selector.encode())
 *         if node == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, node)
 */
  }

  /* "resiliparse/parse/html.pyx":856
 *         if node == NULL:
 *             return None
 *         return _create_dom_node(self.tree, node)             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMCollection query_selector_all(self, str selector):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_2 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_2), __pyx_v_node)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":841
 *             raise KeyError(f'No such attribute: {attr_name}')
 * 
 *     cpdef DOMNode query_selector(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         query_selector(self, selector)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.query_selector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_22query_selector(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_21query_selector[] = "\n        query_selector(self, selector)\n         \n        Find and return the first element matching the given CSS selector. This is more efficient\n        than matching with :meth:`query_selector_all` and discarding additional elements.\n\n        :param selector: CSS selector\n        :type selector: str\n        :return: matching element or ``None``\n        :rtype: DOMNode or None\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_22query_selector(PyObject *__pyx_v_self, PyObject *__pyx_v_selector) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_selector (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_selector), (&PyUnicode_Type), 1, "selector", 1))) __PYX_ERR(0, 841, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_21query_selector(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_selector));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_21query_selector(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_7DOMNode_query_selector(__pyx_v_self, __pyx_v_selector, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.query_selector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":858
 *         return _create_dom_node(self.tree, node)
 * 
 *     cpdef DOMCollection query_selector_all(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         query_selector_all(self, selector)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_24query_selector_all(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_7DOMNode_query_selector_all(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch) {
  lxb_dom_collection_t *__pyx_v_coll;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector_all", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_query_selector_all); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 858, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_24query_selector_all)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_selector) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_selector);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 858, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMCollection))))) __PYX_ERR(0, 858, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":869
 *         :rtype: DOMCollection
 *         """
 *         cdef lxb_dom_collection_t* coll = query_selector_all_impl(self.node, self.tree, selector.encode())             # <<<<<<<<<<<<<<
 *         if coll == NULL:
 *             raise RuntimeError('Failed to match elements by CSS selector')
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 869, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_selector, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_coll = __pyx_f_11resiliparse_5parse_4html_query_selector_all_impl(__pyx_v_self->node, ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), ((PyObject*)__pyx_t_2), NULL);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "resiliparse/parse/html.pyx":870
 *         """
 *         cdef lxb_dom_collection_t* coll = query_selector_all_impl(self.node, self.tree, selector.encode())
 *         if coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Failed to match elements by CSS selector')
 * 
 */
  __pyx_t_5 = ((__pyx_v_coll == NULL) != 0);
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":871
 *         cdef lxb_dom_collection_t* coll = query_selector_all_impl(self.node, self.tree, selector.encode())
 *         if coll == NULL:
 *             raise RuntimeError('Failed to match elements by CSS selector')             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_collection(self.tree, coll)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 871, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":870
 *         """
 *         cdef lxb_dom_collection_t* coll = query_selector_all_impl(self.node, self.tree, selector.encode())
 *         if coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Failed to match elements by CSS selector')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":873
 *             raise RuntimeError('Failed to match elements by CSS selector')
 * 
 *         return _create_dom_collection(self.tree, coll)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint matches(self, str selector):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_2 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_collection(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_2), __pyx_v_coll)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":858
 *         return _create_dom_node(self.tree, node)
 * 
 *     cpdef DOMCollection query_selector_all(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         query_selector_all(self, selector)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.query_selector_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_24query_selector_all(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_23query_selector_all[] = "\n        query_selector_all(self, selector)\n        \n        Find all elements matching the given CSS selector and return a :class:`DOMCollection` with the results.\n\n        :param selector: CSS selector\n        :type selector: str\n        :return: collection of matching elements\n        :rtype: DOMCollection\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_24query_selector_all(PyObject *__pyx_v_self, PyObject *__pyx_v_selector) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_selector_all (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_selector), (&PyUnicode_Type), 1, "selector", 1))) __PYX_ERR(0, 858, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_23query_selector_all(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_selector));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_23query_selector_all(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector_all", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_7DOMNode_query_selector_all(__pyx_v_self, __pyx_v_selector, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.query_selector_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":875
 *         return _create_dom_collection(self.tree, coll)
 * 
 *     cpdef bint matches(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         matches(self, selector)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_26matches(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static int __pyx_f_11resiliparse_5parse_4html_7DOMNode_matches(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matches", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_matches); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 875, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_26matches)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_selector) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_selector);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 875, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 875, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":887
 *         :rtype: bool
 *         """
 *         self.tree.init_css_parser()             # <<<<<<<<<<<<<<
 *         return matches_impl(self.node, self.tree, selector.encode())
 * 
 */
  ((struct __pyx_vtabstruct_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self->tree->__pyx_vtab)->init_css_parser(__pyx_v_self->tree);

  /* "resiliparse/parse/html.pyx":888
 *         """
 *         self.tree.init_css_parser()
 *         return matches_impl(self.node, self.tree, selector.encode())             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=False):
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 888, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_selector, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_f_11resiliparse_5parse_4html_matches_impl(__pyx_v_self->node, ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), ((PyObject*)__pyx_t_2));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":875
 *         return _create_dom_collection(self.tree, coll)
 * 
 *     cpdef bint matches(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         matches(self, selector)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMNode.matches", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_26matches(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_25matches[] = "\n        matches(self, selector)\n        \n        Check whether any element in the DOM tree matches the given CSS selector. This is more efficient\n        than matching with :meth:`query_selector_all` and checking the size of the returned collection.\n\n        :param selector: CSS selector\n        :type selector: str\n        :return: boolean value indicating whether a matching element exists\n        :rtype: bool\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_26matches(PyObject *__pyx_v_self, PyObject *__pyx_v_selector) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matches (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_selector), (&PyUnicode_Type), 1, "selector", 1))) __PYX_ERR(0, 875, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_25matches(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_selector));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_25matches(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_selector) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matches", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_11resiliparse_5parse_4html_7DOMNode_matches(__pyx_v_self, __pyx_v_selector, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.matches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":890
 *         return matches_impl(self.node, self.tree, selector.encode())
 * 
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_attr(self, attr_name, attr_value, case_insensitive=False)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_28get_elements_by_attr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr *__pyx_optional_args) {
  int __pyx_v_case_insensitive = ((int)0);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  lxb_dom_collection_t *__pyx_t_9;
  struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_attr_impl __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_attr", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_case_insensitive = __pyx_optional_args->case_insensitive;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_elements_by_attr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_28get_elements_by_attr)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_case_insensitive); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 890, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_attr_name, __pyx_v_attr_value, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 890, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_attr_name, __pyx_v_attr_value, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 890, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 890, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_attr_name);
          __Pyx_GIVEREF(__pyx_v_attr_name);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_attr_name);
          __Pyx_INCREF(__pyx_v_attr_value);
          __Pyx_GIVEREF(__pyx_v_attr_value);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_attr_value);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 890, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMCollection))))) __PYX_ERR(0, 890, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":906
 *         :rtype: DOMCollection or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_8) {

    /* "resiliparse/parse/html.pyx":907
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_collection(self.tree,
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":906
 *         :rtype: DOMCollection or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":909
 *             return None
 * 
 *         return _create_dom_collection(self.tree,             # <<<<<<<<<<<<<<
 *                                       get_elements_by_attr_impl(self.node, attr_name.encode(), attr_value.encode(),
 *                                                                 10, case_insensitive))
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_1);

  /* "resiliparse/parse/html.pyx":910
 * 
 *         return _create_dom_collection(self.tree,
 *                                       get_elements_by_attr_impl(self.node, attr_name.encode(), attr_value.encode(),             # <<<<<<<<<<<<<<
 *                                                                 10, case_insensitive))
 * 
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 910, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_v_attr_value == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 910, __pyx_L1_error)
  }
  __pyx_t_4 = PyUnicode_AsEncodedString(__pyx_v_attr_value, NULL, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "resiliparse/parse/html.pyx":911
 *         return _create_dom_collection(self.tree,
 *                                       get_elements_by_attr_impl(self.node, attr_name.encode(), attr_value.encode(),
 *                                                                 10, case_insensitive))             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=False):
 */
  __pyx_t_10.__pyx_n = 2;
  __pyx_t_10.init_size = 10;
  __pyx_t_10.case_insensitive = __pyx_v_case_insensitive;
  __pyx_t_9 = __pyx_f_11resiliparse_5parse_4html_get_elements_by_attr_impl(__pyx_v_self->node, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_4), &__pyx_t_10); 
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "resiliparse/parse/html.pyx":909
 *             return None
 * 
 *         return _create_dom_collection(self.tree,             # <<<<<<<<<<<<<<
 *                                       get_elements_by_attr_impl(self.node, attr_name.encode(), attr_value.encode(),
 *                                                                 10, case_insensitive))
 */
  __pyx_t_4 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_collection(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), __pyx_t_9)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":890
 *         return matches_impl(self.node, self.tree, selector.encode())
 * 
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_attr(self, attr_name, attr_value, case_insensitive=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_elements_by_attr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_28get_elements_by_attr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_27get_elements_by_attr[] = "\n        get_elements_by_attr(self, attr_name, attr_value, case_insensitive=False)\n        \n        Find all elements matching the given arbitrary attribute name and value and return a\n        :class:`DOMCollection` with the results.\n        \n        :param attr_name: attribute name\n        :type attr_name: str\n        :param attr_value: attribute value\n        :type attr_name: str\n        :param case_insensitive: match attribute value case-insensitively\n        :type case_insensitive: bool\n        :return: collection of matching elements\n        :rtype: DOMCollection or None\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_28get_elements_by_attr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_attr_name = 0;
  PyObject *__pyx_v_attr_value = 0;
  int __pyx_v_case_insensitive;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_elements_by_attr (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_attr_name,&__pyx_n_s_attr_value,&__pyx_n_s_case_insensitive,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_attr_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_attr_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_elements_by_attr", 0, 2, 3, 1); __PYX_ERR(0, 890, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_case_insensitive);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_elements_by_attr") < 0)) __PYX_ERR(0, 890, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_attr_name = ((PyObject*)values[0]);
    __pyx_v_attr_value = ((PyObject*)values[1]);
    if (values[2]) {
      __pyx_v_case_insensitive = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_case_insensitive == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 890, __pyx_L3_error)
    } else {
      __pyx_v_case_insensitive = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_elements_by_attr", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 890, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_elements_by_attr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 890, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_value), (&PyUnicode_Type), 1, "attr_value", 1))) __PYX_ERR(0, 890, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_27get_elements_by_attr(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), __pyx_v_attr_name, __pyx_v_attr_value, __pyx_v_case_insensitive);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_27get_elements_by_attr(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_v_case_insensitive) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_attr", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.case_insensitive = __pyx_v_case_insensitive;
  __pyx_t_1 = ((PyObject *)__pyx_vtabptr_11resiliparse_5parse_4html_DOMNode->get_elements_by_attr(__pyx_v_self, __pyx_v_attr_name, __pyx_v_attr_value, 1, &__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_elements_by_attr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":913
 *                                                                 10, case_insensitive))
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_element_by_id(self, element_id, case_insensitive=False)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_30get_element_by_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_element_by_id(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_element_id, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_element_by_id *__pyx_optional_args) {
  int __pyx_v_case_insensitive = ((int)0);
  lxb_dom_node_t *__pyx_v_result_node;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  lxb_dom_node_t *__pyx_t_9;
  struct __pyx_opt_args_11resiliparse_5parse_4html_get_element_by_id_impl __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_element_by_id", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_case_insensitive = __pyx_optional_args->case_insensitive;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_element_by_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 913, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_30get_element_by_id)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_case_insensitive); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 913, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_element_id, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 913, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_element_id, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 913, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 913, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_element_id);
          __Pyx_GIVEREF(__pyx_v_element_id);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_element_id);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 913, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 913, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":926
 *         :rtype: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_8) {

    /* "resiliparse/parse/html.pyx":927
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef lxb_dom_node_t* result_node = get_element_by_id_impl(self.node, element_id.encode(), case_insensitive)
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":926
 *         :rtype: DOMNode or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":929
 *             return None
 * 
 *         cdef lxb_dom_node_t* result_node = get_element_by_id_impl(self.node, element_id.encode(), case_insensitive)             # <<<<<<<<<<<<<<
 *         if result_node == NULL:
 *             return None
 */
  if (unlikely(__pyx_v_element_id == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 929, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_element_id, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_10.__pyx_n = 1;
  __pyx_t_10.case_insensitive = __pyx_v_case_insensitive;
  __pyx_t_9 = __pyx_f_11resiliparse_5parse_4html_get_element_by_id_impl(__pyx_v_self->node, ((PyObject*)__pyx_t_1), &__pyx_t_10); 
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_result_node = __pyx_t_9;

  /* "resiliparse/parse/html.pyx":930
 * 
 *         cdef lxb_dom_node_t* result_node = get_element_by_id_impl(self.node, element_id.encode(), case_insensitive)
 *         if result_node == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, result_node)
 */
  __pyx_t_8 = ((__pyx_v_result_node == NULL) != 0);
  if (__pyx_t_8) {

    /* "resiliparse/parse/html.pyx":931
 *         cdef lxb_dom_node_t* result_node = get_element_by_id_impl(self.node, element_id.encode(), case_insensitive)
 *         if result_node == NULL:
 *             return None             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self.tree, result_node)
 * 
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":930
 * 
 *         cdef lxb_dom_node_t* result_node = get_element_by_id_impl(self.node, element_id.encode(), case_insensitive)
 *         if result_node == NULL:             # <<<<<<<<<<<<<<
 *             return None
 *         return _create_dom_node(self.tree, result_node)
 */
  }

  /* "resiliparse/parse/html.pyx":932
 *         if result_node == NULL:
 *             return None
 *         return _create_dom_node(self.tree, result_node)             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=False):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), __pyx_v_result_node)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":913
 *                                                                 10, case_insensitive))
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_element_by_id(self, element_id, case_insensitive=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_element_by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_30get_element_by_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_29get_element_by_id[] = "\n        get_element_by_id(self, element_id, case_insensitive=False)\n        \n        Find and return the element whose ID attribute matches ``element_id``.\n        \n        :param element_id: element ID\n        :type element_id: str\n        :param case_insensitive: match ID case-insensitively\n        :type case_insensitive: bool\n        :return: matching element or ``None`` if no such element exists\n        :rtype: DOMNode or None\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_30get_element_by_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_element_id = 0;
  int __pyx_v_case_insensitive;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_element_by_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_element_id,&__pyx_n_s_case_insensitive,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_element_id)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_case_insensitive);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_element_by_id") < 0)) __PYX_ERR(0, 913, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_element_id = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_case_insensitive = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_case_insensitive == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 913, __pyx_L3_error)
    } else {
      __pyx_v_case_insensitive = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_element_by_id", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 913, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_element_by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_element_id), (&PyUnicode_Type), 1, "element_id", 1))) __PYX_ERR(0, 913, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_29get_element_by_id(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), __pyx_v_element_id, __pyx_v_case_insensitive);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_29get_element_by_id(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_element_id, int __pyx_v_case_insensitive) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_element_by_id __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_element_by_id", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.case_insensitive = __pyx_v_case_insensitive;
  __pyx_t_1 = ((PyObject *)__pyx_vtabptr_11resiliparse_5parse_4html_DOMNode->get_element_by_id(__pyx_v_self, __pyx_v_element_id, 1, &__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_element_by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":934
 *         return _create_dom_node(self.tree, result_node)
 * 
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_class_name(self, element_class, case_insensitive=False)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_32get_elements_by_class_name(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name *__pyx_optional_args) {
  int __pyx_v_case_insensitive = ((int)0);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  lxb_dom_collection_t *__pyx_t_9;
  struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_class_name_impl __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_class_name", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_case_insensitive = __pyx_optional_args->case_insensitive;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_elements_by_class_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 934, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_32get_elements_by_class_name)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_case_insensitive); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 934, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_class_name, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 934, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_class_name, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 934, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 934, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_class_name);
          __Pyx_GIVEREF(__pyx_v_class_name);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_class_name);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 934, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMCollection))))) __PYX_ERR(0, 934, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":947
 *         :rtype: DOMCollection or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_8) {

    /* "resiliparse/parse/html.pyx":948
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_collection(self.tree, get_elements_by_class_name_impl(self.node, class_name.encode(), 10))
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":947
 *         :rtype: DOMCollection or None
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":950
 *             return None
 * 
 *         return _create_dom_collection(self.tree, get_elements_by_class_name_impl(self.node, class_name.encode(), 10))             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_v_class_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 950, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_class_name, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10.__pyx_n = 1;
  __pyx_t_10.init_size = 10;
  __pyx_t_9 = __pyx_f_11resiliparse_5parse_4html_get_elements_by_class_name_impl(__pyx_v_self->node, ((PyObject*)__pyx_t_2), &__pyx_t_10); 
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_collection(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), __pyx_t_9)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":934
 *         return _create_dom_node(self.tree, result_node)
 * 
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_class_name(self, element_class, case_insensitive=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_elements_by_class_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_32get_elements_by_class_name(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_31get_elements_by_class_name[] = "\n        get_elements_by_class_name(self, element_class, case_insensitive=False)\n        \n        Find all elements matching the given class name and return a :class:`DOMCollection` with the results.\n        \n        :param class_name: element class\n        :type class_name: str\n        :param case_insensitive: match class name case-insensitively\n        :type case_insensitive: bool\n        :return: collection of matching elements\n        :rtype: DOMCollection or None\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_32get_elements_by_class_name(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_class_name = 0;
  int __pyx_v_case_insensitive;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_elements_by_class_name (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_class_name,&__pyx_n_s_case_insensitive,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_class_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_case_insensitive);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_elements_by_class_name") < 0)) __PYX_ERR(0, 934, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_class_name = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_case_insensitive = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_case_insensitive == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 934, __pyx_L3_error)
    } else {
      __pyx_v_case_insensitive = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_elements_by_class_name", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 934, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_elements_by_class_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_class_name), (&PyUnicode_Type), 1, "class_name", 1))) __PYX_ERR(0, 934, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_31get_elements_by_class_name(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), __pyx_v_class_name, __pyx_v_case_insensitive);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_31get_elements_by_class_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_v_case_insensitive) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_class_name", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.case_insensitive = __pyx_v_case_insensitive;
  __pyx_t_1 = ((PyObject *)__pyx_vtabptr_11resiliparse_5parse_4html_DOMNode->get_elements_by_class_name(__pyx_v_self, __pyx_v_class_name, 1, &__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_elements_by_class_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":952
 *         return _create_dom_collection(self.tree, get_elements_by_class_name_impl(self.node, class_name.encode(), 10))
 * 
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_tag_name(self, tag_name)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_34get_elements_by_tag_name(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_tag_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_tag_name, int __pyx_skip_dispatch) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_tag_name", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_elements_by_tag_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 952, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_34get_elements_by_tag_name)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_tag_name) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_tag_name);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 952, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMCollection))))) __PYX_ERR(0, 952, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":963
 *         :rtype: DOMCollection
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_5 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_5) {

    /* "resiliparse/parse/html.pyx":964
 *         """
 *         if not check_node(self):
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_collection(self.tree, get_elements_by_tag_name_impl(self.node, tag_name.encode()))
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":963
 *         :rtype: DOMCollection
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":966
 *             return None
 * 
 *         return _create_dom_collection(self.tree, get_elements_by_tag_name_impl(self.node, tag_name.encode()))             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode append_child(self, DOMNode node):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_v_tag_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 966, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_tag_name, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_collection(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), __pyx_f_11resiliparse_5parse_4html_get_elements_by_tag_name_impl(__pyx_v_self->node, ((PyObject*)__pyx_t_2)))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":952
 *         return _create_dom_collection(self.tree, get_elements_by_class_name_impl(self.node, class_name.encode(), 10))
 * 
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_tag_name(self, tag_name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_elements_by_tag_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_34get_elements_by_tag_name(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_33get_elements_by_tag_name[] = "\n        get_elements_by_tag_name(self, tag_name)\n        \n        Find all elements with the given tag name and return a :class:`DOMCollection` with the results.\n        \n        :param tag_name: tag name for matching elements\n        :type tag_name: str\n        :return: collection of matching elements\n        :rtype: DOMCollection\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_34get_elements_by_tag_name(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_elements_by_tag_name (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tag_name), (&PyUnicode_Type), 1, "tag_name", 1))) __PYX_ERR(0, 952, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_33get_elements_by_tag_name(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject*)__pyx_v_tag_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_33get_elements_by_tag_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_tag_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_tag_name", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_tag_name(__pyx_v_self, __pyx_v_tag_name, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.get_elements_by_tag_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":968
 *         return _create_dom_collection(self.tree, get_elements_by_tag_name_impl(self.node, tag_name.encode()))
 * 
 *     cpdef DOMNode append_child(self, DOMNode node):             # <<<<<<<<<<<<<<
 *         """
 *         append_child(self, node)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_36append_child(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_append_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node, int __pyx_skip_dispatch) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append_child", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_append_child); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 968, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_36append_child)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_node)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_node));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 968, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 968, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":980
 *         :raises ValueError: if trying to append node to itself
 *         """
 *         if not check_node(self) or not check_node(node):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Append operation on uninitialized node')
 * 
 */
  __pyx_t_6 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_node) != 0)) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":981
 *         """
 *         if not check_node(self) or not check_node(node):
 *             raise RuntimeError('Append operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         if node.node == self.node:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 981, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":980
 *         :raises ValueError: if trying to append node to itself
 *         """
 *         if not check_node(self) or not check_node(node):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Append operation on uninitialized node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":983
 *             raise RuntimeError('Append operation on uninitialized node')
 * 
 *         if node.node == self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Trying to append child to itself')
 * 
 */
  __pyx_t_5 = ((__pyx_v_node->node == __pyx_v_self->node) != 0);
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":984
 * 
 *         if node.node == self.node:
 *             raise ValueError('Trying to append child to itself')             # <<<<<<<<<<<<<<
 * 
 *         if node.node.parent != NULL:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 984, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":983
 *             raise RuntimeError('Append operation on uninitialized node')
 * 
 *         if node.node == self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Trying to append child to itself')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":986
 *             raise ValueError('Trying to append child to itself')
 * 
 *         if node.node.parent != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_node_remove(node.node)
 *         lxb_dom_node_insert_child(self.node, node.node)
 */
  __pyx_t_5 = ((__pyx_v_node->node->parent != NULL) != 0);
  if (__pyx_t_5) {

    /* "resiliparse/parse/html.pyx":987
 * 
 *         if node.node.parent != NULL:
 *             lxb_dom_node_remove(node.node)             # <<<<<<<<<<<<<<
 *         lxb_dom_node_insert_child(self.node, node.node)
 *         return node
 */
    lxb_dom_node_remove(__pyx_v_node->node);

    /* "resiliparse/parse/html.pyx":986
 *             raise ValueError('Trying to append child to itself')
 * 
 *         if node.node.parent != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_node_remove(node.node)
 *         lxb_dom_node_insert_child(self.node, node.node)
 */
  }

  /* "resiliparse/parse/html.pyx":988
 *         if node.node.parent != NULL:
 *             lxb_dom_node_remove(node.node)
 *         lxb_dom_node_insert_child(self.node, node.node)             # <<<<<<<<<<<<<<
 *         return node
 * 
 */
  lxb_dom_node_insert_child(__pyx_v_self->node, __pyx_v_node->node);

  /* "resiliparse/parse/html.pyx":989
 *             lxb_dom_node_remove(node.node)
 *         lxb_dom_node_insert_child(self.node, node.node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode insert_before(self, DOMNode node, DOMNode reference):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_node));
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":968
 *         return _create_dom_collection(self.tree, get_elements_by_tag_name_impl(self.node, tag_name.encode()))
 * 
 *     cpdef DOMNode append_child(self, DOMNode node):             # <<<<<<<<<<<<<<
 *         """
 *         append_child(self, node)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.append_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_36append_child(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_35append_child[] = "\n        append_child(self, node)\n        \n        Append a new child node to this DOM node.\n        \n        :param node: DOM node to append as new child node\n        :type node: DOMNode\n        :return: the appended child node\n        :rtype: DOMNode\n        :raises ValueError: if trying to append node to itself\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_36append_child(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append_child (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_node), __pyx_ptype_11resiliparse_5parse_4html_DOMNode, 1, "node", 0))) __PYX_ERR(0, 968, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_35append_child(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_node));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_35append_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append_child", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_7DOMNode_append_child(__pyx_v_self, __pyx_v_node, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.append_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":991
 *         return node
 * 
 *     cpdef DOMNode insert_before(self, DOMNode node, DOMNode reference):             # <<<<<<<<<<<<<<
 *         """
 *         insert_before(self, node, reference)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_38insert_before(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_insert_before(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_reference, int __pyx_skip_dispatch) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("insert_before", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_insert_before); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 991, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_38insert_before)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_node), ((PyObject *)__pyx_v_reference)};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 991, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_node), ((PyObject *)__pyx_v_reference)};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 991, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 991, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_node));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_node));
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, ((PyObject *)__pyx_v_node));
          __Pyx_INCREF(((PyObject *)__pyx_v_reference));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_reference));
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, ((PyObject *)__pyx_v_reference));
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 991, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 991, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1007
 *         :raises ValueError: if trying to add node as its own child or if ``reference`` is not a child
 *         """
 *         if not check_node(self) or not check_node(node) or not check_node(reference):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Insert operation on uninitialized node')
 * 
 */
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_node) != 0)) != 0);
  if (!__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_reference) != 0)) != 0);
  __pyx_t_7 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_7)) {

    /* "resiliparse/parse/html.pyx":1008
 *         """
 *         if not check_node(self) or not check_node(node) or not check_node(reference):
 *             raise RuntimeError('Insert operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         if node.node == self.node:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1008, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1007
 *         :raises ValueError: if trying to add node as its own child or if ``reference`` is not a child
 *         """
 *         if not check_node(self) or not check_node(node) or not check_node(reference):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Insert operation on uninitialized node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1010
 *             raise RuntimeError('Insert operation on uninitialized node')
 * 
 *         if node.node == self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Trying to insert node as its own child')
 * 
 */
  __pyx_t_7 = ((__pyx_v_node->node == __pyx_v_self->node) != 0);
  if (unlikely(__pyx_t_7)) {

    /* "resiliparse/parse/html.pyx":1011
 * 
 *         if node.node == self.node:
 *             raise ValueError('Trying to insert node as its own child')             # <<<<<<<<<<<<<<
 * 
 *         if reference.node.parent != self.node:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1011, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1010
 *             raise RuntimeError('Insert operation on uninitialized node')
 * 
 *         if node.node == self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Trying to insert node as its own child')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1013
 *             raise ValueError('Trying to insert node as its own child')
 * 
 *         if reference.node.parent != self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Reference node must be a child node')
 * 
 */
  __pyx_t_7 = ((__pyx_v_reference->node->parent != __pyx_v_self->node) != 0);
  if (unlikely(__pyx_t_7)) {

    /* "resiliparse/parse/html.pyx":1014
 * 
 *         if reference.node.parent != self.node:
 *             raise ValueError('Reference node must be a child node')             # <<<<<<<<<<<<<<
 * 
 *         if node.node.parent != NULL:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1014, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1013
 *             raise ValueError('Trying to insert node as its own child')
 * 
 *         if reference.node.parent != self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Reference node must be a child node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1016
 *             raise ValueError('Reference node must be a child node')
 * 
 *         if node.node.parent != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_node_remove(node.node)
 *         lxb_dom_node_insert_before(reference.node, node.node)
 */
  __pyx_t_7 = ((__pyx_v_node->node->parent != NULL) != 0);
  if (__pyx_t_7) {

    /* "resiliparse/parse/html.pyx":1017
 * 
 *         if node.node.parent != NULL:
 *             lxb_dom_node_remove(node.node)             # <<<<<<<<<<<<<<
 *         lxb_dom_node_insert_before(reference.node, node.node)
 *         return node
 */
    lxb_dom_node_remove(__pyx_v_node->node);

    /* "resiliparse/parse/html.pyx":1016
 *             raise ValueError('Reference node must be a child node')
 * 
 *         if node.node.parent != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_node_remove(node.node)
 *         lxb_dom_node_insert_before(reference.node, node.node)
 */
  }

  /* "resiliparse/parse/html.pyx":1018
 *         if node.node.parent != NULL:
 *             lxb_dom_node_remove(node.node)
 *         lxb_dom_node_insert_before(reference.node, node.node)             # <<<<<<<<<<<<<<
 *         return node
 * 
 */
  lxb_dom_node_insert_before(__pyx_v_reference->node, __pyx_v_node->node);

  /* "resiliparse/parse/html.pyx":1019
 *             lxb_dom_node_remove(node.node)
 *         lxb_dom_node_insert_before(reference.node, node.node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode replace_child(self, DOMNode new_child, DOMNode old_child):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_node));
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":991
 *         return node
 * 
 *     cpdef DOMNode insert_before(self, DOMNode node, DOMNode reference):             # <<<<<<<<<<<<<<
 *         """
 *         insert_before(self, node, reference)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.insert_before", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_38insert_before(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_37insert_before[] = "\n        insert_before(self, node, reference)\n        \n        Insert ``node`` before ``reference`` as a new child node. The reference node must be\n        a child of this node or ``None``. If ``reference`` is ``None``, the new node\n        will be appended after the last child node.\n        \n        :param node: DOM node to insert as new child node\n        :type node: DOMNode\n        :param reference: child node before which to insert the new node or ``None``\n        :type reference: DOMNode\n        :return: the inserted child node\n        :rtype: DOMNode\n        :raises ValueError: if trying to add node as its own child or if ``reference`` is not a child\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_38insert_before(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node = 0;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_reference = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("insert_before (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_node,&__pyx_n_s_reference,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_node)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_reference)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("insert_before", 1, 2, 2, 1); __PYX_ERR(0, 991, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "insert_before") < 0)) __PYX_ERR(0, 991, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_node = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)values[0]);
    __pyx_v_reference = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("insert_before", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 991, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.insert_before", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_node), __pyx_ptype_11resiliparse_5parse_4html_DOMNode, 1, "node", 0))) __PYX_ERR(0, 991, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_reference), __pyx_ptype_11resiliparse_5parse_4html_DOMNode, 1, "reference", 0))) __PYX_ERR(0, 991, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_37insert_before(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), __pyx_v_node, __pyx_v_reference);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_37insert_before(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_reference) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("insert_before", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_7DOMNode_insert_before(__pyx_v_self, __pyx_v_node, __pyx_v_reference, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.insert_before", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1021
 *         return node
 * 
 *     cpdef DOMNode replace_child(self, DOMNode new_child, DOMNode old_child):             # <<<<<<<<<<<<<<
 *         """
 *         replace_child(self, new_child, old_child)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_40replace_child(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_replace_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_new_child, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_old_child, int __pyx_skip_dispatch) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("replace_child", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_replace_child); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1021, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_40replace_child)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_new_child), ((PyObject *)__pyx_v_old_child)};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1021, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_new_child), ((PyObject *)__pyx_v_old_child)};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1021, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1021, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_new_child));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_new_child));
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, ((PyObject *)__pyx_v_new_child));
          __Pyx_INCREF(((PyObject *)__pyx_v_old_child));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_old_child));
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, ((PyObject *)__pyx_v_old_child));
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1021, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 1021, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1035
 *         :raises ValueError: if ``old_child`` is not a child of this node
 *         """
 *         if not check_node(self) or not check_node(new_child) or not check_node(old_child):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Replace operation on uninitialized node')
 * 
 */
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_new_child) != 0)) != 0);
  if (!__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_old_child) != 0)) != 0);
  __pyx_t_7 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_7)) {

    /* "resiliparse/parse/html.pyx":1036
 *         """
 *         if not check_node(self) or not check_node(new_child) or not check_node(old_child):
 *             raise RuntimeError('Replace operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         if old_child.node.parent != self.node:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1036, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1035
 *         :raises ValueError: if ``old_child`` is not a child of this node
 *         """
 *         if not check_node(self) or not check_node(new_child) or not check_node(old_child):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Replace operation on uninitialized node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1038
 *             raise RuntimeError('Replace operation on uninitialized node')
 * 
 *         if old_child.node.parent != self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node is not a child of the current node')
 * 
 */
  __pyx_t_7 = ((__pyx_v_old_child->node->parent != __pyx_v_self->node) != 0);
  if (unlikely(__pyx_t_7)) {

    /* "resiliparse/parse/html.pyx":1039
 * 
 *         if old_child.node.parent != self.node:
 *             raise ValueError('Node is not a child of the current node')             # <<<<<<<<<<<<<<
 * 
 *         if new_child.node == old_child.node:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1039, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1039, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1038
 *             raise RuntimeError('Replace operation on uninitialized node')
 * 
 *         if old_child.node.parent != self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node is not a child of the current node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1041
 *             raise ValueError('Node is not a child of the current node')
 * 
 *         if new_child.node == old_child.node:             # <<<<<<<<<<<<<<
 *             return old_child
 * 
 */
  __pyx_t_7 = ((__pyx_v_new_child->node == __pyx_v_old_child->node) != 0);
  if (__pyx_t_7) {

    /* "resiliparse/parse/html.pyx":1042
 * 
 *         if new_child.node == old_child.node:
 *             return old_child             # <<<<<<<<<<<<<<
 * 
 *         if new_child.node.parent != NULL:
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)__pyx_v_old_child));
    __pyx_r = __pyx_v_old_child;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1041
 *             raise ValueError('Node is not a child of the current node')
 * 
 *         if new_child.node == old_child.node:             # <<<<<<<<<<<<<<
 *             return old_child
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1044
 *             return old_child
 * 
 *         if new_child.node.parent != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_node_remove(new_child.node)
 *         lxb_dom_node_insert_after(old_child.node, new_child.node)
 */
  __pyx_t_7 = ((__pyx_v_new_child->node->parent != NULL) != 0);
  if (__pyx_t_7) {

    /* "resiliparse/parse/html.pyx":1045
 * 
 *         if new_child.node.parent != NULL:
 *             lxb_dom_node_remove(new_child.node)             # <<<<<<<<<<<<<<
 *         lxb_dom_node_insert_after(old_child.node, new_child.node)
 *         lxb_dom_node_remove(old_child.node)
 */
    lxb_dom_node_remove(__pyx_v_new_child->node);

    /* "resiliparse/parse/html.pyx":1044
 *             return old_child
 * 
 *         if new_child.node.parent != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_node_remove(new_child.node)
 *         lxb_dom_node_insert_after(old_child.node, new_child.node)
 */
  }

  /* "resiliparse/parse/html.pyx":1046
 *         if new_child.node.parent != NULL:
 *             lxb_dom_node_remove(new_child.node)
 *         lxb_dom_node_insert_after(old_child.node, new_child.node)             # <<<<<<<<<<<<<<
 *         lxb_dom_node_remove(old_child.node)
 * 
 */
  lxb_dom_node_insert_after(__pyx_v_old_child->node, __pyx_v_new_child->node);

  /* "resiliparse/parse/html.pyx":1047
 *             lxb_dom_node_remove(new_child.node)
 *         lxb_dom_node_insert_after(old_child.node, new_child.node)
 *         lxb_dom_node_remove(old_child.node)             # <<<<<<<<<<<<<<
 * 
 *         return old_child
 */
  lxb_dom_node_remove(__pyx_v_old_child->node);

  /* "resiliparse/parse/html.pyx":1049
 *         lxb_dom_node_remove(old_child.node)
 * 
 *         return old_child             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode remove_child(self, DOMNode node):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_old_child));
  __pyx_r = __pyx_v_old_child;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1021
 *         return node
 * 
 *     cpdef DOMNode replace_child(self, DOMNode new_child, DOMNode old_child):             # <<<<<<<<<<<<<<
 *         """
 *         replace_child(self, new_child, old_child)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.replace_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_40replace_child(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_39replace_child[] = "\n        replace_child(self, new_child, old_child)\n        \n        Replace the child node ``old_child`` with ``new_child``.\n        \n        :param new_child: new child node to insert\n        :type new_child: DOMNode\n        :param old_child: old child node to replace\n        :type old_child: DOMNode\n        :return: the old child node\n        :rtype: DOMNode\n        :raises ValueError: if ``old_child`` is not a child of this node\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_40replace_child(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_new_child = 0;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_old_child = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("replace_child (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_new_child,&__pyx_n_s_old_child,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_new_child)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_old_child)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("replace_child", 1, 2, 2, 1); __PYX_ERR(0, 1021, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "replace_child") < 0)) __PYX_ERR(0, 1021, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_new_child = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)values[0]);
    __pyx_v_old_child = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("replace_child", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1021, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.replace_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_new_child), __pyx_ptype_11resiliparse_5parse_4html_DOMNode, 1, "new_child", 0))) __PYX_ERR(0, 1021, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_old_child), __pyx_ptype_11resiliparse_5parse_4html_DOMNode, 1, "old_child", 0))) __PYX_ERR(0, 1021, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_39replace_child(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), __pyx_v_new_child, __pyx_v_old_child);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_39replace_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_new_child, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_old_child) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("replace_child", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_7DOMNode_replace_child(__pyx_v_self, __pyx_v_new_child, __pyx_v_old_child, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.replace_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1051
 *         return old_child
 * 
 *     cpdef DOMNode remove_child(self, DOMNode node):             # <<<<<<<<<<<<<<
 *         """
 *         remove_child(self, node)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_42remove_child(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_7DOMNode_remove_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node, int __pyx_skip_dispatch) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove_child", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_remove_child); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_42remove_child)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_node)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_node));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1051, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 1051, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1063
 *         :raises ValueError: if ``node`` is not a child of this node
 *         """
 *         if not check_node(self) or not check_node(node):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Remove operation on uninitialized node')
 * 
 */
  __pyx_t_6 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_node) != 0)) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":1064
 *         """
 *         if not check_node(self) or not check_node(node):
 *             raise RuntimeError('Remove operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         if node.node.parent != self.node:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1064, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1064, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1063
 *         :raises ValueError: if ``node`` is not a child of this node
 *         """
 *         if not check_node(self) or not check_node(node):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Remove operation on uninitialized node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1066
 *             raise RuntimeError('Remove operation on uninitialized node')
 * 
 *         if node.node.parent != self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node is not a child of the current node')
 * 
 */
  __pyx_t_5 = ((__pyx_v_node->node->parent != __pyx_v_self->node) != 0);
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":1067
 * 
 *         if node.node.parent != self.node:
 *             raise ValueError('Node is not a child of the current node')             # <<<<<<<<<<<<<<
 * 
 *         lxb_dom_node_remove(node.node)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1067, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1067, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1066
 *             raise RuntimeError('Remove operation on uninitialized node')
 * 
 *         if node.node.parent != self.node:             # <<<<<<<<<<<<<<
 *             raise ValueError('Node is not a child of the current node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1069
 *             raise ValueError('Node is not a child of the current node')
 * 
 *         lxb_dom_node_remove(node.node)             # <<<<<<<<<<<<<<
 *         return node
 * 
 */
  lxb_dom_node_remove(__pyx_v_node->node);

  /* "resiliparse/parse/html.pyx":1070
 * 
 *         lxb_dom_node_remove(node.node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     # noinspection PyAttributeOutsideInit
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_node));
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1051
 *         return old_child
 * 
 *     cpdef DOMNode remove_child(self, DOMNode node):             # <<<<<<<<<<<<<<
 *         """
 *         remove_child(self, node)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.remove_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_42remove_child(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_41remove_child[] = "\n        remove_child(self, node)\n        \n        Remove the child node ``node`` from the DOM tree and return it.\n        \n        :param node: DOM node to remove\n        :type node: DOMNode\n        :return: the removed child node\n        :rtype: DOMNode\n        :raises ValueError: if ``node`` is not a child of this node\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_42remove_child(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove_child (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_node), __pyx_ptype_11resiliparse_5parse_4html_DOMNode, 1, "node", 0))) __PYX_ERR(0, 1051, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_41remove_child(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_node));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_41remove_child(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove_child", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_7DOMNode_remove_child(__pyx_v_self, __pyx_v_node, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.remove_child", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1073
 * 
 *     # noinspection PyAttributeOutsideInit
 *     cpdef void decompose(self):             # <<<<<<<<<<<<<<
 *         """
 *         decompose(self)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_44decompose(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static void __pyx_f_11resiliparse_5parse_4html_7DOMNode_decompose(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, int __pyx_skip_dispatch) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("decompose", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_decompose); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1073, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_44decompose)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1073, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1079
 *         Delete the current node and all its children.
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Decompose operation on uninitialized node')
 * 
 */
  __pyx_t_5 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":1080
 *         """
 *         if not check_node(self):
 *             raise RuntimeError('Decompose operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         lxb_dom_node_destroy_deep(self.node)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1080, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1079
 *         Delete the current node and all its children.
 *         """
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Decompose operation on uninitialized node')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1082
 *             raise RuntimeError('Decompose operation on uninitialized node')
 * 
 *         lxb_dom_node_destroy_deep(self.node)             # <<<<<<<<<<<<<<
 *         self.node = NULL
 *         self.tree = None
 */
  (void)(lxb_dom_node_destroy_deep(__pyx_v_self->node));

  /* "resiliparse/parse/html.pyx":1083
 * 
 *         lxb_dom_node_destroy_deep(self.node)
 *         self.node = NULL             # <<<<<<<<<<<<<<
 *         self.tree = None
 * 
 */
  __pyx_v_self->node = NULL;

  /* "resiliparse/parse/html.pyx":1084
 *         lxb_dom_node_destroy_deep(self.node)
 *         self.node = NULL
 *         self.tree = None             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->tree);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->tree));
  __pyx_v_self->tree = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)Py_None);

  /* "resiliparse/parse/html.pyx":1073
 * 
 *     # noinspection PyAttributeOutsideInit
 *     cpdef void decompose(self):             # <<<<<<<<<<<<<<
 *         """
 *         decompose(self)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMNode.decompose", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_44decompose(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_7DOMNode_43decompose[] = "\n        decompose(self)\n        \n        Delete the current node and all its children.\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_44decompose(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("decompose (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_43decompose(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_43decompose(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("decompose", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_void_to_None(__pyx_f_11resiliparse_5parse_4html_7DOMNode_decompose(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.decompose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1086
 *         self.tree = None
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             return '<INVALID ELEMENT>'
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_46__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_46__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_45__repr__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11resiliparse_5parse_4html_7DOMNode_8__repr___2generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "resiliparse/parse/html.pyx":1091
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_ELEMENT:
 *             attrs = ' '.join(f'{a}="{self[a]}"' for a in self.attrs)             # <<<<<<<<<<<<<<
 *             if attrs:
 *                 attrs = ' ' + attrs
 */

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_8__repr___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *)__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr(__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1091, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11resiliparse_5parse_4html_7DOMNode_8__repr___2generator2, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_repr___locals_genexpr, __pyx_n_s_resiliparse_parse_html); if (unlikely(!gen)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__repr__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11resiliparse_5parse_4html_7DOMNode_8__repr___2generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *__pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1091, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 1091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1091, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self), __pyx_n_s_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1091, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1091, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1091, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1091, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1091, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1091, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_a);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_a, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_6 = 127;
    __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_cur_scope->__pyx_v_a, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_6;
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u__19);
    __pyx_t_5 += 2;
    __Pyx_GIVEREF(__pyx_kp_u__19);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__19);
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1091, __pyx_L1_error) }
    __pyx_t_7 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self), __pyx_cur_scope->__pyx_v_a); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_6;
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__20);
    __pyx_t_5 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__20);
    PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u__20);
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_1, 4, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1086
 *         self.tree = None
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             return '<INVALID ELEMENT>'
 */

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_45__repr__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *__pyx_cur_scope;
  PyObject *__pyx_v_attrs = NULL;
  PyObject *__pyx_gb_11resiliparse_5parse_4html_7DOMNode_8__repr___2generator2 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);
  __pyx_cur_scope = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *)__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__(__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1086, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

  /* "resiliparse/parse/html.pyx":1087
 * 
 *     def __repr__(self):
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return '<INVALID ELEMENT>'
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_1)) != 0)) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "resiliparse/parse/html.pyx":1088
 *     def __repr__(self):
 *         if not check_node(self):
 *             return '<INVALID ELEMENT>'             # <<<<<<<<<<<<<<
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_ELEMENT:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_INVALID_ELEMENT);
    __pyx_r = __pyx_kp_u_INVALID_ELEMENT;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1087
 * 
 *     def __repr__(self):
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return '<INVALID ELEMENT>'
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1090
 *             return '<INVALID ELEMENT>'
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             attrs = ' '.join(f'{a}="{self[a]}"' for a in self.attrs)
 *             if attrs:
 */
  switch (__pyx_cur_scope->__pyx_v_self->node->type) {
    case LXB_DOM_NODE_TYPE_ELEMENT:

    /* "resiliparse/parse/html.pyx":1091
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_ELEMENT:
 *             attrs = ' '.join(f'{a}="{self[a]}"' for a in self.attrs)             # <<<<<<<<<<<<<<
 *             if attrs:
 *                 attrs = ' ' + attrs
 */
    __pyx_t_1 = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_8__repr___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__3, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_attrs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "resiliparse/parse/html.pyx":1092
 *         if self.node.type == LXB_DOM_NODE_TYPE_ELEMENT:
 *             attrs = ' '.join(f'{a}="{self[a]}"' for a in self.attrs)
 *             if attrs:             # <<<<<<<<<<<<<<
 *                 attrs = ' ' + attrs
 *             return f'<{self.tag}{attrs}>'
 */
    __pyx_t_2 = (__pyx_v_attrs != Py_None)&&(__Pyx_PyUnicode_IS_TRUE(__pyx_v_attrs) != 0);
    if (__pyx_t_2) {

      /* "resiliparse/parse/html.pyx":1093
 *             attrs = ' '.join(f'{a}="{self[a]}"' for a in self.attrs)
 *             if attrs:
 *                 attrs = ' ' + attrs             # <<<<<<<<<<<<<<
 *             return f'<{self.tag}{attrs}>'
 *         elif self.node.type == LXB_DOM_NODE_TYPE_TEXT:
 */
      __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u__3, __pyx_v_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1093, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_attrs, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "resiliparse/parse/html.pyx":1092
 *         if self.node.type == LXB_DOM_NODE_TYPE_ELEMENT:
 *             attrs = ' '.join(f'{a}="{self[a]}"' for a in self.attrs)
 *             if attrs:             # <<<<<<<<<<<<<<
 *                 attrs = ' ' + attrs
 *             return f'<{self.tag}{attrs}>'
 */
    }

    /* "resiliparse/parse/html.pyx":1094
 *             if attrs:
 *                 attrs = ' ' + attrs
 *             return f'<{self.tag}{attrs}>'             # <<<<<<<<<<<<<<
 *         elif self.node.type == LXB_DOM_NODE_TYPE_TEXT:
 *             return self.text
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u__21);
    __pyx_t_4 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__21);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u__21);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_tag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyUnicode_Unicode(__pyx_v_attrs); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u__22);
    __pyx_t_4 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__22);
    PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u__22);
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_1, 4, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1090
 *             return '<INVALID ELEMENT>'
 * 
 *         if self.node.type == LXB_DOM_NODE_TYPE_ELEMENT:             # <<<<<<<<<<<<<<
 *             attrs = ' '.join(f'{a}="{self[a]}"' for a in self.attrs)
 *             if attrs:
 */
    break;
    case LXB_DOM_NODE_TYPE_TEXT:

    /* "resiliparse/parse/html.pyx":1096
 *             return f'<{self.tag}{attrs}>'
 *         elif self.node.type == LXB_DOM_NODE_TYPE_TEXT:
 *             return self.text             # <<<<<<<<<<<<<<
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 *             return '[HTML Document]'
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_text_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1096, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1095
 *                 attrs = ' ' + attrs
 *             return f'<{self.tag}{attrs}>'
 *         elif self.node.type == LXB_DOM_NODE_TYPE_TEXT:             # <<<<<<<<<<<<<<
 *             return self.text
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 */
    break;
    case LXB_DOM_NODE_TYPE_DOCUMENT:

    /* "resiliparse/parse/html.pyx":1098
 *             return self.text
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 *             return '[HTML Document]'             # <<<<<<<<<<<<<<
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT_TYPE:
 *             return '<!DOCTYPE html>'
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_HTML_Document);
    __pyx_r = __pyx_kp_u_HTML_Document;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1097
 *         elif self.node.type == LXB_DOM_NODE_TYPE_TEXT:
 *             return self.text
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:             # <<<<<<<<<<<<<<
 *             return '[HTML Document]'
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT_TYPE:
 */
    break;
    case LXB_DOM_NODE_TYPE_DOCUMENT_TYPE:

    /* "resiliparse/parse/html.pyx":1100
 *             return '[HTML Document]'
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT_TYPE:
 *             return '<!DOCTYPE html>'             # <<<<<<<<<<<<<<
 * 
 *         return f'<{self.__class__.__name__} Element>'
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_DOCTYPE_html);
    __pyx_r = __pyx_kp_u_DOCTYPE_html;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1099
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT:
 *             return '[HTML Document]'
 *         elif self.node.type == LXB_DOM_NODE_TYPE_DOCUMENT_TYPE:             # <<<<<<<<<<<<<<
 *             return '<!DOCTYPE html>'
 * 
 */
    break;
    default: break;
  }

  /* "resiliparse/parse/html.pyx":1102
 *             return '<!DOCTYPE html>'
 * 
 *         return f'<{self.__class__.__name__} Element>'             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = 0;
  __pyx_t_5 = 127;
  __Pyx_INCREF(__pyx_kp_u__21);
  __pyx_t_4 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__21);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_kp_u__21);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_class_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_INCREF(__pyx_kp_u_Element);
  __pyx_t_4 += 9;
  __Pyx_GIVEREF(__pyx_kp_u_Element);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_kp_u_Element);
  __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_6, 3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1086
 *         self.tree = None
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             return '<INVALID ELEMENT>'
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attrs);
  __Pyx_XDECREF(__pyx_gb_11resiliparse_5parse_4html_7DOMNode_8__repr___2generator2);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1104
 *         return f'<{self.__class__.__name__} Element>'
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.html
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_48__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_48__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_47__str__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_47__str__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "resiliparse/parse/html.pyx":1105
 * 
 *     def __str__(self):
 *         return self.html             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_html); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1104
 *         return f'<{self.__class__.__name__} Element>'
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.html
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1107
 *         return self.html
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not check_node(self) or not isinstance(other, DOMNode):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_50__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_50__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_49__eq__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_49__eq__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_other_dom = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "resiliparse/parse/html.pyx":1108
 * 
 *     def __eq__(self, other):
 *         if not check_node(self) or not isinstance(other, DOMNode):             # <<<<<<<<<<<<<<
 *             return False
 *         cdef DOMNode other_dom = <DOMNode>other
 */
  __pyx_t_2 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_11resiliparse_5parse_4html_DOMNode); 
  __pyx_t_3 = ((!(__pyx_t_2 != 0)) != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1109
 *     def __eq__(self, other):
 *         if not check_node(self) or not isinstance(other, DOMNode):
 *             return False             # <<<<<<<<<<<<<<
 *         cdef DOMNode other_dom = <DOMNode>other
 *         return other_dom.node == self.node
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1108
 * 
 *     def __eq__(self, other):
 *         if not check_node(self) or not isinstance(other, DOMNode):             # <<<<<<<<<<<<<<
 *             return False
 *         cdef DOMNode other_dom = <DOMNode>other
 */
  }

  /* "resiliparse/parse/html.pyx":1110
 *         if not check_node(self) or not isinstance(other, DOMNode):
 *             return False
 *         cdef DOMNode other_dom = <DOMNode>other             # <<<<<<<<<<<<<<
 *         return other_dom.node == self.node
 * 
 */
  __pyx_t_4 = __pyx_v_other;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_other_dom = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "resiliparse/parse/html.pyx":1111
 *             return False
 *         cdef DOMNode other_dom = <DOMNode>other
 *         return other_dom.node == self.node             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyBool_FromLong((__pyx_v_other_dom->node == __pyx_v_self->node)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1107
 *         return self.html
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not check_node(self) or not isinstance(other, DOMNode):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_other_dom);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1113
 *         return other_dom.node == self.node
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             return 0
 */

/* Python wrapper */
static Py_hash_t __pyx_pw_11resiliparse_5parse_4html_7DOMNode_52__hash__(PyObject *__pyx_v_self); /*proto*/
static Py_hash_t __pyx_pw_11resiliparse_5parse_4html_7DOMNode_52__hash__(PyObject *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_51__hash__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_hash_t __pyx_pf_11resiliparse_5parse_4html_7DOMNode_51__hash__(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "resiliparse/parse/html.pyx":1114
 * 
 *     def __hash__(self):
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return 0
 *         return <size_t>self.node
 */
  __pyx_t_1 = ((!(__pyx_f_11resiliparse_5parse_4html_check_node(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1115
 *     def __hash__(self):
 *         if not check_node(self):
 *             return 0             # <<<<<<<<<<<<<<
 *         return <size_t>self.node
 * 
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1114
 * 
 *     def __hash__(self):
 *         if not check_node(self):             # <<<<<<<<<<<<<<
 *             return 0
 *         return <size_t>self.node
 */
  }

  /* "resiliparse/parse/html.pyx":1116
 *         if not check_node(self):
 *             return 0
 *         return <size_t>self.node             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((size_t)__pyx_v_self->node);
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1113
 *         return other_dom.node == self.node
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         if not check_node(self):
 *             return 0
 */

  /* function exit code */
  __pyx_L0:;
  if (unlikely(__pyx_r == -1) && !PyErr_Occurred()) __pyx_r = -2;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_54__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_54__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_53__reduce_cython__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_53__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_56__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_7DOMNode_56__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_7DOMNode_55__setstate_cython__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_7DOMNode_55__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMNode.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1119
 * 
 * 
 * cdef inline void _join_collections(lxb_dom_collection_t* target, lxb_dom_collection_t* source):             # <<<<<<<<<<<<<<
 *     """
 *     Append elements from ``source` to ``target``.
 */

static CYTHON_INLINE void __pyx_f_11resiliparse_5parse_4html__join_collections(lxb_dom_collection_t *__pyx_v_target, lxb_dom_collection_t *__pyx_v_source) {
  size_t __pyx_v_i;
  __Pyx_RefNannyDeclarations
  size_t __pyx_t_1;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  __Pyx_RefNannySetupContext("_join_collections", 0);

  /* "resiliparse/parse/html.pyx":1127
 *     """
 * 
 *     cdef size_t i = 0             # <<<<<<<<<<<<<<
 *     for i in range(lxb_dom_collection_length(source)):
 *         lxb_dom_collection_append(target, lxb_dom_collection_element(source, i))
 */
  __pyx_v_i = 0;

  /* "resiliparse/parse/html.pyx":1128
 * 
 *     cdef size_t i = 0
 *     for i in range(lxb_dom_collection_length(source)):             # <<<<<<<<<<<<<<
 *         lxb_dom_collection_append(target, lxb_dom_collection_element(source, i))
 * 
 */
  __pyx_t_1 = lxb_dom_collection_length(__pyx_v_source);
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "resiliparse/parse/html.pyx":1129
 *     cdef size_t i = 0
 *     for i in range(lxb_dom_collection_length(source)):
 *         lxb_dom_collection_append(target, lxb_dom_collection_element(source, i))             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (void)(lxb_dom_collection_append(__pyx_v_target, lxb_dom_collection_element(__pyx_v_source, __pyx_v_i)));
  }

  /* "resiliparse/parse/html.pyx":1119
 * 
 * 
 * cdef inline void _join_collections(lxb_dom_collection_t* target, lxb_dom_collection_t* source):             # <<<<<<<<<<<<<<
 *     """
 *     Append elements from ``source` to ``target``.
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "resiliparse/parse/html.pyx":1143
 *     """
 * 
 *     def __cinit__(self, HTMLTree tree):             # <<<<<<<<<<<<<<
 *         self.tree = tree
 *         self.coll = NULL
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tree,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tree)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 1143, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_tree = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1143, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tree), __pyx_ptype_11resiliparse_5parse_4html_HTMLTree, 1, "tree", 0))) __PYX_ERR(0, 1143, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection___cinit__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), __pyx_v_tree);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_13DOMCollection___cinit__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "resiliparse/parse/html.pyx":1144
 * 
 *     def __cinit__(self, HTMLTree tree):
 *         self.tree = tree             # <<<<<<<<<<<<<<
 *         self.coll = NULL
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_tree));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_tree));
  __Pyx_GOTREF(__pyx_v_self->tree);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->tree));
  __pyx_v_self->tree = __pyx_v_tree;

  /* "resiliparse/parse/html.pyx":1145
 *     def __cinit__(self, HTMLTree tree):
 *         self.tree = tree
 *         self.coll = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_v_self->coll = NULL;

  /* "resiliparse/parse/html.pyx":1143
 *     """
 * 
 *     def __cinit__(self, HTMLTree tree):             # <<<<<<<<<<<<<<
 *         self.tree = tree
 *         self.coll = NULL
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1147
 *         self.coll = NULL
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.coll != NULL:
 *             lxb_dom_collection_destroy(self.coll, True)
 */

/* Python wrapper */
static void __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_2__dealloc__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_2__dealloc__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "resiliparse/parse/html.pyx":1148
 * 
 *     def __dealloc__(self):
 *         if self.coll != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_collection_destroy(self.coll, True)
 *             self.coll = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->coll != NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1149
 *     def __dealloc__(self):
 *         if self.coll != NULL:
 *             lxb_dom_collection_destroy(self.coll, True)             # <<<<<<<<<<<<<<
 *             self.coll = NULL
 * 
 */
    (void)(lxb_dom_collection_destroy(__pyx_v_self->coll, 1));

    /* "resiliparse/parse/html.pyx":1150
 *         if self.coll != NULL:
 *             lxb_dom_collection_destroy(self.coll, True)
 *             self.coll = NULL             # <<<<<<<<<<<<<<
 * 
 *     cdef inline size_t _wrap_idx(self, ssize_t idx):
 */
    __pyx_v_self->coll = NULL;

    /* "resiliparse/parse/html.pyx":1148
 * 
 *     def __dealloc__(self):
 *         if self.coll != NULL:             # <<<<<<<<<<<<<<
 *             lxb_dom_collection_destroy(self.coll, True)
 *             self.coll = NULL
 */
  }

  /* "resiliparse/parse/html.pyx":1147
 *         self.coll = NULL
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.coll != NULL:
 *             lxb_dom_collection_destroy(self.coll, True)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "resiliparse/parse/html.pyx":1152
 *             self.coll = NULL
 * 
 *     cdef inline size_t _wrap_idx(self, ssize_t idx):             # <<<<<<<<<<<<<<
 *         if idx >= 0:
 *             return idx
 */

static CYTHON_INLINE size_t __pyx_f_11resiliparse_5parse_4html_13DOMCollection__wrap_idx(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, Py_ssize_t __pyx_v_idx) {
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_wrap_idx", 0);

  /* "resiliparse/parse/html.pyx":1153
 * 
 *     cdef inline size_t _wrap_idx(self, ssize_t idx):
 *         if idx >= 0:             # <<<<<<<<<<<<<<
 *             return idx
 *         return idx % <ssize_t>lxb_dom_collection_length(self.coll)
 */
  __pyx_t_1 = ((__pyx_v_idx >= 0) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1154
 *     cdef inline size_t _wrap_idx(self, ssize_t idx):
 *         if idx >= 0:
 *             return idx             # <<<<<<<<<<<<<<
 *         return idx % <ssize_t>lxb_dom_collection_length(self.coll)
 * 
 */
    __pyx_r = __pyx_v_idx;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1153
 * 
 *     cdef inline size_t _wrap_idx(self, ssize_t idx):
 *         if idx >= 0:             # <<<<<<<<<<<<<<
 *             return idx
 *         return idx % <ssize_t>lxb_dom_collection_length(self.coll)
 */
  }

  /* "resiliparse/parse/html.pyx":1155
 *         if idx >= 0:
 *             return idx
 *         return idx % <ssize_t>lxb_dom_collection_length(self.coll)             # <<<<<<<<<<<<<<
 * 
 *     cdef DOMCollection _forward_collection_match(self, bytes func, attrs):
 */
  __pyx_t_2 = ((Py_ssize_t)lxb_dom_collection_length(__pyx_v_self->coll));
  if (unlikely(__pyx_t_2 == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
    __PYX_ERR(0, 1155, __pyx_L1_error)
  }
  __pyx_r = __Pyx_mod_Py_ssize_t(__pyx_v_idx, __pyx_t_2);
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1152
 *             self.coll = NULL
 * 
 *     cdef inline size_t _wrap_idx(self, ssize_t idx):             # <<<<<<<<<<<<<<
 *         if idx >= 0:
 *             return idx
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMCollection._wrap_idx", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1157
 *         return idx % <ssize_t>lxb_dom_collection_length(self.coll)
 * 
 *     cdef DOMCollection _forward_collection_match(self, bytes func, attrs):             # <<<<<<<<<<<<<<
 *         """
 *         Forward DOM multi-element match operations to all items in the collection and aggregate the results.
 */

static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection__forward_collection_match(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_func, PyObject *__pyx_v_attrs) {
  lxb_dom_collection_t *__pyx_v_joined_coll;
  lxb_dom_node_t *__pyx_v_node;
  lxb_dom_collection_t *__pyx_v_matches;
  size_t __pyx_v_i;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  size_t __pyx_t_6;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  lxb_dom_collection_t *__pyx_t_11;
  struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_attr_impl __pyx_t_12;
  struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_class_name_impl __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_forward_collection_match", 0);

  /* "resiliparse/parse/html.pyx":1165
 *         :return: aggregated collection or single element
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->tree) == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_v_self->coll == NULL) != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":1166
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             raise RuntimeError('Trying to select items from uninitialized collection')             # <<<<<<<<<<<<<<
 * 
 *         if lxb_dom_collection_length(self.coll) == 0:
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1166, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1165
 *         :return: aggregated collection or single element
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1168
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 *         if lxb_dom_collection_length(self.coll) == 0:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  __pyx_t_1 = ((lxb_dom_collection_length(__pyx_v_self->coll) == 0) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1169
 * 
 *         if lxb_dom_collection_length(self.coll) == 0:
 *             return self             # <<<<<<<<<<<<<<
 * 
 *         cdef lxb_dom_collection_t* joined_coll = lxb_dom_collection_make(self.coll.document,
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __pyx_r = __pyx_v_self;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1168
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 *         if lxb_dom_collection_length(self.coll) == 0:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1171
 *             return self
 * 
 *         cdef lxb_dom_collection_t* joined_coll = lxb_dom_collection_make(self.coll.document,             # <<<<<<<<<<<<<<
 *                                                                          lxb_dom_collection_length(self.coll) * 2)
 * 
 */
  __pyx_v_joined_coll = lxb_dom_collection_make(__pyx_v_self->coll->document, (lxb_dom_collection_length(__pyx_v_self->coll) * 2));

  /* "resiliparse/parse/html.pyx":1174
 *                                                                          lxb_dom_collection_length(self.coll) * 2)
 * 
 *         cdef lxb_dom_node_t* node = NULL             # <<<<<<<<<<<<<<
 *         cdef lxb_dom_collection_t* matches = NULL
 *         cdef size_t i = 0
 */
  __pyx_v_node = NULL;

  /* "resiliparse/parse/html.pyx":1175
 * 
 *         cdef lxb_dom_node_t* node = NULL
 *         cdef lxb_dom_collection_t* matches = NULL             # <<<<<<<<<<<<<<
 *         cdef size_t i = 0
 *         for i in range(lxb_dom_collection_length(self.coll)):
 */
  __pyx_v_matches = NULL;

  /* "resiliparse/parse/html.pyx":1176
 *         cdef lxb_dom_node_t* node = NULL
 *         cdef lxb_dom_collection_t* matches = NULL
 *         cdef size_t i = 0             # <<<<<<<<<<<<<<
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = lxb_dom_collection_node(self.coll, i)
 */
  __pyx_v_i = 0;

  /* "resiliparse/parse/html.pyx":1177
 *         cdef lxb_dom_collection_t* matches = NULL
 *         cdef size_t i = 0
 *         for i in range(lxb_dom_collection_length(self.coll)):             # <<<<<<<<<<<<<<
 *             node = lxb_dom_collection_node(self.coll, i)
 *             if func == b'by_attr':
 */
  __pyx_t_5 = lxb_dom_collection_length(__pyx_v_self->coll);
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
    __pyx_v_i = __pyx_t_7;

    /* "resiliparse/parse/html.pyx":1178
 *         cdef size_t i = 0
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = lxb_dom_collection_node(self.coll, i)             # <<<<<<<<<<<<<<
 *             if func == b'by_attr':
 *                 matches = get_elements_by_attr_impl(node, attrs[0], attrs[1], attrs[2], attrs[3])
 */
    __pyx_v_node = lxb_dom_collection_node(__pyx_v_self->coll, __pyx_v_i);

    /* "resiliparse/parse/html.pyx":1179
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = lxb_dom_collection_node(self.coll, i)
 *             if func == b'by_attr':             # <<<<<<<<<<<<<<
 *                 matches = get_elements_by_attr_impl(node, attrs[0], attrs[1], attrs[2], attrs[3])
 *             if func == b'by_class':
 */
    __pyx_t_1 = (__Pyx_PyBytes_Equals(__pyx_v_func, __pyx_n_b_by_attr, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1179, __pyx_L1_error)
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "resiliparse/parse/html.pyx":1180
 *             node = lxb_dom_collection_node(self.coll, i)
 *             if func == b'by_attr':
 *                 matches = get_elements_by_attr_impl(node, attrs[0], attrs[1], attrs[2], attrs[3])             # <<<<<<<<<<<<<<
 *             if func == b'by_class':
 *                 matches = get_elements_by_class_name_impl(node, attrs[0], attrs[1])
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_attrs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (!(likely(PyBytes_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 1180, __pyx_L1_error)
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_attrs, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (!(likely(PyBytes_CheckExact(__pyx_t_8))||((__pyx_t_8) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_8)->tp_name), 0))) __PYX_ERR(0, 1180, __pyx_L1_error)
      __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_attrs, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyInt_As_size_t(__pyx_t_9); if (unlikely((__pyx_t_10 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1180, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_attrs, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1180, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_12.__pyx_n = 2;
      __pyx_t_12.init_size = __pyx_t_10;
      __pyx_t_12.case_insensitive = __pyx_t_3;
      __pyx_t_11 = __pyx_f_11resiliparse_5parse_4html_get_elements_by_attr_impl(__pyx_v_node, ((PyObject*)__pyx_t_4), ((PyObject*)__pyx_t_8), &__pyx_t_12); 
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_matches = __pyx_t_11;

      /* "resiliparse/parse/html.pyx":1179
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = lxb_dom_collection_node(self.coll, i)
 *             if func == b'by_attr':             # <<<<<<<<<<<<<<
 *                 matches = get_elements_by_attr_impl(node, attrs[0], attrs[1], attrs[2], attrs[3])
 *             if func == b'by_class':
 */
    }

    /* "resiliparse/parse/html.pyx":1181
 *             if func == b'by_attr':
 *                 matches = get_elements_by_attr_impl(node, attrs[0], attrs[1], attrs[2], attrs[3])
 *             if func == b'by_class':             # <<<<<<<<<<<<<<
 *                 matches = get_elements_by_class_name_impl(node, attrs[0], attrs[1])
 *             elif func == b'by_tag':
 */
    __pyx_t_3 = (__Pyx_PyBytes_Equals(__pyx_v_func, __pyx_n_b_by_class, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1181, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (__pyx_t_1) {

      /* "resiliparse/parse/html.pyx":1182
 *                 matches = get_elements_by_attr_impl(node, attrs[0], attrs[1], attrs[2], attrs[3])
 *             if func == b'by_class':
 *                 matches = get_elements_by_class_name_impl(node, attrs[0], attrs[1])             # <<<<<<<<<<<<<<
 *             elif func == b'by_tag':
 *                 matches = get_elements_by_tag_name_impl(node, attrs[0])
 */
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_attrs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (!(likely(PyBytes_CheckExact(__pyx_t_8))||((__pyx_t_8) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_8)->tp_name), 0))) __PYX_ERR(0, 1182, __pyx_L1_error)
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_attrs, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = __Pyx_PyInt_As_size_t(__pyx_t_4); if (unlikely((__pyx_t_10 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1182, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13.__pyx_n = 1;
      __pyx_t_13.init_size = __pyx_t_10;
      __pyx_t_11 = __pyx_f_11resiliparse_5parse_4html_get_elements_by_class_name_impl(__pyx_v_node, ((PyObject*)__pyx_t_8), &__pyx_t_13); 
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_matches = __pyx_t_11;

      /* "resiliparse/parse/html.pyx":1181
 *             if func == b'by_attr':
 *                 matches = get_elements_by_attr_impl(node, attrs[0], attrs[1], attrs[2], attrs[3])
 *             if func == b'by_class':             # <<<<<<<<<<<<<<
 *                 matches = get_elements_by_class_name_impl(node, attrs[0], attrs[1])
 *             elif func == b'by_tag':
 */
      goto __pyx_L10;
    }

    /* "resiliparse/parse/html.pyx":1183
 *             if func == b'by_class':
 *                 matches = get_elements_by_class_name_impl(node, attrs[0], attrs[1])
 *             elif func == b'by_tag':             # <<<<<<<<<<<<<<
 *                 matches = get_elements_by_tag_name_impl(node, attrs[0])
 *             elif func == b'selector_all':
 */
    __pyx_t_1 = (__Pyx_PyBytes_Equals(__pyx_v_func, __pyx_n_b_by_tag, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1183, __pyx_L1_error)
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "resiliparse/parse/html.pyx":1184
 *                 matches = get_elements_by_class_name_impl(node, attrs[0], attrs[1])
 *             elif func == b'by_tag':
 *                 matches = get_elements_by_tag_name_impl(node, attrs[0])             # <<<<<<<<<<<<<<
 *             elif func == b'selector_all':
 *                 matches = query_selector_all_impl(node, self.tree, attrs[0])
 */
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_attrs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (!(likely(PyBytes_CheckExact(__pyx_t_8))||((__pyx_t_8) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_8)->tp_name), 0))) __PYX_ERR(0, 1184, __pyx_L1_error)
      __pyx_v_matches = __pyx_f_11resiliparse_5parse_4html_get_elements_by_tag_name_impl(__pyx_v_node, ((PyObject*)__pyx_t_8));
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "resiliparse/parse/html.pyx":1183
 *             if func == b'by_class':
 *                 matches = get_elements_by_class_name_impl(node, attrs[0], attrs[1])
 *             elif func == b'by_tag':             # <<<<<<<<<<<<<<
 *                 matches = get_elements_by_tag_name_impl(node, attrs[0])
 *             elif func == b'selector_all':
 */
      goto __pyx_L10;
    }

    /* "resiliparse/parse/html.pyx":1185
 *             elif func == b'by_tag':
 *                 matches = get_elements_by_tag_name_impl(node, attrs[0])
 *             elif func == b'selector_all':             # <<<<<<<<<<<<<<
 *                 matches = query_selector_all_impl(node, self.tree, attrs[0])
 * 
 */
    __pyx_t_3 = (__Pyx_PyBytes_Equals(__pyx_v_func, __pyx_n_b_selector_all, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1185, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (__pyx_t_1) {

      /* "resiliparse/parse/html.pyx":1186
 *                 matches = get_elements_by_tag_name_impl(node, attrs[0])
 *             elif func == b'selector_all':
 *                 matches = query_selector_all_impl(node, self.tree, attrs[0])             # <<<<<<<<<<<<<<
 * 
 *             if matches != NULL:
 */
      __pyx_t_8 = ((PyObject *)__pyx_v_self->tree);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_attrs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (!(likely(PyBytes_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 1186, __pyx_L1_error)
      __pyx_v_matches = __pyx_f_11resiliparse_5parse_4html_query_selector_all_impl(__pyx_v_node, ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_8), ((PyObject*)__pyx_t_4), NULL);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "resiliparse/parse/html.pyx":1185
 *             elif func == b'by_tag':
 *                 matches = get_elements_by_tag_name_impl(node, attrs[0])
 *             elif func == b'selector_all':             # <<<<<<<<<<<<<<
 *                 matches = query_selector_all_impl(node, self.tree, attrs[0])
 * 
 */
    }
    __pyx_L10:;

    /* "resiliparse/parse/html.pyx":1188
 *                 matches = query_selector_all_impl(node, self.tree, attrs[0])
 * 
 *             if matches != NULL:             # <<<<<<<<<<<<<<
 *                 _join_collections(joined_coll, matches)
 *                 lxb_dom_collection_destroy(matches, True)
 */
    __pyx_t_1 = ((__pyx_v_matches != NULL) != 0);
    if (__pyx_t_1) {

      /* "resiliparse/parse/html.pyx":1189
 * 
 *             if matches != NULL:
 *                 _join_collections(joined_coll, matches)             # <<<<<<<<<<<<<<
 *                 lxb_dom_collection_destroy(matches, True)
 * 
 */
      __pyx_f_11resiliparse_5parse_4html__join_collections(__pyx_v_joined_coll, __pyx_v_matches);

      /* "resiliparse/parse/html.pyx":1190
 *             if matches != NULL:
 *                 _join_collections(joined_coll, matches)
 *                 lxb_dom_collection_destroy(matches, True)             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_collection(self.tree, joined_coll)
 */
      (void)(lxb_dom_collection_destroy(__pyx_v_matches, 1));

      /* "resiliparse/parse/html.pyx":1188
 *                 matches = query_selector_all_impl(node, self.tree, attrs[0])
 * 
 *             if matches != NULL:             # <<<<<<<<<<<<<<
 *                 _join_collections(joined_coll, matches)
 *                 lxb_dom_collection_destroy(matches, True)
 */
    }
  }

  /* "resiliparse/parse/html.pyx":1192
 *                 lxb_dom_collection_destroy(matches, True)
 * 
 *         return _create_dom_collection(self.tree, joined_coll)             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=False):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_4 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_8 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_collection(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_4), __pyx_v_joined_coll)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_8);
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1157
 *         return idx % <ssize_t>lxb_dom_collection_length(self.coll)
 * 
 *     cdef DOMCollection _forward_collection_match(self, bytes func, attrs):             # <<<<<<<<<<<<<<
 *         """
 *         Forward DOM multi-element match operations to all items in the collection and aggregate the results.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection._forward_collection_match", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1194
 *         return _create_dom_collection(self.tree, joined_coll)
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_element_by_id(self, element_id, case_insensitive=False)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_5get_element_by_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_element_id, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id *__pyx_optional_args) {
  int __pyx_v_case_insensitive = ((int)0);
  lxb_dom_node_t *__pyx_v_node;
  size_t __pyx_v_i;
  PyObject *__pyx_v_id_bytes = 0;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  size_t __pyx_t_11;
  size_t __pyx_t_12;
  size_t __pyx_t_13;
  lxb_dom_node_t *__pyx_t_14;
  struct __pyx_opt_args_11resiliparse_5parse_4html_get_element_by_id_impl __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_element_by_id", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_case_insensitive = __pyx_optional_args->case_insensitive;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_element_by_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_5get_element_by_id)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_case_insensitive); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1194, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_element_id, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1194, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_element_id, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1194, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1194, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_element_id);
          __Pyx_GIVEREF(__pyx_v_element_id);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_element_id);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1194, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 1194, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1208
 *         :rtype: DOMNode or None
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 */
  __pyx_t_9 = (((PyObject *)__pyx_v_self->tree) == Py_None);
  __pyx_t_10 = (__pyx_t_9 != 0);
  if (!__pyx_t_10) {
  } else {
    __pyx_t_8 = __pyx_t_10;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = ((__pyx_v_self->coll == NULL) != 0);
  __pyx_t_8 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_8)) {

    /* "resiliparse/parse/html.pyx":1209
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             raise RuntimeError('Trying to select items from uninitialized collection')             # <<<<<<<<<<<<<<
 * 
 *         cdef lxb_dom_node_t* node
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1209, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1208
 *         :rtype: DOMNode or None
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1212
 * 
 *         cdef lxb_dom_node_t* node
 *         cdef size_t i = 0             # <<<<<<<<<<<<<<
 *         cdef bytes id_bytes = element_id.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):
 */
  __pyx_v_i = 0;

  /* "resiliparse/parse/html.pyx":1213
 *         cdef lxb_dom_node_t* node
 *         cdef size_t i = 0
 *         cdef bytes id_bytes = element_id.encode()             # <<<<<<<<<<<<<<
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = get_element_by_id_impl(lxb_dom_collection_node(self.coll, i), id_bytes, case_insensitive)
 */
  if (unlikely(__pyx_v_element_id == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1213, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_element_id, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_id_bytes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":1214
 *         cdef size_t i = 0
 *         cdef bytes id_bytes = element_id.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):             # <<<<<<<<<<<<<<
 *             node = get_element_by_id_impl(lxb_dom_collection_node(self.coll, i), id_bytes, case_insensitive)
 *             if node != NULL:
 */
  __pyx_t_11 = lxb_dom_collection_length(__pyx_v_self->coll);
  __pyx_t_12 = __pyx_t_11;
  for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
    __pyx_v_i = __pyx_t_13;

    /* "resiliparse/parse/html.pyx":1215
 *         cdef bytes id_bytes = element_id.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = get_element_by_id_impl(lxb_dom_collection_node(self.coll, i), id_bytes, case_insensitive)             # <<<<<<<<<<<<<<
 *             if node != NULL:
 *                 return _create_dom_node(self.tree, node)
 */
    __pyx_t_15.__pyx_n = 1;
    __pyx_t_15.case_insensitive = __pyx_v_case_insensitive;
    __pyx_t_14 = __pyx_f_11resiliparse_5parse_4html_get_element_by_id_impl(lxb_dom_collection_node(__pyx_v_self->coll, __pyx_v_i), __pyx_v_id_bytes, &__pyx_t_15); 
    __pyx_v_node = __pyx_t_14;

    /* "resiliparse/parse/html.pyx":1216
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = get_element_by_id_impl(lxb_dom_collection_node(self.coll, i), id_bytes, case_insensitive)
 *             if node != NULL:             # <<<<<<<<<<<<<<
 *                 return _create_dom_node(self.tree, node)
 * 
 */
    __pyx_t_8 = ((__pyx_v_node != NULL) != 0);
    if (__pyx_t_8) {

      /* "resiliparse/parse/html.pyx":1217
 *             node = get_element_by_id_impl(lxb_dom_collection_node(self.coll, i), id_bytes, case_insensitive)
 *             if node != NULL:
 *                 return _create_dom_node(self.tree, node)             # <<<<<<<<<<<<<<
 * 
 *         return None
 */
      __Pyx_XDECREF(((PyObject *)__pyx_r));
      __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_2 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), __pyx_v_node)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "resiliparse/parse/html.pyx":1216
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = get_element_by_id_impl(lxb_dom_collection_node(self.coll, i), id_bytes, case_insensitive)
 *             if node != NULL:             # <<<<<<<<<<<<<<
 *                 return _create_dom_node(self.tree, node)
 * 
 */
    }
  }

  /* "resiliparse/parse/html.pyx":1219
 *                 return _create_dom_node(self.tree, node)
 * 
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=False):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1194
 *         return _create_dom_collection(self.tree, joined_coll)
 * 
 *     cpdef DOMNode get_element_by_id(self, str element_id, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_element_by_id(self, element_id, case_insensitive=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_element_by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_id_bytes);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_5get_element_by_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_4get_element_by_id[] = "\n        get_element_by_id(self, element_id, case_insensitive=False)\n\n        Within all elements in this collection, find and return the element whose ID\n        attribute matches ``element_id``.\n\n        :param element_id: element ID\n        :type element_id: str\n        :param case_insensitive: match ID case-insensitively\n        :type case_insensitive: bool\n        :return: matching element or ``None`` if no such element exists\n        :rtype: DOMNode or None\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_5get_element_by_id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_element_id = 0;
  int __pyx_v_case_insensitive;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_element_by_id (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_element_id,&__pyx_n_s_case_insensitive,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_element_id)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_case_insensitive);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_element_by_id") < 0)) __PYX_ERR(0, 1194, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_element_id = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_case_insensitive = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_case_insensitive == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1194, __pyx_L3_error)
    } else {
      __pyx_v_case_insensitive = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_element_by_id", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1194, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_element_by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_element_id), (&PyUnicode_Type), 1, "element_id", 1))) __PYX_ERR(0, 1194, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_4get_element_by_id(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), __pyx_v_element_id, __pyx_v_case_insensitive);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_4get_element_by_id(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_element_id, int __pyx_v_case_insensitive) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_element_by_id", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.case_insensitive = __pyx_v_case_insensitive;
  __pyx_t_1 = ((PyObject *)__pyx_vtabptr_11resiliparse_5parse_4html_DOMCollection->get_element_by_id(__pyx_v_self, __pyx_v_element_id, 1, &__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_element_by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1221
 *         return None
 * 
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_attr(self, attr_name, attr_value, case_insensitive=False)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_7get_elements_by_attr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr *__pyx_optional_args) {
  int __pyx_v_case_insensitive = ((int)0);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_attr", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_case_insensitive = __pyx_optional_args->case_insensitive;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_elements_by_attr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1221, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_7get_elements_by_attr)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_case_insensitive); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1221, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_attr_name, __pyx_v_attr_value, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1221, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_attr_name, __pyx_v_attr_value, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1221, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1221, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_attr_name);
          __Pyx_GIVEREF(__pyx_v_attr_name);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_attr_name);
          __Pyx_INCREF(__pyx_v_attr_value);
          __Pyx_GIVEREF(__pyx_v_attr_value);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_attr_value);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1221, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMCollection))))) __PYX_ERR(0, 1221, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1237
 *         :rtype: DOMCollection or None
 *         """
 *         return self._forward_collection_match(b'by_attr',             # <<<<<<<<<<<<<<
 *                                               (attr_name.encode(), attr_value.encode(),  10, case_insensitive))
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));

  /* "resiliparse/parse/html.pyx":1238
 *         """
 *         return self._forward_collection_match(b'by_attr',
 *                                               (attr_name.encode(), attr_value.encode(),  10, case_insensitive))             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=False):
 */
  if (unlikely(__pyx_v_attr_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1238, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_attr_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_v_attr_value == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1238, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_attr_value, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_case_insensitive); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyTuple_New(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_2);
  __Pyx_INCREF(__pyx_int_10);
  __Pyx_GIVEREF(__pyx_int_10);
  PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_int_10);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_t_4);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;

  /* "resiliparse/parse/html.pyx":1237
 *         :rtype: DOMCollection or None
 *         """
 *         return self._forward_collection_match(b'by_attr',             # <<<<<<<<<<<<<<
 *                                               (attr_name.encode(), attr_value.encode(),  10, case_insensitive))
 * 
 */
  __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self->__pyx_vtab)->_forward_collection_match(__pyx_v_self, __pyx_n_b_by_attr, __pyx_t_7)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1221
 *         return None
 * 
 *     cpdef DOMCollection get_elements_by_attr(self, str attr_name, str attr_value, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_attr(self, attr_name, attr_value, case_insensitive=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_elements_by_attr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_7get_elements_by_attr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_6get_elements_by_attr[] = "\n        get_elements_by_attr(self, attr_name, attr_value, case_insensitive=False)\n\n        Within all elements in this collection, find the elements matching the given arbitrary attribute\n        name and value and return a :class:`DOMCollection` with the aggregated results.\n\n        :param attr_name: attribute name\n        :type attr_name: str\n        :param attr_value: attribute value\n        :type attr_name: str\n        :param case_insensitive: match attribute value case-insensitively\n        :type case_insensitive: bool\n        :return: collection of matching elements\n        :rtype: DOMCollection or None\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_7get_elements_by_attr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_attr_name = 0;
  PyObject *__pyx_v_attr_value = 0;
  int __pyx_v_case_insensitive;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_elements_by_attr (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_attr_name,&__pyx_n_s_attr_value,&__pyx_n_s_case_insensitive,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_attr_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_attr_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_elements_by_attr", 0, 2, 3, 1); __PYX_ERR(0, 1221, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_case_insensitive);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_elements_by_attr") < 0)) __PYX_ERR(0, 1221, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_attr_name = ((PyObject*)values[0]);
    __pyx_v_attr_value = ((PyObject*)values[1]);
    if (values[2]) {
      __pyx_v_case_insensitive = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_case_insensitive == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1221, __pyx_L3_error)
    } else {
      __pyx_v_case_insensitive = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_elements_by_attr", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1221, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_elements_by_attr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_name), (&PyUnicode_Type), 1, "attr_name", 1))) __PYX_ERR(0, 1221, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr_value), (&PyUnicode_Type), 1, "attr_value", 1))) __PYX_ERR(0, 1221, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_6get_elements_by_attr(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), __pyx_v_attr_name, __pyx_v_attr_value, __pyx_v_case_insensitive);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_6get_elements_by_attr(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_attr_value, int __pyx_v_case_insensitive) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_attr", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.case_insensitive = __pyx_v_case_insensitive;
  __pyx_t_1 = ((PyObject *)__pyx_vtabptr_11resiliparse_5parse_4html_DOMCollection->get_elements_by_attr(__pyx_v_self, __pyx_v_attr_name, __pyx_v_attr_value, 1, &__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_elements_by_attr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1240
 *                                               (attr_name.encode(), attr_value.encode(),  10, case_insensitive))
 * 
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_class_name(self, element_class, case_insensitive=False)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_9get_elements_by_class_name(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name *__pyx_optional_args) {
  int __pyx_v_case_insensitive = ((int)0);
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_class_name", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_case_insensitive = __pyx_optional_args->case_insensitive;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_elements_by_class_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_9get_elements_by_class_name)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_case_insensitive); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1240, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_class_name, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1240, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_class_name, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1240, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1240, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_class_name);
          __Pyx_GIVEREF(__pyx_v_class_name);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_class_name);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1240, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMCollection))))) __PYX_ERR(0, 1240, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1254
 *         :rtype: DOMCollection or None
 *         """
 *         return self._forward_collection_match(b'by_class', (class_name.encode(), 10))             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_class_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1254, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_class_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_int_10);
  __Pyx_GIVEREF(__pyx_int_10);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_10);
  __pyx_t_1 = 0;
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self->__pyx_vtab)->_forward_collection_match(__pyx_v_self, __pyx_n_b_by_class, __pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1240
 *                                               (attr_name.encode(), attr_value.encode(),  10, case_insensitive))
 * 
 *     cpdef DOMCollection get_elements_by_class_name(self, str class_name, bint case_insensitive=False):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_class_name(self, element_class, case_insensitive=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_elements_by_class_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_9get_elements_by_class_name(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_8get_elements_by_class_name[] = "\n        get_elements_by_class_name(self, element_class, case_insensitive=False)\n\n        Within all elements in this collection, find the elements matching the given class name\n        and return a :class:`DOMCollection` with the aggregated results.\n\n        :param class_name: element class\n        :type class_name: str\n        :param case_insensitive: match class name case-insensitively\n        :type case_insensitive: bool\n        :return: collection of matching elements\n        :rtype: DOMCollection or None\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_9get_elements_by_class_name(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_class_name = 0;
  int __pyx_v_case_insensitive;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_elements_by_class_name (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_class_name,&__pyx_n_s_case_insensitive,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_class_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_case_insensitive);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_elements_by_class_name") < 0)) __PYX_ERR(0, 1240, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_class_name = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_case_insensitive = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_case_insensitive == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1240, __pyx_L3_error)
    } else {
      __pyx_v_case_insensitive = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_elements_by_class_name", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1240, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_elements_by_class_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_class_name), (&PyUnicode_Type), 1, "class_name", 1))) __PYX_ERR(0, 1240, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_8get_elements_by_class_name(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), __pyx_v_class_name, __pyx_v_case_insensitive);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_8get_elements_by_class_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_class_name, int __pyx_v_case_insensitive) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_class_name", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.case_insensitive = __pyx_v_case_insensitive;
  __pyx_t_1 = ((PyObject *)__pyx_vtabptr_11resiliparse_5parse_4html_DOMCollection->get_elements_by_class_name(__pyx_v_self, __pyx_v_class_name, 1, &__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_elements_by_class_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1256
 *         return self._forward_collection_match(b'by_class', (class_name.encode(), 10))
 * 
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_tag_name(self, tag_name)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_11get_elements_by_tag_name(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_tag_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_tag_name, int __pyx_skip_dispatch) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_tag_name", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_elements_by_tag_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1256, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_11get_elements_by_tag_name)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_tag_name) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_tag_name);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1256, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMCollection))))) __PYX_ERR(0, 1256, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1268
 *         :rtype: DOMCollection
 *         """
 *         return self._forward_collection_match(b'by_tag', (tag_name.encode(),))             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode query_selector(self, str selector):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_tag_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1268, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_tag_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self->__pyx_vtab)->_forward_collection_match(__pyx_v_self, __pyx_n_b_by_tag, __pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1256
 *         return self._forward_collection_match(b'by_class', (class_name.encode(), 10))
 * 
 *     cpdef DOMCollection get_elements_by_tag_name(self, str tag_name):             # <<<<<<<<<<<<<<
 *         """
 *         get_elements_by_tag_name(self, tag_name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_elements_by_tag_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_11get_elements_by_tag_name(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_10get_elements_by_tag_name[] = "\n        get_elements_by_tag_name(self, tag_name)\n\n        Within all elements in this collection, find the elements with the given tag name and return\n        a :class:`DOMCollection` with the aggregated results.\n\n        :param tag_name: tag name for matching elements\n        :type tag_name: str\n        :return: collection of matching elements\n        :rtype: DOMCollection\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_11get_elements_by_tag_name(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_elements_by_tag_name (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tag_name), (&PyUnicode_Type), 1, "tag_name", 1))) __PYX_ERR(0, 1256, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_10get_elements_by_tag_name(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), ((PyObject*)__pyx_v_tag_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_10get_elements_by_tag_name(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_tag_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_elements_by_tag_name", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_tag_name(__pyx_v_self, __pyx_v_tag_name, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.get_elements_by_tag_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1270
 *         return self._forward_collection_match(b'by_tag', (tag_name.encode(),))
 * 
 *     cpdef DOMNode query_selector(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         query_selector(self, selector)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_13query_selector(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_query_selector(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch) {
  lxb_dom_node_t *__pyx_v_node;
  size_t __pyx_v_i;
  PyObject *__pyx_v_selector_bytes = 0;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  size_t __pyx_t_8;
  size_t __pyx_t_9;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_query_selector); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_13query_selector)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_selector) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_selector);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1270, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 1270, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1283
 *         :rtype: DOMNode or None
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 */
  __pyx_t_6 = (((PyObject *)__pyx_v_self->tree) == Py_None);
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = ((__pyx_v_self->coll == NULL) != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":1284
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             raise RuntimeError('Trying to select items from uninitialized collection')             # <<<<<<<<<<<<<<
 * 
 *         cdef lxb_dom_node_t* node
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1284, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1283
 *         :rtype: DOMNode or None
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1287
 * 
 *         cdef lxb_dom_node_t* node
 *         cdef size_t i = 0             # <<<<<<<<<<<<<<
 *         cdef bytes selector_bytes = selector.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):
 */
  __pyx_v_i = 0;

  /* "resiliparse/parse/html.pyx":1288
 *         cdef lxb_dom_node_t* node
 *         cdef size_t i = 0
 *         cdef bytes selector_bytes = selector.encode()             # <<<<<<<<<<<<<<
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = query_selector_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes)
 */
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1288, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_selector, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_selector_bytes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":1289
 *         cdef size_t i = 0
 *         cdef bytes selector_bytes = selector.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):             # <<<<<<<<<<<<<<
 *             node = query_selector_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes)
 *             if node != NULL:
 */
  __pyx_t_8 = lxb_dom_collection_length(__pyx_v_self->coll);
  __pyx_t_9 = __pyx_t_8;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
    __pyx_v_i = __pyx_t_10;

    /* "resiliparse/parse/html.pyx":1290
 *         cdef bytes selector_bytes = selector.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = query_selector_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes)             # <<<<<<<<<<<<<<
 *             if node != NULL:
 *                 return _create_dom_node(self.tree, node)
 */
    __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_node = __pyx_f_11resiliparse_5parse_4html_query_selector_impl(lxb_dom_collection_node(__pyx_v_self->coll, __pyx_v_i), ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), __pyx_v_selector_bytes);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "resiliparse/parse/html.pyx":1291
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = query_selector_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes)
 *             if node != NULL:             # <<<<<<<<<<<<<<
 *                 return _create_dom_node(self.tree, node)
 * 
 */
    __pyx_t_5 = ((__pyx_v_node != NULL) != 0);
    if (__pyx_t_5) {

      /* "resiliparse/parse/html.pyx":1292
 *             node = query_selector_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes)
 *             if node != NULL:
 *                 return _create_dom_node(self.tree, node)             # <<<<<<<<<<<<<<
 * 
 *         return None
 */
      __Pyx_XDECREF(((PyObject *)__pyx_r));
      __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_2 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), __pyx_v_node)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "resiliparse/parse/html.pyx":1291
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             node = query_selector_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes)
 *             if node != NULL:             # <<<<<<<<<<<<<<
 *                 return _create_dom_node(self.tree, node)
 * 
 */
    }
  }

  /* "resiliparse/parse/html.pyx":1294
 *                 return _create_dom_node(self.tree, node)
 * 
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMCollection query_selector_all(self, str selector):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1270
 *         return self._forward_collection_match(b'by_tag', (tag_name.encode(),))
 * 
 *     cpdef DOMNode query_selector(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         query_selector(self, selector)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.query_selector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_selector_bytes);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_13query_selector(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_12query_selector[] = "\n        query_selector(self, selector)\n\n        Within all elements in this collection, find and return the first element matching\n        the given CSS selector.This is more efficient than matching with :meth:`query_selector_all`\n        and discarding additional elements.\n\n        :param selector: CSS selector\n        :type selector: str\n        :return: matching element or ``None``\n        :rtype: DOMNode or None\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_13query_selector(PyObject *__pyx_v_self, PyObject *__pyx_v_selector) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_selector (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_selector), (&PyUnicode_Type), 1, "selector", 1))) __PYX_ERR(0, 1270, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_12query_selector(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), ((PyObject*)__pyx_v_selector));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_12query_selector(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_13DOMCollection_query_selector(__pyx_v_self, __pyx_v_selector, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.query_selector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1296
 *         return None
 * 
 *     cpdef DOMCollection query_selector_all(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         query_selector_all(self, selector)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_15query_selector_all(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_f_11resiliparse_5parse_4html_13DOMCollection_query_selector_all(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector_all", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_query_selector_all); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_15query_selector_all)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_selector) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_selector);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1296, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMCollection))))) __PYX_ERR(0, 1296, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1308
 *         :rtype: DOMCollection
 *         """
 *         return self._forward_collection_match(b'selector_all', (selector.encode(),))             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint matches(self, str selector):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1308, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_selector, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self->__pyx_vtab)->_forward_collection_match(__pyx_v_self, __pyx_n_b_selector_all, __pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1296
 *         return None
 * 
 *     cpdef DOMCollection query_selector_all(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         query_selector_all(self, selector)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.query_selector_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_15query_selector_all(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_14query_selector_all[] = "\n        query_selector_all(self, selector)\n\n        Within all elements in this collection, find the elements matching the given CSS selector\n        and return a :class:`DOMCollection` with the aggregated results.\n\n        :param selector: CSS selector\n        :type selector: str\n        :return: collection of matching elements\n        :rtype: DOMCollection\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_15query_selector_all(PyObject *__pyx_v_self, PyObject *__pyx_v_selector) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_selector_all (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_selector), (&PyUnicode_Type), 1, "selector", 1))) __PYX_ERR(0, 1296, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_14query_selector_all(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), ((PyObject*)__pyx_v_selector));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_14query_selector_all(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_selector_all", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_13DOMCollection_query_selector_all(__pyx_v_self, __pyx_v_selector, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.query_selector_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1310
 *         return self._forward_collection_match(b'selector_all', (selector.encode(),))
 * 
 *     cpdef bint matches(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         matches(self, selector)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_17matches(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static int __pyx_f_11resiliparse_5parse_4html_13DOMCollection_matches(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector, int __pyx_skip_dispatch) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_selector_bytes = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  size_t __pyx_t_8;
  size_t __pyx_t_9;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matches", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_matches); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_17matches)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_selector) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_selector);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1310, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1310, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1323
 *         :rtype: bool
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 */
  __pyx_t_6 = (((PyObject *)__pyx_v_self->tree) == Py_None);
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = ((__pyx_v_self->coll == NULL) != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":1324
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             raise RuntimeError('Trying to select items from uninitialized collection')             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t i = 0
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1324, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1323
 *         :rtype: bool
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1326
 *             raise RuntimeError('Trying to select items from uninitialized collection')
 * 
 *         cdef size_t i = 0             # <<<<<<<<<<<<<<
 *         cdef bytes selector_bytes = selector.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):
 */
  __pyx_v_i = 0;

  /* "resiliparse/parse/html.pyx":1327
 * 
 *         cdef size_t i = 0
 *         cdef bytes selector_bytes = selector.encode()             # <<<<<<<<<<<<<<
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             if matches_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes):
 */
  if (unlikely(__pyx_v_selector == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1327, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_selector, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_selector_bytes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":1328
 *         cdef size_t i = 0
 *         cdef bytes selector_bytes = selector.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):             # <<<<<<<<<<<<<<
 *             if matches_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes):
 *                 return True
 */
  __pyx_t_8 = lxb_dom_collection_length(__pyx_v_self->coll);
  __pyx_t_9 = __pyx_t_8;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
    __pyx_v_i = __pyx_t_10;

    /* "resiliparse/parse/html.pyx":1329
 *         cdef bytes selector_bytes = selector.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             if matches_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes):             # <<<<<<<<<<<<<<
 *                 return True
 * 
 */
    __pyx_t_1 = ((PyObject *)__pyx_v_self->tree);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = (__pyx_f_11resiliparse_5parse_4html_matches_impl(lxb_dom_collection_node(__pyx_v_self->coll, __pyx_v_i), ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_1), __pyx_v_selector_bytes) != 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "resiliparse/parse/html.pyx":1330
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             if matches_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes):
 *                 return True             # <<<<<<<<<<<<<<
 * 
 *         return False
 */
      __pyx_r = 1;
      goto __pyx_L0;

      /* "resiliparse/parse/html.pyx":1329
 *         cdef bytes selector_bytes = selector.encode()
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             if matches_impl(lxb_dom_collection_node(self.coll, i), self.tree, selector_bytes):             # <<<<<<<<<<<<<<
 *                 return True
 * 
 */
    }
  }

  /* "resiliparse/parse/html.pyx":1332
 *                 return True
 * 
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1310
 *         return self._forward_collection_match(b'selector_all', (selector.encode(),))
 * 
 *     cpdef bint matches(self, str selector):             # <<<<<<<<<<<<<<
 *         """
 *         matches(self, selector)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("resiliparse.parse.html.DOMCollection.matches", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_selector_bytes);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_17matches(PyObject *__pyx_v_self, PyObject *__pyx_v_selector); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_16matches[] = "\n        matches(self, selector)\n\n        Within all elements in this collection, check whether any element in the DOM tree\n        matches the given CSS selector. This is more efficient than matching with\n        :meth:`query_selector_all` and checking the size of the returned collection.\n\n        :param selector: CSS selector\n        :type selector: str\n        :return: boolean value indicating whether a matching element exists\n        :rtype: bool\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_17matches(PyObject *__pyx_v_self, PyObject *__pyx_v_selector) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matches (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_selector), (&PyUnicode_Type), 1, "selector", 1))) __PYX_ERR(0, 1310, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_16matches(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), ((PyObject*)__pyx_v_selector));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_16matches(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_selector) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matches", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_11resiliparse_5parse_4html_13DOMCollection_matches(__pyx_v_self, __pyx_v_selector, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.matches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11resiliparse_5parse_4html_13DOMCollection_20generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "resiliparse/parse/html.pyx":1334
 *         return False
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __iter__(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_19__iter__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_18__iter__[] = "\n        __iter__(self)\n\n        Iterate the DOM node collection.\n\n        :rtype: t.Iterable[DOMNode]\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_18__iter__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_19__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_18__iter__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_18__iter__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 0);
  __pyx_cur_scope = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *)__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__(__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1334, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11resiliparse_5parse_4html_13DOMCollection_20generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter, __pyx_n_s_DOMCollection___iter, __pyx_n_s_resiliparse_parse_html); if (unlikely(!gen)) __PYX_ERR(0, 1334, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11resiliparse_5parse_4html_13DOMCollection_20generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *__pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  size_t __pyx_t_6;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L9_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1334, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":1342
 *         :rtype: t.Iterable[DOMNode]
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to get item of uninitialized collection')
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_cur_scope->__pyx_v_self->tree) == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_cur_scope->__pyx_v_self->coll == NULL) != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":1343
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             raise RuntimeError('Trying to get item of uninitialized collection')             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t i = 0
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1343, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1343, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1342
 *         :rtype: t.Iterable[DOMNode]
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to get item of uninitialized collection')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1345
 *             raise RuntimeError('Trying to get item of uninitialized collection')
 * 
 *         cdef size_t i = 0             # <<<<<<<<<<<<<<
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             yield _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, i))
 */
  __pyx_cur_scope->__pyx_v_i = 0;

  /* "resiliparse/parse/html.pyx":1346
 * 
 *         cdef size_t i = 0
 *         for i in range(lxb_dom_collection_length(self.coll)):             # <<<<<<<<<<<<<<
 *             yield _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, i))
 * 
 */
  __pyx_t_5 = lxb_dom_collection_length(__pyx_cur_scope->__pyx_v_self->coll);
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
    __pyx_cur_scope->__pyx_v_i = __pyx_t_7;

    /* "resiliparse/parse/html.pyx":1347
 *         cdef size_t i = 0
 *         for i in range(lxb_dom_collection_length(self.coll)):
 *             yield _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, i))             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
    __pyx_t_4 = ((PyObject *)__pyx_cur_scope->__pyx_v_self->tree);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_8 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_4), lxb_dom_collection_node(__pyx_cur_scope->__pyx_v_self->coll, __pyx_cur_scope->__pyx_v_i))); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_8;
    __pyx_t_8 = 0;
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_6;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_7;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L9_resume_from_yield:;
    __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
    __pyx_t_6 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_7 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1347, __pyx_L1_error)
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "resiliparse/parse/html.pyx":1334
 *         return False
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __iter__(self)
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1349
 *             yield _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, i))
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __len__(self)
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_22__len__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_21__len__[] = "\n        __len__(self)\n\n        Get the number of items in this collection.\n\n        :rtype: int\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_21__len__;
#endif
static Py_ssize_t __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_22__len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_21__len__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_21__len__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "resiliparse/parse/html.pyx":1357
 *         :rtype: int
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             return 0
 *         return lxb_dom_collection_length(self.coll)
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->tree) == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_v_self->coll == NULL) != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1358
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             return 0             # <<<<<<<<<<<<<<
 *         return lxb_dom_collection_length(self.coll)
 * 
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1357
 *         :rtype: int
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             return 0
 *         return lxb_dom_collection_length(self.coll)
 */
  }

  /* "resiliparse/parse/html.pyx":1359
 *         if self.tree is None or self.coll == NULL:
 *             return 0
 *         return lxb_dom_collection_length(self.coll)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, key):
 */
  __pyx_r = lxb_dom_collection_length(__pyx_v_self->coll);
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1349
 *             yield _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, i))
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         """
 *         __len__(self)
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1361
 *         return lxb_dom_collection_length(self.coll)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         """
 *         __getitem__(self, key)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_24__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_23__getitem__[] = "\n        __getitem__(self, key)\n\n        Return the :class:`DOMNode` at the given index in this collection or another :class:`DOMCollection`\n        if ``key`` is a slice object. Negative indexing is supported.\n\n        :param key: index or slice\n        :rtype: DOMNode or DOMCollection\n        :raises IndexError: if ``key`` is out of range\n        :raises TypeError: if ``key`` is not an ``int`` or ``slice``\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_23__getitem__;
#endif
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_24__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_23__getitem__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_23__getitem__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, PyObject *__pyx_v_key) {
  size_t __pyx_v_coll_len;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_slice_coll = 0;
  lxb_dom_collection_t *__pyx_v_dom_coll;
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_stop = NULL;
  PyObject *__pyx_v_step = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "resiliparse/parse/html.pyx":1373
 *         :raises TypeError: if ``key`` is not an ``int`` or ``slice``
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise IndexError('Trying to get item of uninitialized collection')
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->tree) == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_v_self->coll == NULL) != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":1374
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             raise IndexError('Trying to get item of uninitialized collection')             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t coll_len = lxb_dom_collection_length(self.coll)
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_IndexError, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1374, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1374, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1373
 *         :raises TypeError: if ``key`` is not an ``int`` or ``slice``
 *         """
 *         if self.tree is None or self.coll == NULL:             # <<<<<<<<<<<<<<
 *             raise IndexError('Trying to get item of uninitialized collection')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1376
 *             raise IndexError('Trying to get item of uninitialized collection')
 * 
 *         cdef size_t coll_len = lxb_dom_collection_length(self.coll)             # <<<<<<<<<<<<<<
 * 
 *         cdef DOMCollection slice_coll
 */
  __pyx_v_coll_len = lxb_dom_collection_length(__pyx_v_self->coll);

  /* "resiliparse/parse/html.pyx":1380
 *         cdef DOMCollection slice_coll
 *         cdef lxb_dom_collection_t* dom_coll
 *         if isinstance(key, slice):             # <<<<<<<<<<<<<<
 *             start = key.start
 *             stop = key.stop
 */
  __pyx_t_1 = PySlice_Check(__pyx_v_key); 
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "resiliparse/parse/html.pyx":1381
 *         cdef lxb_dom_collection_t* dom_coll
 *         if isinstance(key, slice):
 *             start = key.start             # <<<<<<<<<<<<<<
 *             stop = key.stop
 *             step = key.step if key.step is not None else 1
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_key, __pyx_n_s_start); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1381, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_start = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "resiliparse/parse/html.pyx":1382
 *         if isinstance(key, slice):
 *             start = key.start
 *             stop = key.stop             # <<<<<<<<<<<<<<
 *             step = key.step if key.step is not None else 1
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_key, __pyx_n_s_stop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_stop = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "resiliparse/parse/html.pyx":1383
 *             start = key.start
 *             stop = key.stop
 *             step = key.step if key.step is not None else 1             # <<<<<<<<<<<<<<
 * 
 *             if start is None:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_key, __pyx_n_s_step); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = (__pyx_t_5 != Py_None);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if ((__pyx_t_3 != 0)) {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_key, __pyx_n_s_step); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __pyx_t_5;
      __pyx_t_5 = 0;
    } else {
      __Pyx_INCREF(__pyx_int_1);
      __pyx_t_4 = __pyx_int_1;
    }
    __pyx_v_step = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "resiliparse/parse/html.pyx":1385
 *             step = key.step if key.step is not None else 1
 * 
 *             if start is None:             # <<<<<<<<<<<<<<
 *                 start = coll_len - 1 if step < 0 else 0
 *             else:
 */
    __pyx_t_3 = (__pyx_v_start == Py_None);
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (__pyx_t_1) {

      /* "resiliparse/parse/html.pyx":1386
 * 
 *             if start is None:
 *                 start = coll_len - 1 if step < 0 else 0             # <<<<<<<<<<<<<<
 *             else:
 *                 start = self._wrap_idx(min(start, coll_len - 1))
 */
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_step, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1386, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1386, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_1) {
        __pyx_t_5 = __Pyx_PyInt_FromSize_t((__pyx_v_coll_len - 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1386, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = __pyx_t_5;
        __pyx_t_5 = 0;
      } else {
        __Pyx_INCREF(__pyx_int_0);
        __pyx_t_4 = __pyx_int_0;
      }
      __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "resiliparse/parse/html.pyx":1385
 *             step = key.step if key.step is not None else 1
 * 
 *             if start is None:             # <<<<<<<<<<<<<<
 *                 start = coll_len - 1 if step < 0 else 0
 *             else:
 */
      goto __pyx_L7;
    }

    /* "resiliparse/parse/html.pyx":1388
 *                 start = coll_len - 1 if step < 0 else 0
 *             else:
 *                 start = self._wrap_idx(min(start, coll_len - 1))             # <<<<<<<<<<<<<<
 * 
 *             if stop is None:
 */
    /*else*/ {
      __pyx_t_6 = (__pyx_v_coll_len - 1);
      __Pyx_INCREF(__pyx_v_start);
      __pyx_t_4 = __pyx_v_start;
      __pyx_t_7 = __Pyx_PyInt_FromSize_t(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = PyObject_RichCompare(__pyx_t_7, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1388, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1388, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (__pyx_t_1) {
        __pyx_t_8 = __Pyx_PyInt_FromSize_t(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1388, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_5 = __pyx_t_8;
        __pyx_t_8 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = __pyx_t_4;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = PyInt_AsSsize_t(__pyx_t_5); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1388, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_FromSize_t(__pyx_f_11resiliparse_5parse_4html_13DOMCollection__wrap_idx(__pyx_v_self, __pyx_t_9)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_5);
      __pyx_t_5 = 0;
    }
    __pyx_L7:;

    /* "resiliparse/parse/html.pyx":1390
 *                 start = self._wrap_idx(min(start, coll_len - 1))
 * 
 *             if stop is None:             # <<<<<<<<<<<<<<
 *                 stop = -1 if step < 0 else coll_len
 *             else:
 */
    __pyx_t_1 = (__pyx_v_stop == Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "resiliparse/parse/html.pyx":1391
 * 
 *             if stop is None:
 *                 stop = -1 if step < 0 else coll_len             # <<<<<<<<<<<<<<
 *             else:
 *                 stop = self._wrap_idx(min(stop, coll_len))
 */
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_step, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_3) {
        __Pyx_INCREF(__pyx_int_neg_1);
        __pyx_t_5 = __pyx_int_neg_1;
      } else {
        __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_coll_len); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1391, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __pyx_t_4;
        __pyx_t_4 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "resiliparse/parse/html.pyx":1390
 *                 start = self._wrap_idx(min(start, coll_len - 1))
 * 
 *             if stop is None:             # <<<<<<<<<<<<<<
 *                 stop = -1 if step < 0 else coll_len
 *             else:
 */
      goto __pyx_L8;
    }

    /* "resiliparse/parse/html.pyx":1393
 *                 stop = -1 if step < 0 else coll_len
 *             else:
 *                 stop = self._wrap_idx(min(stop, coll_len))             # <<<<<<<<<<<<<<
 * 
 *             dom_coll = lxb_dom_collection_make(self.coll.document,
 */
    /*else*/ {
      __pyx_t_6 = __pyx_v_coll_len;
      __Pyx_INCREF(__pyx_v_stop);
      __pyx_t_5 = __pyx_v_stop;
      __pyx_t_8 = __Pyx_PyInt_FromSize_t(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = PyObject_RichCompare(__pyx_t_8, __pyx_t_5, Py_LT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1393, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1393, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_3) {
        __pyx_t_7 = __Pyx_PyInt_FromSize_t(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1393, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __pyx_t_7;
        __pyx_t_7 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_4 = __pyx_t_5;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_9 = PyInt_AsSsize_t(__pyx_t_4); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1393, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_f_11resiliparse_5parse_4html_13DOMCollection__wrap_idx(__pyx_v_self, __pyx_t_9)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_4);
      __pyx_t_4 = 0;
    }
    __pyx_L8:;

    /* "resiliparse/parse/html.pyx":1396
 * 
 *             dom_coll = lxb_dom_collection_make(self.coll.document,
 *                                                min(coll_len, abs((stop - start) // step) + 1))             # <<<<<<<<<<<<<<
 *             for i in range(start, stop, step):
 *                 lxb_dom_collection_append(dom_coll, lxb_dom_collection_element(self.coll, i))
 */
    __pyx_t_4 = PyNumber_Subtract(__pyx_v_stop, __pyx_v_start); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyNumber_FloorDivide(__pyx_t_4, __pyx_v_step); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyNumber_Absolute(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __pyx_v_coll_len;
    __pyx_t_7 = __Pyx_PyInt_FromSize_t(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_5, __pyx_t_7, Py_LT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_3) {
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_4 = __pyx_t_5;
    } else {
      __pyx_t_8 = __Pyx_PyInt_FromSize_t(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_4 = __pyx_t_8;
      __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = __Pyx_PyInt_As_size_t(__pyx_t_4); if (unlikely((__pyx_t_6 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "resiliparse/parse/html.pyx":1395
 *                 stop = self._wrap_idx(min(stop, coll_len))
 * 
 *             dom_coll = lxb_dom_collection_make(self.coll.document,             # <<<<<<<<<<<<<<
 *                                                min(coll_len, abs((stop - start) // step) + 1))
 *             for i in range(start, stop, step):
 */
    __pyx_v_dom_coll = lxb_dom_collection_make(__pyx_v_self->coll->document, __pyx_t_6);

    /* "resiliparse/parse/html.pyx":1397
 *             dom_coll = lxb_dom_collection_make(self.coll.document,
 *                                                min(coll_len, abs((stop - start) // step) + 1))
 *             for i in range(start, stop, step):             # <<<<<<<<<<<<<<
 *                 lxb_dom_collection_append(dom_coll, lxb_dom_collection_element(self.coll, i))
 * 
 */
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_start);
    __Pyx_GIVEREF(__pyx_v_start);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_start);
    __Pyx_INCREF(__pyx_v_stop);
    __Pyx_GIVEREF(__pyx_v_stop);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_stop);
    __Pyx_INCREF(__pyx_v_step);
    __Pyx_GIVEREF(__pyx_v_step);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_step);
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
      __pyx_t_4 = __pyx_t_5; __Pyx_INCREF(__pyx_t_4); __pyx_t_10 = 0;
      __pyx_t_11 = NULL;
    } else {
      __pyx_t_10 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1397, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1397, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    for (;;) {
      if (likely(!__pyx_t_11)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_10 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_10); __Pyx_INCREF(__pyx_t_5); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 1397, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1397, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_10 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_10); __Pyx_INCREF(__pyx_t_5); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 1397, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1397, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_11(__pyx_t_4);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1397, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "resiliparse/parse/html.pyx":1398
 *                                                min(coll_len, abs((stop - start) // step) + 1))
 *             for i in range(start, stop, step):
 *                 lxb_dom_collection_append(dom_coll, lxb_dom_collection_element(self.coll, i))             # <<<<<<<<<<<<<<
 * 
 *             slice_coll = DOMCollection.__new__(DOMCollection, self.tree)
 */
      __pyx_t_6 = __Pyx_PyInt_As_size_t(__pyx_v_i); if (unlikely((__pyx_t_6 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1398, __pyx_L1_error)
      (void)(lxb_dom_collection_append(__pyx_v_dom_coll, lxb_dom_collection_element(__pyx_v_self->coll, __pyx_t_6)));

      /* "resiliparse/parse/html.pyx":1397
 *             dom_coll = lxb_dom_collection_make(self.coll.document,
 *                                                min(coll_len, abs((stop - start) // step) + 1))
 *             for i in range(start, stop, step):             # <<<<<<<<<<<<<<
 *                 lxb_dom_collection_append(dom_coll, lxb_dom_collection_element(self.coll, i))
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "resiliparse/parse/html.pyx":1400
 *                 lxb_dom_collection_append(dom_coll, lxb_dom_collection_element(self.coll, i))
 * 
 *             slice_coll = DOMCollection.__new__(DOMCollection, self.tree)             # <<<<<<<<<<<<<<
 *             slice_coll.coll = dom_coll
 *             return slice_coll
 */
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1400, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_v_self->tree));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self->tree));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self->tree));
    __pyx_t_5 = ((PyObject *)__pyx_tp_new_11resiliparse_5parse_4html_DOMCollection(((PyTypeObject *)__pyx_ptype_11resiliparse_5parse_4html_DOMCollection), __pyx_t_4, NULL)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1400, __pyx_L1_error)
    __Pyx_GOTREF(((PyObject *)__pyx_t_5));
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_slice_coll = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "resiliparse/parse/html.pyx":1401
 * 
 *             slice_coll = DOMCollection.__new__(DOMCollection, self.tree)
 *             slice_coll.coll = dom_coll             # <<<<<<<<<<<<<<
 *             return slice_coll
 * 
 */
    __pyx_v_slice_coll->coll = __pyx_v_dom_coll;

    /* "resiliparse/parse/html.pyx":1402
 *             slice_coll = DOMCollection.__new__(DOMCollection, self.tree)
 *             slice_coll.coll = dom_coll
 *             return slice_coll             # <<<<<<<<<<<<<<
 * 
 *         if type(key) is not int:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_slice_coll));
    __pyx_r = ((PyObject *)__pyx_v_slice_coll);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1380
 *         cdef DOMCollection slice_coll
 *         cdef lxb_dom_collection_t* dom_coll
 *         if isinstance(key, slice):             # <<<<<<<<<<<<<<
 *             start = key.start
 *             stop = key.stop
 */
  }

  /* "resiliparse/parse/html.pyx":1404
 *             return slice_coll
 * 
 *         if type(key) is not int:             # <<<<<<<<<<<<<<
 *             raise TypeError(f'Invalid key type: {type(key)}')
 * 
 */
  __pyx_t_3 = (((PyObject *)Py_TYPE(__pyx_v_key)) != ((PyObject *)(&PyInt_Type)));
  __pyx_t_1 = (__pyx_t_3 != 0);
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":1405
 * 
 *         if type(key) is not int:
 *             raise TypeError(f'Invalid key type: {type(key)}')             # <<<<<<<<<<<<<<
 * 
 *         if key >= coll_len:
 */
    __pyx_t_5 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_key)), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Invalid_key_type, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 1405, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1404
 *             return slice_coll
 * 
 *         if type(key) is not int:             # <<<<<<<<<<<<<<
 *             raise TypeError(f'Invalid key type: {type(key)}')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1407
 *             raise TypeError(f'Invalid key type: {type(key)}')
 * 
 *         if key >= coll_len:             # <<<<<<<<<<<<<<
 *             raise IndexError('Index out of range')
 * 
 */
  __pyx_t_5 = __Pyx_PyInt_FromSize_t(__pyx_v_coll_len); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_key, __pyx_t_5, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":1408
 * 
 *         if key >= coll_len:
 *             raise IndexError('Index out of range')             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, self._wrap_idx(key)))
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_IndexError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1408, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1407
 *             raise TypeError(f'Invalid key type: {type(key)}')
 * 
 *         if key >= coll_len:             # <<<<<<<<<<<<<<
 *             raise IndexError('Index out of range')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1410
 *             raise IndexError('Index out of range')
 * 
 *         return _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, self._wrap_idx(key)))             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)__pyx_v_self->tree);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_9 = PyInt_AsSsize_t(__pyx_v_key); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1410, __pyx_L1_error)
  __pyx_t_5 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_4), lxb_dom_collection_node(__pyx_v_self->coll, __pyx_f_11resiliparse_5parse_4html_13DOMCollection__wrap_idx(__pyx_v_self, __pyx_t_9)))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1361
 *         return lxb_dom_collection_length(self.coll)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         """
 *         __getitem__(self, key)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_slice_coll);
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_stop);
  __Pyx_XDECREF(__pyx_v_step);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1412
 *         return _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, self._wrap_idx(key)))
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return f'{{{", ".join(repr(n) for n in self)}}}'
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_26__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_26__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_25__repr__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11resiliparse_5parse_4html_13DOMCollection_8__repr___2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "resiliparse/parse/html.pyx":1413
 * 
 *     def __repr__(self):
 *         return f'{{{", ".join(repr(n) for n in self)}}}'             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_8__repr___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *)__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr(__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1413, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11resiliparse_5parse_4html_13DOMCollection_8__repr___2generator3, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_repr___locals_genexpr, __pyx_n_s_resiliparse_parse_html); if (unlikely(!gen)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.__repr__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11resiliparse_5parse_4html_13DOMCollection_8__repr___2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *__pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1413, __pyx_L1_error) }
  if (likely(PyList_CheckExact(((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self))) || PyTuple_CheckExact(((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self))) {
    __pyx_t_1 = ((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1413, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 1413, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 1413, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1413, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_n);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_n, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Repr(__pyx_cur_scope->__pyx_v_n); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1412
 *         return _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, self._wrap_idx(key)))
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return f'{{{", ".join(repr(n) for n in self)}}}'
 * 
 */

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_25__repr__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *__pyx_cur_scope;
  PyObject *__pyx_gb_11resiliparse_5parse_4html_13DOMCollection_8__repr___2generator3 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);
  __pyx_cur_scope = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *)__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__(__pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1412, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

  /* "resiliparse/parse/html.pyx":1413
 * 
 *     def __repr__(self):
 *         return f'{{{", ".join(repr(n) for n in self)}}}'             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u__28);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__28);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u__28);
  __pyx_t_4 = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_8__repr___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_Generator_Next(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyUnicode_Join(__pyx_kp_u__29, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u__30);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__30);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u__30);
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1412
 *         return _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, self._wrap_idx(key)))
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return f'{{{", ".join(repr(n) for n in self)}}}'
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_gb_11resiliparse_5parse_4html_13DOMCollection_8__repr___2generator3);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1415
 *         return f'{{{", ".join(repr(n) for n in self)}}}'
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.__repr__()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_28__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_28__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_27__str__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_27__str__(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "resiliparse/parse/html.pyx":1416
 * 
 *     def __str__(self):
 *         return self.__repr__()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_repr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1415
 *         return f'{{{", ".join(repr(n) for n in self)}}}'
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.__repr__()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_30__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_30__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_29__reduce_cython__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_29__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_32__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_32__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_13DOMCollection_31__setstate_cython__(((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_13DOMCollection_31__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.DOMCollection.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1419
 * 
 * 
 * cdef HTMLTree create_html_tree(bytes document, bint reencode=True, str encoding='utf-8', str errors='ignore'):             # <<<<<<<<<<<<<<
 *     """
 *     Create :class:`HTMLTree` instance from bytes content.
 */

static struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_f_11resiliparse_5parse_4html_create_html_tree(PyObject *__pyx_v_document, struct __pyx_opt_args_11resiliparse_5parse_4html_create_html_tree *__pyx_optional_args) {
  int __pyx_v_reencode = ((int)1);
  PyObject *__pyx_v_encoding = ((PyObject*)__pyx_kp_u_utf_8);
  PyObject *__pyx_v_errors = ((PyObject*)__pyx_n_u_ignore);
  lxb_status_t __pyx_v_status;
  lxb_char_t const *__pyx_v_html;
  size_t __pyx_v_html_len;
  struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_tree = 0;
  struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  struct __pyx_opt_args_11resiliparse_5parse_8encoding_bytes_to_str __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  lxb_char_t const *__pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_html_tree", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_reencode = __pyx_optional_args->reencode;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_encoding = __pyx_optional_args->encoding;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_errors = __pyx_optional_args->errors;
        }
      }
    }
  }
  __Pyx_INCREF(__pyx_v_document);
  __Pyx_INCREF(__pyx_v_encoding);

  /* "resiliparse/parse/html.pyx":1429
 *     :return: :class:`HTMLTree` instance
 *     """
 *     encoding = map_encoding_to_html5(encoding)             # <<<<<<<<<<<<<<
 *     if reencode:
 *         document = bytes_to_str(document, encoding, errors).encode()
 */
  __pyx_t_1 = __pyx_f_11resiliparse_5parse_8encoding_map_encoding_to_html5(__pyx_v_encoding, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_encoding, ((PyObject*)__pyx_t_1));
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":1430
 *     """
 *     encoding = map_encoding_to_html5(encoding)
 *     if reencode:             # <<<<<<<<<<<<<<
 *         document = bytes_to_str(document, encoding, errors).encode()
 *     cdef lxb_status_t status
 */
  __pyx_t_2 = (__pyx_v_reencode != 0);
  if (__pyx_t_2) {

    /* "resiliparse/parse/html.pyx":1431
 *     encoding = map_encoding_to_html5(encoding)
 *     if reencode:
 *         document = bytes_to_str(document, encoding, errors).encode()             # <<<<<<<<<<<<<<
 *     cdef lxb_status_t status
 *     cdef const lxb_char_t* html = <const lxb_char_t*>document
 */
    __pyx_t_3.__pyx_n = 2;
    __pyx_t_3.encoding = __pyx_v_encoding;
    __pyx_t_3.errors = __pyx_v_errors;
    __pyx_t_1 = __pyx_f_11resiliparse_5parse_8encoding_bytes_to_str(__pyx_v_document, 0, &__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
      __PYX_ERR(0, 1431, __pyx_L1_error)
    }
    __pyx_t_4 = PyUnicode_AsEncodedString(((PyObject*)__pyx_t_1), NULL, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_document, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "resiliparse/parse/html.pyx":1430
 *     """
 *     encoding = map_encoding_to_html5(encoding)
 *     if reencode:             # <<<<<<<<<<<<<<
 *         document = bytes_to_str(document, encoding, errors).encode()
 *     cdef lxb_status_t status
 */
  }

  /* "resiliparse/parse/html.pyx":1433
 *         document = bytes_to_str(document, encoding, errors).encode()
 *     cdef lxb_status_t status
 *     cdef const lxb_char_t* html = <const lxb_char_t*>document             # <<<<<<<<<<<<<<
 *     cdef size_t html_len = len(document)
 *     cdef HTMLTree tree = HTMLTree.__new__(HTMLTree)
 */
  if (unlikely(__pyx_v_document == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1433, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyBytes_AsUString(__pyx_v_document); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) __PYX_ERR(0, 1433, __pyx_L1_error)
  __pyx_v_html = ((lxb_char_t const *)__pyx_t_5);

  /* "resiliparse/parse/html.pyx":1434
 *     cdef lxb_status_t status
 *     cdef const lxb_char_t* html = <const lxb_char_t*>document
 *     cdef size_t html_len = len(document)             # <<<<<<<<<<<<<<
 *     cdef HTMLTree tree = HTMLTree.__new__(HTMLTree)
 *     with nogil:
 */
  if (unlikely(__pyx_v_document == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 1434, __pyx_L1_error)
  }
  __pyx_t_6 = PyBytes_GET_SIZE(__pyx_v_document); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1434, __pyx_L1_error)
  __pyx_v_html_len = __pyx_t_6;

  /* "resiliparse/parse/html.pyx":1435
 *     cdef const lxb_char_t* html = <const lxb_char_t*>document
 *     cdef size_t html_len = len(document)
 *     cdef HTMLTree tree = HTMLTree.__new__(HTMLTree)             # <<<<<<<<<<<<<<
 *     with nogil:
 *         status = lxb_html_document_parse(tree.dom_document, html, html_len)
 */
  __pyx_t_4 = ((PyObject *)__pyx_tp_new_11resiliparse_5parse_4html_HTMLTree(((PyTypeObject *)__pyx_ptype_11resiliparse_5parse_4html_HTMLTree), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_4));
  __pyx_v_tree = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "resiliparse/parse/html.pyx":1436
 *     cdef size_t html_len = len(document)
 *     cdef HTMLTree tree = HTMLTree.__new__(HTMLTree)
 *     with nogil:             # <<<<<<<<<<<<<<
 *         status = lxb_html_document_parse(tree.dom_document, html, html_len)
 *     if status != LXB_STATUS_OK:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "resiliparse/parse/html.pyx":1437
 *     cdef HTMLTree tree = HTMLTree.__new__(HTMLTree)
 *     with nogil:
 *         status = lxb_html_document_parse(tree.dom_document, html, html_len)             # <<<<<<<<<<<<<<
 *     if status != LXB_STATUS_OK:
 *         raise ValueError('Failed to parse HTML document')
 */
        __pyx_v_status = lxb_html_document_parse(__pyx_v_tree->dom_document, __pyx_v_html, __pyx_v_html_len);
      }

      /* "resiliparse/parse/html.pyx":1436
 *     cdef size_t html_len = len(document)
 *     cdef HTMLTree tree = HTMLTree.__new__(HTMLTree)
 *     with nogil:             # <<<<<<<<<<<<<<
 *         status = lxb_html_document_parse(tree.dom_document, html, html_len)
 *     if status != LXB_STATUS_OK:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L6;
        }
        __pyx_L6:;
      }
  }

  /* "resiliparse/parse/html.pyx":1438
 *     with nogil:
 *         status = lxb_html_document_parse(tree.dom_document, html, html_len)
 *     if status != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         raise ValueError('Failed to parse HTML document')
 *     return tree
 */
  __pyx_t_2 = ((__pyx_v_status != LXB_STATUS_OK) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "resiliparse/parse/html.pyx":1439
 *         status = lxb_html_document_parse(tree.dom_document, html, html_len)
 *     if status != LXB_STATUS_OK:
 *         raise ValueError('Failed to parse HTML document')             # <<<<<<<<<<<<<<
 *     return tree
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1439, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1438
 *     with nogil:
 *         status = lxb_html_document_parse(tree.dom_document, html, html_len)
 *     if status != LXB_STATUS_OK:             # <<<<<<<<<<<<<<
 *         raise ValueError('Failed to parse HTML document')
 *     return tree
 */
  }

  /* "resiliparse/parse/html.pyx":1440
 *     if status != LXB_STATUS_OK:
 *         raise ValueError('Failed to parse HTML document')
 *     return tree             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_tree));
  __pyx_r = __pyx_v_tree;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1419
 * 
 * 
 * cdef HTMLTree create_html_tree(bytes document, bint reencode=True, str encoding='utf-8', str errors='ignore'):             # <<<<<<<<<<<<<<
 *     """
 *     Create :class:`HTMLTree` instance from bytes content.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.create_html_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tree);
  __Pyx_XDECREF(__pyx_v_document);
  __Pyx_XDECREF(__pyx_v_encoding);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1449
 *     HTML DOM tree parser.
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.dom_document = lxb_html_document_create()
 *         if self.dom_document == NULL:
 */

/* Python wrapper */
static int __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree___cinit__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11resiliparse_5parse_4html_8HTMLTree___cinit__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "resiliparse/parse/html.pyx":1450
 *     """
 *     def __cinit__(self):
 *         self.dom_document = lxb_html_document_create()             # <<<<<<<<<<<<<<
 *         if self.dom_document == NULL:
 *             raise RuntimeError('Failed to allocate HTML document')
 */
  __pyx_v_self->dom_document = lxb_html_document_create();

  /* "resiliparse/parse/html.pyx":1451
 *     def __cinit__(self):
 *         self.dom_document = lxb_html_document_create()
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Failed to allocate HTML document')
 *         self.css_parser = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->dom_document == NULL) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "resiliparse/parse/html.pyx":1452
 *         self.dom_document = lxb_html_document_create()
 *         if self.dom_document == NULL:
 *             raise RuntimeError('Failed to allocate HTML document')             # <<<<<<<<<<<<<<
 *         self.css_parser = NULL
 *         self.css_selectors = NULL
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1452, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1451
 *     def __cinit__(self):
 *         self.dom_document = lxb_html_document_create()
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Failed to allocate HTML document')
 *         self.css_parser = NULL
 */
  }

  /* "resiliparse/parse/html.pyx":1453
 *         if self.dom_document == NULL:
 *             raise RuntimeError('Failed to allocate HTML document')
 *         self.css_parser = NULL             # <<<<<<<<<<<<<<
 *         self.css_selectors = NULL
 *         self.selectors = NULL
 */
  __pyx_v_self->css_parser = NULL;

  /* "resiliparse/parse/html.pyx":1454
 *             raise RuntimeError('Failed to allocate HTML document')
 *         self.css_parser = NULL
 *         self.css_selectors = NULL             # <<<<<<<<<<<<<<
 *         self.selectors = NULL
 * 
 */
  __pyx_v_self->css_selectors = NULL;

  /* "resiliparse/parse/html.pyx":1455
 *         self.css_parser = NULL
 *         self.css_selectors = NULL
 *         self.selectors = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_v_self->selectors = NULL;

  /* "resiliparse/parse/html.pyx":1449
 *     HTML DOM tree parser.
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.dom_document = lxb_html_document_create()
 *         if self.dom_document == NULL:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1457
 *         self.selectors = NULL
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.dom_document != NULL:
 *             lxb_html_document_destroy(self.dom_document)
 */

/* Python wrapper */
static void __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_2__dealloc__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_2__dealloc__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "resiliparse/parse/html.pyx":1458
 * 
 *     def __dealloc__(self):
 *         if self.dom_document != NULL:             # <<<<<<<<<<<<<<
 *             lxb_html_document_destroy(self.dom_document)
 *             self.dom_document = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->dom_document != NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1459
 *     def __dealloc__(self):
 *         if self.dom_document != NULL:
 *             lxb_html_document_destroy(self.dom_document)             # <<<<<<<<<<<<<<
 *             self.dom_document = NULL
 * 
 */
    (void)(lxb_html_document_destroy(__pyx_v_self->dom_document));

    /* "resiliparse/parse/html.pyx":1460
 *         if self.dom_document != NULL:
 *             lxb_html_document_destroy(self.dom_document)
 *             self.dom_document = NULL             # <<<<<<<<<<<<<<
 * 
 *         if self.selectors != NULL:
 */
    __pyx_v_self->dom_document = NULL;

    /* "resiliparse/parse/html.pyx":1458
 * 
 *     def __dealloc__(self):
 *         if self.dom_document != NULL:             # <<<<<<<<<<<<<<
 *             lxb_html_document_destroy(self.dom_document)
 *             self.dom_document = NULL
 */
  }

  /* "resiliparse/parse/html.pyx":1462
 *             self.dom_document = NULL
 * 
 *         if self.selectors != NULL:             # <<<<<<<<<<<<<<
 *             lxb_selectors_destroy(self.selectors, True)
 *         if self.css_parser != NULL:
 */
  __pyx_t_1 = ((__pyx_v_self->selectors != NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1463
 * 
 *         if self.selectors != NULL:
 *             lxb_selectors_destroy(self.selectors, True)             # <<<<<<<<<<<<<<
 *         if self.css_parser != NULL:
 *             lxb_css_parser_destroy(self.css_parser, True)
 */
    (void)(lxb_selectors_destroy(__pyx_v_self->selectors, 1));

    /* "resiliparse/parse/html.pyx":1462
 *             self.dom_document = NULL
 * 
 *         if self.selectors != NULL:             # <<<<<<<<<<<<<<
 *             lxb_selectors_destroy(self.selectors, True)
 *         if self.css_parser != NULL:
 */
  }

  /* "resiliparse/parse/html.pyx":1464
 *         if self.selectors != NULL:
 *             lxb_selectors_destroy(self.selectors, True)
 *         if self.css_parser != NULL:             # <<<<<<<<<<<<<<
 *             lxb_css_parser_destroy(self.css_parser, True)
 *             self.css_parser = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->css_parser != NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1465
 *             lxb_selectors_destroy(self.selectors, True)
 *         if self.css_parser != NULL:
 *             lxb_css_parser_destroy(self.css_parser, True)             # <<<<<<<<<<<<<<
 *             self.css_parser = NULL
 *         if self.css_selectors != NULL:
 */
    (void)(lxb_css_parser_destroy(__pyx_v_self->css_parser, 1));

    /* "resiliparse/parse/html.pyx":1466
 *         if self.css_parser != NULL:
 *             lxb_css_parser_destroy(self.css_parser, True)
 *             self.css_parser = NULL             # <<<<<<<<<<<<<<
 *         if self.css_selectors != NULL:
 *             lxb_css_selectors_destroy(self.css_selectors, True, True)
 */
    __pyx_v_self->css_parser = NULL;

    /* "resiliparse/parse/html.pyx":1464
 *         if self.selectors != NULL:
 *             lxb_selectors_destroy(self.selectors, True)
 *         if self.css_parser != NULL:             # <<<<<<<<<<<<<<
 *             lxb_css_parser_destroy(self.css_parser, True)
 *             self.css_parser = NULL
 */
  }

  /* "resiliparse/parse/html.pyx":1467
 *             lxb_css_parser_destroy(self.css_parser, True)
 *             self.css_parser = NULL
 *         if self.css_selectors != NULL:             # <<<<<<<<<<<<<<
 *             lxb_css_selectors_destroy(self.css_selectors, True, True)
 *             self.css_selectors = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->css_selectors != NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1468
 *             self.css_parser = NULL
 *         if self.css_selectors != NULL:
 *             lxb_css_selectors_destroy(self.css_selectors, True, True)             # <<<<<<<<<<<<<<
 *             self.css_selectors = NULL
 * 
 */
    (void)(lxb_css_selectors_destroy(__pyx_v_self->css_selectors, 1, 1));

    /* "resiliparse/parse/html.pyx":1469
 *         if self.css_selectors != NULL:
 *             lxb_css_selectors_destroy(self.css_selectors, True, True)
 *             self.css_selectors = NULL             # <<<<<<<<<<<<<<
 * 
 *     # noinspection PyAttributeOutsideInit
 */
    __pyx_v_self->css_selectors = NULL;

    /* "resiliparse/parse/html.pyx":1467
 *             lxb_css_parser_destroy(self.css_parser, True)
 *             self.css_parser = NULL
 *         if self.css_selectors != NULL:             # <<<<<<<<<<<<<<
 *             lxb_css_selectors_destroy(self.css_selectors, True, True)
 *             self.css_selectors = NULL
 */
  }

  /* "resiliparse/parse/html.pyx":1457
 *         self.selectors = NULL
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.dom_document != NULL:
 *             lxb_html_document_destroy(self.dom_document)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "resiliparse/parse/html.pyx":1472
 * 
 *     # noinspection PyAttributeOutsideInit
 *     cdef void init_css_parser(self):             # <<<<<<<<<<<<<<
 *         """
 *         Initialize CSS selector if not already initialized.
 */

static void __pyx_f_11resiliparse_5parse_4html_8HTMLTree_init_css_parser(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("init_css_parser", 0);

  /* "resiliparse/parse/html.pyx":1476
 *         Initialize CSS selector if not already initialized.
 *         """
 *         if self.css_parser == NULL:             # <<<<<<<<<<<<<<
 *             self.css_parser = lxb_css_parser_create()
 *             lxb_css_parser_init(self.css_parser, NULL, NULL)
 */
  __pyx_t_1 = ((__pyx_v_self->css_parser == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1477
 *         """
 *         if self.css_parser == NULL:
 *             self.css_parser = lxb_css_parser_create()             # <<<<<<<<<<<<<<
 *             lxb_css_parser_init(self.css_parser, NULL, NULL)
 * 
 */
    __pyx_v_self->css_parser = lxb_css_parser_create();

    /* "resiliparse/parse/html.pyx":1478
 *         if self.css_parser == NULL:
 *             self.css_parser = lxb_css_parser_create()
 *             lxb_css_parser_init(self.css_parser, NULL, NULL)             # <<<<<<<<<<<<<<
 * 
 *             self.css_selectors = lxb_css_selectors_create()
 */
    (void)(lxb_css_parser_init(__pyx_v_self->css_parser, NULL, NULL));

    /* "resiliparse/parse/html.pyx":1480
 *             lxb_css_parser_init(self.css_parser, NULL, NULL)
 * 
 *             self.css_selectors = lxb_css_selectors_create()             # <<<<<<<<<<<<<<
 *             lxb_css_selectors_init(self.css_selectors, 32)
 *             lxb_css_parser_selectors_set(self.css_parser, self.css_selectors)
 */
    __pyx_v_self->css_selectors = lxb_css_selectors_create();

    /* "resiliparse/parse/html.pyx":1481
 * 
 *             self.css_selectors = lxb_css_selectors_create()
 *             lxb_css_selectors_init(self.css_selectors, 32)             # <<<<<<<<<<<<<<
 *             lxb_css_parser_selectors_set(self.css_parser, self.css_selectors)
 * 
 */
    (void)(lxb_css_selectors_init(__pyx_v_self->css_selectors, 32));

    /* "resiliparse/parse/html.pyx":1482
 *             self.css_selectors = lxb_css_selectors_create()
 *             lxb_css_selectors_init(self.css_selectors, 32)
 *             lxb_css_parser_selectors_set(self.css_parser, self.css_selectors)             # <<<<<<<<<<<<<<
 * 
 *             self.selectors = lxb_selectors_create()
 */
    lxb_css_parser_selectors_set(__pyx_v_self->css_parser, __pyx_v_self->css_selectors);

    /* "resiliparse/parse/html.pyx":1484
 *             lxb_css_parser_selectors_set(self.css_parser, self.css_selectors)
 * 
 *             self.selectors = lxb_selectors_create()             # <<<<<<<<<<<<<<
 *             lxb_selectors_init(self.selectors)
 * 
 */
    __pyx_v_self->selectors = lxb_selectors_create();

    /* "resiliparse/parse/html.pyx":1485
 * 
 *             self.selectors = lxb_selectors_create()
 *             lxb_selectors_init(self.selectors)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (void)(lxb_selectors_init(__pyx_v_self->selectors));

    /* "resiliparse/parse/html.pyx":1476
 *         Initialize CSS selector if not already initialized.
 *         """
 *         if self.css_parser == NULL:             # <<<<<<<<<<<<<<
 *             self.css_parser = lxb_css_parser_create()
 *             lxb_css_parser_init(self.css_parser, NULL, NULL)
 */
  }

  /* "resiliparse/parse/html.pyx":1472
 * 
 *     # noinspection PyAttributeOutsideInit
 *     cdef void init_css_parser(self):             # <<<<<<<<<<<<<<
 *         """
 *         Initialize CSS selector if not already initialized.
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "resiliparse/parse/html.pyx":1489
 * 
 *     @classmethod
 *     def parse(cls, str document):             # <<<<<<<<<<<<<<
 *         """
 *         parse(self, document)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_5parse(PyObject *__pyx_v_cls, PyObject *__pyx_v_document); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_8HTMLTree_4parse[] = "\n        parse(self, document)\n        \n        Parse HTML from a Unicode string into a DOM tree.\n        \n        :param document: input HTML document\n        :return: HTML DOM tree\n        :rtype: HTMLTree\n        :raises ValueError: if HTML parsing fails for unknown reasons\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_5parse(PyObject *__pyx_v_cls, PyObject *__pyx_v_document) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_document), (&PyUnicode_Type), 1, "document", 1))) __PYX_ERR(0, 1489, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4parse(((PyTypeObject*)__pyx_v_cls), ((PyObject*)__pyx_v_document));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4parse(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_document) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_create_html_tree __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse", 0);

  /* "resiliparse/parse/html.pyx":1500
 *         :raises ValueError: if HTML parsing fails for unknown reasons
 *         """
 *         return create_html_tree(document.encode(), reencode=False)             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_document == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1500, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_document, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.reencode = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_create_html_tree(((PyObject*)__pyx_t_1), &__pyx_t_3)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1489
 * 
 *     @classmethod
 *     def parse(cls, str document):             # <<<<<<<<<<<<<<
 *         """
 *         parse(self, document)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1503
 * 
 *     @classmethod
 *     def parse_from_bytes(cls, bytes document, str encoding='utf-8', str errors='ignore'):             # <<<<<<<<<<<<<<
 *         """
 *         parse_from_bytes(self, document, encoding='utf-8', errors='ignore')
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_7parse_from_bytes(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_8HTMLTree_6parse_from_bytes[] = "\n        parse_from_bytes(self, document, encoding='utf-8', errors='ignore')\n        \n        Decode a raw HTML byte string and parse it into a DOM tree.\n        \n        The decoding routine uses :func:`~.parse.encoding.bytes_to_str` to take care of decoding errors,\n        so it is sufficient if ``encoding`` is just a best guess of what the actual input encoding is.\n        The encoding name will be remapped according to the WHATWG specification by calling\n        :func:`~.parse.encoding.map_encoding_to_html5` before trying to decode the byte string with it.\n        \n        :param document: input byte string\n        :param encoding: encoding for decoding byte string\n        :param errors: decoding error policy (same as ``str.decode()``)\n        :return: HTML DOM tree\n        :rtype: HTMLTree\n        :raises ValueError: if HTML parsing fails for unknown reasons\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_7parse_from_bytes(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_document = 0;
  PyObject *__pyx_v_encoding = 0;
  PyObject *__pyx_v_errors = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse_from_bytes (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_document_2,&__pyx_n_s_encoding,&__pyx_n_s_errors,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject*)__pyx_kp_u_utf_8);
    values[2] = ((PyObject*)__pyx_n_u_ignore);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_document_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_encoding);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_errors);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parse_from_bytes") < 0)) __PYX_ERR(0, 1503, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_document = ((PyObject*)values[0]);
    __pyx_v_encoding = ((PyObject*)values[1]);
    __pyx_v_errors = ((PyObject*)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse_from_bytes", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1503, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.parse_from_bytes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_document), (&PyBytes_Type), 1, "document", 1))) __PYX_ERR(0, 1503, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_encoding), (&PyUnicode_Type), 1, "encoding", 1))) __PYX_ERR(0, 1503, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_errors), (&PyUnicode_Type), 1, "errors", 1))) __PYX_ERR(0, 1503, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_6parse_from_bytes(((PyTypeObject*)__pyx_v_cls), __pyx_v_document, __pyx_v_encoding, __pyx_v_errors);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_6parse_from_bytes(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_document, PyObject *__pyx_v_encoding, PyObject *__pyx_v_errors) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_11resiliparse_5parse_4html_create_html_tree __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse_from_bytes", 0);

  /* "resiliparse/parse/html.pyx":1521
 *         :raises ValueError: if HTML parsing fails for unknown reasons
 *         """
 *         return create_html_tree(document, True, encoding, errors)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 3;
  __pyx_t_2.reencode = 1;
  __pyx_t_2.encoding = __pyx_v_encoding;
  __pyx_t_2.errors = __pyx_v_errors;
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_create_html_tree(__pyx_v_document, &__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1503
 * 
 *     @classmethod
 *     def parse_from_bytes(cls, bytes document, str encoding='utf-8', str errors='ignore'):             # <<<<<<<<<<<<<<
 *         """
 *         parse_from_bytes(self, document, encoding='utf-8', errors='ignore')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.parse_from_bytes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1524
 * 
 *     @property
 *     def document(self):             # <<<<<<<<<<<<<<
 *         """
 *         Document root node.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_8document_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_8document_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_8document___get__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_8document___get__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":1530
 *         :type: DOMNode or None
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->dom_document == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1531
 *         """
 *         if self.dom_document == NULL:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_node(self, <lxb_dom_node_t*>&self.dom_document.dom_document)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1530
 *         :type: DOMNode or None
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1533
 *             return None
 * 
 *         return _create_dom_node(self, <lxb_dom_node_t*>&self.dom_document.dom_document)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(__pyx_v_self, ((lxb_dom_node_t *)(&__pyx_v_self->dom_document->dom_document)))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1524
 * 
 *     @property
 *     def document(self):             # <<<<<<<<<<<<<<
 *         """
 *         Document root node.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.document.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1536
 * 
 *     @property
 *     def head(self):             # <<<<<<<<<<<<<<
 *         """
 *         HTML head element or ``None`` if document has no head.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_4head_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_4head_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4head___get__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4head___get__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":1542
 *         :type: DOMNode or None
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->dom_document == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1543
 *         """
 *         if self.dom_document == NULL:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_node(self, <lxb_dom_node_t*>lxb_html_document_head_element(self.dom_document))
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1542
 *         :type: DOMNode or None
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1545
 *             return None
 * 
 *         return _create_dom_node(self, <lxb_dom_node_t*>lxb_html_document_head_element(self.dom_document))             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(__pyx_v_self, ((lxb_dom_node_t *)lxb_html_document_head_element(__pyx_v_self->dom_document)))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1536
 * 
 *     @property
 *     def head(self):             # <<<<<<<<<<<<<<
 *         """
 *         HTML head element or ``None`` if document has no head.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.head.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1548
 * 
 *     @property
 *     def body(self):             # <<<<<<<<<<<<<<
 *         """
 *         HTML body element or ``None`` if document has no body.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_4body_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_4body_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4body___get__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_4body___get__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":1554
 *         :type: DOMNode or None
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->dom_document == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1555
 *         """
 *         if self.dom_document == NULL:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_node(self, <lxb_dom_node_t*>lxb_html_document_body_element(self.dom_document))
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1554
 *         :type: DOMNode or None
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1557
 *             return None
 * 
 *         return _create_dom_node(self, <lxb_dom_node_t*>lxb_html_document_body_element(self.dom_document))             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(__pyx_v_self, ((lxb_dom_node_t *)lxb_html_document_body_element(__pyx_v_self->dom_document)))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1548
 * 
 *     @property
 *     def body(self):             # <<<<<<<<<<<<<<
 *         """
 *         HTML body element or ``None`` if document has no body.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.body.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1560
 * 
 *     @property
 *     def title(self):             # <<<<<<<<<<<<<<
 *         """
 *         The HTML document title.
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_5title_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_5title_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_5title___get__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_5title___get__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  size_t __pyx_v_title_len;
  lxb_char_t const *__pyx_v_title;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "resiliparse/parse/html.pyx":1566
 *         :type: str or None
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->dom_document == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1567
 *         """
 *         if self.dom_document == NULL:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t title_len = 0
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1566
 *         :type: str or None
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1569
 *             return None
 * 
 *         cdef size_t title_len = 0             # <<<<<<<<<<<<<<
 *         cdef const lxb_char_t* title = lxb_html_document_title(self.dom_document, &title_len)
 *         if title == NULL:
 */
  __pyx_v_title_len = 0;

  /* "resiliparse/parse/html.pyx":1570
 * 
 *         cdef size_t title_len = 0
 *         cdef const lxb_char_t* title = lxb_html_document_title(self.dom_document, &title_len)             # <<<<<<<<<<<<<<
 *         if title == NULL:
 *             return ''
 */
  __pyx_v_title = lxb_html_document_title(__pyx_v_self->dom_document, (&__pyx_v_title_len));

  /* "resiliparse/parse/html.pyx":1571
 *         cdef size_t title_len = 0
 *         cdef const lxb_char_t* title = lxb_html_document_title(self.dom_document, &title_len)
 *         if title == NULL:             # <<<<<<<<<<<<<<
 *             return ''
 *         return title[:title_len].decode()
 */
  __pyx_t_1 = ((__pyx_v_title == NULL) != 0);
  if (__pyx_t_1) {

    /* "resiliparse/parse/html.pyx":1572
 *         cdef const lxb_char_t* title = lxb_html_document_title(self.dom_document, &title_len)
 *         if title == NULL:
 *             return ''             # <<<<<<<<<<<<<<
 *         return title[:title_len].decode()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u__2);
    __pyx_r = __pyx_kp_u__2;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1571
 *         cdef size_t title_len = 0
 *         cdef const lxb_char_t* title = lxb_html_document_title(self.dom_document, &title_len)
 *         if title == NULL:             # <<<<<<<<<<<<<<
 *             return ''
 *         return title[:title_len].decode()
 */
  }

  /* "resiliparse/parse/html.pyx":1573
 *         if title == NULL:
 *             return ''
 *         return title[:title_len].decode()             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode create_element(self, str tag_name):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_decode_c_string(((char const *)__pyx_v_title), 0, __pyx_v_title_len, NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1560
 * 
 *     @property
 *     def title(self):             # <<<<<<<<<<<<<<
 *         """
 *         The HTML document title.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.title.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1575
 *         return title[:title_len].decode()
 * 
 *     cpdef DOMNode create_element(self, str tag_name):             # <<<<<<<<<<<<<<
 *         """
 *         create_element(self, tag_name)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_9create_element(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_8HTMLTree_create_element(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, PyObject *__pyx_v_tag_name, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_tag_name_bytes = 0;
  lxb_dom_element_t *__pyx_v_element;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  lxb_char_t *__pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_element", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_create_element); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1575, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_9create_element)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_tag_name) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_tag_name);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 1575, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1586
 *         :rtype: DOMNode
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to create element in uninitialized document.')
 * 
 */
  __pyx_t_5 = ((__pyx_v_self->dom_document == NULL) != 0);
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":1587
 *         """
 *         if self.dom_document == NULL:
 *             raise RuntimeError('Trying to create element in uninitialized document.')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes tag_name_bytes = tag_name.encode()
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1587, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1586
 *         :rtype: DOMNode
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to create element in uninitialized document.')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1589
 *             raise RuntimeError('Trying to create element in uninitialized document.')
 * 
 *         cdef bytes tag_name_bytes = tag_name.encode()             # <<<<<<<<<<<<<<
 *         cdef lxb_dom_element_t* element = lxb_dom_document_create_element(
 *             <lxb_dom_document_t*>self.dom_document, <lxb_char_t*>tag_name_bytes, len(tag_name_bytes), NULL)
 */
  if (unlikely(__pyx_v_tag_name == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1589, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_tag_name, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_tag_name_bytes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":1591
 *         cdef bytes tag_name_bytes = tag_name.encode()
 *         cdef lxb_dom_element_t* element = lxb_dom_document_create_element(
 *             <lxb_dom_document_t*>self.dom_document, <lxb_char_t*>tag_name_bytes, len(tag_name_bytes), NULL)             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self, <lxb_dom_node_t*>element)
 * 
 */
  if (unlikely(__pyx_v_tag_name_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1591, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsWritableUString(__pyx_v_tag_name_bytes); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 1591, __pyx_L1_error)
  if (unlikely(__pyx_v_tag_name_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 1591, __pyx_L1_error)
  }
  __pyx_t_7 = PyBytes_GET_SIZE(__pyx_v_tag_name_bytes); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1591, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":1590
 * 
 *         cdef bytes tag_name_bytes = tag_name.encode()
 *         cdef lxb_dom_element_t* element = lxb_dom_document_create_element(             # <<<<<<<<<<<<<<
 *             <lxb_dom_document_t*>self.dom_document, <lxb_char_t*>tag_name_bytes, len(tag_name_bytes), NULL)
 *         return _create_dom_node(self, <lxb_dom_node_t*>element)
 */
  __pyx_v_element = lxb_dom_document_create_element(((lxb_dom_document_t *)__pyx_v_self->dom_document), ((lxb_char_t *)__pyx_t_6), __pyx_t_7, NULL);

  /* "resiliparse/parse/html.pyx":1592
 *         cdef lxb_dom_element_t* element = lxb_dom_document_create_element(
 *             <lxb_dom_document_t*>self.dom_document, <lxb_char_t*>tag_name_bytes, len(tag_name_bytes), NULL)
 *         return _create_dom_node(self, <lxb_dom_node_t*>element)             # <<<<<<<<<<<<<<
 * 
 *     cpdef DOMNode create_text_node(self, str text):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(__pyx_v_self, ((lxb_dom_node_t *)__pyx_v_element))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1575
 *         return title[:title_len].decode()
 * 
 *     cpdef DOMNode create_element(self, str tag_name):             # <<<<<<<<<<<<<<
 *         """
 *         create_element(self, tag_name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.create_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tag_name_bytes);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_9create_element(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_8HTMLTree_8create_element[] = "\n        create_element(self, tag_name)\n        \n        Create a new DOM Element node.\n        \n        :param tag_name: element tag name\n        :type tag_name: str\n        :return: new Element node\n        :rtype: DOMNode\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_9create_element(PyObject *__pyx_v_self, PyObject *__pyx_v_tag_name) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_element (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tag_name), (&PyUnicode_Type), 1, "tag_name", 1))) __PYX_ERR(0, 1575, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_8create_element(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self), ((PyObject*)__pyx_v_tag_name));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_8create_element(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, PyObject *__pyx_v_tag_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_element", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_8HTMLTree_create_element(__pyx_v_self, __pyx_v_tag_name, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.create_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1594
 *         return _create_dom_node(self, <lxb_dom_node_t*>element)
 * 
 *     cpdef DOMNode create_text_node(self, str text):             # <<<<<<<<<<<<<<
 *         """
 *         create_text_node(self, text)
 */

static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_11create_text_node(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_f_11resiliparse_5parse_4html_8HTMLTree_create_text_node(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, PyObject *__pyx_v_text, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_text_bytes = 0;
  lxb_dom_text_t *__pyx_v_node;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  lxb_char_t *__pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_text_node", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_create_text_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_11create_text_node)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_text);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1594, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 1594, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "resiliparse/parse/html.pyx":1605
 *         :rtype: DOMNode
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to create text node in uninitialized document.')
 * 
 */
  __pyx_t_5 = ((__pyx_v_self->dom_document == NULL) != 0);
  if (unlikely(__pyx_t_5)) {

    /* "resiliparse/parse/html.pyx":1606
 *         """
 *         if self.dom_document == NULL:
 *             raise RuntimeError('Trying to create text node in uninitialized document.')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes text_bytes = text.encode()
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1606, __pyx_L1_error)

    /* "resiliparse/parse/html.pyx":1605
 *         :rtype: DOMNode
 *         """
 *         if self.dom_document == NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Trying to create text node in uninitialized document.')
 * 
 */
  }

  /* "resiliparse/parse/html.pyx":1608
 *             raise RuntimeError('Trying to create text node in uninitialized document.')
 * 
 *         cdef bytes text_bytes = text.encode()             # <<<<<<<<<<<<<<
 *         cdef lxb_dom_text_t* node = lxb_dom_document_create_text_node(
 *             <lxb_dom_document_t*>self.dom_document, <lxb_char_t*>text_bytes, len(text_bytes))
 */
  if (unlikely(__pyx_v_text == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(0, 1608, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_text, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_text_bytes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":1610
 *         cdef bytes text_bytes = text.encode()
 *         cdef lxb_dom_text_t* node = lxb_dom_document_create_text_node(
 *             <lxb_dom_document_t*>self.dom_document, <lxb_char_t*>text_bytes, len(text_bytes))             # <<<<<<<<<<<<<<
 *         return _create_dom_node(self, <lxb_dom_node_t*>node)
 * 
 */
  if (unlikely(__pyx_v_text_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1610, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsWritableUString(__pyx_v_text_bytes); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 1610, __pyx_L1_error)
  if (unlikely(__pyx_v_text_bytes == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 1610, __pyx_L1_error)
  }
  __pyx_t_7 = PyBytes_GET_SIZE(__pyx_v_text_bytes); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1610, __pyx_L1_error)

  /* "resiliparse/parse/html.pyx":1609
 * 
 *         cdef bytes text_bytes = text.encode()
 *         cdef lxb_dom_text_t* node = lxb_dom_document_create_text_node(             # <<<<<<<<<<<<<<
 *             <lxb_dom_document_t*>self.dom_document, <lxb_char_t*>text_bytes, len(text_bytes))
 *         return _create_dom_node(self, <lxb_dom_node_t*>node)
 */
  __pyx_v_node = lxb_dom_document_create_text_node(((lxb_dom_document_t *)__pyx_v_self->dom_document), ((lxb_char_t *)__pyx_t_6), __pyx_t_7);

  /* "resiliparse/parse/html.pyx":1611
 *         cdef lxb_dom_text_t* node = lxb_dom_document_create_text_node(
 *             <lxb_dom_document_t*>self.dom_document, <lxb_char_t*>text_bytes, len(text_bytes))
 *         return _create_dom_node(self, <lxb_dom_node_t*>node)             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html__create_dom_node(__pyx_v_self, ((lxb_dom_node_t *)__pyx_v_node))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1594
 *         return _create_dom_node(self, <lxb_dom_node_t*>element)
 * 
 *     cpdef DOMNode create_text_node(self, str text):             # <<<<<<<<<<<<<<
 *         """
 *         create_text_node(self, text)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.create_text_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text_bytes);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_11create_text_node(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static char __pyx_doc_11resiliparse_5parse_4html_8HTMLTree_10create_text_node[] = "\n        create_text_node(self, text)\n\n        Create a new DOM Element node.\n\n        :param text: string contents of the new text element\n        :type text: str\n        :return: new text node\n        :rtype: DOMNode\n        ";
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_11create_text_node(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_text_node (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_text), (&PyUnicode_Type), 1, "text", 1))) __PYX_ERR(0, 1594, __pyx_L1_error)
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_10create_text_node(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self), ((PyObject*)__pyx_v_text));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_10create_text_node(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_text_node", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_11resiliparse_5parse_4html_8HTMLTree_create_text_node(__pyx_v_self, __pyx_v_text, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.create_text_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "resiliparse/parse/html.pyx":1613
 *         return _create_dom_node(self, <lxb_dom_node_t*>node)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         cdef DOMNode doc = self.document
 *         if doc is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_13__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_13__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_12__str__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_12__str__(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *__pyx_v_doc = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "resiliparse/parse/html.pyx":1614
 * 
 *     def __str__(self):
 *         cdef DOMNode doc = self.document             # <<<<<<<<<<<<<<
 *         if doc is not None:
 *             return doc.html
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_document_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_11resiliparse_5parse_4html_DOMNode))))) __PYX_ERR(0, 1614, __pyx_L1_error)
  __pyx_v_doc = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":1615
 *     def __str__(self):
 *         cdef DOMNode doc = self.document
 *         if doc is not None:             # <<<<<<<<<<<<<<
 *             return doc.html
 *         return ''
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_doc) != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "resiliparse/parse/html.pyx":1616
 *         cdef DOMNode doc = self.document
 *         if doc is not None:
 *             return doc.html             # <<<<<<<<<<<<<<
 *         return ''
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_doc), __pyx_n_s_html); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "resiliparse/parse/html.pyx":1615
 *     def __str__(self):
 *         cdef DOMNode doc = self.document
 *         if doc is not None:             # <<<<<<<<<<<<<<
 *             return doc.html
 *         return ''
 */
  }

  /* "resiliparse/parse/html.pyx":1617
 *         if doc is not None:
 *             return doc.html
 *         return ''             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__2);
  __pyx_r = __pyx_kp_u__2;
  goto __pyx_L0;

  /* "resiliparse/parse/html.pyx":1613
 *         return _create_dom_node(self, <lxb_dom_node_t*>node)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         cdef DOMNode doc = self.document
 *         if doc is not None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_doc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_15__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_15__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_14__reduce_cython__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_14__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__37, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_17__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_17__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11resiliparse_5parse_4html_8HTMLTree_16__setstate_cython__(((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11resiliparse_5parse_4html_8HTMLTree_16__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__38, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("resiliparse.parse.html.HTMLTree.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":16
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):             # <<<<<<<<<<<<<<
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 */

/* Python wrapper */
static int __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_parents = 0;
  PyObject *__pyx_v_dct = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name_2,&__pyx_n_s_parents,&__pyx_n_s_dct,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parents)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(1, 16, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dct)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(1, 16, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = values[0];
    __pyx_v_parents = values[1];
    __pyx_v_dct = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name, PyObject *__pyx_v_parents, PyObject *__pyx_v_dct) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "EnumBase":17
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)             # <<<<<<<<<<<<<<
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)(&PyType_Type)), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, ((PyObject *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, ((PyObject *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(4+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_cls));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_cls));
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, ((PyObject *)__pyx_v_cls));
    __Pyx_INCREF(__pyx_v_name);
    __Pyx_GIVEREF(__pyx_v_name);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_name);
    __Pyx_INCREF(__pyx_v_parents);
    __Pyx_GIVEREF(__pyx_v_parents);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, __pyx_v_parents);
    __Pyx_INCREF(__pyx_v_dct);
    __Pyx_GIVEREF(__pyx_v_dct);
    PyTuple_SET_ITEM(__pyx_t_5, 3+__pyx_t_4, __pyx_v_dct);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":18
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()             # <<<<<<<<<<<<<<
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 */
  __Pyx_INCREF(__Pyx_OrderedDict);
  __pyx_t_2 = __Pyx_OrderedDict; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members, __pyx_t_1) < 0) __PYX_ERR(1, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":16
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):             # <<<<<<<<<<<<<<
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":19
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):             # <<<<<<<<<<<<<<
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__(PyObject *__pyx_v_cls); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__(PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "EnumBase":20
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())             # <<<<<<<<<<<<<<
 *     def __getitem__(cls, name):
 *         return cls.__members__[name]
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_values); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "EnumBase":19
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):             # <<<<<<<<<<<<<<
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":21
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):             # <<<<<<<<<<<<<<
 *         return cls.__members__[name]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__(PyObject *__pyx_v_cls, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__(PyObject *__pyx_v_cls, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "EnumBase":22
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 *         return cls.__members__[name]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "EnumBase":21
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):             # <<<<<<<<<<<<<<
 *         return cls.__members__[name]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_222419149);
    __Pyx_GIVEREF(__pyx_int_222419149);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_222419149);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_222419149);
    __Pyx_GIVEREF(__pyx_int_222419149);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_222419149);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_unpickle___Pyx_EnumMeta__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_1__new__ = {"__new__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_name = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__new__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_value,&__pyx_n_s_name_2,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cls)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__new__", 0, 2, 3, 1); __PYX_ERR(1, 28, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name_2);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__new__") < 0)) __PYX_ERR(1, 28, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cls = values[0];
    __pyx_v_value = values[1];
    __pyx_v_name = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__new__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 28, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(__pyx_self, __pyx_v_cls, __pyx_v_value, __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_value, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__new__", 0);

  /* "EnumBase":29
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 *         for v in cls:             # <<<<<<<<<<<<<<
 *             if v == value:
 *                 return v
 */
  if (likely(PyList_CheckExact(__pyx_v_cls)) || PyTuple_CheckExact(__pyx_v_cls)) {
    __pyx_t_1 = __pyx_v_cls; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_cls); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 29, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 29, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(1, 29, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 29, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(1, 29, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 29, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 29, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "EnumBase":30
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 *             if v == value:             # <<<<<<<<<<<<<<
 *                 return v
 *         if name is None:
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_v, __pyx_v_value, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 30, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(1, 30, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {

      /* "EnumBase":31
 *         for v in cls:
 *             if v == value:
 *                 return v             # <<<<<<<<<<<<<<
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_v);
      __pyx_r = __pyx_v_v;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "EnumBase":30
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 *             if v == value:             # <<<<<<<<<<<<<<
 *                 return v
 *         if name is None:
 */
    }

    /* "EnumBase":29
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 *         for v in cls:             # <<<<<<<<<<<<<<
 *             if v == value:
 *                 return v
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":32
 *             if v == value:
 *                 return v
 *         if name is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 */
  __pyx_t_5 = (__pyx_v_name == Py_None);
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (unlikely(__pyx_t_6)) {

    /* "EnumBase":33
 *                 return v
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)             # <<<<<<<<<<<<<<
 *         res = int.__new__(cls, value)
 *         res.name = name
 */
    __pyx_t_1 = __Pyx_PyString_FormatSafe(__pyx_kp_s_Unknown_enum_value_s, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(1, 33, __pyx_L1_error)

    /* "EnumBase":32
 *             if v == value:
 *                 return v
 *         if name is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 */
  }

  /* "EnumBase":34
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)             # <<<<<<<<<<<<<<
 *         res.name = name
 *         setattr(cls, name, res)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)(&PyInt_Type)), __pyx_n_s_new); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_cls, __pyx_v_value};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_cls, __pyx_v_value};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cls);
    __Pyx_GIVEREF(__pyx_v_cls);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_cls);
    __Pyx_INCREF(__pyx_v_value);
    __Pyx_GIVEREF(__pyx_v_value);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_v_value);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "EnumBase":35
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 *         res.name = name             # <<<<<<<<<<<<<<
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_res, __pyx_n_s_name_2, __pyx_v_name) < 0) __PYX_ERR(1, 35, __pyx_L1_error)

  /* "EnumBase":36
 *         res = int.__new__(cls, value)
 *         res.name = name
 *         setattr(cls, name, res)             # <<<<<<<<<<<<<<
 *         cls.__members__[name] = res
 *         return res
 */
  __pyx_t_10 = PyObject_SetAttr(__pyx_v_cls, __pyx_v_name, __pyx_v_res); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(1, 36, __pyx_L1_error)

  /* "EnumBase":37
 *         res.name = name
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res             # <<<<<<<<<<<<<<
 *         return res
 *     def __repr__(self):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_members); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely(PyObject_SetItem(__pyx_t_4, __pyx_v_name, __pyx_v_res) < 0)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "EnumBase":38
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res
 *         return res             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_3__repr__ = {"__repr__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__, METH_O, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "EnumBase":40
 *         return res
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)             # <<<<<<<<<<<<<<
 *     def __str__(self):
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_s_s_d, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_5__str__ = {"__str__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__, METH_O, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "EnumBase":42
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 *         return "%s.%s" % (self.__class__.__name__, self.name)             # <<<<<<<<<<<<<<
 * 
 * if PY_VERSION_HEX >= 0x03040000:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_s_s, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta = {"__pyx_unpickle___Pyx_EnumMeta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle___Pyx_EnumMeta") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xd41d8cd) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xd4, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype___Pyx_EnumMeta), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_unpickle___Pyx_EnumMeta__set_state(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_unpickle___Pyx_EnumMeta__set_state(struct __pyx_obj___Pyx_EnumMeta *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_3 = ((__pyx_t_2 > 0) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":13
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 13, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMElementClassList __pyx_vtable_11resiliparse_5parse_4html_DOMElementClassList;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html_DOMElementClassList(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)o);
  p->__pyx_vtab = __pyx_vtabptr_11resiliparse_5parse_4html_DOMElementClassList;
  p->node = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html_DOMElementClassList(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->node);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html_DOMElementClassList(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)o;
  if (p->node) {
    e = (*v)(((PyObject *)p->node), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11resiliparse_5parse_4html_DOMElementClassList(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)o;
  tmp = ((PyObject*)p->node);
  p->node = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_11resiliparse_5parse_4html_DOMElementClassList(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_tp_richcompare_11resiliparse_5parse_4html_DOMElementClassList(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_11__eq__(o1, o2);
    }
    case Py_NE: {
      PyObject *ret;
      ret = __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_11__eq__(o1, o2);
      if (likely(ret && ret != Py_NotImplemented)) {
        int b = __Pyx_PyObject_IsTrue(ret); Py_DECREF(ret);
        if (unlikely(b < 0)) return NULL;
        ret = (b) ? Py_False : Py_True;
        Py_INCREF(ret);
      }
      return ret;
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyMethodDef __pyx_methods_11resiliparse_5parse_4html_DOMElementClassList[] = {
  {"add", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_3add, METH_O, __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_2add},
  {"remove", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_5remove, METH_O, __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_4remove},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_21__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_23__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_DOMElementClassList = {
  __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_13__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_11resiliparse_5parse_4html_DOMElementClassList, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_DOMElementClassList = {
  __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_13__len__, /*mp_length*/
  __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_9__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_11resiliparse_5parse_4html_DOMElementClassList = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.DOMElementClassList", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html_DOMElementClassList, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_17__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_DOMElementClassList, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_DOMElementClassList, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_19__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Class name list of an Element DOM node.", /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html_DOMElementClassList, /*tp_traverse*/
  __pyx_tp_clear_11resiliparse_5parse_4html_DOMElementClassList, /*tp_clear*/
  __pyx_tp_richcompare_11resiliparse_5parse_4html_DOMElementClassList, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_11resiliparse_5parse_4html_19DOMElementClassList_15__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11resiliparse_5parse_4html_DOMElementClassList, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html_DOMElementClassList, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMNode __pyx_vtable_11resiliparse_5parse_4html_DOMNode;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html_DOMNode(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)o);
  p->__pyx_vtab = __pyx_vtabptr_11resiliparse_5parse_4html_DOMNode;
  p->tree = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)Py_None); Py_INCREF(Py_None);
  p->class_list_singleton = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11resiliparse_5parse_4html_7DOMNode_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html_DOMNode(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_11resiliparse_5parse_4html_7DOMNode_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->tree);
  Py_CLEAR(p->class_list_singleton);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html_DOMNode(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)o;
  if (p->tree) {
    e = (*v)(((PyObject *)p->tree), a); if (e) return e;
  }
  if (p->class_list_singleton) {
    e = (*v)(((PyObject *)p->class_list_singleton), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11resiliparse_5parse_4html_DOMNode(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)o;
  tmp = ((PyObject*)p->tree);
  p->tree = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->class_list_singleton);
  p->class_list_singleton = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_11resiliparse_5parse_4html_DOMNode(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_11resiliparse_5parse_4html_DOMNode(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_16__setitem__(o, i, v);
  }
  else {
    return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_20__delitem__(o, i);
  }
}

static PyObject *__pyx_tp_richcompare_11resiliparse_5parse_4html_DOMNode(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_50__eq__(o1, o2);
    }
    case Py_NE: {
      PyObject *ret;
      ret = __pyx_pw_11resiliparse_5parse_4html_7DOMNode_50__eq__(o1, o2);
      if (likely(ret && ret != Py_NotImplemented)) {
        int b = __Pyx_PyObject_IsTrue(ret); Py_DECREF(ret);
        if (unlikely(b < 0)) return NULL;
        ret = (b) ? Py_False : Py_True;
        Py_INCREF(ret);
      }
      return ret;
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4type_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_tag(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_3tag_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_first_child(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_11first_child_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_last_child(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_10last_child_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_child_nodes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_11child_nodes_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_parent(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_6parent_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_next(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4next_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_prev(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4prev_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_text(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4text_1__get__(o);
}

static int __pyx_setprop_11resiliparse_5parse_4html_7DOMNode_text(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4text_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_html(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4html_1__get__(o);
}

static int __pyx_setprop_11resiliparse_5parse_4html_7DOMNode_html(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_4html_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_id(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_2id_1__get__(o);
}

static int __pyx_setprop_11resiliparse_5parse_4html_7DOMNode_id(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_2id_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_class_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_name_1__get__(o);
}

static int __pyx_setprop_11resiliparse_5parse_4html_7DOMNode_class_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_name_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_class_list(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_10class_list_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_7DOMNode_attrs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_7DOMNode_5attrs_1__get__(o);
}

static PyMethodDef __pyx_methods_11resiliparse_5parse_4html_DOMNode[] = {
  {"hasattr", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_8hasattr, METH_O, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_7hasattr},
  {"getattr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_10getattr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_9getattr},
  {"setattr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_14setattr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_13setattr},
  {"delattr", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_18delattr, METH_O, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_17delattr},
  {"query_selector", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_22query_selector, METH_O, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_21query_selector},
  {"query_selector_all", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_24query_selector_all, METH_O, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_23query_selector_all},
  {"matches", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_26matches, METH_O, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_25matches},
  {"get_elements_by_attr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_28get_elements_by_attr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_27get_elements_by_attr},
  {"get_element_by_id", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_30get_element_by_id, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_29get_element_by_id},
  {"get_elements_by_class_name", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_32get_elements_by_class_name, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_31get_elements_by_class_name},
  {"get_elements_by_tag_name", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_34get_elements_by_tag_name, METH_O, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_33get_elements_by_tag_name},
  {"append_child", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_36append_child, METH_O, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_35append_child},
  {"insert_before", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_38insert_before, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_37insert_before},
  {"replace_child", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_40replace_child, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_39replace_child},
  {"remove_child", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_42remove_child, METH_O, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_41remove_child},
  {"decompose", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_44decompose, METH_NOARGS, __pyx_doc_11resiliparse_5parse_4html_7DOMNode_43decompose},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_54__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_7DOMNode_56__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11resiliparse_5parse_4html_DOMNode[] = {
  {(char *)"type", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_type, 0, (char *)"\n        DOM node type.\n\n        :type: NodeType\n        ", 0},
  {(char *)"tag", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_tag, 0, (char *)"\n        DOM node tag name if node is an Element node.\n\n        :type: str or None\n        ", 0},
  {(char *)"first_child", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_first_child, 0, (char *)"\n        First child element of this DOM node.\n\n        :type: DOMNode or None\n        ", 0},
  {(char *)"last_child", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_last_child, 0, (char *)"\n        Last child element of this DOM node.\n\n        :type: DOMNode or None\n        ", 0},
  {(char *)"child_nodes", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_child_nodes, 0, (char *)"\n        List of child nodes.\n\n        :type: t.List[DOMNode]\n        ", 0},
  {(char *)"parent", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_parent, 0, (char *)"\n        Parent of this node.\n\n        :type: DOMNode or None\n        ", 0},
  {(char *)"next", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_next, 0, (char *)"\n        Next sibling node.\n\n        :type: DOMNode or None\n        ", 0},
  {(char *)"prev", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_prev, 0, (char *)"\n        Previous sibling node.\n\n        :type: DOMNode or None\n        ", 0},
  {(char *)"text", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_text, __pyx_setprop_11resiliparse_5parse_4html_7DOMNode_text, (char *)"\n        Text contents of this DOM node and its children.\n\n        The DOM node's inner text can be modified by assigning to this property.\n\n        :type: str\n        ", 0},
  {(char *)"html", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_html, __pyx_setprop_11resiliparse_5parse_4html_7DOMNode_html, (char *)"\n        HTML contents of this DOM node and its children.\n\n        The DOM node's inner HTML can be modified by assigning to this property.\n\n        :type: str\n        ", 0},
  {(char *)"id", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_id, __pyx_setprop_11resiliparse_5parse_4html_7DOMNode_id, (char *)"\n        ID attribute of this Element node (empty string if unset).\n\n        :type: str\n        ", 0},
  {(char *)"class_name", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_class_name, __pyx_setprop_11resiliparse_5parse_4html_7DOMNode_class_name, (char *)"\n        Class name attribute of this Element node (empty string if unset).\n\n        :type: str\n        ", 0},
  {(char *)"class_list", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_class_list, 0, (char *)"\n        List of class names set on this Element node.\n\n        :type: DOMElementClassList\n        ", 0},
  {(char *)"attrs", __pyx_getprop_11resiliparse_5parse_4html_7DOMNode_attrs, 0, (char *)"\n        List of attribute names if node is an Element node.\n\n        :type: t.List[str] or None\n        ", 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_DOMNode = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_11resiliparse_5parse_4html_DOMNode, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_DOMNode = {
  0, /*mp_length*/
  __pyx_pw_11resiliparse_5parse_4html_7DOMNode_12__getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_11resiliparse_5parse_4html_DOMNode, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_11resiliparse_5parse_4html_DOMNode = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.DOMNode", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html_DOMNode, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11resiliparse_5parse_4html_7DOMNode_46__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_DOMNode, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_DOMNode, /*tp_as_mapping*/
  __pyx_pw_11resiliparse_5parse_4html_7DOMNode_52__hash__, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_11resiliparse_5parse_4html_7DOMNode_48__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n    __init__(self)\n\n    DOM node.\n\n    A DOM node is only valid as long as the owning :class:`HTMLTree` is alive\n    and the DOM tree hasn't been modified. Do not access :class:`DOMNode` instances\n    after any sort of DOM tree manipulation.\n    ", /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html_DOMNode, /*tp_traverse*/
  __pyx_tp_clear_11resiliparse_5parse_4html_DOMNode, /*tp_clear*/
  __pyx_tp_richcompare_11resiliparse_5parse_4html_DOMNode, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_11resiliparse_5parse_4html_7DOMNode_5__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11resiliparse_5parse_4html_DOMNode, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11resiliparse_5parse_4html_DOMNode, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html_DOMNode, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct_11resiliparse_5parse_4html_DOMCollection __pyx_vtable_11resiliparse_5parse_4html_DOMCollection;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html_DOMCollection(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)o);
  p->__pyx_vtab = __pyx_vtabptr_11resiliparse_5parse_4html_DOMCollection;
  p->tree = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html_DOMCollection(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->tree);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html_DOMCollection(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)o;
  if (p->tree) {
    e = (*v)(((PyObject *)p->tree), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11resiliparse_5parse_4html_DOMCollection(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *p = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)o;
  tmp = ((PyObject*)p->tree);
  p->tree = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_11resiliparse_5parse_4html_DOMCollection(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyMethodDef __pyx_methods_11resiliparse_5parse_4html_DOMCollection[] = {
  {"get_element_by_id", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_5get_element_by_id, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_4get_element_by_id},
  {"get_elements_by_attr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_7get_elements_by_attr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_6get_elements_by_attr},
  {"get_elements_by_class_name", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_9get_elements_by_class_name, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_8get_elements_by_class_name},
  {"get_elements_by_tag_name", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_11get_elements_by_tag_name, METH_O, __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_10get_elements_by_tag_name},
  {"query_selector", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_13query_selector, METH_O, __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_12query_selector},
  {"query_selector_all", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_15query_selector_all, METH_O, __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_14query_selector_all},
  {"matches", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_17matches, METH_O, __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_16matches},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_30__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_13DOMCollection_32__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_DOMCollection = {
  __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_22__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_11resiliparse_5parse_4html_DOMCollection, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_DOMCollection = {
  __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_22__len__, /*mp_length*/
  __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_24__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_11resiliparse_5parse_4html_DOMCollection = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.DOMCollection", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html_DOMCollection, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_26__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_DOMCollection, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_DOMCollection, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_28__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "\n    __init__(self)\n\n    Collection of DOM nodes that are the result set of an element matching operation.\n\n    A node collection is only valid for as long as the owning :class:`HTMLTree` is alive\n    and the DOM tree hasn't been modified. Do not access :class:`DOMCollection` instances\n    after any sort of DOM tree manipulation.\n    ", /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html_DOMCollection, /*tp_traverse*/
  __pyx_tp_clear_11resiliparse_5parse_4html_DOMCollection, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_11resiliparse_5parse_4html_13DOMCollection_19__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11resiliparse_5parse_4html_DOMCollection, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html_DOMCollection, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct_11resiliparse_5parse_4html_HTMLTree __pyx_vtable_11resiliparse_5parse_4html_HTMLTree;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html_HTMLTree(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)o);
  p->__pyx_vtab = __pyx_vtabptr_11resiliparse_5parse_4html_HTMLTree;
  p->encoding = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html_HTMLTree(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *p = (struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->encoding);
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_8HTMLTree_document(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_8document_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_8HTMLTree_head(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_4head_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_8HTMLTree_body(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_4body_1__get__(o);
}

static PyObject *__pyx_getprop_11resiliparse_5parse_4html_8HTMLTree_title(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_5title_1__get__(o);
}

static PyMethodDef __pyx_methods_11resiliparse_5parse_4html_HTMLTree[] = {
  {"parse", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_5parse, METH_O, __pyx_doc_11resiliparse_5parse_4html_8HTMLTree_4parse},
  {"parse_from_bytes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_7parse_from_bytes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11resiliparse_5parse_4html_8HTMLTree_6parse_from_bytes},
  {"create_element", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_9create_element, METH_O, __pyx_doc_11resiliparse_5parse_4html_8HTMLTree_8create_element},
  {"create_text_node", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_11create_text_node, METH_O, __pyx_doc_11resiliparse_5parse_4html_8HTMLTree_10create_text_node},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_15__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11resiliparse_5parse_4html_8HTMLTree_17__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11resiliparse_5parse_4html_HTMLTree[] = {
  {(char *)"document", __pyx_getprop_11resiliparse_5parse_4html_8HTMLTree_document, 0, (char *)"\n        Document root node.\n\n        :type: DOMNode or None\n        ", 0},
  {(char *)"head", __pyx_getprop_11resiliparse_5parse_4html_8HTMLTree_head, 0, (char *)"\n        HTML head element or ``None`` if document has no head.\n\n        :type: DOMNode or None\n        ", 0},
  {(char *)"body", __pyx_getprop_11resiliparse_5parse_4html_8HTMLTree_body, 0, (char *)"\n        HTML body element or ``None`` if document has no body.\n\n        :type: DOMNode or None\n        ", 0},
  {(char *)"title", __pyx_getprop_11resiliparse_5parse_4html_8HTMLTree_title, 0, (char *)"\n        The HTML document title.\n\n        :type: str or None\n        ", 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11resiliparse_5parse_4html_HTMLTree = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.HTMLTree", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html_HTMLTree, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_11resiliparse_5parse_4html_8HTMLTree_13__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "\n    __init__(self)\n\n    HTML DOM tree parser.\n    ", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11resiliparse_5parse_4html_HTMLTree, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11resiliparse_5parse_4html_HTMLTree, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html_HTMLTree, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct____iter__[8];
static int __pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct____iter__ = 0;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct____iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct____iter__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__)))) {
    o = (PyObject*)__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct____iter__[--__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct____iter__];
    memset(o, 0, sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct____iter__(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct____iter__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__)))) {
    __pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct____iter__[__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct____iter__++] = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct____iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct____iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.__pyx_scope_struct____iter__", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct____iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct____iter__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct____iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct____iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__[8];
static int __pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ = 0;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__)))) {
    o = (PyObject*)__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__[--__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__];
    memset(o, 0, sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__)))) {
    __pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__[__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__++] = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.__pyx_scope_struct_1___repr__", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__, /*tp_traverse*/
  __pyx_tp_clear_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr[8];
static int __pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr = 0;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr)))) {
    o = (PyObject*)__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr[--__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_a);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr)))) {
    __pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr[__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr++] = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_a) {
    e = (*v)(p->__pyx_v_a, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.__pyx_scope_struct_2_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__[8];
static int __pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ = 0;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__)))) {
    o = (PyObject*)__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__[--__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__];
    memset(o, 0, sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__)))) {
    __pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__[__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__++] = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.__pyx_scope_struct_3___iter__", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__[8];
static int __pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ = 0;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__)))) {
    o = (PyObject*)__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__[--__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__];
    memset(o, 0, sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__)))) {
    __pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__[__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__++] = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.__pyx_scope_struct_4___repr__", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__, /*tp_traverse*/
  __pyx_tp_clear_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr[8];
static int __pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr = 0;

static PyObject *__pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr)))) {
    o = (PyObject*)__pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr[--__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr(PyObject *o) {
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_n);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr)))) {
    __pyx_freelist_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr[__pyx_freecount_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr++] = ((struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_n) {
    e = (*v)(p->__pyx_v_n, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.__pyx_scope_struct_5_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyObject *__pyx_tp_new___Pyx_EnumMeta(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = (&PyType_Type)->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc___Pyx_EnumMeta(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  PyObject_GC_Track(o);
  (&PyType_Type)->tp_dealloc(o);
}

static int __pyx_tp_traverse___Pyx_EnumMeta(PyObject *o, visitproc v, void *a) {
  int e;
  if (!(&PyType_Type)->tp_traverse); else { e = (&PyType_Type)->tp_traverse(o,v,a); if (e) return e; }
  return 0;
}

static int __pyx_tp_clear___Pyx_EnumMeta(PyObject *o) {
  if (!(&PyType_Type)->tp_clear); else (&PyType_Type)->tp_clear(o);
  return 0;
}
static PyObject *__pyx_sq_item___Pyx_EnumMeta(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyMethodDef __pyx_methods___Pyx_EnumMeta[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence___Pyx_EnumMeta = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item___Pyx_EnumMeta, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping___Pyx_EnumMeta = {
  0, /*mp_length*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __Pyx_EnumMeta = {
  PyVarObject_HEAD_INIT(0, 0)
  "resiliparse.parse.html.__Pyx_EnumMeta", /*tp_name*/
  sizeof(struct __pyx_obj___Pyx_EnumMeta), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___Pyx_EnumMeta, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence___Pyx_EnumMeta, /*tp_as_sequence*/
  &__pyx_tp_as_mapping___Pyx_EnumMeta, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse___Pyx_EnumMeta, /*tp_traverse*/
  __pyx_tp_clear___Pyx_EnumMeta, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods___Pyx_EnumMeta, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___Pyx_EnumMeta, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_html(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_html},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "html",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_ATTRIBUTE, __pyx_k_ATTRIBUTE, sizeof(__pyx_k_ATTRIBUTE), 0, 0, 1, 1},
  {&__pyx_kp_u_Append_operation_on_uninitialize, __pyx_k_Append_operation_on_uninitialize, sizeof(__pyx_k_Append_operation_on_uninitialize), 0, 1, 0, 0},
  {&__pyx_n_s_CDATA_SECTION, __pyx_k_CDATA_SECTION, sizeof(__pyx_k_CDATA_SECTION), 0, 0, 1, 1},
  {&__pyx_n_s_COMMENT, __pyx_k_COMMENT, sizeof(__pyx_k_COMMENT), 0, 0, 1, 1},
  {&__pyx_kp_u_DOCTYPE_html, __pyx_k_DOCTYPE_html, sizeof(__pyx_k_DOCTYPE_html), 0, 1, 0, 0},
  {&__pyx_n_s_DOCUMENT, __pyx_k_DOCUMENT, sizeof(__pyx_k_DOCUMENT), 0, 0, 1, 1},
  {&__pyx_n_s_DOCUMENT_FRAGMENT, __pyx_k_DOCUMENT_FRAGMENT, sizeof(__pyx_k_DOCUMENT_FRAGMENT), 0, 0, 1, 1},
  {&__pyx_n_s_DOCUMENT_TYPE, __pyx_k_DOCUMENT_TYPE, sizeof(__pyx_k_DOCUMENT_TYPE), 0, 0, 1, 1},
  {&__pyx_n_s_DOMCollection, __pyx_k_DOMCollection, sizeof(__pyx_k_DOMCollection), 0, 0, 1, 1},
  {&__pyx_n_s_DOMCollection___iter, __pyx_k_DOMCollection___iter, sizeof(__pyx_k_DOMCollection___iter), 0, 0, 1, 1},
  {&__pyx_n_s_DOMElementClassList, __pyx_k_DOMElementClassList, sizeof(__pyx_k_DOMElementClassList), 0, 0, 1, 1},
  {&__pyx_n_s_DOMNode, __pyx_k_DOMNode, sizeof(__pyx_k_DOMNode), 0, 0, 1, 1},
  {&__pyx_n_s_DOMNode___iter, __pyx_k_DOMNode___iter, sizeof(__pyx_k_DOMNode___iter), 0, 0, 1, 1},
  {&__pyx_kp_u_Decompose_operation_on_uninitial, __pyx_k_Decompose_operation_on_uninitial, sizeof(__pyx_k_Decompose_operation_on_uninitial), 0, 1, 0, 0},
  {&__pyx_n_s_ELEMENT, __pyx_k_ELEMENT, sizeof(__pyx_k_ELEMENT), 0, 0, 1, 1},
  {&__pyx_n_s_ENTITY, __pyx_k_ENTITY, sizeof(__pyx_k_ENTITY), 0, 0, 1, 1},
  {&__pyx_n_s_ENTITY_REFERENCE, __pyx_k_ENTITY_REFERENCE, sizeof(__pyx_k_ENTITY_REFERENCE), 0, 0, 1, 1},
  {&__pyx_kp_u_Element, __pyx_k_Element, sizeof(__pyx_k_Element), 0, 1, 0, 0},
  {&__pyx_n_s_EnumBase, __pyx_k_EnumBase, sizeof(__pyx_k_EnumBase), 0, 0, 1, 1},
  {&__pyx_n_s_EnumType, __pyx_k_EnumType, sizeof(__pyx_k_EnumType), 0, 0, 1, 1},
  {&__pyx_kp_u_Failed_to_allocate_HTML_document, __pyx_k_Failed_to_allocate_HTML_document, sizeof(__pyx_k_Failed_to_allocate_HTML_document), 0, 1, 0, 0},
  {&__pyx_kp_u_Failed_to_create_DOM_collection, __pyx_k_Failed_to_create_DOM_collection, sizeof(__pyx_k_Failed_to_create_DOM_collection), 0, 1, 0, 0},
  {&__pyx_kp_u_Failed_to_match_elements_by_CSS, __pyx_k_Failed_to_match_elements_by_CSS, sizeof(__pyx_k_Failed_to_match_elements_by_CSS), 0, 1, 0, 0},
  {&__pyx_kp_u_Failed_to_parse_HTML_document, __pyx_k_Failed_to_parse_HTML_document, sizeof(__pyx_k_Failed_to_parse_HTML_document), 0, 1, 0, 0},
  {&__pyx_n_s_HTMLTree, __pyx_k_HTMLTree, sizeof(__pyx_k_HTMLTree), 0, 0, 1, 1},
  {&__pyx_kp_u_HTML_Document, __pyx_k_HTML_Document, sizeof(__pyx_k_HTML_Document), 0, 1, 0, 0},
  {&__pyx_kp_u_INVALID_ELEMENT, __pyx_k_INVALID_ELEMENT, sizeof(__pyx_k_INVALID_ELEMENT), 0, 1, 0, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xd4, __pyx_k_Incompatible_checksums_s_vs_0xd4, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xd4), 0, 0, 1, 0},
  {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
  {&__pyx_kp_u_Index_out_of_range, __pyx_k_Index_out_of_range, sizeof(__pyx_k_Index_out_of_range), 0, 1, 0, 0},
  {&__pyx_kp_u_Insert_operation_on_uninitialize, __pyx_k_Insert_operation_on_uninitialize, sizeof(__pyx_k_Insert_operation_on_uninitialize), 0, 1, 0, 0},
  {&__pyx_n_s_IntEnum, __pyx_k_IntEnum, sizeof(__pyx_k_IntEnum), 0, 0, 1, 1},
  {&__pyx_kp_u_Invalid_key_type, __pyx_k_Invalid_key_type, sizeof(__pyx_k_Invalid_key_type), 0, 1, 0, 0},
  {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
  {&__pyx_n_s_LAST_ENTRY, __pyx_k_LAST_ENTRY, sizeof(__pyx_k_LAST_ENTRY), 0, 0, 1, 1},
  {&__pyx_n_s_NOTATION, __pyx_k_NOTATION, sizeof(__pyx_k_NOTATION), 0, 0, 1, 1},
  {&__pyx_kp_u_No_such_attribute, __pyx_k_No_such_attribute, sizeof(__pyx_k_No_such_attribute), 0, 1, 0, 0},
  {&__pyx_n_s_NodeType, __pyx_k_NodeType, sizeof(__pyx_k_NodeType), 0, 0, 1, 1},
  {&__pyx_kp_u_Node_is_not_a_child_of_the_curre, __pyx_k_Node_is_not_a_child_of_the_curre, sizeof(__pyx_k_Node_is_not_a_child_of_the_curre), 0, 1, 0, 0},
  {&__pyx_kp_u_Node_ist_not_an_Element_node, __pyx_k_Node_ist_not_an_Element_node, sizeof(__pyx_k_Node_ist_not_an_Element_node), 0, 1, 0, 0},
  {&__pyx_kp_u_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 1, 0, 0},
  {&__pyx_n_s_OrderedDict, __pyx_k_OrderedDict, sizeof(__pyx_k_OrderedDict), 0, 0, 1, 1},
  {&__pyx_n_s_PROCESSING_INSTRUCTION, __pyx_k_PROCESSING_INSTRUCTION, sizeof(__pyx_k_PROCESSING_INSTRUCTION), 0, 0, 1, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase, __pyx_k_Pyx_EnumBase, sizeof(__pyx_k_Pyx_EnumBase), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___new, __pyx_k_Pyx_EnumBase___new, sizeof(__pyx_k_Pyx_EnumBase___new), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___repr, __pyx_k_Pyx_EnumBase___repr, sizeof(__pyx_k_Pyx_EnumBase___repr), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___str, __pyx_k_Pyx_EnumBase___str, sizeof(__pyx_k_Pyx_EnumBase___str), 0, 0, 1, 1},
  {&__pyx_kp_u_Reference_node_must_be_a_child_n, __pyx_k_Reference_node_must_be_a_child_n, sizeof(__pyx_k_Reference_node_must_be_a_child_n), 0, 1, 0, 0},
  {&__pyx_kp_u_Remove_operation_on_uninitialize, __pyx_k_Remove_operation_on_uninitialize, sizeof(__pyx_k_Remove_operation_on_uninitialize), 0, 1, 0, 0},
  {&__pyx_kp_u_Replace_operation_on_uninitializ, __pyx_k_Replace_operation_on_uninitializ, sizeof(__pyx_k_Replace_operation_on_uninitializ), 0, 1, 0, 0},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s_TEXT, __pyx_k_TEXT, sizeof(__pyx_k_TEXT), 0, 0, 1, 1},
  {&__pyx_kp_u_Trying_to_append_child_to_itself, __pyx_k_Trying_to_append_child_to_itself, sizeof(__pyx_k_Trying_to_append_child_to_itself), 0, 1, 0, 0},
  {&__pyx_kp_u_Trying_to_create_element_in_unin, __pyx_k_Trying_to_create_element_in_unin, sizeof(__pyx_k_Trying_to_create_element_in_unin), 0, 1, 0, 0},
  {&__pyx_kp_u_Trying_to_create_text_node_in_un, __pyx_k_Trying_to_create_text_node_in_un, sizeof(__pyx_k_Trying_to_create_text_node_in_un), 0, 1, 0, 0},
  {&__pyx_kp_u_Trying_to_get_item_of_uninitiali, __pyx_k_Trying_to_get_item_of_uninitiali, sizeof(__pyx_k_Trying_to_get_item_of_uninitiali), 0, 1, 0, 0},
  {&__pyx_kp_u_Trying_to_insert_node_as_its_own, __pyx_k_Trying_to_insert_node_as_its_own, sizeof(__pyx_k_Trying_to_insert_node_as_its_own), 0, 1, 0, 0},
  {&__pyx_kp_u_Trying_to_select_items_from_unin, __pyx_k_Trying_to_select_items_from_unin, sizeof(__pyx_k_Trying_to_select_items_from_unin), 0, 1, 0, 0},
  {&__pyx_kp_u_Trying_to_set_HTML_contents_of_u, __pyx_k_Trying_to_set_HTML_contents_of_u, sizeof(__pyx_k_Trying_to_set_HTML_contents_of_u), 0, 1, 0, 0},
  {&__pyx_kp_u_Trying_to_set_text_contents_of_u, __pyx_k_Trying_to_set_text_contents_of_u, sizeof(__pyx_k_Trying_to_set_text_contents_of_u), 0, 1, 0, 0},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_kp_s_Unknown_enum_value_s, __pyx_k_Unknown_enum_value_s, sizeof(__pyx_k_Unknown_enum_value_s), 0, 0, 1, 0},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_kp_u__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 1, 0, 0},
  {&__pyx_kp_b__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 0, 0, 0},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_kp_u__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 1, 0, 0},
  {&__pyx_kp_u__21, __pyx_k__21, sizeof(__pyx_k__21), 0, 1, 0, 0},
  {&__pyx_kp_u__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 1, 0, 0},
  {&__pyx_kp_u__28, __pyx_k__28, sizeof(__pyx_k__28), 0, 1, 0, 0},
  {&__pyx_kp_u__29, __pyx_k__29, sizeof(__pyx_k__29), 0, 1, 0, 0},
  {&__pyx_kp_b__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 0, 0},
  {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
  {&__pyx_kp_u__30, __pyx_k__30, sizeof(__pyx_k__30), 0, 1, 0, 0},
  {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
  {&__pyx_n_s_append_child, __pyx_k_append_child, sizeof(__pyx_k_append_child), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_attr_name, __pyx_k_attr_name, sizeof(__pyx_k_attr_name), 0, 0, 1, 1},
  {&__pyx_n_s_attr_value, __pyx_k_attr_value, sizeof(__pyx_k_attr_value), 0, 0, 1, 1},
  {&__pyx_n_s_attrs, __pyx_k_attrs, sizeof(__pyx_k_attrs), 0, 0, 1, 1},
  {&__pyx_n_b_by_attr, __pyx_k_by_attr, sizeof(__pyx_k_by_attr), 0, 0, 0, 1},
  {&__pyx_n_b_by_class, __pyx_k_by_class, sizeof(__pyx_k_by_class), 0, 0, 0, 1},
  {&__pyx_n_b_by_tag, __pyx_k_by_tag, sizeof(__pyx_k_by_tag), 0, 0, 0, 1},
  {&__pyx_n_s_case_insensitive, __pyx_k_case_insensitive, sizeof(__pyx_k_case_insensitive), 0, 0, 1, 1},
  {&__pyx_n_b_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 0, 1},
  {&__pyx_n_s_class_2, __pyx_k_class_2, sizeof(__pyx_k_class_2), 0, 0, 1, 1},
  {&__pyx_n_s_class_name, __pyx_k_class_name, sizeof(__pyx_k_class_name), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
  {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
  {&__pyx_n_s_create_element, __pyx_k_create_element, sizeof(__pyx_k_create_element), 0, 0, 1, 1},
  {&__pyx_n_s_create_text_node, __pyx_k_create_text_node, sizeof(__pyx_k_create_text_node), 0, 0, 1, 1},
  {&__pyx_n_s_dct, __pyx_k_dct, sizeof(__pyx_k_dct), 0, 0, 1, 1},
  {&__pyx_n_s_decompose, __pyx_k_decompose, sizeof(__pyx_k_decompose), 0, 0, 1, 1},
  {&__pyx_n_s_default_value, __pyx_k_default_value, sizeof(__pyx_k_default_value), 0, 0, 1, 1},
  {&__pyx_n_s_delattr, __pyx_k_delattr, sizeof(__pyx_k_delattr), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_kp_u_document, __pyx_k_document, sizeof(__pyx_k_document), 0, 1, 0, 0},
  {&__pyx_n_s_document_2, __pyx_k_document_2, sizeof(__pyx_k_document_2), 0, 0, 1, 1},
  {&__pyx_n_s_element_id, __pyx_k_element_id, sizeof(__pyx_k_element_id), 0, 0, 1, 1},
  {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
  {&__pyx_n_s_encoding, __pyx_k_encoding, sizeof(__pyx_k_encoding), 0, 0, 1, 1},
  {&__pyx_n_s_enum, __pyx_k_enum, sizeof(__pyx_k_enum), 0, 0, 1, 1},
  {&__pyx_n_s_errors, __pyx_k_errors, sizeof(__pyx_k_errors), 0, 0, 1, 1},
  {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_get_element_by_id, __pyx_k_get_element_by_id, sizeof(__pyx_k_get_element_by_id), 0, 0, 1, 1},
  {&__pyx_n_s_get_elements_by_attr, __pyx_k_get_elements_by_attr, sizeof(__pyx_k_get_elements_by_attr), 0, 0, 1, 1},
  {&__pyx_n_s_get_elements_by_class_name, __pyx_k_get_elements_by_class_name, sizeof(__pyx_k_get_elements_by_class_name), 0, 0, 1, 1},
  {&__pyx_n_s_get_elements_by_tag_name, __pyx_k_get_elements_by_tag_name, sizeof(__pyx_k_get_elements_by_tag_name), 0, 0, 1, 1},
  {&__pyx_n_s_getattr, __pyx_k_getattr, sizeof(__pyx_k_getattr), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_hasattr, __pyx_k_hasattr, sizeof(__pyx_k_hasattr), 0, 0, 1, 1},
  {&__pyx_n_s_html, __pyx_k_html, sizeof(__pyx_k_html), 0, 0, 1, 1},
  {&__pyx_n_b_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 0, 1},
  {&__pyx_n_u_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 1, 0, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_insert_before, __pyx_k_insert_before, sizeof(__pyx_k_insert_before), 0, 0, 1, 1},
  {&__pyx_n_s_iter, __pyx_k_iter, sizeof(__pyx_k_iter), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_matches, __pyx_k_matches, sizeof(__pyx_k_matches), 0, 0, 1, 1},
  {&__pyx_n_s_members, __pyx_k_members, sizeof(__pyx_k_members), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_new_child, __pyx_k_new_child, sizeof(__pyx_k_new_child), 0, 0, 1, 1},
  {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
  {&__pyx_n_s_node, __pyx_k_node, sizeof(__pyx_k_node), 0, 0, 1, 1},
  {&__pyx_n_s_old_child, __pyx_k_old_child, sizeof(__pyx_k_old_child), 0, 0, 1, 1},
  {&__pyx_n_s_parents, __pyx_k_parents, sizeof(__pyx_k_parents), 0, 0, 1, 1},
  {&__pyx_n_s_parse, __pyx_k_parse, sizeof(__pyx_k_parse), 0, 0, 1, 1},
  {&__pyx_n_s_parse_from_bytes, __pyx_k_parse_from_bytes, sizeof(__pyx_k_parse_from_bytes), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle___Pyx_EnumMeta, __pyx_k_pyx_unpickle___Pyx_EnumMeta, sizeof(__pyx_k_pyx_unpickle___Pyx_EnumMeta), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_query_selector, __pyx_k_query_selector, sizeof(__pyx_k_query_selector), 0, 0, 1, 1},
  {&__pyx_n_s_query_selector_all, __pyx_k_query_selector_all, sizeof(__pyx_k_query_selector_all), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_reference, __pyx_k_reference, sizeof(__pyx_k_reference), 0, 0, 1, 1},
  {&__pyx_n_s_remove, __pyx_k_remove, sizeof(__pyx_k_remove), 0, 0, 1, 1},
  {&__pyx_n_s_remove_child, __pyx_k_remove_child, sizeof(__pyx_k_remove_child), 0, 0, 1, 1},
  {&__pyx_n_s_replace_child, __pyx_k_replace_child, sizeof(__pyx_k_replace_child), 0, 0, 1, 1},
  {&__pyx_n_s_repr, __pyx_k_repr, sizeof(__pyx_k_repr), 0, 0, 1, 1},
  {&__pyx_n_s_repr___locals_genexpr, __pyx_k_repr___locals_genexpr, sizeof(__pyx_k_repr___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
  {&__pyx_n_s_resiliparse_parse_html, __pyx_k_resiliparse_parse_html, sizeof(__pyx_k_resiliparse_parse_html), 0, 0, 1, 1},
  {&__pyx_kp_s_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 0, 1, 0},
  {&__pyx_kp_s_s_s_d, __pyx_k_s_s_d, sizeof(__pyx_k_s_s_d), 0, 0, 1, 0},
  {&__pyx_n_b_selector_all, __pyx_k_selector_all, sizeof(__pyx_k_selector_all), 0, 0, 0, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_setattr, __pyx_k_setattr, sizeof(__pyx_k_setattr), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
  {&__pyx_n_s_step, __pyx_k_step, sizeof(__pyx_k_step), 0, 0, 1, 1},
  {&__pyx_n_s_stop, __pyx_k_stop, sizeof(__pyx_k_stop), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
  {&__pyx_n_s_tag, __pyx_k_tag, sizeof(__pyx_k_tag), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_kp_u_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 1, 0, 0},
  {&__pyx_n_s_text_2, __pyx_k_text_2, sizeof(__pyx_k_text_2), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_tree, __pyx_k_tree, sizeof(__pyx_k_tree), 0, 0, 1, 1},
  {&__pyx_n_s_typing, __pyx_k_typing, sizeof(__pyx_k_typing), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_kp_u_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 1, 0, 0},
  {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(0, 154, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 268, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 672, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 734, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(0, 1374, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "resiliparse/parse/html.pyx":154
 *     cdef lxb_dom_collection_t* coll = lxb_dom_collection_make(node.owner_document, 20)
 *     if coll == NULL:
 *         raise RuntimeError('Failed to create DOM collection')             # <<<<<<<<<<<<<<
 * 
 *     cdef lxb_status_t status = lxb_dom_elements_by_tag_name(<lxb_dom_element_t*>node,
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_u_Failed_to_create_DOM_collection); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "resiliparse/parse/html.pyx":552
 *     def text(self, str text):
 *         if not check_node(self):
 *             raise RuntimeError('Trying to set text contents of uninitialized DOM node')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes text_bytes = text.encode()
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_u_Trying_to_set_text_contents_of_u); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "resiliparse/parse/html.pyx":578
 *     def html(self, str html):
 *         if not check_node(self):
 *             raise RuntimeError('Trying to set HTML contents of uninitialized DOM node')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes html_bytes = html.encode()
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_u_Trying_to_set_HTML_contents_of_u); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "resiliparse/parse/html.pyx":672
 *         """
 *         if not check_node(self) or self.node.type != LXB_DOM_NODE_TYPE_ELEMENT:
 *             raise ValueError('Node ist not an Element node.')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes attr_name_bytes = attr_name.encode()
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_u_Node_ist_not_an_Element_node); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "resiliparse/parse/html.pyx":871
 *         cdef lxb_dom_collection_t* coll = query_selector_all_impl(self.node, self.tree, selector.encode())
 *         if coll == NULL:
 *             raise RuntimeError('Failed to match elements by CSS selector')             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_collection(self.tree, coll)
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_Failed_to_match_elements_by_CSS); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "resiliparse/parse/html.pyx":981
 *         """
 *         if not check_node(self) or not check_node(node):
 *             raise RuntimeError('Append operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         if node.node == self.node:
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_Append_operation_on_uninitialize); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "resiliparse/parse/html.pyx":984
 * 
 *         if node.node == self.node:
 *             raise ValueError('Trying to append child to itself')             # <<<<<<<<<<<<<<
 * 
 *         if node.node.parent != NULL:
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_Trying_to_append_child_to_itself); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "resiliparse/parse/html.pyx":1008
 *         """
 *         if not check_node(self) or not check_node(node) or not check_node(reference):
 *             raise RuntimeError('Insert operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         if node.node == self.node:
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_Insert_operation_on_uninitialize); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 1008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "resiliparse/parse/html.pyx":1011
 * 
 *         if node.node == self.node:
 *             raise ValueError('Trying to insert node as its own child')             # <<<<<<<<<<<<<<
 * 
 *         if reference.node.parent != self.node:
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_kp_u_Trying_to_insert_node_as_its_own); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "resiliparse/parse/html.pyx":1014
 * 
 *         if reference.node.parent != self.node:
 *             raise ValueError('Reference node must be a child node')             # <<<<<<<<<<<<<<
 * 
 *         if node.node.parent != NULL:
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_u_Reference_node_must_be_a_child_n); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 1014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "resiliparse/parse/html.pyx":1036
 *         """
 *         if not check_node(self) or not check_node(new_child) or not check_node(old_child):
 *             raise RuntimeError('Replace operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         if old_child.node.parent != self.node:
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_u_Replace_operation_on_uninitializ); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 1036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "resiliparse/parse/html.pyx":1039
 * 
 *         if old_child.node.parent != self.node:
 *             raise ValueError('Node is not a child of the current node')             # <<<<<<<<<<<<<<
 * 
 *         if new_child.node == old_child.node:
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_u_Node_is_not_a_child_of_the_curre); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "resiliparse/parse/html.pyx":1064
 *         """
 *         if not check_node(self) or not check_node(node):
 *             raise RuntimeError('Remove operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         if node.node.parent != self.node:
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_Remove_operation_on_uninitialize); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 1064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "resiliparse/parse/html.pyx":1080
 *         """
 *         if not check_node(self):
 *             raise RuntimeError('Decompose operation on uninitialized node')             # <<<<<<<<<<<<<<
 * 
 *         lxb_dom_node_destroy_deep(self.node)
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_u_Decompose_operation_on_uninitial); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 1080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "resiliparse/parse/html.pyx":1166
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             raise RuntimeError('Trying to select items from uninitialized collection')             # <<<<<<<<<<<<<<
 * 
 *         if lxb_dom_collection_length(self.coll) == 0:
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_kp_u_Trying_to_select_items_from_unin); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 1166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "resiliparse/parse/html.pyx":1343
 *         """
 *         if self.tree is None or self.coll == NULL:
 *             raise RuntimeError('Trying to get item of uninitialized collection')             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t i = 0
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_u_Trying_to_get_item_of_uninitiali); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 1343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "resiliparse/parse/html.pyx":1408
 * 
 *         if key >= coll_len:
 *             raise IndexError('Index out of range')             # <<<<<<<<<<<<<<
 * 
 *         return _create_dom_node(self.tree, lxb_dom_collection_node(self.coll, self._wrap_idx(key)))
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_u_Index_out_of_range); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 1408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "resiliparse/parse/html.pyx":1439
 *         status = lxb_html_document_parse(tree.dom_document, html, html_len)
 *     if status != LXB_STATUS_OK:
 *         raise ValueError('Failed to parse HTML document')             # <<<<<<<<<<<<<<
 *     return tree
 * 
 */
  __pyx_tuple__33 = PyTuple_Pack(1, __pyx_kp_u_Failed_to_parse_HTML_document); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "resiliparse/parse/html.pyx":1452
 *         self.dom_document = lxb_html_document_create()
 *         if self.dom_document == NULL:
 *             raise RuntimeError('Failed to allocate HTML document')             # <<<<<<<<<<<<<<
 *         self.css_parser = NULL
 *         self.css_selectors = NULL
 */
  __pyx_tuple__34 = PyTuple_Pack(1, __pyx_kp_u_Failed_to_allocate_HTML_document); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 1452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "resiliparse/parse/html.pyx":1587
 *         """
 *         if self.dom_document == NULL:
 *             raise RuntimeError('Trying to create element in uninitialized document.')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes tag_name_bytes = tag_name.encode()
 */
  __pyx_tuple__35 = PyTuple_Pack(1, __pyx_kp_u_Trying_to_create_element_in_unin); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 1587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "resiliparse/parse/html.pyx":1606
 *         """
 *         if self.dom_document == NULL:
 *             raise RuntimeError('Trying to create text node in uninitialized document.')             # <<<<<<<<<<<<<<
 * 
 *         cdef bytes text_bytes = text.encode()
 */
  __pyx_tuple__36 = PyTuple_Pack(1, __pyx_kp_u_Trying_to_create_text_node_in_un); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__37 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__38 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */
  __pyx_tuple__39 = PyTuple_Pack(5, __pyx_n_s_cls, __pyx_n_s_value, __pyx_n_s_name_2, __pyx_n_s_v, __pyx_n_s_res); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);
  __pyx_codeobj__40 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__39, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_new, 28, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__40)) __PYX_ERR(1, 28, __pyx_L1_error)
  __pyx_tuple__41 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */
  __pyx_tuple__42 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);
  __pyx_codeobj__43 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__42, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_repr, 39, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__43)) __PYX_ERR(1, 39, __pyx_L1_error)

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__44, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_str, 41, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) __PYX_ERR(1, 41, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__46 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__46, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_222419149 = PyInt_FromLong(222419149L); if (unlikely(!__pyx_int_222419149)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_OrderedDict = Py_None; Py_INCREF(Py_None);
  __Pyx_EnumBase = Py_None; Py_INCREF(Py_None);
  __Pyx_globals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("get_element_by_id_impl", (void (*)(void))__pyx_f_11resiliparse_5parse_4html_get_element_by_id_impl, "lxb_dom_node_t *(lxb_dom_node_t *, PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_get_element_by_id_impl *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("get_elements_by_attr_impl", (void (*)(void))__pyx_f_11resiliparse_5parse_4html_get_elements_by_attr_impl, "lxb_dom_collection_t *(lxb_dom_node_t *, PyObject *, PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_attr_impl *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("get_elements_by_class_name_impl", (void (*)(void))__pyx_f_11resiliparse_5parse_4html_get_elements_by_class_name_impl, "lxb_dom_collection_t *(lxb_dom_node_t *, PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_get_elements_by_class_name_impl *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("get_elements_by_tag_name_impl", (void (*)(void))__pyx_f_11resiliparse_5parse_4html_get_elements_by_tag_name_impl, "lxb_dom_collection_t *(lxb_dom_node_t *, PyObject *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("query_selector_impl", (void (*)(void))__pyx_f_11resiliparse_5parse_4html_query_selector_impl, "lxb_dom_node_t *(lxb_dom_node_t *, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("query_selector_all_impl", (void (*)(void))__pyx_f_11resiliparse_5parse_4html_query_selector_all_impl, "lxb_dom_collection_t *(lxb_dom_node_t *, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_query_selector_all_impl *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("matches_impl", (void (*)(void))__pyx_f_11resiliparse_5parse_4html_matches_impl, "int (lxb_dom_node_t *, struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("create_html_tree", (void (*)(void))__pyx_f_11resiliparse_5parse_4html_create_html_tree, "struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *(PyObject *, struct __pyx_opt_args_11resiliparse_5parse_4html_create_html_tree *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_11resiliparse_5parse_4html_DOMElementClassList = &__pyx_vtable_11resiliparse_5parse_4html_DOMElementClassList;
  __pyx_vtable_11resiliparse_5parse_4html_DOMElementClassList._create_list = (PyObject *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *))__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList__create_list;
  __pyx_vtable_11resiliparse_5parse_4html_DOMElementClassList._class_name_bytes = (PyObject *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *))__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList__class_name_bytes;
  __pyx_vtable_11resiliparse_5parse_4html_DOMElementClassList.add = (void (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList_add;
  __pyx_vtable_11resiliparse_5parse_4html_DOMElementClassList.remove = (void (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMElementClassList *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_19DOMElementClassList_remove;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList) < 0) __PYX_ERR(0, 250, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html_DOMElementClassList.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html_DOMElementClassList.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html_DOMElementClassList.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html_DOMElementClassList.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList, "__contains__"); if (unlikely(!wrapper)) __PYX_ERR(0, 250, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__.doc = __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_6__contains__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList, "__getitem__"); if (unlikely(!wrapper)) __PYX_ERR(0, 250, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__.doc = __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_8__getitem__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList, "__eq__"); if (unlikely(!wrapper)) __PYX_ERR(0, 250, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__.doc = __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_10__eq__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList, "__len__"); if (unlikely(!wrapper)) __PYX_ERR(0, 250, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_12__len__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_12__len__.doc = __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_12__len__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_12__len__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList, "__iter__"); if (unlikely(!wrapper)) __PYX_ERR(0, 250, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__.doc = __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_14__iter__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList, "__repr__"); if (unlikely(!wrapper)) __PYX_ERR(0, 250, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__.doc = __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_16__repr__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList, "__str__"); if (unlikely(!wrapper)) __PYX_ERR(0, 250, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_18__str__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_18__str__.doc = __pyx_doc_11resiliparse_5parse_4html_19DOMElementClassList_18__str__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_19DOMElementClassList_18__str__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_11resiliparse_5parse_4html_DOMElementClassList.tp_dict, __pyx_vtabptr_11resiliparse_5parse_4html_DOMElementClassList) < 0) __PYX_ERR(0, 250, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DOMElementClassList, (PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList) < 0) __PYX_ERR(0, 250, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11resiliparse_5parse_4html_DOMElementClassList) < 0) __PYX_ERR(0, 250, __pyx_L1_error)
  __pyx_ptype_11resiliparse_5parse_4html_DOMElementClassList = &__pyx_type_11resiliparse_5parse_4html_DOMElementClassList;
  __pyx_vtabptr_11resiliparse_5parse_4html_DOMNode = &__pyx_vtable_11resiliparse_5parse_4html_DOMNode;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.hasattr = (int (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_hasattr;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode._getattr_impl = (PyObject *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *))__pyx_f_11resiliparse_5parse_4html_7DOMNode__getattr_impl;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.getattr = (PyObject *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_getattr *__pyx_optional_args))__pyx_f_11resiliparse_5parse_4html_7DOMNode_getattr;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode._setattr_impl = (int (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, PyObject *))__pyx_f_11resiliparse_5parse_4html_7DOMNode__setattr_impl;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.setattr = (void (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_setattr;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode._delattr_impl = (int (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *))__pyx_f_11resiliparse_5parse_4html_7DOMNode__delattr_impl;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.delattr = (void (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_delattr;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.get_element_by_id = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_element_by_id *__pyx_optional_args))__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_element_by_id;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.get_elements_by_attr = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr *__pyx_optional_args))__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_attr;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.get_elements_by_class_name = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name *__pyx_optional_args))__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_class_name;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.get_elements_by_tag_name = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_get_elements_by_tag_name;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.query_selector = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_query_selector;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.query_selector_all = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_query_selector_all;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.matches = (int (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_matches;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.append_child = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_append_child;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.insert_before = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_insert_before;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.replace_child = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_replace_child;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.remove_child = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_remove_child;
  __pyx_vtable_11resiliparse_5parse_4html_DOMNode.decompose = (void (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_7DOMNode_decompose;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html_DOMNode) < 0) __PYX_ERR(0, 371, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html_DOMNode.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html_DOMNode.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html_DOMNode.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html_DOMNode.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMNode, "__iter__"); if (unlikely(!wrapper)) __PYX_ERR(0, 371, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_4__iter__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_4__iter__.doc = __pyx_doc_11resiliparse_5parse_4html_7DOMNode_4__iter__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_4__iter__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMNode, "__getitem__"); if (unlikely(!wrapper)) __PYX_ERR(0, 371, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_11__getitem__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_11__getitem__.doc = __pyx_doc_11resiliparse_5parse_4html_7DOMNode_11__getitem__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_11__getitem__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMNode, "__setitem__"); if (unlikely(!wrapper)) __PYX_ERR(0, 371, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_15__setitem__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_15__setitem__.doc = __pyx_doc_11resiliparse_5parse_4html_7DOMNode_15__setitem__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_15__setitem__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMNode, "__delitem__"); if (unlikely(!wrapper)) __PYX_ERR(0, 371, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_19__delitem__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_19__delitem__.doc = __pyx_doc_11resiliparse_5parse_4html_7DOMNode_19__delitem__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_7DOMNode_19__delitem__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_11resiliparse_5parse_4html_DOMNode.tp_dict, __pyx_vtabptr_11resiliparse_5parse_4html_DOMNode) < 0) __PYX_ERR(0, 371, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DOMNode, (PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMNode) < 0) __PYX_ERR(0, 371, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11resiliparse_5parse_4html_DOMNode) < 0) __PYX_ERR(0, 371, __pyx_L1_error)
  __pyx_ptype_11resiliparse_5parse_4html_DOMNode = &__pyx_type_11resiliparse_5parse_4html_DOMNode;
  __pyx_vtabptr_11resiliparse_5parse_4html_DOMCollection = &__pyx_vtable_11resiliparse_5parse_4html_DOMCollection;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection._wrap_idx = (size_t (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, Py_ssize_t))__pyx_f_11resiliparse_5parse_4html_13DOMCollection__wrap_idx;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection._forward_collection_match = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, PyObject *))__pyx_f_11resiliparse_5parse_4html_13DOMCollection__forward_collection_match;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection.get_element_by_id = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id *__pyx_optional_args))__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_element_by_id;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection.get_elements_by_attr = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr *__pyx_optional_args))__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_attr;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection.get_elements_by_class_name = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name *__pyx_optional_args))__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_class_name;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection.get_elements_by_tag_name = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_13DOMCollection_get_elements_by_tag_name;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection.query_selector = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_13DOMCollection_query_selector;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection.query_selector_all = (struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *(*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_13DOMCollection_query_selector_all;
  __pyx_vtable_11resiliparse_5parse_4html_DOMCollection.matches = (int (*)(struct __pyx_obj_11resiliparse_5parse_4html_DOMCollection *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_13DOMCollection_matches;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html_DOMCollection) < 0) __PYX_ERR(0, 1132, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html_DOMCollection.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html_DOMCollection.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html_DOMCollection.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html_DOMCollection.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMCollection, "__iter__"); if (unlikely(!wrapper)) __PYX_ERR(0, 1132, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_18__iter__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_18__iter__.doc = __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_18__iter__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_18__iter__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMCollection, "__len__"); if (unlikely(!wrapper)) __PYX_ERR(0, 1132, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_21__len__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_21__len__.doc = __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_21__len__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_21__len__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMCollection, "__getitem__"); if (unlikely(!wrapper)) __PYX_ERR(0, 1132, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_23__getitem__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_23__getitem__.doc = __pyx_doc_11resiliparse_5parse_4html_13DOMCollection_23__getitem__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_11resiliparse_5parse_4html_13DOMCollection_23__getitem__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_11resiliparse_5parse_4html_DOMCollection.tp_dict, __pyx_vtabptr_11resiliparse_5parse_4html_DOMCollection) < 0) __PYX_ERR(0, 1132, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DOMCollection, (PyObject *)&__pyx_type_11resiliparse_5parse_4html_DOMCollection) < 0) __PYX_ERR(0, 1132, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11resiliparse_5parse_4html_DOMCollection) < 0) __PYX_ERR(0, 1132, __pyx_L1_error)
  __pyx_ptype_11resiliparse_5parse_4html_DOMCollection = &__pyx_type_11resiliparse_5parse_4html_DOMCollection;
  __pyx_vtabptr_11resiliparse_5parse_4html_HTMLTree = &__pyx_vtable_11resiliparse_5parse_4html_HTMLTree;
  __pyx_vtable_11resiliparse_5parse_4html_HTMLTree.create_element = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_8HTMLTree_create_element;
  __pyx_vtable_11resiliparse_5parse_4html_HTMLTree.create_text_node = (struct __pyx_obj_11resiliparse_5parse_4html_DOMNode *(*)(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11resiliparse_5parse_4html_8HTMLTree_create_text_node;
  __pyx_vtable_11resiliparse_5parse_4html_HTMLTree.init_css_parser = (void (*)(struct __pyx_obj_11resiliparse_5parse_4html_HTMLTree *))__pyx_f_11resiliparse_5parse_4html_8HTMLTree_init_css_parser;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html_HTMLTree) < 0) __PYX_ERR(0, 1443, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html_HTMLTree.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html_HTMLTree.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html_HTMLTree.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html_HTMLTree.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11resiliparse_5parse_4html_HTMLTree.tp_dict, __pyx_vtabptr_11resiliparse_5parse_4html_HTMLTree) < 0) __PYX_ERR(0, 1443, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_HTMLTree, (PyObject *)&__pyx_type_11resiliparse_5parse_4html_HTMLTree) < 0) __PYX_ERR(0, 1443, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11resiliparse_5parse_4html_HTMLTree) < 0) __PYX_ERR(0, 1443, __pyx_L1_error)
  __pyx_ptype_11resiliparse_5parse_4html_HTMLTree = &__pyx_type_11resiliparse_5parse_4html_HTMLTree;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct____iter__) < 0) __PYX_ERR(0, 399, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct____iter__.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct____iter__.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct____iter__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct____iter__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct____iter__ = &__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct____iter__;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__) < 0) __PYX_ERR(0, 1086, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__ = &__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_1___repr__;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 1091, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr = &__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_2_genexpr;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__) < 0) __PYX_ERR(0, 1334, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__ = &__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_3___iter__;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__) < 0) __PYX_ERR(0, 1412, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__ = &__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_4___repr__;
  if (PyType_Ready(&__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr) < 0) __PYX_ERR(0, 1413, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr.tp_dictoffset && __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr = &__pyx_type_11resiliparse_5parse_4html___pyx_scope_struct_5_genexpr;
  __Pyx_EnumMeta.tp_base = (&PyType_Type);
  if (PyType_Ready(&__Pyx_EnumMeta) < 0) __PYX_ERR(1, 15, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __Pyx_EnumMeta.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__Pyx_EnumMeta.tp_dictoffset && __Pyx_EnumMeta.tp_getattro == PyObject_GenericGetAttr)) {
    __Pyx_EnumMeta.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_setup_reduce((PyObject*)&__Pyx_EnumMeta) < 0) __PYX_ERR(1, 15, __pyx_L1_error)
  __pyx_ptype___Pyx_EnumMeta = &__Pyx_EnumMeta;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(2, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("resiliparse.parse.encoding"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_11resiliparse_5parse_8encoding_EncodingDetector = __Pyx_ImportType(__pyx_t_1, "resiliparse.parse.encoding", "EncodingDetector", sizeof(struct __pyx_obj_11resiliparse_5parse_8encoding_EncodingDetector), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_11resiliparse_5parse_8encoding_EncodingDetector) __PYX_ERR(3, 18, __pyx_L1_error)
  __pyx_vtabptr_11resiliparse_5parse_8encoding_EncodingDetector = (struct __pyx_vtabstruct_11resiliparse_5parse_8encoding_EncodingDetector*)__Pyx_GetVtable(__pyx_ptype_11resiliparse_5parse_8encoding_EncodingDetector->tp_dict); if (unlikely(!__pyx_vtabptr_11resiliparse_5parse_8encoding_EncodingDetector)) __PYX_ERR(3, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __pyx_t_1 = PyImport_ImportModule("resiliparse.parse.encoding"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction(__pyx_t_1, "bytes_to_str", (void (**)(void))&__pyx_f_11resiliparse_5parse_8encoding_bytes_to_str, "PyObject *(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_8encoding_bytes_to_str *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "map_encoding_to_html5", (void (**)(void))&__pyx_f_11resiliparse_5parse_8encoding_map_encoding_to_html5, "PyObject *(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_11resiliparse_5parse_8encoding_map_encoding_to_html5 *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC inithtml(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC inithtml(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_html(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_html(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_html(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'html' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_html(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("html", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_resiliparse__parse__html) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "resiliparse.parse.html")) {
      if (unlikely(PyDict_SetItemString(modules, "resiliparse.parse.html", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  if (unlikely(__Pyx_modinit_function_export_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  if (unlikely(__Pyx_modinit_function_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "resiliparse/parse/html.pyx":17
 * # distutils: language = c++
 * 
 * import typing as t             # <<<<<<<<<<<<<<
 * 
 * from cpython.ref cimport PyObject
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_typing, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_t, __pyx_t_1) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "resiliparse/parse/html.pyx":1489
 * 
 *     @classmethod
 *     def parse(cls, str document):             # <<<<<<<<<<<<<<
 *         """
 *         parse(self, document)
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_11resiliparse_5parse_4html_HTMLTree, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "resiliparse/parse/html.pyx":1488
 * 
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def parse(cls, str document):
 *         """
 */
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_11resiliparse_5parse_4html_HTMLTree->tp_dict, __pyx_n_s_parse, __pyx_t_2) < 0) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_11resiliparse_5parse_4html_HTMLTree);

  /* "resiliparse/parse/html.pyx":1503
 * 
 *     @classmethod
 *     def parse_from_bytes(cls, bytes document, str encoding='utf-8', str errors='ignore'):             # <<<<<<<<<<<<<<
 *         """
 *         parse_from_bytes(self, document, encoding='utf-8', errors='ignore')
 */
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_11resiliparse_5parse_4html_HTMLTree, __pyx_n_s_parse_from_bytes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "resiliparse/parse/html.pyx":1502
 *         return create_html_tree(document.encode(), reencode=False)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def parse_from_bytes(cls, bytes document, str encoding='utf-8', str errors='ignore'):
 *         """
 */
  __pyx_t_1 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_11resiliparse_5parse_4html_HTMLTree->tp_dict, __pyx_n_s_parse_from_bytes, __pyx_t_1) < 0) __PYX_ERR(0, 1503, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_11resiliparse_5parse_4html_HTMLTree);

  /* "resiliparse/parse/html.pyx":1
 * # Copyright 2021 Janek Bevendorff             # <<<<<<<<<<<<<<
 * #
 * # Licensed under the Apache License, Version 2.0 (the "License");
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":9
 * 
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 */
  __pyx_t_3 = ((PY_VERSION_HEX >= 0x02070000) != 0);
  if (__pyx_t_3) {

    /* "EnumBase":10
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:
 *     from collections import OrderedDict as __Pyx_OrderedDict             # <<<<<<<<<<<<<<
 * else:
 *     __Pyx_OrderedDict = dict
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_OrderedDict);
    __Pyx_GIVEREF(__pyx_n_s_OrderedDict);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_OrderedDict);
    __pyx_t_2 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XGOTREF(__Pyx_OrderedDict);
    __Pyx_DECREF_SET(__Pyx_OrderedDict, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "EnumBase":9
 * 
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 */
    goto __pyx_L2;
  }

  /* "EnumBase":12
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 *     __Pyx_OrderedDict = dict             # <<<<<<<<<<<<<<
 * 
 * @cython.internal
 */
  /*else*/ {
    __Pyx_INCREF(((PyObject *)(&PyDict_Type)));
    __Pyx_XGOTREF(__Pyx_OrderedDict);
    __Pyx_DECREF_SET(__Pyx_OrderedDict, ((PyObject *)(&PyDict_Type)));
    __Pyx_GIVEREF(((PyObject *)(&PyDict_Type)));
  }
  __pyx_L2:;

  /* "EnumBase":26
 * 
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):             # <<<<<<<<<<<<<<
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)(&PyInt_Type)));
  __Pyx_GIVEREF(((PyObject *)(&PyInt_Type)));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)(&PyInt_Type)));
  __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_2, __pyx_n_s_Pyx_EnumBase, __pyx_n_s_Pyx_EnumBase, (PyObject *) NULL, __pyx_n_s_EnumBase, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "EnumBase":27
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta             # <<<<<<<<<<<<<<
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_metaclass, ((PyObject *)__pyx_ptype___Pyx_EnumMeta)) < 0) __PYX_ERR(1, 27, __pyx_L1_error)

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_1__new__, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_Pyx_EnumBase___new, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__40)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__41);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_new, __pyx_t_5) < 0) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_3__repr__, 0, __pyx_n_s_Pyx_EnumBase___repr, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__43)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_repr, __pyx_t_5) < 0) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_5__str__, 0, __pyx_n_s_Pyx_EnumBase___str, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_str, __pyx_t_5) < 0) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "EnumBase":26
 * 
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):             # <<<<<<<<<<<<<<
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 */
  __pyx_t_5 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_Pyx_EnumBase, __pyx_t_2, __pyx_t_4, NULL, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__Pyx_EnumBase);
  __Pyx_DECREF_SET(__Pyx_EnumBase, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "EnumBase":44
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 *     from enum import IntEnum as __Pyx_EnumBase
 * 
 */
  __pyx_t_3 = ((PY_VERSION_HEX >= 0x03040000) != 0);
  if (__pyx_t_3) {

    /* "EnumBase":45
 * 
 * if PY_VERSION_HEX >= 0x03040000:
 *     from enum import IntEnum as __Pyx_EnumBase             # <<<<<<<<<<<<<<
 * 
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_IntEnum);
    __Pyx_GIVEREF(__pyx_n_s_IntEnum);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_IntEnum);
    __pyx_t_1 = __Pyx_Import(__pyx_n_s_enum, __pyx_t_2, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_IntEnum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XGOTREF(__Pyx_EnumBase);
    __Pyx_DECREF_SET(__Pyx_EnumBase, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumBase":44
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 *     from enum import IntEnum as __Pyx_EnumBase
 * 
 */
  }

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta, NULL, __pyx_n_s_EnumBase); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta, __pyx_t_1) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumType":50
 * 
 * 
 * cdef dict __Pyx_globals = globals()             # <<<<<<<<<<<<<<
 * if PY_VERSION_HEX >= 0x03040000:
 * 
 */
  __pyx_t_1 = __Pyx_Globals(); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 50, __pyx_L1_error)
  __Pyx_XGOTREF(__Pyx_globals);
  __Pyx_DECREF_SET(__Pyx_globals, ((PyObject*)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "EnumType":51
 * 
 * cdef dict __Pyx_globals = globals()
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 * 
 *     NodeType = __Pyx_EnumBase('NodeType', __Pyx_OrderedDict([
 */
  __pyx_t_3 = ((PY_VERSION_HEX >= 0x03040000) != 0);
  if (__pyx_t_3) {

    /* "EnumType":54
 * 
 *     NodeType = __Pyx_EnumBase('NodeType', __Pyx_OrderedDict([
 *         ('ELEMENT', ELEMENT),             # <<<<<<<<<<<<<<
 *         ('ATTRIBUTE', ATTRIBUTE),
 *         ('TEXT', TEXT),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_ELEMENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_ELEMENT);
    __Pyx_GIVEREF(__pyx_n_s_ELEMENT);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_ELEMENT);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":55
 *     NodeType = __Pyx_EnumBase('NodeType', __Pyx_OrderedDict([
 *         ('ELEMENT', ELEMENT),
 *         ('ATTRIBUTE', ATTRIBUTE),             # <<<<<<<<<<<<<<
 *         ('TEXT', TEXT),
 *         ('CDATA_SECTION', CDATA_SECTION),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_ATTRIBUTE); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_n_s_ATTRIBUTE);
    __Pyx_GIVEREF(__pyx_n_s_ATTRIBUTE);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_ATTRIBUTE);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":56
 *         ('ELEMENT', ELEMENT),
 *         ('ATTRIBUTE', ATTRIBUTE),
 *         ('TEXT', TEXT),             # <<<<<<<<<<<<<<
 *         ('CDATA_SECTION', CDATA_SECTION),
 *         ('ENTITY_REFERENCE', ENTITY_REFERENCE),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_TEXT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_n_s_TEXT);
    __Pyx_GIVEREF(__pyx_n_s_TEXT);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_n_s_TEXT);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":57
 *         ('ATTRIBUTE', ATTRIBUTE),
 *         ('TEXT', TEXT),
 *         ('CDATA_SECTION', CDATA_SECTION),             # <<<<<<<<<<<<<<
 *         ('ENTITY_REFERENCE', ENTITY_REFERENCE),
 *         ('ENTITY', ENTITY),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_CDATA_SECTION); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_n_s_CDATA_SECTION);
    __Pyx_GIVEREF(__pyx_n_s_CDATA_SECTION);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_n_s_CDATA_SECTION);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":58
 *         ('TEXT', TEXT),
 *         ('CDATA_SECTION', CDATA_SECTION),
 *         ('ENTITY_REFERENCE', ENTITY_REFERENCE),             # <<<<<<<<<<<<<<
 *         ('ENTITY', ENTITY),
 *         ('PROCESSING_INSTRUCTION', PROCESSING_INSTRUCTION),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_ENTITY_REFERENCE); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_n_s_ENTITY_REFERENCE);
    __Pyx_GIVEREF(__pyx_n_s_ENTITY_REFERENCE);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_ENTITY_REFERENCE);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":59
 *         ('CDATA_SECTION', CDATA_SECTION),
 *         ('ENTITY_REFERENCE', ENTITY_REFERENCE),
 *         ('ENTITY', ENTITY),             # <<<<<<<<<<<<<<
 *         ('PROCESSING_INSTRUCTION', PROCESSING_INSTRUCTION),
 *         ('COMMENT', COMMENT),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_ENTITY); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_n_s_ENTITY);
    __Pyx_GIVEREF(__pyx_n_s_ENTITY);
    PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_n_s_ENTITY);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":60
 *         ('ENTITY_REFERENCE', ENTITY_REFERENCE),
 *         ('ENTITY', ENTITY),
 *         ('PROCESSING_INSTRUCTION', PROCESSING_INSTRUCTION),             # <<<<<<<<<<<<<<
 *         ('COMMENT', COMMENT),
 *         ('DOCUMENT', DOCUMENT),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_PROCESSING_INSTRUCTION); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_n_s_PROCESSING_INSTRUCTION);
    __Pyx_GIVEREF(__pyx_n_s_PROCESSING_INSTRUCTION);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_n_s_PROCESSING_INSTRUCTION);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":61
 *         ('ENTITY', ENTITY),
 *         ('PROCESSING_INSTRUCTION', PROCESSING_INSTRUCTION),
 *         ('COMMENT', COMMENT),             # <<<<<<<<<<<<<<
 *         ('DOCUMENT', DOCUMENT),
 *         ('DOCUMENT_TYPE', DOCUMENT_TYPE),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_COMMENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_INCREF(__pyx_n_s_COMMENT);
    __Pyx_GIVEREF(__pyx_n_s_COMMENT);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_n_s_COMMENT);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":62
 *         ('PROCESSING_INSTRUCTION', PROCESSING_INSTRUCTION),
 *         ('COMMENT', COMMENT),
 *         ('DOCUMENT', DOCUMENT),             # <<<<<<<<<<<<<<
 *         ('DOCUMENT_TYPE', DOCUMENT_TYPE),
 *         ('DOCUMENT_FRAGMENT', DOCUMENT_FRAGMENT),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_DOCUMENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_INCREF(__pyx_n_s_DOCUMENT);
    __Pyx_GIVEREF(__pyx_n_s_DOCUMENT);
    PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_n_s_DOCUMENT);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":63
 *         ('COMMENT', COMMENT),
 *         ('DOCUMENT', DOCUMENT),
 *         ('DOCUMENT_TYPE', DOCUMENT_TYPE),             # <<<<<<<<<<<<<<
 *         ('DOCUMENT_FRAGMENT', DOCUMENT_FRAGMENT),
 *         ('NOTATION', NOTATION),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_DOCUMENT_TYPE); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_INCREF(__pyx_n_s_DOCUMENT_TYPE);
    __Pyx_GIVEREF(__pyx_n_s_DOCUMENT_TYPE);
    PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_n_s_DOCUMENT_TYPE);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":64
 *         ('DOCUMENT', DOCUMENT),
 *         ('DOCUMENT_TYPE', DOCUMENT_TYPE),
 *         ('DOCUMENT_FRAGMENT', DOCUMENT_FRAGMENT),             # <<<<<<<<<<<<<<
 *         ('NOTATION', NOTATION),
 *         ('LAST_ENTRY', LAST_ENTRY),
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_DOCUMENT_FRAGMENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_INCREF(__pyx_n_s_DOCUMENT_FRAGMENT);
    __Pyx_GIVEREF(__pyx_n_s_DOCUMENT_FRAGMENT);
    PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_n_s_DOCUMENT_FRAGMENT);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":65
 *         ('DOCUMENT_TYPE', DOCUMENT_TYPE),
 *         ('DOCUMENT_FRAGMENT', DOCUMENT_FRAGMENT),
 *         ('NOTATION', NOTATION),             # <<<<<<<<<<<<<<
 *         ('LAST_ENTRY', LAST_ENTRY),
 *     ]))
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_NOTATION); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_INCREF(__pyx_n_s_NOTATION);
    __Pyx_GIVEREF(__pyx_n_s_NOTATION);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_n_s_NOTATION);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":66
 *         ('DOCUMENT_FRAGMENT', DOCUMENT_FRAGMENT),
 *         ('NOTATION', NOTATION),
 *         ('LAST_ENTRY', LAST_ENTRY),             # <<<<<<<<<<<<<<
 *     ]))
 *     __Pyx_globals['ELEMENT'] = NodeType.ELEMENT
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_LAST_ENTRY); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_INCREF(__pyx_n_s_LAST_ENTRY);
    __Pyx_GIVEREF(__pyx_n_s_LAST_ENTRY);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_n_s_LAST_ENTRY);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "EnumType":53
 * if PY_VERSION_HEX >= 0x03040000:
 * 
 *     NodeType = __Pyx_EnumBase('NodeType', __Pyx_OrderedDict([             # <<<<<<<<<<<<<<
 *         ('ELEMENT', ELEMENT),
 *         ('ATTRIBUTE', ATTRIBUTE),
 */
    __pyx_t_1 = PyList_New(13); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_4);
    PyList_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyList_SET_ITEM(__pyx_t_1, 2, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyList_SET_ITEM(__pyx_t_1, 3, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_7);
    PyList_SET_ITEM(__pyx_t_1, 4, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_8);
    PyList_SET_ITEM(__pyx_t_1, 5, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_9);
    PyList_SET_ITEM(__pyx_t_1, 6, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_10);
    PyList_SET_ITEM(__pyx_t_1, 7, __pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_11);
    PyList_SET_ITEM(__pyx_t_1, 8, __pyx_t_11);
    __Pyx_GIVEREF(__pyx_t_12);
    PyList_SET_ITEM(__pyx_t_1, 9, __pyx_t_12);
    __Pyx_GIVEREF(__pyx_t_13);
    PyList_SET_ITEM(__pyx_t_1, 10, __pyx_t_13);
    __Pyx_GIVEREF(__pyx_t_14);
    PyList_SET_ITEM(__pyx_t_1, 11, __pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyList_SET_ITEM(__pyx_t_1, 12, __pyx_t_15);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_8 = 0;
    __pyx_t_9 = 0;
    __pyx_t_10 = 0;
    __pyx_t_11 = 0;
    __pyx_t_12 = 0;
    __pyx_t_13 = 0;
    __pyx_t_14 = 0;
    __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_CallOneArg(__Pyx_OrderedDict, __pyx_t_1); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_NodeType);
    __Pyx_GIVEREF(__pyx_n_s_NodeType);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_NodeType);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_15);
    __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_Call(__Pyx_EnumBase, __pyx_t_1, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_NodeType, __pyx_t_15) < 0) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":68
 *         ('LAST_ENTRY', LAST_ENTRY),
 *     ]))
 *     __Pyx_globals['ELEMENT'] = NodeType.ELEMENT             # <<<<<<<<<<<<<<
 *     __Pyx_globals['ATTRIBUTE'] = NodeType.ATTRIBUTE
 *     __Pyx_globals['TEXT'] = NodeType.TEXT
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_ELEMENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 68, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ELEMENT, __pyx_t_1) < 0)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":69
 *     ]))
 *     __Pyx_globals['ELEMENT'] = NodeType.ELEMENT
 *     __Pyx_globals['ATTRIBUTE'] = NodeType.ATTRIBUTE             # <<<<<<<<<<<<<<
 *     __Pyx_globals['TEXT'] = NodeType.TEXT
 *     __Pyx_globals['CDATA_SECTION'] = NodeType.CDATA_SECTION
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ATTRIBUTE); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 69, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ATTRIBUTE, __pyx_t_15) < 0)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":70
 *     __Pyx_globals['ELEMENT'] = NodeType.ELEMENT
 *     __Pyx_globals['ATTRIBUTE'] = NodeType.ATTRIBUTE
 *     __Pyx_globals['TEXT'] = NodeType.TEXT             # <<<<<<<<<<<<<<
 *     __Pyx_globals['CDATA_SECTION'] = NodeType.CDATA_SECTION
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType.ENTITY_REFERENCE
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_TEXT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 70, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_TEXT, __pyx_t_1) < 0)) __PYX_ERR(1, 70, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":71
 *     __Pyx_globals['ATTRIBUTE'] = NodeType.ATTRIBUTE
 *     __Pyx_globals['TEXT'] = NodeType.TEXT
 *     __Pyx_globals['CDATA_SECTION'] = NodeType.CDATA_SECTION             # <<<<<<<<<<<<<<
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType.ENTITY_REFERENCE
 *     __Pyx_globals['ENTITY'] = NodeType.ENTITY
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_CDATA_SECTION); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 71, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_CDATA_SECTION, __pyx_t_15) < 0)) __PYX_ERR(1, 71, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":72
 *     __Pyx_globals['TEXT'] = NodeType.TEXT
 *     __Pyx_globals['CDATA_SECTION'] = NodeType.CDATA_SECTION
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType.ENTITY_REFERENCE             # <<<<<<<<<<<<<<
 *     __Pyx_globals['ENTITY'] = NodeType.ENTITY
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType.PROCESSING_INSTRUCTION
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_ENTITY_REFERENCE); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 72, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ENTITY_REFERENCE, __pyx_t_1) < 0)) __PYX_ERR(1, 72, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":73
 *     __Pyx_globals['CDATA_SECTION'] = NodeType.CDATA_SECTION
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType.ENTITY_REFERENCE
 *     __Pyx_globals['ENTITY'] = NodeType.ENTITY             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType.PROCESSING_INSTRUCTION
 *     __Pyx_globals['COMMENT'] = NodeType.COMMENT
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ENTITY); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 73, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ENTITY, __pyx_t_15) < 0)) __PYX_ERR(1, 73, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":74
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType.ENTITY_REFERENCE
 *     __Pyx_globals['ENTITY'] = NodeType.ENTITY
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType.PROCESSING_INSTRUCTION             # <<<<<<<<<<<<<<
 *     __Pyx_globals['COMMENT'] = NodeType.COMMENT
 *     __Pyx_globals['DOCUMENT'] = NodeType.DOCUMENT
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_PROCESSING_INSTRUCTION); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 74, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PROCESSING_INSTRUCTION, __pyx_t_1) < 0)) __PYX_ERR(1, 74, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":75
 *     __Pyx_globals['ENTITY'] = NodeType.ENTITY
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType.PROCESSING_INSTRUCTION
 *     __Pyx_globals['COMMENT'] = NodeType.COMMENT             # <<<<<<<<<<<<<<
 *     __Pyx_globals['DOCUMENT'] = NodeType.DOCUMENT
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType.DOCUMENT_TYPE
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_COMMENT); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 75, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_COMMENT, __pyx_t_15) < 0)) __PYX_ERR(1, 75, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":76
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType.PROCESSING_INSTRUCTION
 *     __Pyx_globals['COMMENT'] = NodeType.COMMENT
 *     __Pyx_globals['DOCUMENT'] = NodeType.DOCUMENT             # <<<<<<<<<<<<<<
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType.DOCUMENT_TYPE
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType.DOCUMENT_FRAGMENT
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_DOCUMENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 76, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_DOCUMENT, __pyx_t_1) < 0)) __PYX_ERR(1, 76, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":77
 *     __Pyx_globals['COMMENT'] = NodeType.COMMENT
 *     __Pyx_globals['DOCUMENT'] = NodeType.DOCUMENT
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType.DOCUMENT_TYPE             # <<<<<<<<<<<<<<
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType.DOCUMENT_FRAGMENT
 *     __Pyx_globals['NOTATION'] = NodeType.NOTATION
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DOCUMENT_TYPE); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 77, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_DOCUMENT_TYPE, __pyx_t_15) < 0)) __PYX_ERR(1, 77, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":78
 *     __Pyx_globals['DOCUMENT'] = NodeType.DOCUMENT
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType.DOCUMENT_TYPE
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType.DOCUMENT_FRAGMENT             # <<<<<<<<<<<<<<
 *     __Pyx_globals['NOTATION'] = NodeType.NOTATION
 *     __Pyx_globals['LAST_ENTRY'] = NodeType.LAST_ENTRY
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_DOCUMENT_FRAGMENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 78, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_DOCUMENT_FRAGMENT, __pyx_t_1) < 0)) __PYX_ERR(1, 78, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":79
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType.DOCUMENT_TYPE
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType.DOCUMENT_FRAGMENT
 *     __Pyx_globals['NOTATION'] = NodeType.NOTATION             # <<<<<<<<<<<<<<
 *     __Pyx_globals['LAST_ENTRY'] = NodeType.LAST_ENTRY
 * else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NOTATION); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 79, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_NOTATION, __pyx_t_15) < 0)) __PYX_ERR(1, 79, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":80
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType.DOCUMENT_FRAGMENT
 *     __Pyx_globals['NOTATION'] = NodeType.NOTATION
 *     __Pyx_globals['LAST_ENTRY'] = NodeType.LAST_ENTRY             # <<<<<<<<<<<<<<
 * else:
 *     class NodeType(__Pyx_EnumBase):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_LAST_ENTRY); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 80, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_LAST_ENTRY, __pyx_t_1) < 0)) __PYX_ERR(1, 80, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":51
 * 
 * cdef dict __Pyx_globals = globals()
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 * 
 *     NodeType = __Pyx_EnumBase('NodeType', __Pyx_OrderedDict([
 */
    goto __pyx_L4;
  }

  /* "EnumType":82
 *     __Pyx_globals['LAST_ENTRY'] = NodeType.LAST_ENTRY
 * else:
 *     class NodeType(__Pyx_EnumBase):             # <<<<<<<<<<<<<<
 *         pass
 *     __Pyx_globals['ELEMENT'] = NodeType(ELEMENT, 'ELEMENT')
 */
  /*else*/ {
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__Pyx_EnumBase);
    __Pyx_GIVEREF(__Pyx_EnumBase);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_EnumBase);
    __pyx_t_15 = __Pyx_CalculateMetaclass(NULL, __pyx_t_1); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_Py3MetaclassPrepare(__pyx_t_15, __pyx_t_1, __pyx_n_s_NodeType, __pyx_n_s_NodeType, (PyObject *) NULL, __pyx_n_s_EnumType, (PyObject *) NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_13 = __Pyx_Py3ClassCreate(__pyx_t_15, __pyx_n_s_NodeType, __pyx_t_1, __pyx_t_14, NULL, 0, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_NodeType, __pyx_t_13) < 0) __PYX_ERR(1, 82, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":84
 *     class NodeType(__Pyx_EnumBase):
 *         pass
 *     __Pyx_globals['ELEMENT'] = NodeType(ELEMENT, 'ELEMENT')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['ATTRIBUTE'] = NodeType(ATTRIBUTE, 'ATTRIBUTE')
 *     __Pyx_globals['TEXT'] = NodeType(TEXT, 'TEXT')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_ELEMENT); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_n_s_ELEMENT);
    __Pyx_GIVEREF(__pyx_n_s_ELEMENT);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_n_s_ELEMENT);
    __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_14, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 84, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ELEMENT, __pyx_t_15) < 0)) __PYX_ERR(1, 84, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":85
 *         pass
 *     __Pyx_globals['ELEMENT'] = NodeType(ELEMENT, 'ELEMENT')
 *     __Pyx_globals['ATTRIBUTE'] = NodeType(ATTRIBUTE, 'ATTRIBUTE')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['TEXT'] = NodeType(TEXT, 'TEXT')
 *     __Pyx_globals['CDATA_SECTION'] = NodeType(CDATA_SECTION, 'CDATA_SECTION')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_ATTRIBUTE); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_n_s_ATTRIBUTE);
    __Pyx_GIVEREF(__pyx_n_s_ATTRIBUTE);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_ATTRIBUTE);
    __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_1, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 85, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ATTRIBUTE, __pyx_t_14) < 0)) __PYX_ERR(1, 85, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

    /* "EnumType":86
 *     __Pyx_globals['ELEMENT'] = NodeType(ELEMENT, 'ELEMENT')
 *     __Pyx_globals['ATTRIBUTE'] = NodeType(ATTRIBUTE, 'ATTRIBUTE')
 *     __Pyx_globals['TEXT'] = NodeType(TEXT, 'TEXT')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['CDATA_SECTION'] = NodeType(CDATA_SECTION, 'CDATA_SECTION')
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType(ENTITY_REFERENCE, 'ENTITY_REFERENCE')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_TEXT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_TEXT);
    __Pyx_GIVEREF(__pyx_n_s_TEXT);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_n_s_TEXT);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 86, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_TEXT, __pyx_t_1) < 0)) __PYX_ERR(1, 86, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":87
 *     __Pyx_globals['ATTRIBUTE'] = NodeType(ATTRIBUTE, 'ATTRIBUTE')
 *     __Pyx_globals['TEXT'] = NodeType(TEXT, 'TEXT')
 *     __Pyx_globals['CDATA_SECTION'] = NodeType(CDATA_SECTION, 'CDATA_SECTION')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType(ENTITY_REFERENCE, 'ENTITY_REFERENCE')
 *     __Pyx_globals['ENTITY'] = NodeType(ENTITY, 'ENTITY')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_CDATA_SECTION); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_n_s_CDATA_SECTION);
    __Pyx_GIVEREF(__pyx_n_s_CDATA_SECTION);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_n_s_CDATA_SECTION);
    __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_14, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 87, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_CDATA_SECTION, __pyx_t_15) < 0)) __PYX_ERR(1, 87, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":88
 *     __Pyx_globals['TEXT'] = NodeType(TEXT, 'TEXT')
 *     __Pyx_globals['CDATA_SECTION'] = NodeType(CDATA_SECTION, 'CDATA_SECTION')
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType(ENTITY_REFERENCE, 'ENTITY_REFERENCE')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['ENTITY'] = NodeType(ENTITY, 'ENTITY')
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType(PROCESSING_INSTRUCTION, 'PROCESSING_INSTRUCTION')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_ENTITY_REFERENCE); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_n_s_ENTITY_REFERENCE);
    __Pyx_GIVEREF(__pyx_n_s_ENTITY_REFERENCE);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_ENTITY_REFERENCE);
    __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_1, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 88, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ENTITY_REFERENCE, __pyx_t_14) < 0)) __PYX_ERR(1, 88, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

    /* "EnumType":89
 *     __Pyx_globals['CDATA_SECTION'] = NodeType(CDATA_SECTION, 'CDATA_SECTION')
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType(ENTITY_REFERENCE, 'ENTITY_REFERENCE')
 *     __Pyx_globals['ENTITY'] = NodeType(ENTITY, 'ENTITY')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType(PROCESSING_INSTRUCTION, 'PROCESSING_INSTRUCTION')
 *     __Pyx_globals['COMMENT'] = NodeType(COMMENT, 'COMMENT')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_ENTITY); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_ENTITY);
    __Pyx_GIVEREF(__pyx_n_s_ENTITY);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_n_s_ENTITY);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 89, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ENTITY, __pyx_t_1) < 0)) __PYX_ERR(1, 89, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":90
 *     __Pyx_globals['ENTITY_REFERENCE'] = NodeType(ENTITY_REFERENCE, 'ENTITY_REFERENCE')
 *     __Pyx_globals['ENTITY'] = NodeType(ENTITY, 'ENTITY')
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType(PROCESSING_INSTRUCTION, 'PROCESSING_INSTRUCTION')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['COMMENT'] = NodeType(COMMENT, 'COMMENT')
 *     __Pyx_globals['DOCUMENT'] = NodeType(DOCUMENT, 'DOCUMENT')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 90, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_PROCESSING_INSTRUCTION); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 90, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 90, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_n_s_PROCESSING_INSTRUCTION);
    __Pyx_GIVEREF(__pyx_n_s_PROCESSING_INSTRUCTION);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_n_s_PROCESSING_INSTRUCTION);
    __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_14, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 90, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 90, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PROCESSING_INSTRUCTION, __pyx_t_15) < 0)) __PYX_ERR(1, 90, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":91
 *     __Pyx_globals['ENTITY'] = NodeType(ENTITY, 'ENTITY')
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType(PROCESSING_INSTRUCTION, 'PROCESSING_INSTRUCTION')
 *     __Pyx_globals['COMMENT'] = NodeType(COMMENT, 'COMMENT')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['DOCUMENT'] = NodeType(DOCUMENT, 'DOCUMENT')
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType(DOCUMENT_TYPE, 'DOCUMENT_TYPE')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_COMMENT); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_n_s_COMMENT);
    __Pyx_GIVEREF(__pyx_n_s_COMMENT);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_COMMENT);
    __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_1, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 91, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_COMMENT, __pyx_t_14) < 0)) __PYX_ERR(1, 91, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

    /* "EnumType":92
 *     __Pyx_globals['PROCESSING_INSTRUCTION'] = NodeType(PROCESSING_INSTRUCTION, 'PROCESSING_INSTRUCTION')
 *     __Pyx_globals['COMMENT'] = NodeType(COMMENT, 'COMMENT')
 *     __Pyx_globals['DOCUMENT'] = NodeType(DOCUMENT, 'DOCUMENT')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType(DOCUMENT_TYPE, 'DOCUMENT_TYPE')
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType(DOCUMENT_FRAGMENT, 'DOCUMENT_FRAGMENT')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_DOCUMENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_DOCUMENT);
    __Pyx_GIVEREF(__pyx_n_s_DOCUMENT);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_n_s_DOCUMENT);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 92, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_DOCUMENT, __pyx_t_1) < 0)) __PYX_ERR(1, 92, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":93
 *     __Pyx_globals['COMMENT'] = NodeType(COMMENT, 'COMMENT')
 *     __Pyx_globals['DOCUMENT'] = NodeType(DOCUMENT, 'DOCUMENT')
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType(DOCUMENT_TYPE, 'DOCUMENT_TYPE')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType(DOCUMENT_FRAGMENT, 'DOCUMENT_FRAGMENT')
 *     __Pyx_globals['NOTATION'] = NodeType(NOTATION, 'NOTATION')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 93, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_DOCUMENT_TYPE); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 93, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 93, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_n_s_DOCUMENT_TYPE);
    __Pyx_GIVEREF(__pyx_n_s_DOCUMENT_TYPE);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_n_s_DOCUMENT_TYPE);
    __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_14, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 93, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 93, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_DOCUMENT_TYPE, __pyx_t_15) < 0)) __PYX_ERR(1, 93, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "EnumType":94
 *     __Pyx_globals['DOCUMENT'] = NodeType(DOCUMENT, 'DOCUMENT')
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType(DOCUMENT_TYPE, 'DOCUMENT_TYPE')
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType(DOCUMENT_FRAGMENT, 'DOCUMENT_FRAGMENT')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['NOTATION'] = NodeType(NOTATION, 'NOTATION')
 *     __Pyx_globals['LAST_ENTRY'] = NodeType(LAST_ENTRY, 'LAST_ENTRY')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 94, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_DOCUMENT_FRAGMENT); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 94, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 94, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_n_s_DOCUMENT_FRAGMENT);
    __Pyx_GIVEREF(__pyx_n_s_DOCUMENT_FRAGMENT);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_DOCUMENT_FRAGMENT);
    __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_1, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 94, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 94, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_DOCUMENT_FRAGMENT, __pyx_t_14) < 0)) __PYX_ERR(1, 94, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

    /* "EnumType":95
 *     __Pyx_globals['DOCUMENT_TYPE'] = NodeType(DOCUMENT_TYPE, 'DOCUMENT_TYPE')
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType(DOCUMENT_FRAGMENT, 'DOCUMENT_FRAGMENT')
 *     __Pyx_globals['NOTATION'] = NodeType(NOTATION, 'NOTATION')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['LAST_ENTRY'] = NodeType(LAST_ENTRY, 'LAST_ENTRY')
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_NOTATION); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_NOTATION);
    __Pyx_GIVEREF(__pyx_n_s_NOTATION);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_n_s_NOTATION);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 95, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_NOTATION, __pyx_t_1) < 0)) __PYX_ERR(1, 95, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "EnumType":96
 *     __Pyx_globals['DOCUMENT_FRAGMENT'] = NodeType(DOCUMENT_FRAGMENT, 'DOCUMENT_FRAGMENT')
 *     __Pyx_globals['NOTATION'] = NodeType(NOTATION, 'NOTATION')
 *     __Pyx_globals['LAST_ENTRY'] = NodeType(LAST_ENTRY, 'LAST_ENTRY')             # <<<<<<<<<<<<<<
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_NodeType); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(__pyx_e_11resiliparse_5parse_4html_LAST_ENTRY); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_n_s_LAST_ENTRY);
    __Pyx_GIVEREF(__pyx_n_s_LAST_ENTRY);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_n_s_LAST_ENTRY);
    __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_14, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 96, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_LAST_ENTRY, __pyx_t_15) < 0)) __PYX_ERR(1, 96, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  }
  __pyx_L4:;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init resiliparse.parse.html", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init resiliparse.parse.html");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* decode_c_string */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    Py_ssize_t length;
    if (unlikely((start < 0) | (stop < 0))) {
        size_t slen = strlen(cstring);
        if (unlikely(slen > (size_t) PY_SSIZE_T_MAX)) {
            PyErr_SetString(PyExc_OverflowError,
                            "c-string too long to convert to Python");
            return NULL;
        }
        length = (Py_ssize_t) slen;
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    if (unlikely(stop <= start))
        return __Pyx_NewRef(__pyx_empty_unicode);
    length = stop - start;
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (__Pyx_PyFastCFunction_Check(func)) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* StringJoin */
#if !CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    return PyObject_CallMethodObjArgs(sep, __pyx_n_s_join, values, NULL);
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* None */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      CYTHON_UNUSED Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind;
    Py_ssize_t i, char_pos;
    void *result_udata;
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely(char_pos + ulength < 0))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + char_pos * result_ukind, udata, (size_t) (ulength * result_ukind));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    result_ulength++;
    value_count++;
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* None */
static CYTHON_INLINE Py_ssize_t __Pyx_mod_Py_ssize_t(Py_ssize_t a, Py_ssize_t b) {
    Py_ssize_t r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* py_abs */
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject *__Pyx_PyLong_AbsNeg(PyObject *n) {
    if (likely(Py_SIZE(n) == -1)) {
        return PyLong_FromLong(((PyLongObject*)n)->ob_digit[0]);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    {
        PyObject *copy = _PyLong_Copy((PyLongObject*)n);
        if (likely(copy)) {
            __Pyx_SET_SIZE(copy, -Py_SIZE(copy));
        }
        return copy;
    }
#else
    return PyNumber_Negative(n);
#endif
}
#endif

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYSTON || CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    #if PY_MAJOR_VERSION == 2
    static PyTypeObject *methoddescr_type = NULL;
    if (methoddescr_type == NULL) {
       PyObject *meth = PyObject_GetAttrString((PyObject*)&PyList_Type, "append");
       if (!meth) return NULL;
       methoddescr_type = Py_TYPE(meth);
       Py_DECREF(meth);
    }
    #else
    PyTypeObject *methoddescr_type = &PyMethodDescr_Type;
    #endif
    if (__Pyx_TypeCheck(method, methoddescr_type))
#endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        #if PY_VERSION_HEX < 0x03020000
        PyTypeObject *d_type = descr->d_type;
        #else
        PyTypeObject *d_type = descr->d_common.d_type;
        #endif
        return PyDescr_NewClassMethod(d_type, descr->d_method);
    }
#endif
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
}

/* GetNameInClass */
static PyObject *__Pyx_GetGlobalNameAfterAttributeLookup(PyObject *name) {
    PyObject *result;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    result = __Pyx_PyObject_GetAttrStr(nmspace, name);
    if (!result) {
        result = __Pyx_GetGlobalNameAfterAttributeLookup(name);
    }
    return result;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunctionShared */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
#if PY_MAJOR_VERSION < 3
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
#endif
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* Globals */
static PyObject* __Pyx_Globals(void) {
    Py_ssize_t i;
    PyObject *names;
    PyObject *globals = __pyx_d;
    Py_INCREF(globals);
    names = PyObject_Dir(__pyx_m);
    if (!names)
        goto bad;
    for (i = PyList_GET_SIZE(names)-1; i >= 0; i--) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject* name = PySequence_ITEM(names, i);
        if (!name)
            goto bad;
#else
        PyObject* name = PyList_GET_ITEM(names, i);
#endif
        if (!PyDict_Contains(globals, name)) {
            PyObject* value = __Pyx_GetAttr(__pyx_m, name);
            if (!value) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                goto bad;
            }
            if (PyDict_SetItem(globals, name, value) < 0) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                Py_DECREF(value);
                goto bad;
            }
        }
#if CYTHON_COMPILING_IN_PYPY
        Py_DECREF(name);
#endif
    }
    Py_DECREF(names);
    return globals;
bad:
    Py_XDECREF(names);
    Py_XDECREF(globals);
    return NULL;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(size_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(size_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 2 * PyLong_SHIFT) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 3 * PyLong_SHIFT) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 4 * PyLong_SHIFT) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(size_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(size_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(size_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(size_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const char neg_one = (char) -1, const_zero = (char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(char) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(char, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (char) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (char) 0;
                case  1: __PYX_VERIFY_RETURN_INT(char, digit, digits[0])
                case 2:
                    if (8 * sizeof(char) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) >= 2 * PyLong_SHIFT) {
                            return (char) (((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(char) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) >= 3 * PyLong_SHIFT) {
                            return (char) (((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(char) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) >= 4 * PyLong_SHIFT) {
                            return (char) (((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (char) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(char) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(char, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(char) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(char, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (char) 0;
                case -1: __PYX_VERIFY_RETURN_INT(char, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(char,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(char) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 2 * PyLong_SHIFT) {
                            return (char) (((char)-1)*(((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(char) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 2 * PyLong_SHIFT) {
                            return (char) ((((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(char) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 3 * PyLong_SHIFT) {
                            return (char) (((char)-1)*(((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(char) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 3 * PyLong_SHIFT) {
                            return (char) ((((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(char) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 4 * PyLong_SHIFT) {
                            return (char) (((char)-1)*(((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(char) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 4 * PyLong_SHIFT) {
                            return (char) ((((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(char) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(char, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(char) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(char, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            char val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (char) -1;
        }
    } else {
        char val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (char) -1;
        val = __Pyx_PyInt_As_char(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to char");
    return (char) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to char");
    return (char) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_11resiliparse_5parse_4html_NodeType(enum __pyx_t_11resiliparse_5parse_4html_NodeType value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const enum __pyx_t_11resiliparse_5parse_4html_NodeType neg_one = (enum __pyx_t_11resiliparse_5parse_4html_NodeType) -1, const_zero = (enum __pyx_t_11resiliparse_5parse_4html_NodeType) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum __pyx_t_11resiliparse_5parse_4html_NodeType) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum __pyx_t_11resiliparse_5parse_4html_NodeType) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_11resiliparse_5parse_4html_NodeType) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum __pyx_t_11resiliparse_5parse_4html_NodeType) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_11resiliparse_5parse_4html_NodeType) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum __pyx_t_11resiliparse_5parse_4html_NodeType),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* CoroutineBase */
#include <structmember.h>
#include <frameobject.h>
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(CYTHON_UNUSED __pyx_CoroutineObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(CYTHON_UNUSED PyObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(CYTHON_UNUSED PyObject *gen, PyObject *value, CYTHON_UNUSED int closing) {
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_type) {
        #if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
        #else
        if (exc_state->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_state->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = tstate->frame;
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body((PyObject *) self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *exc_tb = exc_state->exc_traceback;
    if (likely(exc_tb)) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
#endif
    }
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(CYTHON_UNUSED PyObject* gen, PyObject *retval) {
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
            _PyGen_SetStopIterationValue(result);
        }
        Py_CLEAR(result);
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, CYTHON_UNUSED PyObject *arg) {
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = PyObject_CallObject(meth, args);
            } else {
                ret = PyObject_CallFunctionObjArgs(meth, typ, val, tb, NULL);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (Py_REFCNT(self) > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *frame = self->gi_frame;
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* FunctionExport */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
#if PY_VERSION_HEX >= 0x02070000
    cobj = PyCapsule_New(tmp.p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(tmp.p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction
#define __PYX_HAVE_RT_ImportFunction
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, funcname);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C function %.200s",
                PyModule_GetName(module), funcname);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    tmp.p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, desc);
        goto bad;
    }
    tmp.p = PyCObject_AsVoidPtr(cobj);}
#endif
    *f = tmp.fp;
    if (!(*f))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
